(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   9749337,     134138]*)
(*NotebookOutlinePosition[   9750392,     134174]*)
(*  CellTagsIndexPosition[   9750348,     134170]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[CellGroupData[{Cell[TextData["Mandelbrot Movie"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["This uses the ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["MathLink",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" program described on pages 382-388 of ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Applied Mathematica: Getting Started, Getting it Done",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  " by Shaw and Tigg, Addison Wesley, ISBN: 0-201-54217-X.  The source code \
is availabe on ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["MathSource",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" as item 0205-366.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["This ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["MathLink",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  " program was built as a native Power Macintosh program called \"Fractals\" \
without any changes using Metrowerks CodeWarrior on a Power Macintosh \
6100/60. ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["Installation"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["Install[\"Fractals\"]"], "Input",
  AspectRatioFixed->True],

Cell[OutputFormData["\<\
LinkObject[\"Fractals\", 2, 2]\
\>", 
"\<\
LinkObject[Fractals, 2, 2]\
\>"], "Output",
  Evaluatable->False,
  AspectRatioFixed->True]}, Open]],

Cell[CellGroupData[{Cell[TextData["LinkPatterns[%]"], "Input",
  AspectRatioFixed->True],

Cell[OutputFormData["\<\
{HoldForm[FractalML[a_Real, b_Real, 
 
    {{c_Real, d_Real}, {e_Real, f_Real}}, g_Integer]]}\
\>", 
"\<\
{FractalML[a_Real, b_Real, 
 
   {{c_Real, d_Real}, {e_Real, f_Real}}, g_Integer]}\
\>"], "Output",
  Evaluatable->False,
  AspectRatioFixed->True]}, Open]]}, Open]],

Cell[CellGroupData[{Cell[TextData["The MathMovies"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["f[n_] := 0.8^n"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"g[n_] := {{-1.40835915-f[n],-1.40835915+f[n]},\n\t\t\t\
{0.13627737-f[n],0.13627737+f[n]}}"], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["g[0]"], "Input",
  AspectRatioFixed->True],

Cell[OutputFormData["\<\
{{-2.40835915, -0.4083591499999999}, 
 
  {-0.86372263, 1.13627737}}\
\>", 
"\<\
{{-2.40836, -0.408359}, {-0.863723, 1.13628}}\
\>"], "Output",
  Evaluatable->False,
  AspectRatioFixed->True]}, Open]],

Cell[TextData[
"plot[n_]:=Show[Graphics[RasterArray[\n\t\tFractalML[0.0, 0.0, g[n], 216]], \n\
\t\tAspectRatio -> 1]]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"The following takes 1770.40 seconds on a Power Macintosh 6100/60."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[TextData["Do[plot[n],{n,-3, 30}]"], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600\
FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600\
FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600\
FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF3300FF3300FF3300
FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF3300
FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF6600FF7300FF7300FF7300FF6600FF6600FF6600FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF6600FF7300FF8C00FF9900FF7F00FF8C00FF7300FF6600FF6600FF6600\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF7300FF7F00FF9900FFE600FFB300FF7F00FF7300FF6600FF6600\
FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF7300FF7300FF7F00FFA600FF9900FF7F00FF7300FF7300FF6600\
FF6600FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF7300FF7300FF7F0099FF00FFB300FFB300FF7F00FF7300FF7300\
FF7300FF6600FF6600FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF7300FF7300FF7F00FFA600000000FFF300FF8C00FF7F00FF7F00\
FF7300FF7300FF7300FF8C00FF7300FF6600FF6600FF5900FF5900FF5900FF5900
FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FFF300FFC000FFF300FFCC00FF8C00FF7F00\
FF7F00FF7F00FF8C00FFE600FF7F00FF6600FF6600FF5900FF5900FF5900FF5900
FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FF9900FFC000FFD900FFA600FF9900\
FF9900FFA600FFB300C0FF00FFA600FF7300FF6600FF6600FF5900FF5900FF5900
FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FF9900FFB300F3FF00FFC000FFB300\
FFCC00FFE600FFD900FFB300FF7F00FF7300FF6600FF6600FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFC0003FFF0059FF00\
A6FF00FFB300FF9900FF8C00FF7F00FF7300FF6600FF6600FF6600FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFC000FFFF00FFD900\
FFB300FF9900FF8C00FF7F00FF7F00FF7300FF6600FF6600FF6600FF6600FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFB300B3FF003FFF00E6FF00\
FFB300FF9900FF8C00FF7F00FF7F00FF7300FF7300FF6600FF6600FF6600FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FFA600FFC000FFF300FFF30000FF19FFF300\
FFCC00FFCC00FF9900FF8C00FF7F00FF7300FF7300FF6600FF6600FF6600FF6600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7F00FF9900FFA600FF9900FF9900FFB300D9FF004CFF0000FFFF000000C0FF00\
E6FF00FFCC00FF9900FF8C00FF8C00FF7F00FF7300FF7300FF6600FF6600FF6600
FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7F00FF7F00FF8C00FFA600FFF300FFB300FFB300FFC000FFE6008CFF00000000000000000000\
E6FF00FFCC00FFA600FF9900FF9900FF9900FF8C00FF7300FF7300FF6600FF6600
FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7F00FFF300FFC000E6FF00CCFF00FFD900FFD900D9FF00F3FF0073FF00000000000000000000\
D9FF00FFD900FFB300FFB30099FF00FFE600FF9900FF7F00FF7300FF6600FF6600
FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00
FF8C00FFB300FFF300FFE60000FF40F3FF00E6FF000033FF00FF1900000000000000000000FFB3\
000000A6FF00FFD900FFCC0099FF00FFC000FF8C00FF7F00FF7300FF7300FF6600
FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00
FF8C00FF9900FFA600FFCC0000FF9900FF4C0CFF00000000000000000000000000000000000000\
000000000000C0FF00FFFF0099FF00C0FF00FFCC00FF7F00FF7300FF7300FF6600
FF6600FF6600FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00
FF8C00FF9900FFA600FFC000B3FF00000000000000000000000000000000000000000000000000\
00000000000000000000FFD9F3FF00FFC000FF9900FF7F00FF7F00FF7300FF7300
FF6600FF6600FF6600FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF8C00FF9900FFA60000FFFFF3FF0019FF00000000000000000000000000000000000000000000\
00000000000000000000D9FFFFD900FFA600FF9900FF7F00FF7F00FF7300FF7300
FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF8C00FF9900FFC00080FF0099FF00000000000000000000000000000000000000000000000000\
000000000000000000A6FF00B3FF00A6FF00FF9900FF8C00FF7F00FF7F00FF7300
FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF9900FFC000FFE60033FF00000000000000000000000000000000000000000000000000\
00000000000000000000D9FF33FF00FFC000FF9900FF8C00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF9900FF9900FFB300FFCC00000000000000000000000000000000000000000000000000000000\
000000000000000000B3FF00FFD900FFB300FF9900FF8C00FF8C00FF7F00FF7F00
FF7F00FF7300FF7300FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF9900\
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FFA600FFB300FFCC00FFFF00000000000000000000000000000000000000000000000000\
000000000000000000000000FFCC00FFB300FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7300FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF7300FF7F00FF9900FFB300FF8C00FF8C00FF9900D9FF00\
F3FF00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFA600
FFA600FFB300FFB300FFCC00FFE600B3FF00000000000000000000000000000000000000000000\
000000000000000000FFE600FFC000FFB300FFA600FFA600FF9900FF9900FF9900
FFC000FF9900FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF9900\
FFA600FF7F00FF6600FF6600FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF7300FF7300FF8C0000FF59FFD900FFB300C0FF00FFD90000FF33\
FFC000FF9900FF9900FF8C00FF9900FF9900FFC000F3FF00E6FF00FFC000FFB300
FFD900FFE600FFCC00FFD900FFF300F3FF008CFF00000000000000000000000000000000000000\
0000005900FFE6FF00FFE600FFD900FFCC00FFC0008CFF00FFB300FFA600FFB300
FFD900FFCC00FFA600FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF9900\
FFCC00FFA600FF7300FF6600FF6600FF5900FF5900FF5900FF5900FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF9900FFD90073FF0026FF0000FF59FFF300\
FFC000FFB300FFA600FF9900FF9900FFA600F3FF003F00FF3FFF00F3FF00FFD900
80FF0000BFFFB3FF0000000000E6FF00000080FF003FFF0000FF730000000000000000000026FF\
26FF000000008CFF0000FF80D9FF00004CFFFFFF00000000FFFF00FFC000FFD900
73FF0000FF40FFC000FF9900FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FFB300\
FFD900FF9900FF7300FF6600FF6600FF5900FF5900FF5900FF5900FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7F00FF7F00FF9900FFC000D9FF0080FF00B3FF00F3FF00\
FFE600F3FF00FFCC00FFB300FFB300FFC000FFFF0099FF0000000000FFD9E6FF00
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000C00FF66FF00000000E6FF00FFF300000000
00B3FF4CFF0000FF26FFA600FF9900FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFCC00\
B3FF00FF9900FF7F00FF7300FF6600FF6600FF5900FF5900FF5900FF5900FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FFC000A6FF00FFFF00E6FF0000FFD900FFCC\
C0FF0080FF00C0FF00FFCC00FFC000FFD900FFF3000080FF00000000000000E6FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000FFE699FF00000000
00000019FF00FFD900FFB300FFA600FF9900FFA600FFFF00FFD900FFC000FFA600FFB300FFCC00\
A6FF00FFB300FF9900FFCC00FF7300FF6600FF5900FF5900FF5900FF5900FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FFA600FFC000FFCC0033FF00F300FF000000\
00000000000066FF00FFFF00FFE60000000099FF004CFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000080FF00FFF30000FF8CFFB300FFB300FFB300FFD90000FFD9F3FF00FFD900FFE600FFE600\
0CFF00000000E6FF00FF8C00FF7300FF6600FF5900FF5900FF5900FF5900FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7F00FF8C00FF9900FFA600FFE600F3FF0000FF33000000\
000000000000000000CCFF0000D9FF00FF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000080FF0000008C00FFFFE600FFCC004CFF0099FF0000000059FF00C0FF0000FF6633FF00\
E6FF00FFFF00FFA600FF7F00FF7300FF6600FF6600FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFF3004CFF00000000000000\
00000000000000000073FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000019FF000033FFFFF300B300FF00000000000000000000000000000099FF00\
FFD900FFCC00E6FF00FF7F00FF7300FF6600FF6600FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFCC00E6FF0000FF8C000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000C0FF0000000000000000000000000000000000FF40FFFF00\
FFB300FF9900FF8C00FF7300FF7300FF6600FF6600FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FF9900FFA600FFC000FFD900B3FF00000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000004CFF000000000000000000000000000000FFFF00\
FFD900FF9900FF7F00FF7300FF7300FF6600FF6600FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7F00FF7F00FF8C00FF8C00FFA600FFA600FFA600FFB300FFCC00FFE600D9FF0000B3FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000FF26\
FFCC00FF8C00FF7F00FF7300FF7300FF6600FF6600FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7F00FF7F00FF8C00FF9900FFA60099FF00FFF300FFC000FFCC00C000FF00F3FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000026FF0000E6FFFFC000\
FF9900FF8C00FF7F00FF7300FF7300FF6600FF6600FF6600FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF8C00CCFF00FFE600CCFF004CFF00FFFF00FFF300FFE60073FF00000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000B3FF00FFF300FFC000FFA600\
FF9900FF8C00FF7F00FF7300FF7300FF6600FF6600FF6600FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF7300FF7300FF7300FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF8C00FFA600FFFF0000FF1933FF0059FF00000000CCFF00000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000D9FF00FFCC00FFB300\
FF9900FF8C00FF7F00FF7F00FF7300FF7300FF6600FF6600FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF7300FFCC00FF7F00FF7300FF7300FF7300FF7300
FF7300FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF8C00FFA600FFD90033FF000059FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFF0000BFFF\
FFB300FF8C00FF8C00FF7F00FF7F00FF7300FF6600FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF7300FFB300FFCC00FF9900FF8C00FF7F00FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF9900FFB300FFD90000FFA6000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000D9FF\
FFF300FF9900FF8C00FF8C00FF8C00FF7F00FF7300FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF7300FF7F00FF9900FFE600FF9900FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF9900FFA600FFB300FFCC00F3FF0066FF00000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000E6FF00\
FFC000FFA600FF9900FF9900FFA600FFE600FF7F00FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF7300FF7300FF7F00FFA60000FF33FF9900FF8C00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FFB300FFA600FF8C00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF9900FF9900FFB30059FF00FFE60000F3FF00FF8C000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
FFD900FFF30000FFA6FFB300FFCC00FFF300FF7F00FF7300FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF7300FF7F00FF8C00FFB300FFF300FFA600FF9900FF8C00
FF8C00FF8C00FF8C00FF7F00FF7F00FF8C00FF8C00FFB300FFD900CCFF00FF9900FF8C00FF8C00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF9900FFE600B3FF0066FF0000FF4066FF00000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0019FF0080FFA6FF00FFE600F3FF00FFB300FF7F00FF7300FF6600FF6600FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF7300FF7F00FF9900FFB30073FF00FFB300FFA600FF9900
FF9900FF9900FFA600FF8C00FF8C00FF8C00FF9900FFB30000FF66FFC000FFA600FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FFA600FFE60000FF00000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000FF3300FFCCCCFF00FF8C00FF7300FF6600FF6600FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF7300FF7300FF7F00FF8C00FF9900E6FF00FFF300FFCC00FFD900
FFB300FFC000FFC000FFA600FF9900FF9900FFA600FFC000A6FF00A6FF00FFCC00FFC000FFA600\
FF9900FFA600FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FFA600FFC000FFF300000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000FF40B3FF00B3FF00FF7F00FF7300FF6600FF6600FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7F00FF7F00FF8C00FFA600FFCC00FFD900CCFF00
D9FF0000FF19A6FF00FFCC00FFC000FFB300FFB300FFC000FFD900D9FF00B3FF00FFF300FFB300\
FFC00000FF40FFC000FFA600FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFB300FFCC0073FF000CFF00000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000FF3300FF1959FF00FF9900FF7F00FF7300FF6600FF6600FF6600FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFB300D9FF00
D9FF0026FF0000FF26F3FF00FFD900FFC000FFD900FFCC00F3FF0000FF8C000000C0FF00FFD900\
FFE600A6FF00FFCC00FFB300FFA600FFA600FF9900FF9900FF9900FFA600FFA600
FFC0000099FF00FF0000FF80000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000099FF00FFC000FFA600FF8C00FF7F00FF7300FF6600FF6600FF6600FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFB300FFCC00
E6FF0000FF8C7300FF26FF00D9FF00FFF30000FF26F3FF00D9FF0000FF80000000CC00FFCCFF00\
F3FF00B3FF0019FF00FFCC00FFE600FFC000FFA600FFA600FFA600FFA600FFB300
FFC000F3FF00000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000FFF3FFCC00FF9900FF8C00FF7F00FF7300FF6600FF6600FF6600FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFC000FFD900
00FF990000000000000000008C00FF4CFF008CFF0000000000000000FF5900000000FF406600FF\
00E6FF000000000000F3FF0059FF00FFCC00FFC000FFB300FFB300FFB300FFC000
FFCC00000000004CFF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000059FF00FFCC00FFA600FFA600FF7F00FF7300FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFD900C0FF00
B3FF00000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000026FF33FF0099FF00FFFF00FFC000FFC000FFC000FFCC00
FFE60000FF99000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000008CFF008CFF00FFCC00FFE600FF8C00FF7300FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300FFC000FFE600
00FFCCD900FF000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000FFA60080FFFFD900FFCC00FFCC00FFCC00
FFF30033FF00000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000C0FF00FFD900FF7F00FF7300FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF8C00FFC000FFC000FFB300FFC000FFCC00F3FF00
CCFF0033FF00000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000FFA6FFE600FFD900FFE600
F3FF004C00FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000073FF003FFF000CFF0019FF00FF7F00FF7300FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF9900FFA60073FF00FFD900FFFF00D9FF008CFF00
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000FFFFFFF300FFF300
00FF4C000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000066FF00FFC000FF9900FF8C00FF7300FF7300FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFC000FFE60000FF59004CFF00FF0C
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000F3FF00F3FF00
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000E6FF00FFCC00FFA600FF7F00FF7300FF6600FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FFCC00FFC000\
FF9900FF9900FF9900FF9900FFA600FFA600FFC000FFD900CCFF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000008CFF00D9FF00
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000CCFF00FFA600FF7F00FF7300FF6600FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF8C00F3FF00FFF300\
FFA600FFA600FFA600FFB300FFB300FFB300C0FF00FFF30073FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000B3FF00
00FFF3000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F3FF0000FF33FF8C00FF7300FF7300FF6600FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFA600FFE600\
FFCC00FFC000FFB30080FF00FFCC00FFCC00FFD900A6FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000000000000073FF00
E600FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00FFBFFFE600FF8C00FF7F00FF7300FF6600FF6600FF6600FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FFA600FFB300\
F3FF00FFF300FFD900F3FF00FFF300F3FF00FFF30080FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
26FF0000FF33FF7F00FF7300FF7300FF6600FF6600FF6600FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFC000\
FFFF0059FF0099FF0099FF00008CFFA6FF00D9FF006600FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00FF26FF8C00FF7F00FF7300FF7300FF6600FF6600FF6600FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7F00FF8C00FF7F00FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FF9900FF9900FFA600FFCC00FFCC00\
FFF30033FF0000000000000000000000000000B3FF4CFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000008CFF00\
FF9900FF7F00FF7F00FF7300FF7300FF6600FF6600FF6600FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7F00FF8C00FFB300FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFFF00FFB300FFA600FFB300FFE600C0FF00\
D9FF0000000000000000000000000000000000000000FF40000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000D9FF00FF9900\
FF8C00FF7F00FF7300FF7300FF6600FF6600FF6600FF6600FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF8C00FFB300F3FF00FFCC00FF9900FF8C00FF8C00FF9900FF9900FFB300
FFB300FF9900FFA600FF9900FF9900FFA600FFB300FFCC00FFD900FFD900FFD900FFF30080FF00\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFC000FFA600FF8C00\
FF7F00FF7F00FF7300FF7300FF6600FF6600FF6600FF6600FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FFCC00FFF300FFF300E6FF00F3FF00D9FF00F3FF00B3FF00CCFF00A6FF00\
CCFF00B3FF004C00FF00000066FF00A6FF00B3FF0033FF008CFF0066FF0000FF0C
80FF0073FF0019FF0073FF0073FF0000FF0C3FFF0000FF4000FFA600FFCC00FF80000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FF80E6FF00FFD900FFB300FF9900FF8C00\
FF7F00FF7F00FF7300FF7300FF6600FF6600FF6600FF6600FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF8C00FFB300F3FF00FFCC00FF9900FF8C00FF8C00FF9900FF9900FFB300
FFB300FF9900FFA600FF9900FF9900FFA600FFB300FFCC00FFD900FFD900FFD900FFF30080FF00\
00FFA6000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFC000FFA600FF8C00\
FF7F00FF7F00FF7300FF7300FF6600FF6600FF6600FF6600FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7F00FF8C00FFB300FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFFF00FFB300FFA600FFB300FFE600CCFF00\
D9FF0000000000000000000000000000000000000000FF40000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000D9FF00FF9900\
FF8C00FF7F00FF7300FF7300FF6600FF6600FF6600FF6600FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7F00FF8C00FF7F00FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FF9900FF9900FFA600FFCC00FFCC00\
FFF30033FF0000000000000000000000000000E6FF4CFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000008CFF00\
FF9900FF7F00FF7F00FF7300FF7300FF6600FF6600FF6600FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFC000\
FFFF0059FF0099FF0099FF000026FFA6FF00D9FF0026FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
1900FFFF8C00FF7F00FF7300FF7300FF6600FF6600FF6600FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FFA600FFB300\
F3FF00FFF300FFD900F3FF00FFF300F3FF00FFF30080FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00D9FF0099FFFF7F00FF7300FF7300FF6600FF6600FF6600FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFA600FFE600\
FFCC00FFC000FFB30080FF00FFCC00FFCC00FFD900A6FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000000000000073FF00
D900FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00FFA6FFE600FF8C00FF7F00FF7300FF6600FF6600FF6600FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF8C00F3FF00FFF300\
FFA600FFA600FFA600FFB300FFB300FFB300C0FF00FFF30073FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000B3FF00
00FFF3000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000F3FF0000FF0CFF8C00FF7300FF7300FF6600FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FFCC00FFC000\
FF9900FF9900FF9900FF9900FFA600FFA600FFC000FFD900CCFF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000008CFF00D9FF00
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000CCFF00FFA600FF7F00FF7300FF6600FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFC000FFE60000FF4C004CFF00FF0C
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000059FFF3FF00F3FF00
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000E6FF00FFCC00FFA600FF7F00FF7300FF6600FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF9900FFA60066FF00FFD900FFFF00D9FF0099FF00
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000FFF3FFF300FFF300
00FF40000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000066FF00FFC000FF9900FF8C00FF7300FF7300FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF8C00FFC000FFC000FFB300FFC000FFCC00F3FF00
CCFF0033FF00000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000FFA6FFE600FFD900FFE600
F3FF006600FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000073FF003FFF0000FF8C00FF26FF7F00FF7300FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300FFC000FFE600
00FFBF000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000FF660040FFFFD900FFCC00FFCC00FFCC00
FFF3003FFF00000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000C0FF00FFD900FF7F00FF7300FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFD900C0FF00
B3FF00000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000026FF33FF008CFF00FFFF00FFC000FFC000FFC000FFCC00
FFE60000FF99000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000008CFF008CFF00FFCC00FFE600FF8C00FF7300FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFC000FFD900
00FF9900000000000000000000FFB333FF008CFF0000000000000000FF5900000000FF40000000\
00FFF3000000000000F3FF0059FF00FFCC00FFC000FFB300FFB300FFB300FFC000
FFCC003F00FF0066FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000059FF00FFCC00FFA600FFA600FF7F00FF7300FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFB300FFCC00
E6FF0000FF8CB300FF26FF00D9FF00FFF30000FF19F3FF00D9FF0000FF80000000000000CCFF00\
F3FF00B3FF0019FF00FFCC00FFE600FFC000FFA600FFA600FFA600FFA600FFB300
FFC000F3FF00000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000026FFFFCC00FF9900FF8C00FF7F00FF7300FF6600FF6600FF6600FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFB300D9FF00
D9FF0026FF0000FF4CF3FF00FFD900FFC000FFD900FFCC00F3FF0000B3FF0066FFC0FF00FFD900\
FFE600A6FF00FFCC00FFB300FFA600FFA600FF9900FF9900FF9900FFA600FFA600
FFC00000FFD900FF0000FF80000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000033FF00FFC000FFA600FF8C00FF7F00FF7300FF6600FF6600FF6600FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7F00FF7F00FF8C00FFA600FFCC00FFD900CCFF00
D9FF0000FFF3A6FF00FFCC00FFC000FFB300FFB300FFC000FFD900D9FF00B3FF00FFF300FFB300\
FFC00000FF00FFC000FFA600FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFB300FFCC0066FF000CFF00000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000FF3300FF0C59FF00FF9900FF7F00FF7300FF6600FF6600FF6600FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF7300FF7300FF7F00FF8C00FF9900E6FF00FFF300FFCC00FFD900
FFB300FFC000FFC000FFA600FF9900FF9900FFA600FFC000A6FF00A6FF00FFCC00FFC000FFA600\
FF9900FFA600FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FFA600FFC000FFF300000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000FF4CB3FF00B3FF00FF7F00FF7300FF6600FF6600FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF7300FF7F00FF9900FFB30073FF00FFB300FFA600FF9900
FF9900FF9900FFA600FF8C00FF8C00FF8C00FF9900FFB30000FF59FFC000FFA600FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FFA600FFE60000FF0C000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000FF336600FFCCFF00FF8C00FF7300FF6600FF6600FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF7300FF7F00FF8C00FFB300FFF300FFA600FF9900FF8C00
FF8C00FF8C00FF8C00FF7F00FF7F00FF8C00FF8C00FFB300FFD900CCFF00FF9900FF8C00FF8C00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF9900FFE600B3FF0066FF0000FF4C66FF00000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000006600FF\
00FFE60073FFA6FF00FFE600F3FF00FFB300FF7F00FF7300FF6600FF6600FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF7300FF7300FF7F00FFA60000FF26FF9900FF8C00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FFB300FFA600FF8C00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF9900FF9900FFB30059FF00FFE60000F3FF00FF8C000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
FFD900FFF30000FF40FFB300FFCC00FFF300FF7F00FF7300FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF7300FF7F00FF9900FFE600FF9900FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF9900FFA600FFB300FFCC00F3FF0066FF00000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000E6FF00\
FFC000FFA600FF9900FF9900FFA600FFE600FF7F00FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF7300FFB300FFCC00FF9900FF8C00FF7F00FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF9900FFB300FFD90000FFA6000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000CCFF\
FFF300FF9900FF8C00FF8C00FF8C00FF7F00FF7300FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF7300FFC000FF7F00FF7300FF7300FF7300FF7300
FF7300FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF8C00FFA600FFD90026FF000066FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFF0000FFFF\
FFB300FF8C00FF8C00FF7F00FF7F00FF7300FF6600FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF7300FF7300FF7300FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF8C00FFA600FFFF0000FF193FFF0059FF00000000CCFF00000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000D9FF00FFCC00FFB300\
FF9900FF8C00FF7F00FF7F00FF7300FF7300FF6600FF6600FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF8C00CCFF00FFE600CCFF004CFF00FFFF00FFF300FFE60073FF00000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000B3FF00FFF300FFC000FFA600\
FF9900FF8C00FF7F00FF7300FF7300FF6600FF6600FF6600FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7F00FF7F00FF8C00FF9900FFA60099FF00FFF300FFC000FFCC00000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000019FF003300FFFFC000\
FF9900FF8C00FF7F00FF7300FF7300FF6600FF6600FF6600FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7F00FF7F00FF8C00FF8C00FFA600FFA600FFA600FFB300FFCC00FFE600D9FF0000BFFF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000FF26\
FFCC00FF8C00FF7F00FF7300FF7300FF6600FF6600FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FF9900FFA600FFC000FFD900B3FF00000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000004CFF000000000000000000000000000000FFFF00\
FFD900FF9900FF7F00FF7300FF7300FF6600FF6600FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFCC00E6FF0000FF8C000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000C0FF0000000000000000000000000000000000FF4CFFFF00\
FFB300FF9900FF8C00FF7300FF7300FF6600FF6600FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFF3004CFF00000000000000\
00000000000000000073FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000019FF000026FFFFF3007300FF000000000000000000000000000000A6FF00\
FFD900FFCC00E6FF00FF7F00FF7300FF6600FF6600FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7F00FF8C00FF9900FFA600FFE600F3FF0000FF26000000\
000000000000000000CCFF0000CCFF00FF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000099FF00FF4CC000FFFFE600FFCC004CFF0099FF0000000059FF00C0FF0000FF5926FF00\
E6FF00FFFF00FFA600FF7F00FF7300FF6600FF6600FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FFA600FFC000FFCC0033FF00F300FF000000\
00000000000066FF00FFFF00FFE60000000099FF004CFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000073FF00FFF300008CFFFFB300FFB300FFB300FFD90000CCFFF3FF00FFD900FFE600FFE600\
19FF00000000E6FF00FF8C00FF7300FF6600FF5900FF5900FF5900FF5900FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FFC000A6FF00FFFF00E6FF0000FFD900FFD9\
C0FF0080FF00C0FF00FFCC00FFC000FFD900FFF3000080FF00000000000000E6FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000FFE699FF00000000
00000019FF00FFD900FFB300FFA600FF9900FFA600FFFF00FFD900FFC000FFA600FFB300FFCC00\
A6FF00FFB300FF9900FFCC00FF7300FF6600FF5900FF5900FF5900FF5900FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7F00FF7F00FF9900FFC000D9FF0080FF00B3FF00F3FF00\
FFE600F3FF00FFCC00FFB300FFB300FFC000FFFF0099FF0000000000FFD9E6FF00
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000066FF00000000E6FF00FFF300000000
00B3FF3FFF0000FF26FFA600FF9900FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFCC00\
B3FF00FF9900FF7F00FF7300FF6600FF6600FF5900FF5900FF5900FF5900FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF9900FFD90073FF0019FF0000FF4CFFF300\
FFC000FFB300FFA600FF9900FF9900FFA600F3FF000000003FFF00F3FF00FFD900
80FF0000BFFFC0FF0000000000E6FF00000080FF003FFF0000FF73000000000000000000000000\
26FF000000008CFF004C00FFD9FF000066FFFFFF0000CCFFFFFF00FFC000FFD900
73FF0000FF40FFC000FF9900FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FFB300\
FFD900FF9900FF7300FF6600FF6600FF5900FF5900FF5900FF5900FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF7300FF7300FF8C0000BFFFFFD900FFB300C0FF00FFD90000FF26\
FFC000FF9900FF9900FF8C00FF9900FF9900FFC000F3FF00E6FF00FFC000FFB300
FFD900FFE600FFCC00FFD900FFE600F3FF008CFF00000000000000000000000000000000000000\
0000003F00FFE6FF00FFE600FFD900FFCC00FFC0008CFF00FFB300FFA600FFB300
FFD900FFCC00FFA600FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF9900\
FFCC00FFA600FF7300FF6600FF6600FF5900FF5900FF5900FF5900FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF7300FF7F00FF9900FFB300FF8C00FF8C00FF9900D9FF00\
F3FF00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFA600
FFA600FFB300FFB300FFCC00FFE600B3FF00000000000000000000000000000000000000000000\
000000000000000000FFE600FFC000FFB300FFA600FFA600FF9900FF9900FF9900
FFC000FF9900FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF9900\
FFA600FF7F00FF6600FF6600FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF9900\
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FFA600FFB300FFCC00FFFF00000000000000000000000000000000000000000000000000\
00000000000000000000FF8CFFCC00FFB300FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7300FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF9900FF9900FFB300FFCC0000FF59000000000000000000000000000000000000000000000000\
000000000000000000B3FF00FFD900FFB300FF9900FF8C00FF8C00FF7F00FF7F00
FF7F00FF7300FF7300FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF9900FFC000FFE60033FF00000000000000000000000000000000000000000000000000\
00000000000000000000D9FF33FF00FFC000FF9900FF8C00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF8C00FF9900FFC00080FF0099FF00000000000000000000000000000000000000000000000000\
000000000000000000A6FF00B3FF00A6FF00FF9900FF8C00FF7F00FF7F00FF7300
FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF8C00FF9900FFA60000FF59F3FF0019FF00000000000000000000000000000000000000000000\
00000000000000000000BFFFFFD900FFA600FF9900FF7F00FF7F00FF7300FF7300
FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00
FF8C00FF9900FFA600FFC000B3FF00000000000000000000000000000000000000000000000000\
00000000000000000000FFE6F3FF00FFC000FF9900FF7F00FF7F00FF7300FF7300
FF6600FF6600FF6600FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00
FF8C00FF9900FFA600FFCC0000FF4000FF590CFF00000000000000000000000000000000000000\
000000000000CCFF00FFFF0099FF00C0FF00FFCC00FF7F00FF7300FF7300FF6600
FF6600FF6600FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00
FF8C00FFB300FFF300FFE60000FFA6F3FF00E6FF00000CFF00FF1900000000000000000000FFD9\
000000A6FF00FFD900FFCC0099FF00FFC000FF8C00FF7F00FF7300FF7300FF6600
FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7F00FFF300FFC000E6FF00CCFF00FFD900FFD900D9FF00F3FF0073FF00000000000000000000\
D9FF00FFD900FFB300FFB300A6FF00FFE600FF9900FF7F00FF7300FF6600FF6600
FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7F00FF7F00FF8C00FFA600FFF300FFB300FFB300FFC000FFE6008CFF00000000000000000000\
E6FF00FFCC00FFA600FF9900FF9900FF9900FF8C00FF7300FF7300FF6600FF6600
FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7F00FF9900FFA600FF9900FF9900FFB300D9FF004CFF00B300FF000000C0FF00\
E6FF00FFCC00FF9900FF8C00FF8C00FF7F00FF7300FF7300FF6600FF6600FF6600
FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FFA600FFC000FFF300FFF30000FF0CFFF300\
FFCC00FFCC00FF9900FF8C00FF7F00FF7300FF7300FF6600FF6600FF6600FF6600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFB300C0FF003FFF00E6FF00\
FFB300FF9900FF8C00FF7F00FF7F00FF7300FF7300FF6600FF6600FF6600FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFC000FFFF00FFD900\
FFB300FF9900FF8C00FF7F00FF7F00FF7300FF6600FF6600FF6600FF6600FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFC00073FF004CFF00\
A6FF00FFB300FF9900FF8C00FF7F00FF7300FF6600FF6600FF6600FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FF9900FFB300F3FF00FFC000FFB300\
FFCC00FFE600FFD900FFB300FF7F00FF7300FF6600FF6600FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FF9900FFC000FFD900FFA600FF9900\
FF9900FFA600FFB300B3FF00FFA600FF7300FF6600FF6600FF5900FF5900FF5900
FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FFF300FFC000FFF300FFCC00FF8C00FF7F00\
FF7F00FF7F00FF8C00FFE600FF7F00FF6600FF6600FF5900FF5900FF5900FF5900
FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF7300FF7300FF7F00FFA600000000FFF300FF8C00FF7F00FF7F00\
FF7300FF7300FF7300FF8C00FF7300FF6600FF6600FF5900FF5900FF5900FF5900
FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF7300FF7300FF7F0059FF00FFB300FFB300FF7F00FF7300FF7300\
FF7300FF6600FF6600FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF7300FF7300FF7F00FFA600FF9900FF7F00FF7300FF7300FF6600\
FF6600FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF7300FF7F00FF9900FFE600FFB300FF7F00FF7300FF6600FF6600\
FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF6600FF7300FF8C00FF9900FF7F00FF8C00FF7300FF6600FF6600FF6600\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF6600FF7300FF7300FF7300FF6600FF6600FF6600FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF3300
FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600\
FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600\
FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600\
FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600\
FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600\
FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600\
FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600\
FF2600FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600\
FF2600FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600\
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600\
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600\
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600\
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600\
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600\
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600
FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600\
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600
FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600\
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600
FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600\
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600
FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600\
FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600FF2600
FF2600FF2600FF2600FF2600FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  AnimationCycleOffset->0.0625,
  AnimationCycleRepetitions->Infinity,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF7F00FF8C00FF7300
FF7300FF7300FF7300FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF7F00FFB300FF9900
FF8C00FF8C00FF8C00FF7300FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF7300FF8C00FFA600
FFCC00FFD900FF7F00FF7300FF6600FF6600FF6600FF6600FF6600FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF7300FF7F00FF8C00
FFCC00FFA600FF8C00FF7F00FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF7300FF7F00FF8C00
FFB300FFB300FF9900FF7F00FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00
FFB300FFD900FFCC00FF9900FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF6600\
FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00
FFA600A6FF0080FF00FFA600FF8C00FF7F00FF7F00FF7300FF7300FF7300FF7F00FF8C00FF7F00\
FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00
FFD900FFCC00FFD900FFD900FFA600FF8C00FF7F00FF7F00FF7F00FF7F00FF8C00FFB300FF8C00\
FF7300FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF7F00
FF9900FFA600FFB30000FFB3FFB300FF9900FF8C00FF8C00FF9900FF9900FFA600FFCC00FFC000\
FF7F00FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00
FF8C00FF9900FFA600FFFF00FFFF00FFB300FFA600FFA600FFE600FFF300FFE600FFB300FF8C00\
FF7300FF7300FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00
FF8C00FF9900FFA600FFD900FFFF00FFCC00FFC000FFE600F3FF00FFC000FFC000FF9900FF7F00\
FF7300FF7300FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00
FF8C00FF9900FFA600FFB300FFCC0033FF0066FF00FFE600FFC000FFA600FF9900FF8C00FF7F00\
FF7300FF7300FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00
FF8C00FF9900FFA600FFB300FFC000E6FF00FFE600FFC000FFA600FF9900FF8C00FF7F00FF7F00\
FF7300FF7300FF6600FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00
FF8C00FF9900FFA600FFB300FFE600C0FF00F3FF00FFC000FFA600FF9900FF8C00FF7F00FF7F00\
FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00
FF9900FFA600FFCC00FFCC00FFF3004CFF00F3FF00FFC000FFB300FF9900FF8C00FF8C00FF7F00\
FF7F00FF7300FF7300FF6600FF6600FF6600FF6600FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF8C00FF9900
FFC000FFD90066FF00FFF30080FF000059FF3FFF00FFD900FFFF00FFB300FF9900FF8C00FF7F00\
FF7F00FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7F00FF7F00FFA600FFB300FF9900FF9900FFA600
FFC000FFF300CCFF004CFF0033FF00000000000CFFE6FF00F3FF00FFB300FF9900FF8C00FF8C00\
FF7F00FF7F00FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7F00FF8C00FF8C00FFB300FFF300FFB300FFB300FFB300
FFC000FFD900B3FF000000000000000000007300FFA6FF00FFF300FFC000FFA600FF9900FF9900\
FF8C00FF9900FF7F00FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7F00FF8C00FFA600FFB300FFCC00F3FF00FFD900FFC000FFD900
E6FF00FFF300CCFF0000000000000000000000000026FF00FFE600FFC000FFB300FFA600FFB300\
FFB300CCFF00FF8C00FF7F00FF7300FF7300FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7F00FF8C0066FF00FFE600C0FF00E6FF000CFF00FFF300FFE600FFF300
00FF59B3FF0033FF0000FF1900000000000000FF59C0FF00FFFF00A6FF00FFC000FFC000FFD900\
59FF00FFD900FF8C00FF7F00FF7300FF7300FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7F00FF8C00FF9900E6FF00FFCC00FFD90000FFCCB3FF0073FF00CCFF00
00000000000000000000000000000000000000000000000080FF008CFF00FFE600FFD90000FF8C\
FFF300FFB300FF9900FF7F00FF7300FF7300FF7300FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7F00FF8C00FF8C00FFA600FFB300FFD90066FF0000FFCC00000000FF00
00000000000000000000000000000000000000000000000000000073FF008CFF00F3FF00CCFF00\
FFFF0000FF80FFFF00FF7F00FF7F00FF7300FF7300FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFCC00A6FF0000FFCC000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFD9A6FF00\
FFD900FFC000FF9900FF8C00FF7F00FF7300FF7300FF7300FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF8C00FF8C00FF9900FFB300FFD900FFFF0099FF00000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFE6F3FF00\
FFC000FFA600FF8C00FF8C00FF7F00FF7300FF7300FF7300FF7300FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF8C00FF8C00FFA600FFC000A6FF00D9FF0000FF8C000000000000
00000000000000000000000000000000000000000000000000000000000000000099FF00FFE600\
FFCC00FFA600FF8C00FF8C00FF7F00FF7F00FF7300FF7300FF7300FF7300FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF8C00FF8C00FF9900FFA600E6FF00B3FF0033FF00000000000000000000
0000000000000000000000000000000000000000000000000000000000000000008CFF00CCFF00\
C0FF00FFB300FF9900FF8C00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF9900FFA600FFC000FFE6008CFF0000FFBF000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000FFCC\
00FFD9FFA600FF9900FF8C00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF9900FF9900FFA600FFB300FFD90000FF8C00FF0C000000000000
0000000000000000000000000000000000000000000000000000000000000000008CFF00FFF300\
FFC000FFA600FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7300FF7300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FFA600FFB300FFE600D9FF0000FFF3000000000000
0000000000000000000000000000000000000000000000000000000000000000004CFF00D9FF00\
FFB300FFA600FF9900FF9900FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF7300FF7F00FF7F00FF8C00FF7F00FF7F00FF8C00FF8C00
FFD900FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FFA600FFA600FFB300FFB300FFCC00FFE60000FF40000000000000
00000000000000000000000000000000000000000000000000000000000000CCFFF3FF00FFCC00\
FFB300FFA600FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF7300FF7F00F3FF00FFE600FFCC00FF9900FF9900FF9900FFA600
66FF00F3FF00FFA600FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFB300FFB300FFA600FFB300\
FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFE600F3FF0000FF80000000
000000000000000000000000000000000000000000000000000000000000C0FF00FFE600FFCC00\
FFC000FFB300FFB300FFA600FFA600FF9900FF9900FF9900FFB30066FF00FF8C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7F00FF9900FFE600E6FF00FFC000FFCC00FFD900D9FF00
00FF73FFE600FFA600FF9900FF9900FF9900FF9900FF9900FFA600FFD90000FFD9A6FF00FFFF00\
FFC000FFC000FFF300FFD900FFD900FFD900FFE600FFF300FFFF00D9FF00000000
00000000000000000000000000000000000000000000000000000073FF00F3FF00FFF300FFD900\
FFD900FFCC00FFCC0000FFCCFFC000FFA600FFA600FFC000FFD900FFFF00FFB300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7F00FF8C00FFA600FFF300A6FF00FFFF00D9FF0000FF59
FFF300FFCC00FFB300FFA600FFA600FF9900FF9900FFA600FFB300FFE60073FF0000FF26000000\
FFE600FFD900CCFF0000B3FFF3FF00CCFF00008CFFB3FF00CCFF00B3FF008CFF00
3FFF0000FF8C00000000000000000000000000000000FF0073FF00A6FF004C00FFB3FF00E6FF00\
3300FFF3FF00FFFF0000FFB3000000FFC000FFC000FFF30000FF4C00FF26CCFF00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7F00FF8C00FF9900FFB300FFE600C0FF0059FF00D9FF00
FFF300FFD900FFE600FFF300FFC000FFA600FFA600FFB300FFC000C0FF00A6FF000000004CFF00\
66FF00FFFF000CFF0000000000000000FF0C000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000FF33\
00000080FF0000FFA600000099FF00FFE600FFF3008CFF000073FF000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7F00FF8C00FFD900FFD90073FF00A6FF0000FFFF4CFF00
0073FF33FF00CCFF001900FFB3FF00FFCC00FFB300FFC000FFCC00FFF300000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000003300FF00000080FF00C000FFD9FF0000000000000000FF4CF3FF00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7F00FF7F00FF8C0000FFD9E6FF00FFF300FFF300B3FF00000000
00000073FF0066FF0000FF33D9FF00FFD900FFCC00FFE6003FFF00FFFF0080FF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000D9FF59FF0000000000000000000000FFBF
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF8C00FFA600FFB300FFC000FFE60000FF993F00FF
0000000000000000000000003FFF00E6FF00FFE60000E6FF00000099FF00E600FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000004CFF00F3FF00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFC000FFF300D9FF0000FF73
000000000000000000000000000000000000E6FF0000FF00000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000000000000000FFD9
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFA600FFC00080FF008CFF00000000
00000000000000000000000000000080FF0000E6FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA6008CFF00B300FF00FFE6A600FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFC000FFF3000000FF00FFF3
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFB300FFCC00FFF300CCFF00
F300FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF8C00FF8C00FF9900FFA600FFA600FFA600FFB300FFC000FFD900FFF300E6FF00
00FF73000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00\
FF8C00FF9900FFCC00F3FF00FFC000FFB300FFC000CCFF0000F3FFD9FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFA600\
FFB300FFF300FFE60019FF00FFD900FFCC00FFD9008CFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF9900E6FF00\
C0FF0059FF0000FF99CCFF00D9FF000033FFFFFF00D9FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF7300FF7300FF7300FF7300FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFB300\
C0FF0033FF0000FF9900FF9900FF66000000C0FF000040FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF7F00FF9900FF7F00FF7300FF7300
FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FFB300\
FFE60000000000FF730000000000000000004C00FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF7300FF7F00FFD900FF9900FF8C00FF8C00
FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600\
FFC000FFE60000FF33000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF7300FF7F00FF9900FFB300FFC000FFA600
FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600\
FFB300FFCC0059FF0026FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF7300FF7F00FF8C00FFA600D9FF00FFA600
FF8C00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFB300\
FFC000FFD900FFF300CCFF004CFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FFA600000000FFB300
FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FFA600FFE600FF9900FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600D9FF00\
4CFF00FFF30033FF0000FF33000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF9900FFB30033FF00FFA600
FF9900FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FFA600\
FFCC00B3FF00FFA600FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFB300FFD900A6FF00\
00FF6680FF00B3FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF8C00FFD900FFCC00FFFF00FFC000
FFA600FF9900FF9900FF8C00FF8C00FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFC000\
80FF00FFCC00FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFC00019FF00000000\
00000000000000FF19000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FFA600FFD900FFCC00
FFB300FFA600FFB300FFA600FFA600FFFF00FFA600FF9900FF9900FF9900FF9900FFA600FFD900\
80FF00FFD900FFC000FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300F3FF000099FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FF9900FFF300D9FF00
FFD90026FF00E6FF00FFCC00FFC000FFFF00FFC000FFA600FFA600FFA600FFA600FFA600FFC000\
FFFF00E6FF003FFF00FFE600FFC000FFA600FFA600FFB3003FFF00FFA600FF9900
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFCC00FFFF00\
66FF0000FF59000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF8C00FFA600FFC000
FFCC00FFD900D9FF008CFF00FFFF00000000FFE600FFCC00FFE600FFB300FFB300FFB300FFC000\
FFD900F3FF003FFF0066FF0000FF33FFC000FFC00099FF00E6FF00FFB300FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFB300FFC000004CFFD9FF00\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600
FFB300FFC000F3FF00D9FF0000FFB38CFF00D9FF00E6FF00FFD900FFC000FFC000FFCC00FFCC00\
FFF300F3FF008CFF0000FFCCD9FF00FFD900FFD9000073FF99FF00FFCC00FFB300
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFC00033FF000033FF000000\
00FF19000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FF9900
FFA600FFC000FFD900FFF30099FF0000000073FF0033FF0000FF73FFE600FFFF00FFFF00FFF300\
CCFF0033FF00000000000000000000FFFF00FFF300F3FF0099FF00B3FF00FFCC00
FFC000FFCC00FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFC00000FF2600FF26000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FF9900
FFA600FFC000FFD900F3FF008CFF000000000000000000000026FFF3FF00F3FF0026FF0000FFA6\
B3FF003FFF0000000000000000FF1999FF00B3FF0000FF8C00FF0000FFBFFFF300
3FFF0066FF00FFC000FFB300FFA600FFA600FFB300FFB300FFB300FFC000FFE600CCFF0019FF00\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF9900FF9900
FFB300FFD900FFF30000FF4C00FFB300000000000000000000F3FFA6FF0000000000FF59000000\
00000000000000000000000000000000000000000000FF0C000000A600FFD9FF00
C0FF00000CFFFFCC00FFC000FFB300FFB300FFB300FFB300FFC000FFD90000FF80CC00FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600
FFB300FFF300F3FF00CCFF00000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
8C00FF00FFB3FFFF00CCFF00FFCC00FFC000FFC000FFC000FFCC00FFE60019FF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600
FFB300FFCC00FFE60099FF0066FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000008CFFA6FF0000FF80FFD900FFCC00FFCC00FFCC00FFCC00FFE60000FF40000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FFA600FFA600FFA600FFB300
FFC000FFCC00FFF300E6FF00A6FF000CFF00000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000C0FF00FFE600FFD900FFD900FFD900FFFF0000FFFF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFC000FFE600FFC000FFCC00
FFFF00FFF300B3FF0000D9FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000033FF00F3FF00FFE600FFE600FFE600F3FF0000CCFF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFB30059FF00F3FF00D9FF00
00FF9973FF00A6FF00000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FF8CF3FF00FFF300FFFF00E6FF0000FF0C000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF9900FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFB300FFC000FFE6008CFF00
00FFBF00000000FF40000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000019FF00F3FF00F3FF0000FF0C000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF8C00FFFF00FFE600\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFB300FFC000FFD900F3FF00
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000E6FFCCFF00D9FF0000FF8C000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF9900FFCC00FFCC00\
FFA600FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFCC00FFE600E6FF00
80FF00000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000080FF00C0FF0059FF00000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFB300CCFF00\
FFC000FFB300FFA600FFB300FFD900FFC000FFC000FFC000FFF3005900FF0059FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000099FF003FFF00000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFA600FFC000\
FFFF00FFCC00FFC000FFC000F3FF00FFD900FFCC00FFD900FFE600F3FF0026FF00
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000066FF00000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300\
FFD90073FF00FFE600FFE600FFFF00C0FF00FFF300FFF300FFFF008CFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFB300\
FFFF0033FF008CFF00C0FF00B3FF0000FFB373FF00D9FF00E6FF008CFF003F00FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000008000FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FF7F00\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFC000\
FFD900F3FF0059FF0000000000000000000000000000FF4019FF0066FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FFB300FF8C00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFD900FFA600FFA600FFA600FFB300E6FF00FFD900\
FFFF00B3FF0000FF0000000000000000000000000000000000000033FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFFF00FF9900\
FF8C00FF8C00FF7F00FF7F00FF7F00FF8C00FF8C00FFA600FF9900FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFD900FFC000FFB300FFB300FFC000FFE600A6FF00\
99FF0073FF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFC000F3FF00FFFF00\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FFC000FFB300FFA600FF9900
FFD900FF9900FF9900FFA600FFB300FFB300FFCC00FFE600FFCC00FFE600FFE600FFFF0059FF00\
00CCFF00FF33000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF7F00FF8C00FF9900FF9900FFC000
FFA600FFA600FFA600FFA600FFC0008CFF00FFB300FFC000FFC000FFCC0000FF33000000000000\
FFD900FFD900FFCC00FFCC00FFE600FFD900FFE60033FF00FFFF00D9FF00FFE600
B3FF00FFE600FFD900FFE60073FF00CCFF00CCFF00000000A6FF008CFF00B3FF0000FF332600FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF6600FF6600FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FFA600FFD90026FF0073FF00\
FFB300FF9900FF9900FF9900FFA600FF9900FFA600FFC000FFC000FFA600FFA600
D9FF00FFA600FFA600FFA600FFC000FFC000FFD900FFF300FFD900FFF300FFE600E6FF0080FF00\
00000000FFE6000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFF300FFA600\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FFA600FFA600FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FFA600FFE600FFC000FFB300FFC000FFCC00FFE60000FF40\
8CFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF8C00FFCC00FF8C00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF9900E6FF00FFA600FFA600FFA600FFC0008CFF00FFE600\
FFFF004CFF0000FF590000000000000000000000000000000000000CFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF9900FF7F00\
FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FF9900FF9900FF9900FFB300FFC000FFCC00\
FFE600E6FF0019FF0000000000000000000000000000A6FF0CFF0073FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFC000\
FFE60000FF1900FF4C80FF0099FF0000000000FF4CC0FF00D9FF008CFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300\
FFD90000FFA6FFF300FFF300C0FF00D9FF00F3FF00FFFF00FFFF00C0FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FFF3000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFA600FFC000\
FFFF00FFE600FFCC00FFCC00FFF300FFE600FFD900FFD900FFE600F3FF0066FF00
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000004CFF00000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA60026FF00\
FFCC00FFB300FFB300FFB300FFD900FFC000FFC000FFCC00FFE600CCFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000001900FF8CFF00000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF9900FFE600FFE600\
FFB300FFA600FFA600FFA600FFA600FFA600FFB300FFC000FFE600FFF300A6FF00
00FF00000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000002600FFB3FF0073FF00000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFFF00FFC000\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFD900F3FF00
00FF73000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF73CCFF00D9FF00A6FF00000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFC000FFD90000FF73
00000000000000FFD9000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000E6FF00F3FF00C0FF00000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFB300E6FF00D9FF000080FF
00000000FFF300FF73000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000019FF00F3FF00FFFF00FFFF00E6FF00000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFC000D9FF00FFCC00FFD900
C0FF00FFFF00C0FF00000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000E6FF00FFF300FFE600FFF300E6FF00008CFF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FFB300FFB300FFB300FFB300
FFCC00FFD900FFFF00D9FF0066FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000B3FF0033FF00FF00FFF300FFD900FFD900FFE600FFFF0000E6FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FF9900FFA600FFA600
FFB300FFCC00FFE600B3FF008CFF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000FF4C99FF0000FFF3FFE600FFCC00FFCC00FFCC00FFD900FFE60000000000FF73000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600
FFB300FFD900FFF300D9FF00A600FF00000000000000000000FFFF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000CC00FF
00FF999900FFF3FF00000000FFCC00FFC000FFC000FFC000FFCC00FFE600CCFF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900
FFC000E6FF00FFFF000CFF0000000000000000000000000000000000FFD93F00FF00FF8C000000\
0000000000000000000000000000000000000000000000000000000000008CFF00
C0FF0019FF00FFD900FFC000FFC000FFB300FFB300FFC000FFC000FFD90000FFD9000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FF9900
FFA600FFC000FFD900CCFF0059FF00000000000000000000C000FFE6FF00D9FF000033FF00FF0C\
33FF0000FF5900000000000026FF0073FF0000FFE659FF00000000000000FFFF00
00FF0CFFFF00FFC000FFB300FFB300FFB300FFB300FFB300FFC000FFCC00FFF300B3FF00000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FF9900
FFA600FFB300FFCC00FFFF0000FF190000003FFF003FFF00C0FF00FFE600FFFF00D9FF00FFFF00\
E6FF0073FF0000000000000000FFBFE6FF00FFFF00E6FF0000CCFF00B3FFFFCC00
FFCC0000FFBFFFB300FFA600FFA600FFA600FFA600FFA600FFB300FFC000FFF300000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600
FFB300FFC00059FF00F3FF0059FF0073FF00D9FF00D9FF00FFE600FFCC00FFCC00FFD900FFD900\
00FFCCA6FF0026FF002600FFB3FF00FFE600FFD900CCFF0000FFA6FFD900FFB300
FFA600FFA600FFA600FF9900FF9900FF9900FFA600FFA600FFA600FFC0007300FF00FFBF000000\
00FF66000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFB300
FFC000FFCC0000FFD933FF00E6FF0080FF00FFE600FFF300FFE600FFB300FFB300FFC000FFC000\
FFD900F3FF008CFF0000FF4019FF00FFC000FFC00059FF00FFF300FFC000FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFB300FFC00000FF80CCFF00\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FF9900FFC000FFF300
FFFF00A6FF00B3FF00E6FF00FFCC00D9FF00FFCC00FFB300FFA600FFA600FFA600FFB300FFC000\
FFE600F3FF0080FF00FFFF00FFC000FFA600FFA600FFCC00FFFF00FFB300FF9900
FF9900FF9900FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFD900FFFF00\
B3FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FFA600FFCC00FFD900
FFC000FFB300FFC000FFA600FFA6003FFF00FFA600FF9900FF9900FF9900FF9900FFA600FFC000\
D9FF00FFF300FFE600FFB300FFA600FF9900FF9900FF9900FFA600FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFE6008CFF00\
00FF59000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FFFF00FFC000D9FF00FFE600
FFA600FF9900FF9900FF9900FF9900FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF9900FFC000\
80FF00FFCC00FFB300FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFC00000FF9900FF4C\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF9900FFC000C0FF00FFB300
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF8C00FF8C00FF8C00FFE600\
8CFF00B3FF00FFA600FF9900FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFE600FFF30059FF00\
99FF000019FFA6FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FFA600F3FF00FFB300
FF9900FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FFA600E6FF00FFA600FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFB300FFF300\
C0FF00FFFF000CFF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF7300FF7F00FF8C00FFA600FFE600FFA600
FF8C00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF9900FF9900FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300\
FFCC00FFD900FFF300C0FF000CFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF7300FF7F00FF8C00FFA600FFD900FFA600
FF8C00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600\
FFB300FFCC000033FF00FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF7300FF7F00FFD900FFA600FF8C00FF9900
FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600\
FFC000FFD9008000FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF7300FF7F00FFC000FF7F00FF7F00FF7300
FF7300FF7300FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FFA600\
FFD9000099FF00A6FF0000000000000000004C00FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFB300\
0CFF0000FFFFA600FF008CFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFCC00\
66FF0000FF33000000CCFF0000000000FF99F3FF00CCFF0019FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFB300\
FFC000FFF300D9FF008CFF00FFE600FFD900FFD90080FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00\
FF9900FFA6000CFF0099FF00FFCC00FFC000FFCC0000000000FF73C0FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF8C00FF8C00FFA600FFA600FFA600FFA600FFB300FFC000FFE600FFF30000FFA6
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFCC00FFE600E6FF00
8CFF0000FF3300FFF3000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFB300FFD900E6FF00E600FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFD9005900FF3300FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFA600FFC00000FF0C33FF00000000
00000000000000000000000000000073FF00000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFC000CCFF00CCFF000000FF
0000000000000000000000000000008CFF00C0FF00000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF8C00FF9900FFB300FFC000FFE60000000000B3FF
00000000000000000000000000FF1900E6FFFFF300C0FF000000004CFF00000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000000080FF00CCFF00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7F00FF7F00FF8C00FFCC00FFE600FFE600FFF30066FF000073FF
00000026FF000C00FF000CFFCCFF00FFE600FFD900FFFF0000FFB3E6FF0099FF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000CC00FFE6FF00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7F00FF8C00FFC000FFF300B3FF00E6FF0059FF003FFF00
3FFF0073FF00D9FF000073FF00FF19FFCC00FFC000FFC000FFCC00FFF30000FFFF000000000000\
00FF800080FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000007300FF000000B3FF00000000000000008CFFF3FF00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7F00FF8C00FF9900FFC000FFF30099FF0000FF66D9FF00
FFFF00FFE600F3FF0080FF00FFC000FFB300FFB300FFB300FFC000F3FF00B3FF000000000099FF\
7300FFF3FF0000000000000026FF0000FF0C000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000004CFF000099FF00000000FF26FFF300FFFF0000E6FF00FFCC00FF0080FF00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7F00FF8C00FFA600FFC000E6FF00CCFF00C0FF0000FF40
FFF300FFCC00FFB300FFB300FFA600FFA600FFA600FFA600FFB30059FF0000FF73000000A6FF00\
FFE600FFE6000000000059FFD9FF0000FF59000000D900FF66FF0000FFA6000000
00FF0C00FF5900000000000000000000000000FFE600FF1919FF0066FF000000008CFF00000000\
A600FF00FF8CE6FF0000FF4099FF00FFCC00FFCC00FFE60080FF000000000CFF00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7F00FF9900FFCC008CFF00FFCC00FFD900FFF300CCFF00
00A6FFFFCC00FFA600FF9900FF9900FF9900FF9900FF9900FFA600FFC00000FFBF73FF00F3FF00\
FFCC00FFC000FFF300FFFF00FFD900FFD900FFF300FFF300F3FF00D9FF0073FF00
000000000000000000000000000000000000000000000000000000C0FF00F3FF00FFF300FFE600\
00E6FFFFCC00FFD90000A6FFB3FF00FFB300FFB300FFD900FFF30080FF00FFCC00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7F00A6FF00FFF300FFC000FF9900FFA600FFB300FFB300
FFF300FFD900FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF9900A6FF00FFC000FFB300FFCC00\
FFB300FFA600FFB300FFB300FFC000FFC000FFCC00FFE600FFFF0000A6FF000000
000000000000000000000000000000000000000000000000000000000000A600FFFFE600FFCC00\
FFC000FFB300FFB300FFB300FFA600FF9900FF9900FFA600FFC000C0FF00FF9900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FFD900FFA600FF9900FF8C00FF8C00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFB300FFC000FFCC00FFE60059FF008C00FF000000
00000000000000000000000000000000000000000000000000000000000000FF0C00FF66FFCC00\
FFC000FFB300FFA600FF9900FF9900FF9900FF8C00FF8C00FF9900FF8C00FF8C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FFA600FFA600FFB300FFD900FFFF00000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000A6FFFFE600\
FFB300FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF9900FF9900FFA600FFB300FFD90000FF5900FF80000000000000
000000000000000000000000000000000000000000000000000000000000000000A6FF00FFF300\
FFC000FFA600FF9900FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF9900FFA600FFC000FFD900CCFF0000FF80000000000000
000000000000000000000000000000000000000000000000000000000000000000000000A6FF00\
73FF00FFA600FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7300FF7300FF7300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF9900FFB30000FFFFD9FF001900FF000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00A6FF00\
F3FF00FFB300FF9900FF8C00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF8C00FF9900FFA600FFCC0000E6FFCCFF0000FF26000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF0CFFF300\
FFF300FFA600FF8C00FF8C00FF7F00FF7F00FF7300FF7300FF7300FF7300FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF8C00FF8C00FF9900FFC0003FFF00FFFF0066FF00000000000000
00000000000000000000000000000000000000000000000000000000000000000000000099FF00\
FFC000FFA600FF8C00FF8C00FF7F00FF7300FF7300FF7300FF7300FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFCC00F3FF000C00FF000000000000
00000000000000000000000000000000000000000000000000000000000000000000000026FF00\
FFD900FFB300FF9900FF8C00FF7F00FF7300FF7300FF7300FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7F00FF8C00FF8C00FF9900FFB300FFD90000FF19000000000000000000
00000000000000000000000000000000000000000000000000000000FF5999FF00D9FF00A6FF00\
FFF3008CFF00FFCC00FF8C00FF7F00FF7300FF7300FF7300FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7F00FF8C00FF9900FFCC00FFC000FFD9004CFF00B3FF0000FFFF99FF00
00FFD900000000000000000000000000000000000000000000000099FF00FFF300FFE600CCFF00\
B3FF003FFF00FF9900FF7F00FF7300FF7300FF7300FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7F00FF8C00FFCC0073FF00E6FF00FFFF00B3FF00FFF300FFF300FFFF00
00FFFFC000FF00FF0C00FF6600000000000000FF00A6FF00F3FF00D9FF00FFCC00FFC00066FF00\
FFFF00FFB300FF8C00FF7F00FF7300FF7300FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7F00FF9900FFB30066FF00FFF300E6FF00FFE600FFCC00E6FF00
A6FF00FFFF00C0FF00000000000000000000000000B3FF00FFE600FFCC00FFB300FFB300FFC000\
FFCC00FFFF00FF8C00FF7F00FF7300FF7300FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7F00FF7F00FF8C00FF9900FFB300C0FF00FFCC00FFB300FFB300
FFC000FFD90033FF00000000000000000000000000B3FF00FFE600FFC000FFA600FF9900FF9900\
FF9900FFA600FF7F00FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7F00FF8C00FFB300FFCC00FFA600FFA600FFA600
FFC000FFE600D9FF0000FF0000FF8000000000FF59B3FF00B3FF00FFCC00FF9900FF8C00FF8C00\
FF8C00FF7F00FF7F00FF7300FF7300FF6600FF6600FF6600FF6600FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7F00FF8C00FF8C00FF8C00FF9900FF9900
33FF00B3FF008CFF00FFFF0000FF5900FF598CFF00FFE60059FF00FFB300FF9900FF8C00FF7F00\
FF7F00FF7F00FF7300FF7300FF6600FF6600FF6600FF6600FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF8C00
FF9900FFB300FFE600FFCC00FFF30000FF00FFF300FFCC00FFB300FFA600FF8C00FF8C00FF7F00\
FF7F00FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00
FF9900FF9900FFA600FFC000E6FF0000FF1900FF19FFC000FFA600FF9900FF8C00FF7F00FF7F00\
FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00
FF8C00FF9900FFA600FFB300FFCC008CFF00FFE600FFC000FFA600FF9900FF8C00FF7F00FF7F00\
FF7300FF7300FF6600FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF8C00FF9900FFA600FFB300FFCC00F3FF00E6FF00FFCC00FFB300FFA600FF9900FF8C00FF7F00\
FF7300FF7300FF6600FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00
FF8C00FF9900FFA600FFC000FFF300FFE600FFCC00E6FF00FFF300FFB300FFB300FF8C00FF7F00\
FF7300FF7300FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00
FF8C00FF9900FFA600FFE600F3FF00FFB300FFA600FFB300FFD900A6FF0099FF00FFB300FF8C00\
FF7300FF7300FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF7F00
FF8C00FF9900FFB300FFFF00FFC000FF9900FF9900FF9900FFC000FFA600FFA600F3FF00FFC000\
FF7F00FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00
FFB300FFB300FFCC004CFF00FFA600FF8C00FF8C00FF7F00FF7F00FF8C00FF8C00FFD900FF8C00\
FF7300FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00
FFB300C0FF00D9FF00FFA600FF9900FF7F00FF7F00FF7F00FF7300FF7F00FF7F00FF8C00FF8C00\
FF7300FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00
FFB300FFFF00E6FF00FF9900FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00
FFB300FFB300FF9900FF8C00FF7F00FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600\
FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF7300FF7F00FF8C00
FFB300FFA600FF8C00FF7F00FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF7300FF7F00FF9900
FFD900FFB300FF7F00FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF7F00FFA600FFB300
FF8C00FF9900FF8C00FF7300FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FFB300FFA600FF7F00
FF7300FF7300FF7300FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF7300FF6600
FF6600FF6600FF6600FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF3300FF3300FF3300FF3300FF3300FF3300FF3300
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF7F00FFC000FF9900FF7F00FF7F00FF7F00FFCC00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF7300FF8C00FFC000FFB300FF8C00FF9900FFC000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF7300FF7F00FF8C00FFA600F3FF00F3FF00FF9900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FFB300FFB300FF8C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FFA600FFCC00FF9900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FFCC00FFCC00FFA600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FFA600C0FF00FFFF00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FFA600FFF300000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C003FFF0066FF00FFF300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FF9900FFA600FFB300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FF9900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600FFE600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFB300FFC000FFE600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF8C00FF9900FF9900FF9900FF9900FFA600FFC000E6FF0000FF0C
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF8C00FFB300FFD900FFA600FFA600FFA600FFA600FFC000FFCC00FFF300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF8C00\
FF8C00FF9900FFC00000FFB3CCFF00FFB300FFB300FFB300FFC000FFD900F3FF00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF8C00FFB300\
FFA60026FF00FFCC00FFFF00C0FF00FFCC00FFC000FFF300F3FF00FFF300F3FF00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF8C00FFD900F3FF00\
E6FF00C0FF00D9FF0000FF0CFFFF00FFE600FFD900FFFF0000FFB3CCFF000C00FF
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF8C00FFA600C0FF00\
FFE600FFD900FFE60000FFFF00FF66E6FF008CFF00D9FF0000FF990019FF000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600\
FFB300FFC000FFD9000CFF0000FF7326FF0066FF0073FF00000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF9900\
FFA600FFB300FFE60000FF3300FF40000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900\
FFA600FFB300FFCC00F3FF00000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900\
FFA600FFC000FFD900FFF300CCFF0026FF00000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900\
FFA600B3FF0000FF73F3FF0099FF000C00FF000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900\
FFB300CCFF0033FF00B3FF0026FF00000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600\
66FF00B3FF00D9FF00B300FF000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600\
FFB300FFCC00FFE600C0FF000033FF000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600\
FFB300FFC000FFE60000F3FF73FF00000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600\
FFB300FFC000FFE60000FF4C00FF73000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FFC000FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600\
FFB300FFC000FFD900FFF300B3FF001900FF000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FF8C00FF9900FF8C00FF8C00FF8C00\
FF8C00FF9900FFCC00B3FF00FFA600FF8C00FF8C00FF8C00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFB300FFC000FFCC00FFE600000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7F00FFB300FFCC00FFD900FFC000FF9900FF9900FFA600\
FFA600FFB300FFF300F3FF00FFD900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FFA600FFC000FFB300FFB300FFC000FFA600FFA600FFA600FFB300FFB300FFB300\
FFC000FFC000FFCC00FFD900FFF3008C00FF000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FFCC00FFFF00FFE600FFB300FFB300CCFF00\
FFCC00B3FF0019FF00C0FF00FFB300FFA600FF9900FF9900FF8C00FF8C00FF9900
FF9900FF9900FFB3008CFF00D9FF00F3FF00E6FF00FFC000FFB300FFB300FFF300FFCC00FFD900\
FFCC00FFD900FFD900FFE600FFFF00E6FF0000CCFF00FFD9000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FFA600FFB3003FFF0033FF00FFE600B3FF00\
FFFF0099FF00E6FF00FFD900FFB300FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FFA600FFC00026FF0000FF2600FF0C33FF0000FF4CFFCC00FFCC00E6FF000080FF00FF99\
FFF3004CFF00B3FF00F3FF00D9FF00D9FF00C0FF0099FF003FFF00000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF9900FFA600FFC000FFE6008CFF0099FF00\
00000059FF00FFF300FFD900FFC000FFC000FFC000FFB300FFA600FFA600FFA600
FFA600FFC00000D9FF00A6FF33FF0000BFFFA6FF00F3FF00FFE600F3FF0000FF99004CFF73FF00\
B3FF0000FF4C26FF0000FF2626FF0000000000000000FFE6000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7F00FF8C00FF9900FFA600FFC000FFFF0099FF0066FF00\
73FF00D9FF00F3FF00FFE600FFE60000FF1999FF00FFCC00FFB300FFB300FFB300
FFB300FFC000FFFF00E6FF0026FF000000003300FF00FFFFE6FF00E6FF000040FF000000000000\
0000000000002600FF000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7F00FF8C00FF9900CCFF00FFE6008CFF001900FFD9FF00\
00FFA673FF004CFF0033FF00F3FF008CFF000033FF00FFCCFFFF00FFC000FFC000
FFC000FFCC00FFE60000FF4000FF330000000000006600FF99FF00000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFB300CCFF00B3FF0033FF00FFF300E6FF00\
99FF000000000000000C00FF00FFE666FF0000FFBFC0FF00FFE600FFCC00FFCC00
FFD900FFF300FFF30073FF000000000000000000000000000099FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFC000FFC000FFCC00FFD900F3FF00\
00FF9900000000000000000000000000000000000080FF000099FFFFE600FFE600
CCFF003F00FF00000073FF0066FF0000A6FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FF9900FFA600FFC000FFD900FFFF00\
B3FF0000FF800000000000000000000000000000000066FF80FF00FFFF00FFFF00
00000000000000000000FFFF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFC000C0FF00D9FF00\
33FF00008CFF00000000000000000000000000000000000000FFFFD9FF000026FF
00FF2600FF80000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFC00000FF4C00FF99\
004CFF00000000000000000000000000000000000000000000000000000000FF66
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600FFFF00C0FF0000FF26\
00000000000000000000000000000000000000000000000000FF008000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFC000F3FF00F3FF00\
99FF0000FFCC000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFCC00FFD900\
0000004C00FFB300FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFD900\
FFF300E6FF0099FF00B300FF00FF8C000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFA600FFA600FFA600FFB300FFC000FFCC00FFE600\
FFFF00CCFF0073FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF8C00FF8C00FF9900FF9900FFD900C0FF00FFD900FFB300FFB300FFC000C0FF00CCFF00CCFF00\
B3FF0000000000FF99000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00
FF9900FFA600FFA600FFC000FFFF0073FF00FFE600FFCC00FFCC00FFD90059FF0000000000FF19\
80FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900
FFE600FFF300FFFF0033FF0000FF1959FF00FFF300FFF300FFE600FFE60000FF9900FF0C000000\
00E6FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900
FFC0008CFF0000FF8C00FF193FFF00C0FF00C0FF000026FF26FF00F3FF00D9FF0073FF0000CCFF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF9900
FFB300FFFF0000B3FF00FF73C000FF00FF990000000000000CFF00B3FF0000FF80000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF7300FF7F00FF8C00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900
FFB300FFF300E6FF0099FF006600FF000000000000000000000000000000D900FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF7300FF7F00FFB300FF9900
FF8C00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900
FFA600FFB3004CFF00F3FF00B3FF0000FFB3000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF7300FF7F00FFA600CCFF00
FFC000FF9900FFD900FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900
FFA600FFB300FFC000FFE60000FFD9000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FF9900
FFD900CCFF00FF9900FF8C00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900
FFA600FFB300FFC000FFD9000059FF8000FF0059FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FF9900
FFB300FFD900FF9900FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FFF300FF8C00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600
FFB300FFC000FFCC00FFD900FFF300D9FF00000CFF0026FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FF9900
FFE600D9FF00FFB300FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF9900E6FF00FFA600FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600
FFD900B3FF00FFFF00FFF30073FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FFA600
FFCC00FFCC00FFA600FF9900FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFCC00E6FF00FFA600FF8C00
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFB300FFC000
D900FF000000E6FF00E6FF00B3FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FFA600FFD900
FFF300FFCC00FFB300FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FFCC0033FF00E6FF00FFCC00FFA600FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFA60000FF26C0FF00
00FF5959FF0000FF0000000073FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FFA600FFB300
FFCC00B3FF00FFC000FFA600FFA600FF9900FF9900FF9900FF9900FF9900FFA600FF9900FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FFB300D9FF00FFE600FFC000FFA600FF9900
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFD90080FF00
00FF6600000000000000000000FF80000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF7F00FF8C00FF9900
FFB300FFF300FFCC00FFB300FFB300FFB300FFC000FFA600FFA600FFD900FFD900FFA600FF9900\
FF9900FF9900FF9900FF9900FFA600FFC000B3FF00FFF300FFD900FFC000FFB300
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFC000C0FF00
D900FF3FFF00000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900
FFC000FFE600B3FF00FFD900FFE600FFE600CCFF00FFC000FFC000FFD900FFD900FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFC000FFE600D9FF0080FF00C0FF00FFD900
FFE600FFA600FFA600FFA600FFA600FFC000FFC000FF9900FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFB300FFC000FFD900
FFF30000000000000000FFE6000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00
FF9900FFB3004CFF00FFF300FFD900E6FF00B3FF00F3FF00FFE600F3FF00D9FF00FFCC00FFC000\
FFFF00FFB300FFA600FFB300FFB300FFC000FFCC00FFE600E6FF0000000000FF0C
FFFF00FFC000FFB300FFB300FFE60099FF0099FF00FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFFF00
F3FF00CCFF000CFF00000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00
FF9900FF9900FFA600FFB300FFC000FFD900CCFF0073FF00B3FF0000FFCCF3FF00FFE60059FF00\
FFE600FFC000FFB300FFC000FFC000FFCC00FFD900FFE600E6FF008CFF0000A6FF
00FF80FFD900FFCC00FFCC0059FF00FFFF00FFCC00FFB300FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFD90000B3FF
99FF008CFF00000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00
FF8C00FF9900FFA600FFA600FFB300FFFF00CCFF00E6FF00A6FF0000FF0099FF00E6FF00C0FF00\
FFF300FFCC00FFCC00FFE600FFD900FFD900FFFF00F3FF008CFF00000000000000
A6FF00D9FF00FFD900FFE600F3FF00B3FF000CFF00FFCC00FFB300FFB300FFA600FFA600FFA600\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB3008CFF0000FF4C00FF73
6600FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00
FF8C00FF9900FF9900FFA600FFB300FFC000FFD900FFFF0080FF000000000066FF00FF2600FFA6\
00FFBFFFF300FFE60000FFA6FFFF00FFF300F3FF00B3FF0000FFF3000000000000
8000FFCCFF00F3FF00FFF300F3FF0099FF0000FF0C00FFB3FFCC00FFC000FFCC00FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFC000FFD90099FF0033FF00
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00
FF8C00FF9900FF9900FFA600FFB300FFC000FFE600F3FF008CFF00000000000000000000000000\
59FF00E6FF00FFFF00E6FF0000FF0033FF00A6FF0099FF0000FFE6000000000000
000000A6FF0066FF00CCFF008CFF000080FF00FF4000FF66FFE600CCFF0066FF00FFCC00FFB300\
FFB300FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFF300CCFF00
3FFF00000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF9900FF9900FFB300FFC000FFCC00FFF30000FF333FFF00000000000000000000000000\
000000A6FF0000FF5999FF0000000000000000FF8C00FF5900FF80000000000000
00FF9900000000000000FF664C00FF000000000000000000F3FF00A6FF0000FF59FFD900FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFCC00FFD90000FF1980FF00
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF9900FFA600FFB30000FF00F3FF0066FF0080FF00000000000000000000000000000000\
00000066FF00000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000059FF00A6FF00B3FF0000F3FF0073FFFFD900\
FFCC00FFC000FFC000FFB300FFC000FFC000FFC000FFCC000000000099FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF9900FF9900FFA600FFB300FFCC00FFE600FFFF00CCFF0000FF59000000000000000000000000\
0059FF000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFD900FF00\
008CFFFFCC00FFC000FFC000FFC000FFC000FFCC00FFD900FFFF00B3FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900
FF9900FFA600FFA600FFB300FFC000FFD900FFF3000080FF8CFF00000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000005900FF99FF00\
00FF59FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFD900F3FF004CFF000099FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600
FFA600FFA600FFB300FFC000FFCC00FFD900FFF300E6FF00B3FF0059FF0000FF99000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000FFE6\
0073FFE6FF0000FF99FFD900FFD900FFD900FFD900FFF3000099FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900E6FF00CCFF00
FFC000FFC000FFC000FFF300FFD900D9FF00A6FF0099FF00A600FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00FF1959FF00E6FF00FFE600FFE600FFE600FFE600FFF300CCFF0000B3FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFB30099FF00
FFE600FFD900FFE600B3FF00E6FF00E6FF00000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000FF33FFF300FFF300FFF300FFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFB300FFCC00
D9FF00A6FF0059FF003300FF4CFF00004CFF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000FF0066FF00F3FF00FFFF00FFFF00F3FF0000FF99000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FFCC00FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFC000
FFCC00FFF3004CFF00000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000026FF00CCFF00F3FF00F3FF00D9FF000CFF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF8C00FFA600FFF300FFFF00\
FF9900FF9900FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFB300FFC000
FFCC00FFF300E6FF003300FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000FF99D9FF00D9FF00CCFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFCC00FFCC00\
FFA600FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000
FFCC00FFE600F3FF00A6FF0000FF19000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000008CFF00CCFF00B3FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FFA600FFCC0066FF00\
FFCC00FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFD900
D9FF00F3FF0000000059FF00000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000FFF3B3FF0099FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFB300C0FF00\
73FF00FFC000FFB300FFB300FFB300FFC000D9FF00FFC000FFC000FFCC00FFD900
FFFF008CFF003F00FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000FFF38CFF0080FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFC000\
FFF300B3FF00FFD900FFC000FFC000FFD900E6FF00FFD900FFCC00FFD900FFD900
FFF300D9FF004CFF00000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000004CFF0059FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600FFB300\
FFCC00E6FF00E6FF00FFD900FFD900FFE60059FF00FFF300FFF300FFF300FFF300
00FF8000FF33000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000FF9926FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300\
FFE600B3FF008CFF00E6FF00E6FF00E6FF003FFF0000E6FFCCFF00E6FF00F3FF00
E6FF008CFF00000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000FF19000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFC000\
FFCC00FFFF00A6FF0000FFCC19FF0080FF000099FF00B3FF0CFF008CFF00B3FF00
C0FF0066FF00000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000FF66000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7F00FF8C00FF8C00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFC000FFC000FFCC00\
FFD900FFF3000033FF00FFE60000000000000000000000000000000000000C00FF
80FF0000FF00000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000FFE6000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7F00FF7F00FF9900FFA600FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FFA600FFC000FFA600FFA600FFA600FFB300FFCC0099FF00FFD900\
FFF300B3FF0099FF0000FFA6000000000000000000000000000000000000000000
00FFCC00FF26000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000059FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF8C00FF9900FFC000FF9900FF9900FF8C00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF9900FFA600FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FFB300D9FF00FFC000FFB300FFB300FFC000FFCC00FFE60059FF00\
E6FF00C0FF0026FF00000000000000000000000000000000000000000000000000
00000000FFA6000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FFB300FFB300FFF300FFCC00FFB300FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FFC000FFCC00FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFB300FFE600FFCC00FFC0004CFF00FFCC00FFE600FFF300B3FF00\
66FF003FFF00F300FF000000000000000000000000000000000000000000000000
0000000026FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF6600FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF8C00FF8C00
FF9900FF9900FFA600FFC000E6FF00000000000000FFCC00FFA600FFA600FFA600FFA600FFA600\
FFB300FFA600FFB300FFCC00FFE600FFB300FFB300FFB300FFD900FFB300FFB300
FFB300FFB300FFCC00FFCC00FFD900F3FF00D9FF00FFE600E6FF00FFFF00F3FF00CCFF003FFF00\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF6600FF7F00FF8C00FF8C00FF8C00\
FF9900FFA600FF9900FF9900FF9900FF9900FFA600FFB300FFB300FFA600FFD900
FFB300FFCC00FFC000D9FF00000000000000000000FFD900FFC000FFC000FFC000FFC000FFC000\
FFD900FFD900FFCC00FFF3004CFF00FFD900FFD900FFD900F3FF00FFD900FFE600
FFCC00FFFF00FFFF00FFFF00E6FF0073FF0066FF00D9FF0080FF0073FF0000FFB34CFF000C00FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF7F00FF8C00
FF8C00FF8C00FF9900FFC000FFD900B3FF00CCFF00FFC000FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFC000FFCC00FFA600FFA600FFA600FFC000FFA600FFA600
FFA600FFA600FFB300FFB300FFC000FFF300FFE600FFD900CCFF00FFD900FFFF00F3FF00A6FF00\
0000002600FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF8C00FF9900FFA600F3FF00FFB300FFB300FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FFA600FFC000FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FFA600FFB300F3FF00FFC000FFC000FFC000FFC000FFCC00FFF3003FFF00\
C0FF0099FF00000000000000000000000000000000000000000000000000000000
00000000D9FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF8C00FF9900FFB300FF9900FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FFA600FFF300FFB300FFA600FFA600FFB300FFCC00F3FF00FFFF00\
FFFF00CCFF0000FF80000000000000000000000000000000000000000000000000
00000000FF8C000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000004C00FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7F00FF8C00FF9900FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF9900FFA600FF9900FF9900FFA600FFA600FFCC00FFE600FFCC00\
FFE600E6FF00C0FF0000FF19000000000000000000000000000000000000000000
4CFF000CFF00000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000BFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF8C00FF8C00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFC000\
FFCC00FFF300D9FF003FFF0000000000FF260066FF00000000BFFF00FF7380FF00
A6FF00008CFF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000FFA6000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFA600FFB300\
FFD900F3FF0000FFE600FF8C99FF00C0FF004CFF0000FF6600FFBFC0FF00CCFF00
CCFF0000FFE6000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000FF40000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFB300\
FFCC00D9FF00CCFF00FFF300FFFF00F3FF0000FF66F3FF00E6FF00FFFF00FFFF00
E6FF0073FF00000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000019FF00FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300\
FFCC00C0FF00E6FF00FFCC00FFCC00FFE600E6FF00FFE600FFE600FFE600FFE600
E6FF00C0FF000CFF00000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000003FFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFCC00\
B3FF00FFCC00FFC000FFC000FFC000FFD900E6FF00FFCC00FFCC00FFCC00FFD900
FFF300C0FF000000FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000073FF0066FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFB300D9FF00\
FFCC00FFB300FFA600FFA600FFA600FFC000FFCC00FFC000FFC000FFC000FFD900
00FF0CD900FF00FFBF00FFD9000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000007300FF99FF008CFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFA600FFE600FFE600\
FFC000FFA600FFA600FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFCC00
FFE600FFF300C0FF0019FF0000FFFF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000008CFF00C0FF00A6FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFE600FFCC00\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000
FFCC00FFE600F3FF0066FF0000B3FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000FF66CCFF00CCFF00C0FF0000FF59000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FFCC00FFB300FFA600\
FF9900FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300
FFCC00F3FF0000FFE626FF00000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000D9FFB3FF00E6FF00E6FF00D9FF0000FF73000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFC000
FFD900E6FF008CFF007300FF00BFFF2600FF00FF73000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000C000FFC0FF00F3FF00F3FF00E6FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFB300FFE600
00FF4CE6FF00E6FF004CFF00B3FF00C0FF0073FF00000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000059FF00C0FF00FFFF00FFF300FFF300F3FF008CFF00A600FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFB3004CFF00
FFCC00FFCC00FFD900D9FF00FFF300F3FF004CFF0000FF73B300FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000CFF00000000FFFF00FFE600FFE600FFE600FFFF0000FF4C000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFC000FFC000
FFB300FFB300FFC000FFCC00FFD90080FF00F3FF00D9FF0073FF00000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00F3FF00FFD900FF4CFFE600FFD900FFD900FFE600FFF300CCFF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900
FFA600FFA600FFB300FFB300FFC000FFD900FFF300E6FF0059FF000CFF0000F3FFCC00FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000F300FF59FF00\
000000FFF300FFE600FFD900FFCC00FFCC00FFD900FFE6000000000000008C00FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900
FF9900FF9900FFA600FFB300FFC000FFD900FFF300D9FF000C00FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000099FF0000FF19\
D9FF00FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFFF0033FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF9900FF9900FFA600FFB30099FF0059FF00F3FF00C0FF0000FFBF000000000000000000000000\
00000000CCFF000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000080FF00FF0C0026FFFFF300\
B3FF00FFCC00FFC000FFC000FFC000FFC000FFCC00FFD900CCFF00000CFF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF9900FFA600FFB300E6FF00FFE60066FF0000FF0C000000000000000000000000000000\
0000008CFF0000FFB3000000000000000000000000000000000000000000000000
00000000000000000000000000FF8C0000000000003FFF00CCFF00C0FF0059FF0000FF19FFCC00\
FFC000FFC000FFB300FFB300FFB300FFC000FFC000FFCC00D9FF000000FF000000
00A6FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF9900FF9900FFA600FFB300FFCC00F3FF0099FF0000FF19000000000000000000000000\
00FF80CCFF0099FF00CCFF0000FF6600FF5966FF0066FF0000FF33000000000000
00A6FF00FF260000003FFF0073FF0000000000000080FF00FFFF0000FF33D9FF00FFCC00FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFD9003FFF00A6FF00
8000FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00
FF8C00FF9900FF9900FFA600FFB300FFC000FFD900E6FF00004CFF0000000000000099FF000000\
A6FF00CCFF00FFF300D9FF003F00FFD9FF00E6FF00B3FF0000E6FF000000000000
0C00FFC0FF0019FF00F3FF00CCFF00B3FF000059FF00A6FFFFD900FFD900E6FF00FFCC00FFB300\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFF300C0FF00
00FFBF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00
FF8C00FF9900FF9900FFA600FFB300FFCC00FFE600FFFF00C0FF0000000000FF73C0FF0000FFF3\
C0FF00FFE600FFD90019FF00FFE600FFE600F3FF0000FF598000FF0040FF000000
26FF00CCFF00FFF300FFF300FFFF00CCFF0073FF00E6FF00FFC000FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFD9000033FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00
FF8C00FF9900FFA600FFB300FFC000FFD900CCFF00CCFF0033FF0073FF00CCFF00FFFF00E6FF00\
FFE600FFCC00FFC000FFCC00FFCC00FFCC00FFE600FFF300E6FF008CFF00000000
B3FF00FFFF00FFD900FFD90000FF4C00D9FFFFE600FFC000FFB300FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFD900CCFF00000000
9900FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00
FF9900FFA600FFB300FFC000FFCC00FFE6008CFF0099FF00F3FF004CFF00E6FF00FFD900FFE600\
80FF00FFB300FFB300FFB300FFB300FFC000FFCC00FFE60000BFFF66FF0000FF4C
D9FF00FFD900FFC000FFC00059FF00F3FF00FFD900FFB300FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFCC00000000
CCFF0066FF00000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00
FFB300FFC000D9FF00E6FF00C0FF000CFF00F3FF0000FF26FFCC00FFE600C0FF00FFC000FFB300\
FFB300FFA600FFA600FFA600FFB300FFC000FFCC00FFF300E6FF0099FF00FFFF00
FFE600FFB300FFA600FFB3008CFF00FFE600FFF300FFA600FF9900FF9900FF9900FF9900FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFB300FFC000FFD900
FFFF00D9FF0073FF00000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900
FFB300B3FF00F3FF00FFC000FFC000FFC000FFD900FFB300FFB300FFF300FFCC00FFA600FFA600\
FF9900FF9900FF9900FFA600FFA600FFC000D9FF0073FF004CFF00FFF300FFC000
FFE600FFA600FF9900FF9900FFA600FFA600FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFC000FFD900
FFFF00000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF7F00FF8C00FFA600
FFD90080FF00FFCC00FFB300FFA600FFA600FFA600FF9900FF9900FFB300FFD900FF9900FF9900\
FF8C00FF8C00FF9900FF9900FFA600FFD900A6FF00FFE600FFCC00FFB300FFA600
FF9900FF9900FF9900FF8C00FF8C00FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFCC008CFF00
00FF590000000000000000002600FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FFD900FFCC00
FFE600FFD900FFB300FFA600FF9900FF9900FF9900FF8C00FF8C00FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FFB30073FF00FFE600FFC000FFA600FF9900
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFD90066FF00
A600FF00FF5900B3FF00000019FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF9900FFB300
FFCC00FFD900FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FFB300FFD900F3FF00F3FF00FFA600FF9900
FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFD900FFE600
26FF0059FF0000000026FF00A6FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FF9900
FFD900FFD900FFA600FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFCC00FFD900FFA600FF8C00
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFB300
FFD90019FF00F3FF00FFFF000CFF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FF9900
FFE600FFF300FFA600FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FFE600FF9900FF8C00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600
FFC000FFD900FFD900FFE600FFFF0099FF00000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FF9900
FFB300FFCC00FF9900FF8C00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900
FFA600FFB300FFC000FFD900FFF300D9FF0080FF00000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FFB300
E6FF00FFC000FFA600FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900
FFA600FFB300FFC000FFD90000000000FF99000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF7300FF7F00FFCC00FFA600
FF9900FF8C00FF8C00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900
FFA600FFB300FFD900FFF30000FF4C00FF8C000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF7300FF7F00FFCC00FF8C00
FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900
FFA600FFC00000FF80CCFF0000FF1900000000000000000000000000FFCC000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF7F00FF7F00FF7300
FF7300FF7300FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF9900
FFB30026FF00CCFF0000000000FF4C00000000000000000000000066FF00000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF7300FF7300
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF9900
FFB300FFE600A6FF000033FF00FF0000FF1980FF0000FF1973FF00D9FF0000000000FF26000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900
00FF998CFF00E6FF0000FFCC0066FFCCFF00F3FF0026FF00F3FF00FFF300E6FF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00
FFA600FFE600FFB3008CFF00F3FF0000FF00FFE600FFD900FFD900FFD900D9FF00000000000000\
00FF0C000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00
FF8C00FF9900FF9900FFA600FFF30099FF00FFF300FFC000FFC000FFCC00B3FF009900FF00FFBF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF8C00FF8C00FF990099FF00FFB300FFB300FFB300FFB300FFC000FFCC00FFFF00FFFF00\
D9FF003F00FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFCC00FFD900\
FFF300E6FF00B3FF0059FF000019FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000FFD900\
F3FF00C0FF0000FFE6000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFD900FFE600\
00FF4000FFF3000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFCC00F3FF00C0FF00\
0073FF8000FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFCC0000FFCC0CFF00\
00FFE6000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFC000B3FF003300FF\
80FF000000000000000000000000000000000000000000006600FFB3FF0033FF00
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFC000FFF300FFFF00\
8CFF00004CFF000000000000000000000000000000000000000000E6FF00000000
99FF00000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFB300FFC000FFD900D9FF00\
73FF0000000000000000000000000000000000000019FF0000FF0CFFF300FFF300
80FF002600FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFB300FFF300FFD900FFD900FFE600CCFF00\
66FF0000000000000000FF730080FF00FF0C000000B3FF00FFFF00FFD900FFD900
73FF000CFF00A6FF00D9FF00000CFF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFA600A6FF00B3FF0000FF4CFFFF00E6FF00\
59FF0000FFBF00FF268CFF00C0FF00B3FF0026FF00B3FF00FFF300FFCC00FFC000
FFCC00FFD900FFE600CCFF00000000000000000000000000F300FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7F00FF8C00FF9900E6FF00FFCC0059FF000040FFC0FF00\
0099FF8CFF0000FF80F3FF00FFF30066FF0059FF00FFF300FFCC00FFB300FFB300
FFB300FFC000FFE600B3FF004CFF000000000000002600FFC0FF000000004CFF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF8C00FFA600FFC000FFE600E6FF004CFF00\
99FF00E6FF00FFF300FFD900FFCC00FFD90099FF00FFC000FFB300FFA600FFA600
FFB300FFC0008CFF0099FF003FFF0000000000FFFF00FF80FFFF00F3FF003FFF00000000000000\
99FF0000000000000000FFA6000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FF9900FFA600FFCC00E6FF0066FF000CFF00\
CCFF0000FF40FFF300FFCC00FFC000FFB300FFB300FFA600FFA600FF9900FF9900
FFA600FFB30000FF4CD9FF000066FF00FF2680FF00FFFF00FFD900FFFF0000A6FF000000000000\
E6FF0000FF7300FF9980FF000000000000000026FF0000003FFF0000FF19000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FFE600FFCC0033FF00FFE600FFCC0099FF00\
FFE60019FF000026FFFFD900FFB300FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFB300FFFF0000FF9900FF73E6FF00FFE600FFC000FFC00000FF3333FF00FFFF00\
FFD900FFF300FFF300FFF300FFFF00E6FF00CCFF008CFF0000E6FF000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FFC000C0FF00FFC000FFA600FFA60073FF00\
FFB300FFC000FFF300D9FF00FFB300FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FFB30000FF19FFE600FFD90059FF00FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFCC00FFD900FFE600FFF300E6FF0000FF4C000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF8C00FFA600FFA600B3FF00FF9900FF8C00FF9900\
FF9900FFA60000FF80B3FF00C0FF00FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFCC00FFD900F3FF0000FF19000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FFE600FFA600FF9900FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFB300FFC000FFCC00FFE600000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600\
FFB300FFC0008CFF00F3FF0000FF190033FF000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600\
FFB300FFC000FFD9000099FF0CFF00000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFA600\
FFB300FFC000FFD900D9FF0000FF26000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600\
FFC000FFD900FFFF002600FF000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600\
D9FF004CFF0080FF0000FF734C00FF000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900\
FFB300FFE60073FF00CCFF008CFF00000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900\
FFA6000CFF00F3FF00FFFF00008CFF000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900\
FFA600FFB300FFCC00F3FF00E600FF00FFD9000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF9900\
FFA600FFB300FFE600F3FF004CFF00000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF9900\
FFA600FFB300F3FF0066FF0000FF660000000000FF3300FF000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFB300\
FFC000FFCC00FFD9008CFF0000FF80C0FF0080FF0080FF000080FF000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF8C00FFC000FFF300\
A6FF00FFF300FFF30073FF00F3FF00FFF300FFF300F3FF0000FF2673FF00000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FFA600CCFF00\
FFC000E6FF00C0FF00E6FF00F3FF00FFD900FFCC0000FF26A6FF00F3FF0033FF00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF8C00FF9900\
FF9900FFA600FFC000F3FF00FFF300FFC000FFC000FFCC00FFD900FFE600E6FF00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF8C00FF9900FFB300F3FF00FFD900FFB300FFA600FFB300FFC000FFCC00FFF300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF8C0073FF00C0FF00FFA600FF9900FFA600FFA600FFB300FFD900FFFF00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFCC00E6FF00D9FF00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600FFB300FFD900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FF9900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FF8C00FF9900FFA600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FFB300FFB300FFC000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00F3FF00F3FF003FFF00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FFA600E6FF00000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FFB300FFF300FFCC00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FFB300FFCC00FF9900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FFB300FFCC00FF9900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF7300FF7F00FF7F00FF9900FFB300FFB300FF8C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF7300FF7F00FF9900FFC000FFB300FFB300FF9900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF7300FF8C00FFB300FF8C00FF7F00FF8C00FFC000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF7F00FF8C00FFA600FF7300FF7300FF7300FF7300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF7300FF7300FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C0099FF00FF9900FF8C00\
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00
FF7F00FF8C00FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFCC00FFCC00FFA600\
FF9900FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FFB300
FFA600FFC000FFFF00FF9900FF9900FF9900FF9900FF9900FF9900FFC00080FF00C0FF0019FF00\
FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FFA600
FFCC0019FF00FFCC00FFB300FFA600FFA60066FF00FFC000FFB300FFC000FFF300E6FF00FFC000\
FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF8C00
C0FF00FFD90099FF00A6FF00FFC000FFC000E6FF00FFD900FFD90080FF00000000E6FF00FFC000\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF8C00
FF9900FFB30080FF00D9FF00CCFF00FFE600D9FF00F3FF00E6FF0099FF00F3FF00FFD900FFC000\
FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFB300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00
FF9900FFA600FFB300FFD900F3FF0000FF80B3FF00A6FF0073FF00E6FF00FFF300FFD900FFCC00\
FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFB3000CFF00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00
FF9900FFA600FFB300FFCC00FFF300D9FF0033FF0066FF00C0FF00F3FF00FFF300FFE600FFD900\
FFE600FFD90080FF00FFC000FFB300FFA600FFA600FFA600FFB300FFB300FFD900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00
FF9900FFC000FFCC00E6FF00C0FF0000FF40B3FF0059FF00CC00FFCCFF0000FFCCE6FF00FFF300\
F3FF0019FF0080FF00D9FF00FFD900FFC000FFB300FFB300FFB300FFC000FFCC00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00
FFA600FFF300FFF30000FF00CCFF00E6FF00E6FF0000D9FF00B3FF00FF4000FF3300FF19D9FF00\
D9FF003FFF0000FF1980FF0000FF19FFCC00FFC000FFC000FFC000FFCC00FFD900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00
FFD900F3FF00F3FF0073FF00FFF300FFF300F3FF00B3FF0000FFF300000000000000FF8C000000\
4CFF0000FFCC00FFD900FFCCFFFF00FFD900FFCC00FFCC00FFE600FFE600F3FF00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00
FFA600FFC000FFC000FFCC00FFCC00FFD900FFFF0000FFD900FFCC00000000000000FFF3000000\
1900FF0000000000008CFF0080FF00FFF300FFD900FFE600F3FF00000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00
FF9900FFA600FFA600FFB300FFC000FFD900FFFF0026FF00000000000000000000000000000000\
00000000000000000000FF4C0C00FF0CFF00FFF300FFFF00C0FF0000FF59000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF9900FFA600FFB300FFC000FFE600FFFF00D9FF0059FF00000000000000000000000000\
00000000000000000000000019FF00CCFF00F3FF00D9FF00B3FF00000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF9900FFA600FFB300FFCC000CFF00B3FF00B3FF000019FF000000000000000000000000\
000000000000000000000000000000A6FF00C0FF000099FF000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF9900FFA600FFB300FFCC0000E6FF0080FF9900FF000000000000000000000000000000\
00000000000000000000000000000080FF00B300FF00FFCC000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF9900FFA600FFB3000026FF8CFF0000FF00000000000000000000000000000000000000\
00000000000000000000000000000000FF19000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF9900FF9900FFA600FFB300FFCC00C0FF00CCFF0073FF00000000000000000000000000000000\
00000000000000000000000000FFD9000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FFA600FFB300FFC000FFD900FFE60000FF40000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FFA600FFA600FFB300FFB300FFCC00FFD900E6FF0000FF4000FF40000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FFA600FFA600FFA600FFB300FFC000FFCC00FFD900FFE600FFFF00D9FF00A6FF0059FF0000FF0C\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600
FFA600FFA600FFB300FFB300FFC000FFCC00FFE600FFF300F3FF00CCFF000033FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFC000FFC000FFCC00FFB300
FFB300FFB300FFB300FFC000FFD90000BFFFE6FF00F3FF0000000019FF00000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFE60000FF4CCCFF00FFD900
FFC000FFC000FFC000FFE60000FF3300000000FFFFC0FF0000FF66000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF8C00FF9900FFB300FFA600FFB300B3FF00FFE6008CFF00B3FF00FFD900
FFCC00FFCC00FFD900FFF3000000000000004C00FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF8C00FF9900FFFF0073FF00FFD90000FF5900FF193FFF008CFF00F3FF00FFF300
D9FF00FFE600FFE600FFF30000FFA600FFD9000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF8C00FF9900FFCC00FFF3003F00FF8CFF0000CCFF00BFFFB3FF00D9FF0000F3FF
00000080FF00E6FF00F3FF00C0FF003FFF00000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF9900FFA600FFD900D9FF0000FF0C00FF400019FF33FF0000000066FF00
00FF730CFF00B3FF00C0FF00000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF7300
FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF9900FFA60000FF8C00FF008CFF0059FF00E600FF000000000000000000
0000000000003300FF8CFF0000FF4C000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF7300FF7F00
FFD900FFD900FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF9900FFA600FFC000FFE60000FF19C0FF000033FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF7300FF7F00
FF8C00FFCC00FF9900FF8C00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF9900FFA600FFB300FFCC00B3FF00FFFF00C0FF006600FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF7300FF7F00
FF9900FFCC00FFD900FFD900FF9900FF9900FF9900FF7F00FF7F00FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF9900FFA600FFA600FFC000FFCC00FFE60033FF0000FF33000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00
FF7F00FF9900FFA600FFF300FFC000FFD900FF9900FF7F00FF7F00FF7F00FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF9900FF9900FFA600FFA600FFB300FFCC00FFD90000FF8C4CFF0000FF66000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00
FF7F00FF8C00FF9900FFB300FFF300FFB300FF9900FF8C00FF7F00FF7F00FF7F00FF7F00FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FFA600FFB300FFC000FFCC00FFD900FFF300E6FF0000FF404CFF00
00FF59000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00
FF7F00FF8C00FF9900FFB300FFF300FFB300FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FFC000FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FFA600FFB300FFC000FFCC00FFD900FFE600FFF30000FFA699FF0000FF73
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00
FF7F00FF8C00FF9900FFCC00000000FFFF00FFA600FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF9900D9FF00FFCC00FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FFA600FFB300FFCC000080FFB3FF00FFF300FFF3001900FF00000026FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00
FF7F00FF8C00FFA600FFC000FFD900FFB300FFA600FF9900FF8C00FF8C00FF8C00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF9900FFA600FFC0003FFF00FFD900FF9900FF8C00FF8C00FF8C00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600\
FFB300FFC000E6FF0019FF00CCFF00F3FF00F3FF00B3FF0000FFB3000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00
FF8C00FF9900FFC000FFCC00B3FF00FFB300FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF9900FFCC00FFFF0066FF00FFFF00FFC000FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFCC00\
00FF73FFFF0000FFD90033FF99FF000040FF0033FF99FF008000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00
D9FF00FFF300FFD900FFE600FFE600FFC000FFB300FFA600FF9900FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FFA600FFC000D9FF00FFF300FFCC00FFB300FFA600FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFC000\
FFFF0059FF0000000000000000000000000000000019FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00
FF8C00FF9900FFA600FFC00080FF00CCFF00FFB300FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FFA600FFC000FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FFA600FFD90019FF00FFE600FFCC00FFB300FFA600FFA600FF9900FF9900FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300\
0CFF0000FF000066FF00FF99000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00
FF8C00FF8C00FF9900FFB300FFD900E6FF00FFCC00FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFB300E6FF00FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFB300FFCC008CFF00FFF300FFE600FFCC00FFC000FFB300FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300\
FFCC00FFFF0000000073FF0000F3FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00
FF7F00FF8C00FF9900FFB300F3FF00D9FF00FFF300FFCC00FFD900FFD900FFE600FFCC00FFC000\
FFC000FFCC0080FF00FFC000FFB300FFA600FFA600FF9900FF9900FF9900FFA600
FFA600FFB300FFC000FFF30000FF80CCFF00B3FF00F3FF00FFD90000FF0CFFB300FFA600FFA600\
FFA600FFA600FFB3008CFF00FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300\
FFC000FFD900FFF300C0FF0000FF59000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF8C00FF8C00FFA600FFB300FFC000FFFF0066FF00FFF300C0FF0073FF00FFFF00FFFF00\
FFD900FFE600CCFF00F3FF00FFC000FFB300FFB300FFB300FFA600FFA600FFA600
FFB300FFB300FFC000FFD900FFE600FFFF003FFF00C0FF00F3FF0099FF00FFC000FFB300FFB300\
FFB300FFD90033FF00F3FF0099FF00FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300\
FFCC00FFE600FFFF00E6FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF8C00FF8C00FF9900FFA600FFB300FFB300FFC000FFCC00FFD900F3FF0000FF19C0FF00\
FFFF00CCFF0000FFF3FFFF00FFCC00FFD900A6FF00FFC000FFB300FFB300FFB300
FFB300FFC000FFC000FFCC00FFE6008CFF0059FF0000FF1933FF00CCFF00F3FF00FFC000FFC000\
FFC00000FF40CCFF00FFF300FFCC00FFB300FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000\
FFE60019FF00CCFF00CCFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFA600FFB300FFC000FFCC00FFF3008CFF00B3FF00\
00FF0C3FFF00C0FF00F3FF00FFF300E6FF00FFF300FFCC00FFC000FFC000FFC000
FFC000FFCC00FFCC00FFD900FFF300F3FF00CCFF0073FF0000FFF380FF00FFF300FFD900FFCC00\
FFD90099FF00CCFF00FFF300FFCC00FFB300FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFD900\
59FF0000FF6600FFF300000000FF4C000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFCC00B3FF00FFFF00E6FF00\
B3FF0000FF0080FF0026FF00E6FF0099FF0000CCFFFFF300FFCC00FFCC00FFE600
FFE600FFD900FFD900F3FF00E6FF0066FF0059FF0000FF800000008CFF004C00FFFFF300FFD900\
FFE600FFFF00CCFF00000000FFF300FFD900FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFCC000099FF\
00000000FFD90080FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000FFCC00FFE600FFFF00\
B3FF0019FF00000CFF0CFF0080FF0033FF0000FF66F3FF00FFE600FFE60099FF00
F3FF00FFF300FFF300F3FF00A6FF0033FF0000000000000000000000000000FF00FFFF00FFFF00\
FFF300FFFF00D9FF0026FF00B3FF00CCFF00FFCC00FFC000FFC000FFCC00FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFCC00F3FF00\
00FFB326FF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000FFCC00FFE600C0FF00\
33FF0000FFE600000000E6FF0000008000FF00FF000026FFFFFF00FFFF00E6FF00
0000004CFF0099FF00D9FF00B3FF0000000000000000000000000000000066FF00C0FF00C0FF00\
E6FF0000FF80C0FF0073FF0000A6FF00FF19FFE600FFD900B3FF00C0FF00FFCC00
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFD900\
FFFF00C0FF0000FFFF00FFE6000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000FFD900D9FF0059FF00\
80FF0000FFFF00000000000000000000000000FF8000FF80E6FF00B3FF00CCFF00
000000E600FF26FF003FFF0066FF000000000000000000000000000000004CFF0080FF00000000\
59FF0080FF0000FFFF0073FF00000099FF00FFFF00F3FF00A6FF00FFFF00FFCC00
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFE600\
CC00FFB3FF003300FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFD900FFD900FFE600B3FF0000FF4C\
00000000000000000000000000000000000000000000FF99B3FF0066FF00000000
26FF0000000000000000FFF30000000000000000000000000000000000000000000066FF000000\
00FF5919FF0000000000000000000033FF00D9FF00D9FF00A6FF0000FF00FFE600
FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900000000\
00FFB3000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300CCFF00C0FF00C0FF0000FF4080FF00\
0C00FF00000000000000000000000000000000000000FF333FFF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000059FF008CFF0000000080FF0000FFBFCCFF00
FFD900FFD900FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00F3FF008C00FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFCC00FFF300FFF300F3FF00C0FF00\
00FF2600000000000000000000000000000000000000FF73000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000002600FF26FF0000000000000000E6FF
E6FF0073FF00F3FF00FFCC00FFC000FFC000FFC000FFC000FFC000FFCC00FFD900FFE600D9FF00\
73FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFCC00FFE600FFFF00C0FF00\
66FF0000E6FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000A6FF00
A6FF0019FF00FFF300FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFF30033FF00\
73FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFE600FFFF00D9FF00\
A6FF0059FF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000000000BFFF000000
59FF0000FF80A6FF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFD900FFE600CCFF00000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF9900FFA600FFB300FFA600FFB300FFB300FFC000FFC000FFCC00FFE600FFF300F3FF00D9FF00\
A6FF004CFF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000066FF0026FF00D9FF00FFE600FFD900FFD900FFD900FFD900FFF300CCFF0000FF40\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900
FFA600E6FF00F3FF00FFC000FFC000FFC000FFCC00FFE600FFE600FFF30099FF0099FF0066FF00\
0000000026FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000FFE666FF0033FF00F3FF00FFF300FFE600FFE600FFE600FFE600FFF300E6FF0026FF00\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900
FFA600FFCC0073FF00FFE600FFCC00FFD900FFE60059FF00E6FF00F3FF00CCFF000026FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFCC5900FF000000D9FF00FFF300FFF300FFE600FFF300FFFF0033FF00000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FFA600FFC000FFE6000099FF26FF000073FF59FF0000B3FF99FF00A6FF00A6FF0026FF00000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000009900FF3FFF0080FF00F3FF00FFFF00FFF300FFFF00F3FF00CCFF0019FF00\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FFA600FFB300FFC000FFD900FFF300CCFF0026FF000026FF00FF8C00000033FF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000C0FF00F3FF00FFFF00F3FF00E6FF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFCC00FF9900FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FFA600FFB300FFC000FFCC00FFE600D9FF0000D9FF00FFF3000000000000008CFF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FF3300FFE6E6FF00E6FF00E6FF00D9FF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFA600FFE600FFF300\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFB300FFC000FFCC00FFD900FFFF00D9FF00000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF4000FF40D9FF00D9FF00CCFF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FFA600FFD900FFD900\
FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFB300FFB300FFC000FFCC00FFD900FFF300D9FF0099FF000CFF00000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000066FF00C0FF00CCFF00C0FF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FFC00099FF00FFF300\
E6FF00FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFC000FFE600FFE600FFF3008CFF0099FF0026FF00000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000F300FFA6FF00B3FF00A6FF0000FFCC000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FFA600FFB300FFFF00\
FFE600FFC000FFB300FFA600FFA600FFA600FFB300FFCC00FFC000FFB300FFB300
FFC000FFC000FFD9003FFF0059FF0000FF1900FF33000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000066FF0099FF008CFF0000FFD9000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFB300FFD900\
8CFF00FFCC00FFC000FFB300FFB300FFB300FFC000E6FF00FFF300FFCC00FFC000
FFCC00FFCC00FFD900FFF300D9FF0000FF26000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000080FF0073FF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600FFB300\
FFCC0099FF00FFE600F3FF00FFCC00FFC000FFCC00FFF300FFFF00FFD900FFD900
FFD900FFD900FFE600FFF300E6FF00A6FF000CFF00000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000059FF0059FF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300\
FFC000FFFF004CFF00FFFF00FFD900FFD900FFD900FFF30099FF00FFF300FFE600
CCFF00FFE600FFF300E6FF00B3FF008000FF00CCFF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000CFF0033FF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300\
FFC000FFE60099FF00D9FF00FFFF00A6FF00FFFF00CCFF0066FF00D9FF00F3FF00
CCFF00FFFF00FFFF00E6FF00C0FF0019FF00000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300\
FFCC00FFF300CCFF0073FF0059FF0000D9FF8CFF00B3FF0033FF003300FF80FF00
73FF00CCFF00D9FF00D9FF0066FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF33000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FF7F00FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFC000\
FFCC00FFD900FFFF00CCFF0000FF330000000000FF00FF4000FF7300000000FF40
00000000FFCCA6FF00B3FF0080FF0000A6FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF8C000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF8C00FFA600FF8C00FF7F00
FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFB300FFCC00FFC000FFCC00\
FFCC00FFF300FFFF0099FF000066FF000000000000000000000000000000000000
00000000000000000000FF9959FF00C000FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFF3000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFD900FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF9900FFCC00FFA600FFA600FFA600FFA600FFA600FFB300A6FF0099FF00FFD900\
FFE600F3FF00A6FF0059FF0000FF00000000000000000000000000000000000000
0000000000000000000000FF26FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000059FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFCC00FFA600FF9900
FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FFA600\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FFA6004CFF00FFC000FFB300FFA600FFB300FFB300FFC000FFCC00FFFF00F3FF00\
FFFF00E6FF00B3FF00004CFF000000000000000000000000000000000000000000
00000000000000000000000000FF40000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FFA600FFC000FFC000FFB300
FFA600FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFD900\
FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FFA600FFB300FFE600FFD900FFC000FFC000FFC000FFC000FFCC00FFD900FFFF003FFF00\
C0FF0059FF0080FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF9900D9FF00FFC000FFE60000FF26E6FF00
FFB300FF9900FF9900FF9900FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFB300FFE600\
FFB300FFA600FF9900FF9900FFA600FFA600FF9900FF9900FF9900FFA600FFA600
FFA600FFB300FFC000FFD900FFFF00FFD900FFCC00E6FF00FFD900FFD900CCFF00F3FF00C0FF00\
00FF8C004CFF00FF19000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF6600FF7300FF7300FF7F00
FF7F00FF7F00FF8C00FF8C00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FFA600FF9900\
FF8C00FF9900FF9900FF9900FF9900FFA600FFCC00D9FF0000000000000000FF33
FFC000FFB300FFA600FFA600FFA600FFA600FFA600FFD900FFA600FFB300FFB300FFF300D9FF00\
FFCC00FFB300FFB300FFB300FFC000FFCC00FFB300FFB300FFB300FFB300FFE600
FFCC00FFD900FFD900A6FF0080FF00F3FF00FFF300E6FF00FFFF00FFFF00B3FF00B3FF0000FF33\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF7F00FF8C00FF9900FF9900
FF9900FFA600FFCC00FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFFF00FFC000\
FFC000FFD900FFC000FFC000FFC000FFCC00B3FF00000000000000000000D900FF
FFE600FFD900FFD900E6FF00FFE600FFD900FFCC00D9FF00FFD900FFF300FFD900FFF300000000\
FFF300FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFD900FFF300F3FF00
F3FF00F3FF00D9FF00C0FF00000000A6FF00B3FF008CFF0059FF00A6FF0000FF7300FF2600FFB3\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF6600FF6600FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFC000FFF30000FF0C00000059FF00
FFC000FFA600FFA600FFA600FF9900FF9900FFA600FFC000FFA600FFA600FFA600FFC000D9FF00\
FFC000FFB300FFA600FFA600FFC000FFC000FFA600FFA600FFA600FFB300FFFF00
FFC000FFC000FFCC00FFF300A6FF00D9FF00FFE600F3FF00FFF300FFF300D9FF00D9FF0059FF00\
00FF73000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FFB300FFB300FFD900D9FF00FFD900
FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFB300FFF300\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFB300FFCC00FFE600FFCC00FFCC00FFE600FFCC00FFD900FFE600FFFF00C0FF00\
00FF4C00FF4033FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFC000FFB300FFA600
FF9900FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFCC00\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FFA600FFB300FFD900FFD900FFC000FFB300FFB300FFC000FFC000FFD900FFF3000073FF\
D9FF00A6FF0000FF1900FF4C000000000000000000000000000000000000000000
00000000000000000000000000D9FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFF300FF9900FF8C00
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FFA600FFF300FFC000FFA600FFA600FFA600FFB300FFC000FFCC0026FF00FFF300\
FFF300F3FF0080FF0000FFF300F3FF000000000000000000000000000000000000
00000000000000000000000000FF19000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFC000FF8C00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF9900FFB300FFA600FF9900FF9900FFA600FFA600FFB300FFF300FFE600FFD900\
FFD9004CFF00D9FF00B3FF003FFF000059FF000000000000000000000000000000
00000000000000000026FF003FFF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000099FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FFA600FF7F00FF7F00
FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFB300FFC000FFC000\
FFCC00FFE600FFFF00B3FF0033FF000000000000000019FF000000000000000000
0000000019FF0000008CFF0073FF000099FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFCC000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFB300\
FFCC00FFD900D9FF00B3FF0000000000FF803FFF0000FF4C00FF5900000026FF00
00000000F3FFC0FF00C0FF0099FF0000FF73000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF73000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300\
FFCC00CCFF00A6FF00A6FF00B3FF0066FF0000FF99C0FF0000FF2600FF00B3FF00
00CCFFE6FF00E6FF00D9FF00A6FF0000FFE6000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF26000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300\
FFC000FFE60000FF00CCFF00FFF30080FF00FFF30073FF0000FF73F3FF00FFFF00
A6FF00FFFF00FFFF00F3FF00B3FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000CFF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFB300\
FFC000FFFF004CFF00FFFF00FFD900FFCC00FFD900FFF300E6FF00FFE600FFE600
FFF300FFE600FFE6008CFF00CCFF0000F3FF00FF8C000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000019FF003FFF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600FFC000\
FFE600FFF300FFCC00FFD900FFC000FFC000FFCC00FFF300FFFF00FFD900FFCC00
FFCC00FFD900FFD900FFF300E6FF00A6FF00000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000066FF0066FF005900FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFB300B3FF00\
A6FF00FFCC00FFB300FFB300FFB300FFB300FFB300FFD900F3FF00FFC000FFC000
FFC000FFCC00FFD900FFF300D9FF0000FF99000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000F3FF8CFF0080FF0000FFF3000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FFA600FFC000FFFF00\
FFD900FFB300FFA600FFA600FFA600FFA600FFA600FFC000FFB300FFB300FFB300
FFC000FFC000FFD90000FF99E6FF0033FF0026FF0019FF00000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000080FF00A6FF0099FF0000FF8C000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FFB300FFD900FFE600\
FFC000FFA600FFA600FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300
FFB300FFC000FFCC00FFD900FFE600B3FF00CCFF0073FF0000FF8C000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FF80B3FF00C0FF00B3FF00008CFF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FFA600FFD900FFCC00\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFB300FFB300FFC000FFCC00FFD900FFF300B3FF004CFF0000FFB3000CFF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000080FF00CCFF00CCFF00C0FF0000E6FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFB300FFD900FFC000\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600
FFA600FFB300FFC000FFCC00FFE600E6FF00CCFF000059FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000F300FF0000008CFF00E6FF00E6FF00CCFF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFC000FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FFA600FFB300FFC000FFCC00FFE600CCFF000000006600FF00000000000000FFA6000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FF0073FF00E6FF00F3FF00F3FF00E6FF0080FF0000FFF3\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FFA600FFB300FFCC00FFE600FFFF0099FF0000000000FF4C0CFF0000000066FF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FFF300FFD9E6FF00FFFF00FFFF00FFFF00F3FF0073FF00000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900
FFA600FFD900F3FF0099FF00FFF3003FFF0080FF0026FF00B3FF00C0FF00B3FF0026FF00000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000066FF008CFF00FFFF00FFF300FFF300FFF300F3FF00B3FF0000FF00\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900
FFA600FFCC00CCFF00FFD900FFCC00FFCC00FFE600C0FF00FFFF00FFFF00CCFF008C00FF00FFE6\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF4000FF5900FF73FFFF00FFF300FFE600FFE600FFF300FFFF00CCFF0000FFB3\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900
FFA600FFD900D9FF00FFB300FFB300FFC000FFCC00FFD900FFD900FFF300CCFF00CCFF00B3FF00\
0073FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000080FF000CFF00F3FF00FFE600FFE600FFD900FFE600FFE600FFF300F3FF000026FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFD900FFE600FFFF00E6FF00\
B3FF0073FF0000FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00FFF30000004CFF0080FF00F3FF00FFD900FFD900FFD900FFD900FFD900FFE60000FF0C0040FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00FFE600FFFF00C0FF00\
A6FF0026FF001900FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000000000FF8000FFD9
8CFF0000FF26000000FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFFF003300FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFD900FFE600FFFF00CCFF00\
00FF264C00FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000FFA6000000000000A6FF00
3F00FF0059FFFFF300FFD900FFCC00FFCC00FFC000FFCC00FFCC00FFCC00FFD900FFE600C0FF00\
8CFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFD900E6FF00F3FF0059FF00C0FF00\
00FF0C00000000000000000000000000000000000000FF19000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000006600FF0000000CFF0000000000FF99A600FF
FFFF0000FF73FFE600FFCC00FFC000FFC000FFC000FFC000FFC000FFCC00FFD900FFF30000F3FF\
00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFC000D9FF00F3FF00F3FF003FFF004CFF00\
0000000000000000000000000000000000000000006600FF00FF003FFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000073FF00A6FF00C0FF008CFF00008CFFE6FF00
FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFC000FFC000FFC000FFCC0000FF9900B3FF\
00FFCC0000000073FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFC000FFCC00FFD900F3FF0000E6FF\
3FFF000000000000000000000000000000000000003FFF00C0FF0000FFCC99FF00
33FF000000000019FF00FF6600FF8000000000D9FF00000000000000000000000000B3FF000000\
19FF003FFF000000000000000000003FFF00E6FF00D9FF0073FF00CCFF00FFD900
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFD900FFFF00\
00000073FF0000FFCC000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000FFCC00FFFF00E6FF00\
99FF0000FF0C00000000000000000000000000FF1966FF00E6FF00E6FF00D9FF00
004CFF7300FF00FF0066FF0099FF0033FF0000000000000000000000000073FF0099FF000066FF\
B3FF006600FF0000000000000040FF0CFF00FFF300F3FF00A6FF00E6FF00FFCC00
FFC000FFB300FFB300FFB300FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFCC00FFE600\
C0FF00C0FF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000FFCC00FFE60000FFF3\
59FF00D900FF0000000073FF3300FF00FF5900BFFFD9FF00FFF300FFF300E6FF00
00FFFFB3FF00D9FF00E6FF00C0FF0000FF9900000000000000000000000073FF00D9FF00A6FF00\
F3FF00D9FF00CCFF0059FF0000FF738CFF00FFD900FFCC00C0FF0000FFFFFFC000
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFE600\
F3FF00B3FF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000FFD900FFE600FFFF00\
CCFF0033FF0000FFFF00FF33A6FF004C00FF00D9FFFFFF00FFD900FFD900C0FF00
FFFF00FFE600FFE600F3FF004CFF0000FF5900000000000000000019FF004CFF00FFFF00FFF300\
FFF300FFFF00D9FF0066FF00D9FF00FFFF00FFC000FFC000FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFCC003FFF00\
0026FF00FFBF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFB300FFB300FFCC0080FF00E6FF00D9FF00\
99FF0000FFCC99FF00A6FF00F3FF00D9FF00D9FF00FFD900FFCC00FFCC00FFD900
FFD900FFCC00FFD90066FF00FFFF00CCFF0099FF000000000099FF99FF0066FF00FFE600FFD900\
FFE600E6FF008CFF0026FF00FFD900FFC000FFB300FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFD9008CFF00\
00000000FF5900FF73000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFA600FFB300FFC000FFCC00FFF3000C00FF66FF00\
73FF004CFF004CFF00FFFF00FFE600E6FF00FFF300FFCC00FFC000FFB300FFC000
FFC000FFC000FFCC00FFD900FFE600FFFF00C0FF0000FF19000000000000FFF300FFCC00FFCC00\
FFCC0000FF00E6FF00FFE600FFCC00FFB300FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFCC00\
8CFF0000000099FF0073FF0000FF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF8C00FF8C00FF9900FFA600FFB300FFC000FFCC00FFCC00FFFF00D9FF0000FF99E6FF00\
FFF300A6FF0000FF0C73FF00FFCC00FFCC00FFF300FFC000FFB300FFB300FFB300
FFB300FFC000FFC000FFCC00FFE600F3FF000CFF0000E6FF73FF00E6FF00F3FF00FFC000FFB300\
FFC000FFF300A6FF00D9FF00FFCC00FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000\
FFE6008CFF00CCFF00D9FF0000000000FF99000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF8C00FF9900FFCC00FFC000FFD90099FF00FFFF00D9FF00A6FF00CCFF00FFF30019FF00\
FFCC00FFD900C0FF00D9FF00FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFB300FFC000FFD900FFF300F3FF0000FF1959FF00FFFF00FFE600FFB300FFB300FFA600\
FFA600FFC000FFCC00F3FF00FFC000FFA600FF9900FF9900FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFC000FFD900FFF300E6FF00A6FF0019FF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00
FF7F00FF8C00FF9900FFB300E6FF00D9FF00E6FF00FFCC00FFCC00FFCC00FFD900FFC000FFB300\
FFB300FFCC00FFF300FFC000FFA600FFA600FF9900FF9900FF9900FF9900FFA600
FFA600FFB300FFCC00E6FF00C0FF003FFF00F3FF00FFD900FFCC00D9FF00FFA600FFA600FF9900\
FF9900FFA600FFA600FFD900FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300\
FFC000FFD900FFFF00CCFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00
FF8C00FF9900FF9900FFB300FFE600FFF300FFC000FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFB300C0FF00FFB300FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFB300FFE60000FF8CFFF300FFD900FFC000FFB300FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFB300\
FFCC0000FF6633FF0073FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00
FF8C00FFA600FFB300FFCC00C0FF0066FF00FFB300FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FFA600FFCC0073FF00FFE600FFCC00FFB300FFA600FF9900FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300\
33FF0066FF0000000000FFF3000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00
FFA600FFC000E6FF00E6FF00FFE600FFC000FFA600FFA600FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FFA600FFE600CCFF00FFFF00FFCC00FFB300FFA600FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFC000\
D9FF000000000066FF19FF0000000000FF7300FF804CFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00
FF8C00FF9900FFA600FFCC00FFFF00FFB300FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF9900FFB300F3FF00FFF300D9FF00FFCC00FF9900FF8C00FF8C00FF8C00FF8C00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFB300\
66FF00FFE60000FF1900FF19B3FF0000FF730000FFB3FF0026FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00
FF7F00FF8C00FF9900FFE600FFE600FFC000FFA600FF9900FF8C00FF8C00FF8C00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF9900FFA600FFC00033FF00D9FF00FF9900FF8C00FF8C00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFA600\
FFA600FFB300FFD90073FF00CCFF00FFFF00FFFF0000FF669900FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00
FF7F00FF8C00FF9900C0FF00000000FFE600FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF9900F3FF00FFB300FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FFA600FFA600FFC000E6FF0000FF99FFE600FFF30099FF0000FF7366FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00
FF7F00FF8C00FF9900FFB300FFF300FFB300FF9900FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FFE600FF9900FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FFA600FFB300FFC000FFCC00FFCC00FFD900FFF300E6FF00B3FF003FFF00
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00
FF7F00FF8C00FF9900FFB300F3FF00FFB300FF9900FF8C00FF7F00FF7F00FF7F00FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FFA600FFB300FFC000FFCC00FFD900FFFF00CCFF00000000000000
C000FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00
FF8C00FF9900FFB300E6FF00FFB300FFD900FF9900FF7F00FF7F00FF7F00FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF9900FF9900FFA600FFA600FFB300FFCC00FFD90000FF1900E6FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF7300FF7F00
FF9900D9FF00FFA600FFB300FF8C00FF8C00FF8C00FF7F00FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF9900FFA600FFB300FFC000FFD900FFF30000FF8019FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF7300FF7F00
FF8C00FFC000FF8C00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF9900FFA600FFB300FFCC004CFF00E6FF00B3FF0000FF0C000000000000
0000000000000000003F00FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF7300FF7300
FFC000FF8C00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF9900FFA600C0FF00FFF30000FF40A6FF00000000000000000000000000
0000000000000000003FFF00000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF9900FFA60073FF0000FF8099FF003FFF0000E6FF0000000000003F00FF
00000000000000FF99A6FF00000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF9900FFB300FFD900F3FF0066FF0000E6FF4CFF0000FF4C00CCFF80FF00
00FF4059FF00CCFF00D9FF0000000000FF0C000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF8C00FF99008CFF008CFF00D9FF0080FF0000000000FF66B3FF00E6FF00D9FF00
00FF26E6FF00FFFF00FFFF00CCFF000059FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF8C00FF9900FFCC00D9FF00FFCC00FFD90000FF5900FF8C6600FFF3FF00FFE600
FFE600FFD900FFD900FFF30000FF73A600FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF8C00FF9900FFA600FFA600FFA600FFC000FFE60000FFBFF3FF00FFD900
FFCC00FFCC00FFCC00FFF30000FF190C00FF00FF0000FFE6000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600F3FF0000FF408CFF00FFCC00
FFC000FFC000FFC000FFE60099FF00000000000000D9FF00000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFCC0000FFBFFFFF00FFFF0000FF804CFF000000003F00FF000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600
FFA600FFA600FFB300FFB300FFC000FFCC00FFD900FFE600FFFF00D9FF00A6FF0000FFF3000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FFA600FFA600FFB300FFC000FFCC00FFD900FFE600F3FF00B3FF0073FF0000FF33000000\
00FFFF000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FFA600FFB300FFC000FFCC00FFD900F3FF0000FF0026FF00000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF9900FF9900FFA600FFB300FFC00000FF33FFFF00B3FF0019FF00000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF9900FF9900FFA600FFB300FFE600CCFF00B3FF0000FF6600FF33000000000000000000000000\
00000000000000000000000000FF73000000000000000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF9900FFA600FFB300FFFF0066FF0000FF4000FF4C000000000000000000000000000000\
0000000000000000000000000000003FFF0000FFF3000000000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF9900FFA600FFB300FFCC00A6FF0000FFE600CCFF000000000000000000000000000000\
000000000000000000000000CC00FF99FF0000000000FF00000000000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF9900FFA600FFB300FFD900CCFF00B3FF00C0FF00000000000000000000000000000000\
00000000000000000000000000FFE64C00FFCCFF003300FF00FF59000000000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00
FF9900FF9900FFA600FFB300FFC000FFD900FFF300D9FF0073FF0000FFF3000000000000000000\
00000000000000000000000000FFF3D9FF00F3FF00F3FF00CCFF000066FF000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00
FF9900FFA600FFB300FFC000FFCC00FFD90066FF0000FF8C00FF0C000000000000000000000000\
000000000000E600FF00FF8C000000E6FF00FFF300FFF30000000000D9FF000000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00
FFB300FFD900FFD900FFD900FFD900FFE600F3FF000019FF8C00FF00000000000000FF8C1900FF\
0099FF0066FF000000A6FF007300FFFFE600FFD900FFD900F3FF00004CFF80FF00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00
FFC00073FF004CFF0066FF00D9FF00FFF300F3FF00B3FF0000FF000000000073FF0CFF0000FFF3\
0033FF80FF0000A6FFB3FF00FFFF00FFD900FFCC00FFCC00FFCC00FFD900FFF300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00
FF9900A6FF00FFE600C0FF00B3FF0059FF00D9FF0000FF2600FF4C80FF003FFF0000FF26E6FF00\
E6FF00000CFF00FFF300FF0C00BFFFFFCC00FFC000FFC000FFC000FFCC00FFD900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00
FF9900FFB300FFC000FFD900E6FF0000FF198CFF0000FF4C00FF40D9FF00A6FF00FFFF00FFE600\
FFFF008CFF008CFF00FFFF00FFC000FFB300FFB300FFB300FFB300FFC000FFCC00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00
FF9900FFA600FFB300FFCC00FFF300D9FF004CFF000CFF00C0FF00F3FF00FFF300FFD900FFCC00\
FFCC00FFCC00E6FF00FFC000FFB300FFA600FFA600FFA600FFA600FFB300FFD900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF8C00
FF9900FFA600FFC000FFFF0080FF0059FF00C0FF00CCFF0000A6FF99FF00FFF300FFD900FFC000\
FFB300FFB300FFB300FFA600FFA600FFA600FF9900FFA600FFA600FFA600FFC000
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF8C00
FFA600FFB300FFF30000FFA633FF00FFD90000FF26FFFF00FFFF0000FFE6A6FF00FFF300FFC000\
FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFB300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF9900
FFD900FFF300E6FF00A6FF00FFB300FFC000CCFF00FFD900FFCC00FFFF000CFF0033FF00FFC000\
FFA600FF9900FF9900FF9900FF9900FF8C00FF8C00FF9900FF9900FF9900FFA600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FFE600
59FF00D9FF00FFCC00FFA600FF9900FFA600FFE600FFB300FFA600FFC000FFF300F3FF00FFCC00\
FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00
FF9900FFA600CCFF00FF9900FF8C00FF8C00FF8C00FF9900FF9900FFD900FFFF00D9FF00F3FF00\
FFA600FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF8C00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFCC00FFB300FF9900\
FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FF8C00FF8C00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFB300FFB300FFD900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFB300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FF9900FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FF9900FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFA600FFB300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFD900FFE600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FFA60080FF0000FF26
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FFC000F3FF00D9FF00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FFA600FFB300FFFF00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FFB300FFE600FFCC008CFF00FFB300FFB300FFB300FFB300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FFA600FFE60026FF0080FF00D9FF00FFCC00FFC000FFC000FFC000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600\
FFA600FFB300FFC000FFD900CCFF0000FFD9FFF300FFD900FFCC00FFCC00FFCC00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FFB300FFFF00FFCC00\
FFC000FFD900A6FF00F3FF0000FF2680FF00FFF300FFE600FFD900FFD900FFD900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FFB300F3FF00B3FF00FFF300\
FFF300CCFF0000FF1999FF003FFF00C0FF00F3FF00F3FF00B3FF00FFF300FFF300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FFA600FFC000FFE600B3FF00\
00FF0059FF0000FF33008CFF99FF00C0FF00D9FF0000FF6600E6FF0026FF19FF00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFB300FFD900FFFF00\
A6FF0000B3FF00D9FF00FF0C66FF0000FFB30033FF66FF0000FF6600FFA6A6FF00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFB300CCFF0059FF00\
A6FF0000FF0C4CFF0000000000000000000000B3FF000000A600FF00000000FFE6
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF7300FF7F00FFB300FF8C00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFB300CCFF00FFF300\
F3FF0000FF4C99FF003FFF00000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7F00FF9900D9FF00FF9900FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFCC00\
19FF000073FFCCFF0059FF0000FF260099FF000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7F00FF8C00FFC000FFA600FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFC000\
33FF00F3FF00F3FF00C0FF0073FF00000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7F00FF8C00FFC000FFC000FFCC00FFCC00FF9900FF9900FFA600FF8C00FF7F00\
FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300\
FFCC00FFD900FFF30066FF000019FF000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7F00FF8C00FF9900FFA600FFC000FFFF00FFB300FFD900FFB300FF8C00FF7F00\
FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300\
FFC000FFCC00FFE6000040FF00FFD900CCFF000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFCC00F3FF00FFD900FFA600FF8C00FF8C00\
FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFB300\
FFC000FFCC00FFD900F3FF000000000000000000000C00FF7300FF0080FF000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7F00FF7F00FF8C00FF8C00FFA600FFB300F3FF00FFC000FFA600FF8C00FF8C00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFC000\
FFC000FFCC00FFD900FFF300F3FF00D9FF00A6FF0059FF00000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7F00FF7F00FF8C00FF8C00FFA600FFC000FFF300FFCC00FFA600FF9900FF8C00\
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FFB300FFC000FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000FFD900\
FFD900FFD900FFE600FFF30059FF00B3FF0000000000FF66000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFE600000000FFFF00FFC000FF9900FF8C00\
FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF9900FFFF00FFD900FFA600FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFD90000D9FF000000\
E6FF00FFE600FFF3000C00FF00A6FF00FFCC00FF00000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600A6FF00FFF300FFCC00FFA600FF9900FF9900\
FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900\
FFA600FFC000FFE600FFD900FFE600FF9900FF8C00FF8C00FF8C00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000FFE60080FF00000CFF\
F3FF00FFFF00F3FF00B3FF00000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7F00FF7F00FF8C00FF8C00FF9900FFB300FFCC00F3FF00FFC000FFA600FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFA600\
FFCC00FFCC00FFFF00E6FF00FFB300FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFC000FFCC00FFE60099FF0000FF9900FFD9\
CCFF0066FF00A6FF00C0FF0059FF00000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7F00FF7F00FF8C00FFA600FFB300FFD900FFE600FFFF00FFC000FFB300FFA600FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFC000C0FF00\
CCFF00A6FF00D9FF00FFCC00FFB300FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FFA600FFCC00000000D9FF0000FF990000000073FF73FF00\
00000000F3FF26FF008CFF00000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7F00FF7F00FFB300FFD900CCFF00FFCC00FFE600FFF300FFCC00FFC000FFA600FFA600\
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFB300FFD900\
B3FF00FFF300FFCC00FFC000FFB300FFA600FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFD900CCFF000000003F00FFCC00FF000000\
00FFB300000000000000FF26000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7F00FF7F00FF8C00FF9900FFA600FFB300FFCC008CFF00CCFF00FFCC00FFB300FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFCC00FFA600
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300F3FF00\
3FFF00FFE600FFCC00FFC000FFB300FFA600FFA600FF9900FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FFA600FFB300FFFF00C0FF000000FF00000000FF26000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300FFD90000FF26FFCC00FFC000FFB300\
FFB300FFA600FFA600FFB300FFA600FFA600FFA600FFA600FFCC00D9FF00FFC000
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFC000FFF300\
73FF00FFF300FFD900FFCC00FFC000FFB300FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFE600D9FF00C000FF80FF00000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFB300FFE60073FF00FFF300FFCC00FFC000\
FFC000FFC000FFC0004CFF00FFC000FFB300FFB300FFB300FFF300FFE600FFC000
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFD900\
66FF00E6FF0066FF0099FF0099FF00FFCC00FFC000FFC000FFB300FFA600FF9900
FF9900FF9900FF9900FF9900FFA600FFB300FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFCC00FFE600F3FF00B3FF000073FF\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFE600FFF300FFD900D9FF00FFF300FFD900\
D9FF00A6FF00FFF300CCFF00FFD900FFCC00FFC000FFC000FFD90099FF00FFCC00
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFCC00\
FFE600F3FF00F3FF0073FF0000FF33FFF300FFE600F3FF00FFC000FFB300FFA600
FFA600FFA600FFA600FFB300FFB300B3FF00FFC000FFA600FF9900FF9900FF9900FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFCC00FFD900FFF300E6FF00000000\
33FF00000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300FFC000FFF300E6FF00D9FF00\
FFE600FFFF00CCFF008CFF00F3FF00F3FF00FFD900FFE600FFF300C0FF00F3FF00
FFC000FFC000FFB300FFC000FFB300FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00\
FFD900FFE600FFF300E6FF0000FF00CCFF00E6FF0000FF19FFCC00FFC000FFB300
FFB300FFB300FFB300C0FF00A6FF00F3FF00D9FF00FFB300FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFD900FFF300FFFF00E6FF00C0FF00\
66FF007300FF000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFA600FFB300FFC000FFC000\
FFCC00FFD900FFF30080FF0000FF0C00FFBFF3FF00F3FF0000FFCC00FFD9F3FF00
FFD900FFCC00FFF300C0FF00FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFCC00\
FFD900FFE600FFF300B3FF0066FF0000FFCC73FF00B3FF003FFF00FFD900FFC000
FFC000FFC000FFD90066FF00D9FF00FFFF00FFD900FFB300FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFCC0000FF6673FF00CCFF00CCFF00000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFB300\
FFC000FFCC00FFD900F3FF000080FF80FF0066FF00C0FF0000CCFF8CFF00FFFF00
FFE600FFE60080FF00FFF300FFCC00FFC000FFC000FFB300FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFE600FFFF00D9FF00B3FF0026FF0000FFB300FF8C00FF19FFE600FFCC00
FFCC00FFCC00FFE60026FF00E6FF00FFF300FFCC00FFC000FFB300FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFB300FFC000FFCC00FFE600B3FF0000000000BFFF80FF0066FF00\
0066FF000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300\
FFB300FFC000FFF300E6FF00D9FF00D9FF000CFF0000FF7300FF73B3FF0000FFFF
F3FF00FFFF00C0FF00E6FF00FFD900FFCC00FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900\
FFF300FFFF00F3FF00C0FF003FFF0000FFD99900FF26FF00CCFF0000FF00FFD900
FFD900FFD900FFF3004CFF0080FF0026FF0000FF33FFCC00FFC000FFB300FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFB300FFB300FFD90026FF0026FF0000FF5919FF0000000000000000FF19\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600\
FFB300FFC000FFD900FFF300FFF300F3FF00D9FF0099FF003F00FF0CFF0000FF80
CCFF00B3FF0000FF0CD9FF0026FF00FFD900FFCC00FFD900F3FF00FFFF00FFD900FFD900FFE600\
00FF59CCFF008CFF0000A6FF00FF80A600FF00000019FF0026FF00D9FF00FFF300
FFE600FFE600FFF300F3FF00D9FF0000FFB373FF0080FF00FFD900FFC000FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFC000FFCC00A6FF0000FF99000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600\
FFB300FFC000FFCC00FFD900FFE600FFFF00D9FF0059FF00000000B300FF00FF26
59FF008CFF00008CFF19FF00F3FF00FFE600FFE600FFE60000FFCCF3FF00FFFF00FFF300FFF300\
E6FF00B3FF0000000000000000000000000000000000000000FFFFC0FF00F3FF00
F3FF00FFF300FFFF00F3FF00D9FF0000FF4019FF0099FF00FFE600FFCC00FFC000FFC000FFC000\
80FF00FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFC000FFCC00FFF30080FF0000FFBF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600\
FFB300FFC000FFC000FFD900FFE600E6FF0000CCFF0CFF00000000000000000000
00FFA600FF4000000033FF00B3FF00E6FF00FFF300FFFF00E6FF0073FF0080FF008CFF00E6FF00\
D9FF00C0FF0073FF0000000000000000000000000000000000FFF3A6FF00C0FF00
B3FF00E6FF00E6FF00CCFF00C0FF0073FF0000FF6600FF80D9FF00FFD900FFD900FFFF0073FF00\
19FF00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFC000FFCC00FFD900FFF300D9FF0066FF0000FF730080FF000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600\
FFB300FFC000FFCC00FFD900FFFF00E6FF00B3FF0059FF0000FF8C000000000000
0000000000000000000CFF0033FF00D9FF00F3FF00E6FF00D9FF0000FF0C0000006600FF99FF00\
80FF0099FF0066FF0000000000000000000000000000000000FF594CFF0099FF00
00FF1980FF00B3FF0026FF000059FF00FF267300FF00FF00CCFF00FFF300FFFF0073FF00D9FF00\
F3FF00FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFCC00FFD900E6FF00C0FF00B3FF0000FF26000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300\
FFC000FFCC00FFCC00FFE600E6FF0000FF7373FF0000FF99000000000000000000
0000000000000000000000004CFF00C0FF00C0FF00B3FF00B3FF0073FF0000E6FF00000000FF00\
0000000C00FF00000000FF5900000000000000000000000000FF3300FF6600FF4C
008CFF00FF9959FF003FFF0000000000000000000000FF26C0FF00F3FF00E6FF003300FF00FFF3\
FFF300FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFCC00FFD900FFF3000040FF80FF0080FF000040FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFC000\
FFE600FFF300FFE600CCFF008CFF0000FF1900FF8C0000FF000000000000000000
00000000000000000000000000000099FF0099FF000000000C00FF0CFF00000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000080FF00000000FF33000000000000000000000000A6FF00CCFF00D9FF00B3FF0073FF00\
B3FF00F3FF00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFCC00FFF3005900FF00000000000000B3FF00A6FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFC000\
FFD90000FF8CC0FF00A6FF0000FF0C99FF0000FF4C000000000000000000000000
00000000000000000000000000FF194CFF0000000000FF73000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FF004CFF0000D9FF8CFF0099FF0000FF0C\
00FF0033FF00FFE600FFD900FFD900FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFD900CCFF000026FF0C00FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300\
FFCC00FFE600FFF300FFFF00E6FF00CCFF0019FF0000F3FF000000000000000000
00000000000000000000000000FF4C000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000099FF33FF006600FF00E6FF\
000000B3FF00F3FF0000FF198CFF00FFD900FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFD900FFF300C0FF000000007300FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFB300\
FFC000FFCC00FFD900FFE600FFFF00D9FF00000000000000000000000000000000
0000000000000000000000FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00FFD9B3FF00B3FF0000FF19F3FF00FFE600FFCC00FFCC00FFCC00FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFD900FFF300D9FF008CFF004CFF00000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300\
FFC000FFCC00FFD900FFE600F3FF000099FFB3FF004CFF0000FFD9000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00FF000099FF99FF0066FF000073FFFFF300FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFE600FFFF00008CFF0CFF0000FF33000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFC000\
FFC000FFCC00FFD900FFE600FFFF00E6FF00CCFF008CFF0000FF1900FF2600FFB3
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000002600FF00FF0000F3FFF3FF00FFF300FFF300FFD900FFD900FFCC00
FFCC00FFD900FFD900FFD900FFF3003FFF00000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF9900FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFCC00\
FFCC00FFD900FFFF00FFFF00F3FF00D9FF00A6FF0080FF0000FF73000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000FF4CB3FF004CFF00004CFFFFE600FFD900FFD900
FFD900FFD900FFD900FFE600FFF300CCFF00000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF9900FFA60066FF00F3FF00FFCC00FFC000FFC000FFC000FFC000FFE600FFE600\
FFD900FFE600CCFF00CCFF00A6FF008CFF0059FF000000000000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000FF1973FF0026FF00E6FF00FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFF300E6FF000CFF0000FF8C000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF9900FFA600FFB300FFFF00E6FF00FFD900FFCC00FFCC00FFD900FFF300D9FF00\
E6FF00FFFF00F3FF00A6FF000026FF00FF9900FF4C000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000FFA600FF8026FF00F3FF00FFF300FFE600
FFE600FFE600FFE600FFF300FFFF00A6FF0000FFBF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FFA600FFC000FFFF00A6FF00E6FF00FFE600FFF300FFFF00E6FF0033FF00\
C0FF0000FF19D9FF008CFF0000FF59000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000073FF0019FF00E6FF00FFF300
FFF300FFF300FFF300FFFF00F3FF0000FFBF00FF99000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FFA600FFB300FFC00000FF0C3FFF00E6FF0026FF0000FFE60099FF000000\
73FF00A600FF80FF004CFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000019FF0000FF19D9FF00F3FF00
FFFF00FFFF00FFFF00FFFF00E6FF0099FF0000FF00000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FFA600FFB300FFB300FFC000FFD900FFE600E6FF0099FF0000D9FF0000FF\
00E6FF00000000000000FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000A6FF0000FF00
F3FF00FFFF00F3FF00F3FF00D9FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFB300FFA600FF9900FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFCC00FFD900FFFF0000B3FF33FF000C00FF\
0000000000000000000059FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000FFE600FF0CC0FF00
E6FF00F3FF00F3FF00E6FF00D9FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFD900FFC000FFB300\
FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00FFD900D9FF00D9FF008CFF00000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000000000000073FF00
B3FF00D9FF00E6FF00D9FF00C0FF00A600FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFC000FFFF00FFE600\
FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFD900FFF300F3FF004CFF00000000\
B300FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000000000000000FF4C
B3FF00CCFF00D9FF00CCFF00C0FF0000FFBF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FFB300FFE600FFE600\
FFC000FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFD900FFE600FFF300F3FF00CCFF008CFF00\
00FF19000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000B3FF00C0FF00C0FF0099FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900CCFF00E6FF00F3FF00\
FFE600FFC000FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFC000FFCC00FFF300FFF300FFF300F3FF0073FF0099FF0000FFCC\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000099FF00B3FF00B3FF0099FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFC000FFE600\
F3FF00FFCC00FFB300FFB300FFA600FFA600FFA600FFA600FFB300FFC000FFC000
FFC000FFB300FFB300FFC000FFC000FFCC00FFFF0000FF99CCFF008CFF0000000000000000FF26\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000FFD999FF0099FF0080FF0000FFBF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300CCFF00\
66FF00FFF300FFC000FFB300FFB300FFB300FFB300FFB300FFC000FFD900A6FF00
FFCC00FFC000FFC000FFC000FFCC00FFCC00FFE600FFFF00D9FF0000FFCC00CCFF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000FFE680FF008CFF0066FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFC000\
E6FF0019FF00FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFE60000FF0C
FFD900FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFF300F3FF00B3FF004CFF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000059FF0073FF004CFF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300\
FFC000FFD900A6FF00FFF30033FF00FFD900FFCC00FFCC00FFCC00FFE6003FFF00
FFE600FFD900FFD900FFD900FFD900FFE600FFE600FFFF00E6FF0099FF004CFF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000F300FF59FF0033FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300\
FFC000FFCC00FFFF0000FF0CF3FF00FFE600FFD900FFD900FFE600FFF30000FF19
D9FF00FFF300FFF30000FF0CFFF300FFF300FFF30073FF0099FF000000000026FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000033FF0019FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300\
FFC000FFCC00FFF3004CFF00CCFF00FFFF00FFFF00F3FF00FFFF00D9FF00000000
C0FF00E6FF00F3FF008CFF00FFFF00FFFF00FFFF00E6FF00C0FF0000FF26000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF0000FF19000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300\
FFC000F3FF00D9FF0099FF0099FF00B3FF00C0FF00C0FF00B3FF00CCFF002600FF
00FFF3A6FF00A6FF0000FF80D9FF00C0FF00E6FF00D9FF00A6FF0000FF8C00E6FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF3300FF66000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFB300\
FFC000FFD900FFE60080FF0000FF003FFF0000FF9900FF2673FF0066FF0026FF00
00A6FF00FFB34CFF00000000A6FF0099FF00CCFF00C0FF0099FF00000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000D900FF00FF80000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FFC000FF7F00\
FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000\
FFC000FFD900FFE600FFFF00D9FF008CFF0000B3FF0000000073FF00FF5900FFE6
0000000019FF00000000000000FF1933FF000099FFA6FF003FFF00000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000F3FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF8C00FFCC00FF8C00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFC000FFCC00FFCC00FFCC00\
FFCC00FFE600FFFF00F3FF00C0FF0000F3FF00B3FF000000000000000000000000
00000000000000000000000000000000BFFF00FF2659FF004CFF00000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000D9FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFB300FF9900\
FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900
FFA600FFC000FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFC00000FF0CFFF300FFD900\
FFD900FFF300A6FF00B3FF0059FF0000FF2600FFCC000000000000000000000000
00000000000000000000000000000000000000000000FF0C33FF00000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000059FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFB300FFA600\
FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FFA600FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FFB300F3FF00FFC000FFB300FFA600FFA600FFA600FFB300FFB300FFC000FFE60000FF40FFF300\
FFF300FFFF00E6FF0073FF00008CFF000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FF19000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFB300FFC000\
FFA600FF9900FF9900FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFD900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600
FFB300FFE600FFE600FFC000FFB300FFB300FFB300FFB300FFC000FFCC00FFD900FFF30000FF66\
D9FF00CCFF00CCFF008CFF0019FF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FF9900FFA600FFC000FFF300\
FFFF00FFC000FFB300FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FFC000FFFF00FFC000FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFB300FFD900FFF300FFCC00FFC000FFC000FFCC00FFC000FFCC00FFD900FFE600FFFF00B3FF00\
8CFF00A6FF0066FF0066FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600F3FF00FFC000FFF300C0FF00\
C0FF00FFE600FFB300FFA600FF9900FF9900FF9900FF9900FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFB300CCFF00FFC000FFA600FFA600FF9900FF9900FFA600\
FFCC00FFA600FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFB300FFB300
FFC000FFD900D9FF00FFD900FFCC00FFD9000CFF00FFD900FFD900FFF300FFFF00F3FF00C0FF00\
00FF7300FFE60C00FF00FFBF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFCC0073FF0099FF00000000\
0000008CFF00FFCC00FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFC000FFA600FFA600FFA600FFB300FFD900E6FF00FFE600FFB300FFB300FFB300FFB300FFB300\
F3FF00FFC000FFB300FFB300FFB300FFB300FFB300FFFF00FFCC00FFCC00FFE600
FFD900E6FF0000FF19B3FF00FFF300FFF300E6FF00FFFF00FFFF00FFFF0000FF59C0FF0000FF19\
00FF19000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF6600FF7300FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFF300\
FFA600FFA600FFA600FFB300FFB300FFA600FFB300FFB300FFB300FFC000FFD900
FFCC00FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFD900B3FF00000000000000000000\
00000080FF00FFF300F3FF00FFD900FFCC00FFF300FFD900FFCC00FFCC00FFD900
F3FF00FFD900FFF300FFD900FFE600FFFF00000000F3FF00CCFF00FFE600FFF300FFF300FFF300\
99FF00FFF300FFE600FFF300FFE600FFF300FFFF00A6FF00F3FF00F3FF00A6FF00
CCFF00A6FF0000000080FF00C0FF008CFF0000FF0099FF0099FF0000FF1900FF1900FF1900BFFF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF6600FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FFA600\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFC000FFE60033FF0059FF00000000\
00000019FF00FFCC00FFB300FFB300FFB300FFC000FFA600FFA600FFA600FFB300
FFFF00FFB300FFB300FFB300FFC000FFFF00D9FF00E6FF00FFC000FFC000FFC000FFC000FFC000\
A6FF00FFC000FFC000FFC000FFB300FFC000FFC000FFF300FFD900FFD900CCFF00
FFE600CCFF0080FF00C0FF00FFFF00F3FF00B3FF00F3FF00E6FF00D9FF0059FF0019FF0000FF00\
00FFCC000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFCC00FFD900E6FF0080FF00\
33FF00E6FF00FFC000FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FF9900FF9900FFA600FFA600FFC00080FF00FFC000FFB300FFA600FFA600FFA600FFA600\
FFE600FFA600FFA600FFA600FFA600FFA600FFA60080FF00FFB300FFB300FFC000
FFCC00FFE6008CFF00FFF300FFD900FFD90073FF00FFE600FFE600FFF300E6FF00D9FF00A6FF00\
3FFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFB300FFB300FFC000FFFF00\
FFE600FFD900FFB300FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FFB300E6FF00FFB300FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300
FFC000FFD900FFF300FFCC00FFC000FFCC00E6FF00FFCC00FFCC00FFD900FFE600FFFF00CCFF00\
00000033FF0033FF003FFF00B300FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FF9900FFB300FFCC00\
FFA600FFA600FFA600FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFF300FFA600FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600
FFB300FFF300FFE600FFC000FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFFF0066FF00\
B3FF00CCFF00B3FF0066FF0000FF59000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFB300FFB300\
FF9900FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFC000FF9900FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600
FFB30066FF00FFCC00FFB300FFB300FFA600FFB300FFB300FFB300FFC000FFD900F3FF00E6FF00\
F3FF00F3FF00D9FF00A6FF00000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FF4CCC00FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FFB300FFA600\
FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FFA600F3FF00FFB300FFA600FFA600FFA600FFA600FFA600FFB300FFC000FFFF00FFFF00FFE600\
FFE600FFF300E6FF0000FF808CFF0026FF000099FF000000000000000000000000
00000000000000000000000000000000000000000000000019FF000000FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000019FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFC000FF9900\
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF9900FFA600FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFC000FFF300FFCC00FFCC00\
FFD900FFF300E6FF00E6FF00C0FF0066FF003F00FF000000000000000000000000
00000000000000000000000000000000000000000059FF0059FF00000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000A6FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF8C00FFD900FF8C00\
FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFB300FFB300FFC000FFC000\
FFCC00FFD900FFE600FFFF00C0FF0080FF0000FFE60000001900FF0000FF000000
00000000000000000000000000FF8C0073FF00FF2699FF0080FF0000FFD9000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FFF3000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FF7F00\
FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFB300\
FFC000FFCC00FFE600F3FF00C0FF0000FF0C00FFB300FF4C00FFD90080FF00FF00
00000000000019FF008C00FF73FF0059FF00C0FF00C0FF0099FF0000FFBF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF99000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300\
FFC000FFE600FFFF00B3FF000CFF0066FF008CFF008CFF00A6FF00B3FF0066FF00
0000000059FF0CFF000CFF00CCFF0000FF19D9FF00CCFF0000F3FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF59000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300\
FFC000FFD900FFFF0080FF00C0FF00F3FF00F3FF00E6FF00F3FF00D9FF0000FF73
A6FF008CFF00E6FF00B3FF00F3FF00F3FF00F3FF00E6FF00C0FF0073FF0000FFBF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF0C00FF26000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300\
FFC000FFCC00FFF30099FF00CCFF00FFF300FFE600FFF300FFE600F3FF00A6FF00
B3FF00FFFF00FFFF0059FF00FFF300FFF300FFFF00E6FF00A6FF00000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000026FF0000FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300\
FFC000FFD900B3FF00CCFF00E6FF00FFD900FFCC00FFCC00FFD900FFE6008CFF00
FFF300FFE600FFE600FFF300FFE600FFE600FFF300E6FF00D9FF0073FF0000FF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000006600FF4CFF0026FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300\
FFCC00FFFF00FFF300FFD900FFD900FFCC00FFC000FFC000FFCC00FFE600CCFF00
FFE600FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300F3FF00C0FF008000FF00FF8C000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000033FF0066FF004CFF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300FFD900\
FFFF00FFF300FFCC00FFC000FFB300FFB300FFB300FFB300FFC00066FF00D9FF00
FFCC00FFCC00FFC000FFC000FFCC00FFD900FFE600FFF300E6FF0000FF4000FF4C000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000073FF0080FF0066FF008C00FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300FFE600\
F3FF00FFCC00FFC000FFB300FFB300FFA600FFA600FFB300FFB300FFC000FFD900
FFC000FFC000FFC000FFC000FFC000FFCC00FFE600CCFF0000FF4C00FF19004CFF00A6FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000FF338CFF0099FF0080FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFE600FFD90000FF0C\
D9FF00FFC000FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFCC00E6FF00CCFF00FFFF00E6FF00008CFF59FF0019FF00\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000FFA6A6FF00A6FF0080FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFB300FFE600FFE600\
FFC000FFB300FFA600FFA600FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFD900FFE60000FF0CE6FF00C0FF0073FF00\
00FF26000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00FF99B3FF00C0FF00C0FF0099FF0000FF4C000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFB300FFD900FFD900\
FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFF300F3FF00B3FF0066FF00\
E600FF00FFF3000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
99FF00CCFF00CCFF00CCFF00B3FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFC000FFD900FFD900\
FFB300FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFD900FFF300F3FF00B3FF004C00FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
99FF00D9FF00D9FF00D9FF00B3FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFA600FFC000FFA600FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00FFD900F3FF0059FF0080FF0000FFA6\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000000000FF4000B3FF
D9FF00E6FF00E6FF00E6FF00CCFF000099FF0033FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FFA600FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFCC00FFE600FFFF008CFF0000FFD9000000\
00000000000000000000FFBF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000CFF00FFD900FFBF
F3FF00F3FF00F3FF00F3FF00D9FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FFA600FFB300FFC000FFD900FFF300FFFF0000FF2600FFE600FF3300FF26\
3FFF000019FF4CFF003FFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000066FF00FFFFCCFF00F3FF00
FFFF00FFFF00FFFF00F3FF00E6FF004CFF00000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FFA600FFB300FFD900E6FF00C0FF00FFFF00D9FF00E6FF0066FF0000FF80\
A6FF0080FF00C0FF0099FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000059FF0000FF4CE6FF00FFFF00
FFF300FFF300FFF300FFFF00F3FF00B3FF0033FF000C00FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF9900FFA600FFB300F3FF0000FF00FFE600FFCC00FFD900FFD900FFF30000B3FF\
D9FF00F3FF00E6FF00A6FF0000000000000000FFA6000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000019FF000000000000CCFF00FFFF00FFF300
FFE600FFE600FFF300FFF300F3FF000080FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF9900FFA600FFC00066FF00FFD900FFC000FFC000FFC000FFCC00F3FF00FFF300\
FFE600FFF300E6FF000040FF00FF0C00000000FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000FF6659FF0026FF0026FF00FFF300FFE600FFE600
FFE600FFE600FFE600FFF300FFFF00D9FF0000FF0000FF26000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF9900FFA600FFC000FFC000FFC000FFB300FFB300FFB300FFC000FFCC00FFCC00\
FFCC00FFD90033FF00F3FF00C0FF00CCFF0073FF0019FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000B300FF99FF0000FF59E6FF00FFE600FFE600FFD900
FFD900FFD900FFE600FFE600FFF300E6FF0099FF00000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000\
FFCC00FFCC00FFE600FFF300FFFF00E6FF00CCFF0099FF0059FF0000FF0000D9FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000FF4C00FFE64C00FFD9FF0099FF0000FFCCFFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFF3000CFF00A600FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300\
FFC000FFCC00FFD900FFE600FFFF00D9FF00C0FF0059FF0000FF733F00FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000008000FF\
00FF3333FF0080FF0000FF7359FF00FFFF00FFE600FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFE600F3FF0000FFFF00FFE600FFB3000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFB300\
FFC000FFCC00FFD900FFE600FFFF00CCFF0000FFB30CFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
6600FFA6FF00A6FF004CFF00E6FF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFF30000FF3366FF00000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300\
FFC000FFD900FFE600FFF300F3FF00C0FF0000FF8C000000000000000000000000
00000000000000000000000000FFCC000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF0C8C00FF000000\
1900FFC0FF00D9FF0080FF000073FFFFD900FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFD900FFF300E6FF00A6FF009900FF00FFD9000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300\
FFD900CCFF0059FF00E6FF0099FF00B3FF0033FF008000FF000000000000000000
00000000000000000000000000FF26008CFF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000004CFF00FF8000FF590019FF00FFE600D9FF26FF00\
0066FF0CFF00FFE600E6FF0080FF00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFD900CCFF0000FF6600BFFF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFCC00\
3FFF00C0FF00FFF300D9FF000CFF004CFF004C00FF000000000000000000000000
00000000000000000000000000FF5980FF0073FF004C00FF7300FF0000000073FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000B3FF0000000000000000000080FF80FF00B3FF00CCFF00B3FF0066FF00\
99FF00FFFF00FFD900FFCC00FFCC00FFC000FFC000FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFCC00FFD90000FFFF0000000000000066FF0000001900FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300\
FFC000FFCC00FFD900FFE600E6FF0000FF0000FF1900FF66000000000000000000
00000000000000000000000000FFB3B3FF00B3FF000059FF66FF0000FF0C00000000000000FF26\
000000000000000000000000000CFF000000000000008CFF000000004CFF00FFA6
0000000000000080FF00FF4000000000000000000000FFE6C0FF00E6FF00E6FF0099FF0066FF00\
F3FF00FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFCC00FFD900FFFF00E600FF59FF004C00FF00FF8C000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600\
FFB300FFC000FFCC00FFE600D9FF0000FF1966FF003F00FF0000FF000000000000
00000000000000000000FFCC00FF8CD9FF00D9FF00D9FF00CCFF0033FF0000FF8C00000066FF00\
00000033FF0059FF0000FFA60000000000000000000000000CFF0000000073FF00
00B3FF00FF73A6FF0059FF000073FF00000000000026FF00C0FF00FFFF00F3FF0080FF00D9FF00\
FFF300FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFCC00FFE60099FF0080FF0099FF00000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600\
FFB300FFC000FFC000FFD900FFE600F3FF00B3FF0059FF00000000000000000000
000000D900FF00000000FF2673FF00E6FF00FFFF00FFFF00E6FF0019FF0000FF333FFF00CCFF00\
CCFF00B3FF00000000000000000000000000000000000000000000A6FF00B3FF00
3FFF00D9FF00CCFF00B3FF008CFF0066FF0000FF1900B3FF4CFF00FFE600FFE60000FF5900FF8C\
99FF00FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFC000FFCC00FFD900FFF300E6FF00A6FF003FFF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600\
FFB300FFC000FFC000FFD900FFE600F3FF00CCFF0000FFFF0080FF000000000000
00FF2659FF0000FF0C73FF00E6FF00FFF300FFE600FFF30059FF0099FF00F3FF00F3FF00FFFF00\
E6FF00C0FF008CFF00000000000000000000000000000000000000B3FF00E6FF00
00FF0CFFFF00FFFF00E6FF00CCFF000CFF0000A6FF00FFA666FF00FFCC00FFCC00FFCC00FFD900\
66FF00FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFC000FFCC00FFE600E6FF000073FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600\
FFB300FFC000FFCC00FFE600FFF300FFFF00D9FF0000FF0C00FFB300FF40B300FF
B3FF00B3FF0000000099FF00F3FF00FFE600FFD900FFD90000FF8CF3FF00FFE600FFE600FFF300\
D9FF0080FF0000FF4C5900FF00FF8C0000000000000080FF00F3FFA6FF00FFF300
FFF300FFE600FFF300F3FF00D9FF0099FF0080FF0000FF33FFD900FFC000FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFC000FFCC0000FF0C00000000FFBFC000FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300\
FFB300FFC00099FF0033FF00F3FF00E6FF004CFF0080FF0000FF40A6FF0000FF33
E6FF00CCFF00A6FF00F3FF00FFE600FFCC00FFCC00FFCC00FFE600FFD900FFCC00FFD900FFD900\
33FF00F3FF00CCFF0066FF004CFF000000FF00000019FF00B3FF00C0FF00FFE600
FFD900FFD900FFF300CCFF00B3FF0000FF40E6FF00FFCC00FFC000FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFE60000D9FF00000000000000FFBF00000000000000FF80\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300\
FFC000FFCC00FFD900FFFF00A6FF00B3FF0000FF6659FF0019FF00CCFF00F3FF00
FFF300FFF300A6FF00FFE600FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFE600FFFF00E6FF00B3FF0066FF0000FFF366FF00C0FF00FFE600FFCC00
FFCC00FFCC00FFF300008CFFCCFF00FFF300FFCC00FFC000FFB300FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFB300FFC000FFD900FFFF0066FF0000FF0000000000FF994CFF00\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFB300FFB300FFC000\
FFC000FFCC00FFE600C0FF000000003FFF00D9FF00E6FF008CFF0080FF00FFFF00
FFD900FFD900C0FF00B3FF00FFCC00FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00\
FFD900FFE600FFFF0000FF8099FF0000FF7319FF0073FF00A6FF00FFD900FFC000
FFC000FFC000FFE60059FF00E6FF00FFF300FFCC00FFB300FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFD90000FF33000000C0FF00C0FF00000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FF9900FFA600FFB3000CFF00FFD900FFE600\
FFD900FFF300F3FF0000FF0CD9FF00F3FF00FFE600FFF300F3FF0080FF00FFFF00
FFCC00FFC000FFC000FFF300FFB300FFB300FFA600FFA600FFB300FFB300FFB300FFC000FFCC00\
FFD900FFE600FFF300E6FF0000FFB359FF0066FF0033FF00FFD900FFC000FFB300
FFB300FFB300FFC000FFFF00000000A6FF00CCFF00FFB300FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFCC00FFE6000CFF00E6FF00E6FF00A6FF00\
00E6FF000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900C0FF00FFCC00FFCC00FFF300D9FF00FFF300\
C0FF0000FF19E6FF0000FF59FFE600FFFF00FFCC00FFCC00FFE6003FFF00F3FF00
FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFC000FFCC00\
FFD900FFF300FFFF00C0FF0000FF33F3FF00FFF30059FF00FFC000FFB300FFA600
FFA600FFA600FFB300FFC000FFCC00E6FF00FFCC00FFA600FF9900FF9900FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFCC00FFE600FFF300F3FF00C0FF00\
80FF0000FF0C000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFB300D9FF00E6FF00A6FF00FFD900FFCC00\
FFCC00FFE600FFCC0000FF40FFC000FFB300FFB300FFC000FFD900FFF300FFC000
FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFE600\
D9FF0099FF00CCFF008CFF00B3FF00FFD900FFCC00FFF300FFB300FFA600FFA600
FFA600FF9900FFA600FFA600FFA600FFCC00FFB300FF9900FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFCC00FFD900FFFF00D9FF001900FF\
00FFBF000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300FFCC00CCFF00FFD900FFC000FFB300\
FFB300FFB300FFB300FFC000FFB300FFA600FFA600FFB300FFCC00FFFF00FFC000
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFC000FFE600\
00FF59FFFF00FFF300FFE600FFCC00FFC000FFB300FFB300FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFD900FFFF0000FFA680FF0000FF19\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7F00FF7F00FF8C00FF9900FF9900FFA600FFCC00C0FF00F3FF00FFCC00FFB300FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FFA600FFA600FFCC00FFB300
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFC00099FF00\
CCFF00FFE600FFCC00FFC000FFB300FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFE600F3FF0000FF8C00FF73000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7F00FF7F00FF9900FFC000FFCC00FFC000FFD90073FF008CFF00FFCC00FFB300FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFD900\
00FFA6FFF300FFCC00FFC000FFB300FFA600FF9900FF9900FF9900FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFE6000033FF00FF0C00FF99000000000000\
3F00FF0000000000000000FF000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7F00FF7F00FF9900FFC000FFC000E6FF00B3FF00FFF300FFC000FFB300FFA600FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFB300FFF300\
A6FF00D9FF00FFE600FFC000FFB300FFA600FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FFA600FFC00099FF0000FFF30CFF0000FF9900FF0000FFFF\
26FF0000BFFF00000066FF00000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7F00FF7F00FF8C00FF9900FFA600FFB300FFCC00C0FF00FFC000FFA600FFA600FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600FFB300\
F3FF00FFE600CCFF00D9FF00FFB300FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFE600FFFF00000CFF00000000000073FF00\
99FF0000000000B3FFB3FF00000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFCC00FFE600FFC000FFA600FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900\
FFA600FFC000FFE600FFFF00FFB300FF9900FF8C00FF8C00FF8C00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFB300FFCC00E6FF003FFF00CC00FF\
E6FF00F3FF00F3FF00C0FF00000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFCC0033FF00F3FF00FFB300FF9900FF8C00\
FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF9900FFCC00F3FF00FFB300FFA600FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFD90000BFFFA6FF00\
F3FF00FFF300FFFF008CFF0000000000FF8C00FF33000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7F00FF7F00FF8C00FF8C00FFA600B3FF00CCFF00FFCC00FFB300FF9900FF8C00\
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF9900FFE600FFC000FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFC000FFCC0080FF00\
FFE600FFE600FFE600FFFF0000FF0C80FF00000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7F00FF7F00FF8C00FF8C00FFA600FFB300FFF300FFC000FFA600FF9900FF8C00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FFA600FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFB300FFC000\
FFCC00FFD900FFD900FFF300F3FF00CCFF00A6FF0033FF00000CFF000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFC000CCFF00FFC000FFA600FF8C00FF8C00\
FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFB300\
FFC000FFCC00FFD900FFF300E6FF00C0FF006600FF00000000FF40000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7F00FF7F00FF8C00FFA600FFB300C0FF00FFC000FFD900FFA600FF8C00FF7F00\
FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300\
FFC000FFCC00FFE60099FF0000FF333FFF00000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7F00FF8C00FFA600D9FF00F3FF00FFC000FFA600FFA600FFCC00FF8C00FF7F00\
FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300\
FFC000FFCC00FFE60000FFD9000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7F00FF8C00FFC000FFA600FF9900FF9900FF8C00FF8C00FF8C00FF7F00FF7F00\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFC000\
FFD900FFE600FFFF0000FF8059FF000C00FF000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7F00FF8C00FFCC00FF9900FF8C00FF7F00FF7F00FF7F00FF7F00FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFC000\
3FFF0066FF00E6FF00B3FF0033FF0000A6FF000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF7300FF7F00FFC000FF9900FF8C00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFB300FFD900FFD900\
F3FF005900FFB3FF0000FF8C000000000000000000000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFB30066FF0000FF4C\
D9FF0033FF0066FF000000000C00FF0000003F00FF000000000000000000000000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFB30000FF40E6FF00\
19FF003FFF0000FF0C00000000FF3300FF8019FF0000FFD90073FF00FFF300FF19
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFB300FFD900F3FF00\
00FFB300CCFF00FF6633FF0099FF00A6FF00C0FF0000FF000000000CFF0000FFA6
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FFA60000FF19B3FF0059FF00\
E6FF0033FF0000FF4C6600FF66FF00CCFF00F3FF00D9FF0000FF00008CFFD9FF00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FFC000FFD900D9FF00FFD900\
FFCC00FFF30000FF66C0FF004CFF0000FF19FFFF00FFE600FFF300FFE600FFD900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFB300FFB300\
FFB300FFCC003FFF00FFE6003FFF0000FF99FFF300FFD900FFCC00FFCC00FFCC00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900\
FF9900FFA600FFB300FFCC0000FF33C0FF00FFFF00FFCC00FFC000FFC000FFC000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF9900FF9900FFA600FFC000D9FF00FFF30000FFBFFFC000FFB300FFB300FFC000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF9900FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFC000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00D9FF00FFD90026FF00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FFA600FFF30073FF00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFC00000FF00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFB300FFC000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FF9900FFB300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FF9900FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFB300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFA600FFB300FFC000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF9900D9FF00FFD900F3FF00
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FF9900FFC000CCFF00FFFF00
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FFF300FFCC00FFE600FFFF00
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FF9900FF9900FFB300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300\
FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300FF3300
FF3300FF3300FF3300FF3300FF3300FF3300FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FFD900FF9900FF8C00FF7F00FF7F00FF7F00\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF9900FFC000FFA600FF8C00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FFB300FFA600FF9900FF8C00FF8C00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF9900F3FF00FFC000FFA600FFA600FFA600\
FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FF9900FFFF00FFE600C0FF00FFC000\
FFA600FFA600FFCC00FFB300FF8C00FF7F00FF7F00FF7F00FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFC00000FF40\
FFC000FFC000FFC000FF9900FF8C00FF7F00FF7F00FF7F00FF7F00FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FF9900FFA600FFCC00\
CCFF00FFF300FFB300FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFC000\
80FF00FFC000FFA600FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFC000\
FFD900FFF300FFB300FF9900FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF9900D9FF00FFA600FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF9900FFB3008CFF00\
A6FF0099FF00FFC000FFA600FF9900FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF9900FFB300B3FF00FFB300FF9900FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFB300FFD900\
00FF4CE6FF00FFCC00FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF9900FFA6008CFF0099FF00FFB300FFA600FF9900FF8C00FF8C00FF8C00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FF9900FFB300FFFF00\
FFF300FFCC00FFB300FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF9900FFA600FFB300FFCC00FFF300FFE600FFF300FFA600FF9900FF8C00FF8C00FF8C00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300FFCC00\
E6FF00FFCC00FFB300FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900
FFA600FFB300FFC000FFD900D9FF00D9FF00FFC000FFA600FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFD900FFCC00FFD900\
CCFF00FFCC00FFB300FFA600FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900CCFF00
FFCC00FFE600FFFF000CFF0066FF00FFD900FFC000FFA600FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFA600FFCC00FFC000A6FF0080FF00E6FF00\
FFF300FFCC00FFC000FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFB300
FFE600F3FF00B3FF00FFF300FFD900FFC000FFB300FFA600FF9900FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFB300FFCC00FFC000FFCC00FFD900\
C0FF00FFE600FFCC00FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300
FFCC00CCFF00A6FF00FFE600FFCC00FFC000FFB300FFA600FFA600FF9900FF9900FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFA600FFA600FFB300FFD900\
D9FF008CFF00FFFF00FFC000FFB300FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFF300FFA600FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFC000
FFF30099FF00FFFF00FFD900FFCC00FFC000FFB300FFB300FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFC000\
FFD900B3FF00FFE600FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFD9008CFF00FFB300FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFCC00
FFF30000FF00F3FF00FFE600FFD900FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300\
FFCC00FFFF00FFFF00FFD900FFC000FFC000FFB300FFB300FFB300FFB300FFD900
FFC000FFB300FFA600FFA600FFB300FFC0008CFF00FFD900FFB300FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000
FFD90019FF00D9FF00F3FF00CCFF00F3FF00FFE600FFD900FFC000FFB300FFB300FFB300FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FF9900
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300\
F3FF00FFFF00B3FF00D9FF00FFD900FFCC00FFCC00FFD900FFD900FFCC00FFFF00
FFD900FFC000FFC000FFB300FFC000FFCC0066FF00FFE600FFC000FFB300FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000
FFCC00FFF30066FF0026FF00CCFF0019FF00CCFF00FFFF00FFCC00FFCC0080FF00FFCC00FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFCC00B3FF00FFA600
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFF300\
FFD900FFCC00FFE600CCFF00E6FF00FFF300B3FF0080FF00D9FF00F3FF008CFF00
FFF300FFE600FFE600FFCC00FFCC00FFD900FFF300B3FF00FFFF00FFC000FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000
FFCC00FFD900FFE600FFF300FFFF0073FF0073FF00C0FF00FFF300FFF3004CFF00FFCC00FFB300\
FFB300FFA600FFA600FFA600FFA600FFB300FFC000FFC000FFE60099FF00FFC000
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600\
FFA600FFB300FFC000FFFF00FFF300F3FF00FFE600FFE600E6FF00D9FF0000FF0C
E6FF0059FF00FFF300FFD900FFE600FFFF00F3FF0019FF00FFF300FFCC00FFC000FFC000FFC000\
FFCC00FFB300FFB300FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000
FFC000FFCC00FFD900FFE600FFFF00E6FF003FFF0000FFBFE6FF00D9FF0080FF00FFE600FFCC00\
FFC000FFB300FFB300FFB300FFB300FFC00073FF003FFF00E6FF003FFF00FFFF00
FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900\
FFA600FFA600FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300CCFF00
8CFF0000FF0CE6FF00FFFF00FFFF00A6FF0059FF0080FF00E6FF00FFD900FFCC00FFCC00FFF300\
00FFCCFFCC00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFCC00FFCC00FFD900FFE600FFFF00C0FF0000FF2619FF0000FFBF73FF0099FF00F3FF0066FF00\
FFCC00FFC000FFB300FFC000FFC000FFD90000FF73C0FF00D9FF00D9FF00FFCC00
FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900\
FF9900FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFCC00FFE600F3FF00
66FF0000000000FF40A6FF00D9FF00A6FF0066FF00D9FF00FFF300FFE600FFD900FFF300B3FF00\
FFF300FFCC00FFC000FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFCC00FFD900FFD900FFE600FFFF00CCFF00B3FF008CFF0000FF1900FFF333FF0080FF00FFFF00\
FFD900FFCC00FFC000FFC000FFCC00FFFF0000FF33E6FF00FFF300FFD900FFCC00
FFB300FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFE600FFFF00
00FF0C99FF00B3FF000033FF26FF0000FFBFA6FF00D9FF00E6FF00FFFF00FFF300F3FF00CCFF00\
FFE600FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900FFE600FFF300FFFF00E6FF00C0FF0099FF0033FF006600FF66FF00B3FF00FFFF00\
FFE600FFD900FFCC00FFCC00FFD900D9FF0080FF00B3FF00E6FF00FFE600FFCC00
FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00C0FF008CFF00
CCFF00F3FF00D9FF008CFF0000FF0C00A6FF00CCFFB3FF008CFF00E6FF00F3FF00D9FF0000D9FF\
FFFF00FFE600FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFCC00FFD900
FFD900FFFF00A6FF00F3FF008CFF0080FF008CFF0000000000FFCCC000FF00CCFFB3FF0033FF00\
0CFF00FFE600FFD900FFD900FFE600FFFF0026FF00A6FF0073FF00CCFF00FFE600
FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFD900FFF300
FFF300FFFF00F3FF00D9FF0099FF0000FFBF00FF2659FF004CFF00C0FF00CCFF0000FF593FFF00\
D9FF000CFF00FFE600FFD900FFD900FFD900FFFF003FFF00FFE600FFD900FFE600
FFE600E6FF0000FF33B3FF004CFF0000000000FF0000FF8C00000000000000FF0C3FFF0000FF73\
F3FF00FFF300FFE600FFE600FFE600FFF300F3FF00D9FF00B3FF0000FF00E6FF00
00D9FFFFE600FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00FFD900
FFE600FFF300F3FF00CCFF0080FF0000FF1900000000BFFF0CFF0073FF0099FF0059FF00000000\
000000CCFF00FFF300FFE600FFE600FFE60000FF0CD9FF00FFFF00FFF300FFF300
FFF300F3FF00B3FF00A6FF003FFF0000B3FF00000000000000000000000000000000FF59000000\
E6FF00FFFF00FFFF00FFF300FFF300FFFF00F3FF00D9FF00A6FF00000000B3FF00
80FF00FFE600FFCC00FFC000FFC000FFC000FFC000FFCC00FFC000FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00FFCC00
FFD900FFF30099FF0026FF0000FFBF00000000000000000000000000FF1900FF2600E6FF000000\
00FF19D9FF00D9FF00FFF300FFF300FFF300D9FF008CFF003F00FFC0FF00E6FF00
F3FF00E6FF00D9FF00B3FF0073FF0000FF9900000000000000000000000000000000000066FF00\
CCFF00CCFF0033FF00F3FF00F3FF00E6FF00D9FF00CCFF0000FFB33FFF0000CCFF
33FF0000FF19FFD900FFCC00FFCC003FFF00FFFF0000FF0CFFCC00FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00FFD900
FFE600FFF300E6FF00B3FF0066FF0000FFD9000000000000000000000000000000000000000000\
59FF0059FF00D9FF00F3FF00FFFF00F3FF00E6FF00C0FF0000FF6600000059FF00
99FF00B3FF00C0FF0080FF000CFF000000000000000000000000000000000000000000004CFF00\
B3FF00A6FF00D900FFA6FF00D9FF0000FF00A6FF0000FF7366FF0033FF00D900FF
0019FF00FF4CFFF300FFE600FFF30000FFA699FF0000FFFFFFE600FFC000FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFC000FFCC00FFD900
73FF0066FF00C0FF0033FF0000FF590059FF000000000000000000000000000000000000000000\
00FF4000FF99A6FF00E6FF00D9FF00D9FF00D9FF004CFF007300FF00000000FF99
0073FF66FF0019FF0080FF004CFF0000FF7300000000000000000000000000000000000059FF00\
59FF0066FF008C00FF000000A6FF0099FF004CFF0000FFA600FFE6000000E600FF
33FF00C0FF00FFFF00FFFF00D9FF008CFF00CCFF00FFFF00FFD900FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00FFD900FFE600
FFFF004CFF0000FF0C66FF0000FF33000000000000000000000000000000000000000000000000\
00000033FF0073FF00CCFF0000FF0CA6FF00A6FF008CFF001900FF000000000000
00000000FF5900000000FF732600FF00FF590026FF00000000000000000000000000FFE6000000\
00000000FF190000000000003FFF0066FF000000004C00FF000000000000000000
00FF59B3FF00E6FF00F3FF00D9FF000066FF59FF00F3FF00FFD900FFCC00FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FFA600FFA600FFB300FFCC00FFFF00FFE600FFE600FFFF00
CCFF0000E6FF8C00FF00FF33D900FF000000000000000000000000000000000000000000000000\
0000000000FF8CFF0099FF008CFF0000000000000026FF0000FF4C000000000000
9900FF000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000FFD98C00FF00FFCC000000000000000000000000
0033FFA6FF00CCFF00D9FF00CCFF00B3FF0080FF003300FFE6FF00FFD900FFCC00FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FFA600FFA600FFC000FFD900B3FF00D9FF00FFFF0026FF00
00FFD93FFF0059FF002600FF000000000000000000000000000000000000000000000000000000\
00000000000066FF0033FF000CFF0000FF7300000000B3FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
26FF0066FF0080FF00C0FF00B3FF00A6FF0000FF0C00FF8C3FFF00FFF300FFD900FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFC000FFC000FFC000FFC000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FFA600FFA600FFB300FFCC0059FF00D9FF0000FFA6E6FF00
D9FF00C0FF0000FF4000FF730099FF000000000000000000000000000000000000000000000000\
0000000040FF00FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00FFF300FF263F00FF80FF000000004C00FF19FF0000FFA600FFBFF3FF00FFF300F3FF00FFFF00\
FFE600FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFCC00FFD900FFE600FFF300
FFFF00E6FF0099FF0000F3FF9900FF000000000000000000000000000000000000000000000000\
00000000FF8C000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000D900FF00FF0C000000000000000000000000D9FF00D9FF0066FF0059FF00\
D9FF00FFD900FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00FFCC00FFD900FFE600
FFF300E6FF0080FF0000FF19000000000000000000000000000000000000000000000000000000\
7300FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FFFF00000000000000000000FF00C0FF00A6FF0000FF80CCFF00\
FFF300FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFE600
FFF30080FF000CFF00A6FF004CFF00A600FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000026FF0099FF0099FF0073FF0000FF73\
F3FF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600
FFF300F3FF00D9FF00C0FF0000B3FF59FF0000FF0C000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000C00FF0000FF3FFF004CFF0000FF5900E6FF\
0073FFFFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFD900
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFE600FFF300
FFFF00F3FF00D9FF00C0FF00A6FF0073FF0026FF0000FF80000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000008CFF000000B300FF000000\
00B3FFE6FF0066FF008CFF00FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFC000FFB300FFC000FFB300FFB300\
FFB300FFB300FFB300FFC000FFCC00FFCC00FFCC00FFD900FFE60099FF00FFFF00
F3FF00D9FF00C0FF008CFF00008CFF00FF1900FFD9000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000CCFF\
80FF00008CFF0080FFC0FF00FFF300FFE600FFD900FFD900FFD900FFD900FFD900
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFD900A6FF0099FF00FFCC00FFC000\
FFC000FFC000FFC000FFCC00FFFF00FFE600FFD900FFE600FFF300C0FF00C0FF00
A6FF000000FF8CFF00000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000FF40\
4CFF0066FF0019FF00D9FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFE600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFF30073FF004CFF00FFCC00\
FFCC00FFCC00FFCC00FFD900FFFF00E6FF00FFFF00FFF300FFFF00E6FF00A6FF00
00FF8C0059FF00FF5900FF26000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000FF3300FF99000000F3FF00FFFF00FFF300FFE600FFE600FFE600FFE600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFE600A6FF00CCFF00E6FF00\
FFD900FFD900FFF300FFF300F3FF0026FF0026FF00E6FF00E6FF00D9FF0073FF00
0000008C00FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000009900FF00FF4C4CFF00FFFF00FFF300FFF300FFF300FFF300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFCC00FFE60000FFA6B3FF00\
FFFF00D9FF0000FF0CD9FF0059FF0000FF6673FF00A6FF00A6FF00B3FF0099FF00
4CFF00000CFF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000004CFF0000FFB3C0FF00F3FF00FFFF00FFF300FFF300FFF300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFB300FFCC00FFD900FFF300\
FFFF00B3FF0000FF4C00FFF300D9FF00FF730066FF00FF40000CFF66FF0059FF00
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000CFF00FF00E6FF00F3FF00FFFF00FFFF00FFFF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFCC00FFD900\
FFE600FFFF00CCFF0073FF0000FFF3000000000000A600FF0000000000000059FF
0099FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000FF99C0FF00F3FF00F3FF00F3FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFF300FF9900FF9900FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFC000FFCC00\
FFD900FFF300CCFF000000003FFF000000000000000000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000004CFF0CFF0000FF40CCFF00E6FF00F3FF00F3FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFCC00FFC000FFB300FFA600\
FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFB300FFC000FFCC00\
FFD90000FFE6B3FF0080FF0099FF0000FF19000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000D9FF00A6FFA6FF00CCFF00E6FF00E6FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFA600FFCC00FFE600FFD900\
FFC000FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00\
FFD900FFE600FFFF00E6FF00B3FF000C00FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000E6FF8CFF00D9FF00D9FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FFA600FFC000FFE600FFE600\
FFC000FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00\
FFD900FFE600FFFF00E6FF00B3FF0000FF2600F3FF000000004CFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000FFD98CFF00C0FF00CCFF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFC000FFE600FFFF00\
FFC000FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFD900\
FFE600FFF300F3FF00E6FF00C0FF0099FF003FFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000B3FF99FF00C0FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFC000FFFF0073FF00FFFF00\
FFE600F3FF00FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFD900FFE600FFE600\
FFF300FFFF000CFF0073FF00A6FF0026FF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000026FF8CFF00B3FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300FFCC00FFF300\
CCFF00FFD900FFC000FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFC000FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900B3FF00B3FF00\
F3FF00CCFF0000FFCC00FFBF00000026FF0000E6FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000026FF00FFE699FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFC000FFD900\
B3FF00FFE600FFCC00FFC000FFB300FFB300FFB300FFA600FFA600FFB300FFB300
FFC000FFD900FFD900FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFD900FFF300E6FF00\
B3FF0000FF802600FFD900FFD900FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000000000000000FFBF
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFE600\
CCFF00B3FF00FFD900FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFC000
FFCC00FFFF0059FF00FFD900FFCC00FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300\
E6FF0019FF00B300FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000000000003FFF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300\
FFCC00FFF300FFFF00FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFCC00FFFF00C0FF00FFE600FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300\
F3FF00CCFF008CFF000C00FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300\
FFC000FFCC00FFF30000FFD9FFF300FFF300FFF300FFCC00FFCC00FFCC00FFCC00
FFD900FFF300D9FF00FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFF300FFFF00\
F3FF00B3FF0066FF0000FF400080FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300\
FFB300FFC000FFE600CCFF0000FF668CFF00FFF300FFD900FFD900FFD900FFD900
FFE600FFF3003FFF00FFFF00FFF300FFE600FFE600E6FF00FFE600FFE600FFF300FFFF0000FF66\
CCFF0099FF000000000080FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300\
FFB300FFC000FFD900FFFF004CFF00A6FF00E6FF00FFF300FFF300FFFF00FFE600
FFF300E6FF0080FF00A6FF00FFFF00FFF300F3FF0080FF00FFFF00FFF300FFF300FFFF00E6FF00\
C0FF0000FFFF6600FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300\
FFB300FFCC00FFE600FFFF00A6FF00B3FF00E6FF00F3FF00E6FF00E6FF00FFFF00
F3FF00C0FF0000FF40B3FF00CCFF00E6FF00D9FF00CCFF00F3FF00FFFF00F3FF00F3FF00E6FF00\
CCFF0099FF0000FF0C0073FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFC000FFCC00F3FF00E6FF00B3FF004CFF00B3FF008CFF0099FF00B3FF0099FF00
D9FF00B3FF0000FF267300FF00FF00B3FF000033FF0000FFD9FF00D9FF00D9FF00E6FF00D9FF00\
8CFF004CFF000040FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300\
FFC000FFCC00FFD900FFF300C0FF0099FF0073FF009900FF00FF0C33FF0000FF19
99FF008CFF003FFF0000FFA6008CFF59FF0000FF4C00FF26A6FF008CFF00C0FF00CCFF00C0FF00\
A6FF0000FF99000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF8C00FF9900
FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000\
FFC000FFCC00FFD900FFE600FFFF00E6FF003FFF004CFF0000FFB37300FF0019FF
3FFF0000000000FF3300000000000000FFBF0073FF00000033FF0000FF00A6FF008CFF00B3FF00\
80FF0033FF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFD900
FF8C00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFB300FFB300FFC000FFC000FFC000\
FFCC00FFCC00FFD900FFF300FFFF00B3FF00A6FF004CFF000033FF000000000000
00FFB34C00FF0000000000000000000000000000000000000000001900FF00FF2680FF008CFF00\
80FF0019FF008000FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00F3FF00
FF9900FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300F3FF00C0FF00FFCC00FFCC00\
FFCC00FFD90099FF00F3FF00F3FF00D9FF008CFF003FFF00B300FF000000000000
0000000000000000000000000000000000000000000000000000000000006600FF00FF0066FF00\
59FF000026FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFB300
FFA600FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFF300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFC000F3FF008CFF00FFF300FFD900\
FFD900FFE600FFFF0099FF00B3FF00B3FF0080FF0000FF0C00F3FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000CC00FF\
33FF00CC00FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FFC000
FFB300FF9900FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFD900C0FF00
FFB300FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFFF00B3FF00FFF300\
FFF300FFF300FFFF00E6FF003FFF0000FF0000000000FFA6000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000040FF\
00FF1900FF73000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFB300
FFC000FFA600FF9900FF9900FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600FFA600
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFD900FFF300
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFE600FFFF0099FF00\
D9FF00F3FF00CCFF00D9FF00A6FF0033FF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00FFE6000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFB300
FFD900FFB300FFA600FFA600FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFB300FFC000
FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFD900CCFF00
FFCC00FFC000FFC000FFB300FFC000FFC000FFC000FFC000FFCC00FFD900FFE600E6FF0033FF00\
3FFF00CCFF00A6FF00A6FF0080FF0000FF0C0C00FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000CCFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFB300FFA600FFB300FFC000
FFF300FFF300FFCC00F3FF00FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600F3FF00FFE600
FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFCC00F3FF00
FFD900FFCC00FFC000FFC000FFCC00FFD900FFCC00FFCC00FFD900FFE600FFF300FFFF00CCFF00\
26FF0000FF7373FF004CFF004CFF0000FF26000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000026FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFC000FFCC00FFCC00FFF300
B3FF00E600FFF3FF00FFD900FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFB300FFCC00FFD900
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFA600FFA600FF9900FF9900\
FFA600FFA600FFA600FFC000FFB300FFB300FFB300FFC000FFC000FFCC00FFFF00
FFFF00FFE600FFD900FFD900FFE600F3FF00FFD900FFD900FFE6004CFF00FFFF00D9FF00C0FF00\
59FF000C00FF00FFD900000000FF8000FFA6000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFC000FFFF00E6FF00B3FF00
000000000000000000D9FF00FFC000FFB300FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FFA600FFA600FFC000FFA600FFA600FFA600FFA600FFB300FFC000FFD900FFF300
FFD900FFB300FFB300FFB300FFB300FFB300FFB300FFCC00FFCC00FFB300FFB300FFB300FFA600\
FFA600FFB300FFB300FFF300FFCC00FFC000FFCC00FFD900FFD9008CFF00F3FF00
CCFF0073FF00FFF300FFE600FFF300D9FF00FFF300FFF300FFFF00E6FF0000FF33C0FF0000FF40\
3FFF006600FF000000000000000000004CFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF6600FF6600FF7300FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF9900FFD900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFB300FFB300FFA600FFA600FFA600FFB300\
FFA600FFA600FFA600FFC000FFB300FFB300FFC000FFFF00B3FF0000000000FFF3
000000000000000000E6FF00FFD900FFC000FFC000FFC000FFC000FFCC00FFB300FFB300FFC000\
FFC000FFC000FFF300FFC000FFC000FFD900FFC000FFCC00FFD900C0FF000026FF
FFF300FFCC00FFCC00FFCC00CCFF00FFCC00FFCC00FFE600FFE600FFCC00FFCC00FFE600FFCC00\
FFC000E6FF00FFD900FFF300FFE600CCFF00FFE600F3FF00F3FF00F3FF0066FF00
00000066FF00B3FF00CCFF00D9FF0059FF00CCFF00C0FF00D9FF004CFF0033FF0000E6FF00FF00\
7300FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF6600FF7300FF7F00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FFF300FFA600FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFC000FFC000FFC000FFA600FFB300FFC000\
FFB300FFB300FFB300FFF300FFB300FFC000FFCC00C0FF0066FF000000002600FF
000000000000000000E6FF00FFD900FFD900FFCC00FFCC00FFCC00FFD900FFC000FFC000FFD900\
FFC000FFCC00FFFF00FFCC00FFCC00FFF300FFCC00FFCC00FFE600A6FF00000000
FFFF00FFE600FFD900FFD900C0FF00FFD900FFD900FFFF00FFF300FFD900FFD900FFF300FFE600\
FFCC0073FF00F3FF00FFFF00FFFF0099FF00FFFF00D9FF00B3FF00D9FF000CFF00
000000A6FF00B3FF00C0FF00C0FF0033FF0080FF0099FF00C0FF0080FF0000D9FF4C00FF00FFA6\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF6600FF6600FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FFA600FF9900FF9900FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFB300FFCC00FFF300CCFF0080FF00
000000000000000000F3FF00FFC000FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFCC00FFA600FFA600FFA600FFB300FFB300FFCC00FFE600FFF300
FFFF00FFC000FFB300FFB300FFB300FFB300FFB300FFCC00FFCC00FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFE600FFCC00FFC000FFCC00FFE600FFD9008CFF00E6FF00
C0FF00B3FF00FFF300FFF300FFFF00A6FF00FFFF00F3FF00FFFF00D9FF0099FF00B3FF0033FF00\
19FF000000000000000000000000007300FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFC000FFD900FFD900E6FF00
B3FF00000000CCFF00FFD900FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFCC00FFF300
FFC000FFB300FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFCC00FFB300FFB300FFB300FFC000FFC000FFD900FFFF00
FFFF00FFE600FFD900FFD900FFE600D9FF00FFE600FFE600FFE600A6FF00F3FF00D9FF00B3FF00\
73FF0000FF8C00000000000000000000FFE6000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFCC00FFB300FFB300FFCC00
FFF300E6FF00FFD900FFD900FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFD900FFD900
FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFC000FFCC00FFFF00
FFE600FFCC00FFCC00FFCC00FFCC00FFE600FFCC00FFCC00FFD900FFE600FFF300FFFF00D9FF00\
73FF0033FF004CFF0026FF0033FF0000FFCC000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000007300FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFB300
FFE600FFC000FFB300FFB300FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFC000FFCC00
FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFCC0073FF00
FFD900FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFD900FFE600E6FF0099FF00\
73FF00C0FF00A6FF0099FF0080FF0000FFE6000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000B3FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFB300
FFC000FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFB300
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFB300FFD900FFFF00
FFCC00FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFFF0000FF0C\
CCFF00E6FF000CFF00CCFF00A6FF0059FF0000BFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00FFCC00FFD9000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFB300
FFB300FF9900FF9900FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFB300FFE600FFE600
FFB300FFB300FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFF3000040FFFFFF00\
F3FF00FFFF00FFFF00E6FF0099FF0000FF330000000099FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00FF3300FF8C000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFB300
FFA600FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600F3FF00FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFC000FFE600B3FF00FFF300FFE600\
FFE600FFE600FFFF00D9FF0059FF00A6FF004CFF000040FF0033FF000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000B3FF\
26FF0000FF4C000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF9900FFCC00
FF9900FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFF300E6FF00FFD900FFCC00\
FFCC00FFD900E6FF00D9FF00E6FF00CCFF00A6FF004CFF000019FF000000000000
0000000000000000000000000000000000000000000000000000000000000000005900FF59FF00\
59FF0000FF33000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFC000
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFE600FFF300FFFF008CFF0080FF0000FF00000000000000000000
0000FF00000000000000000000000000000000000000000000000000000000000073FF008CFF00\
80FF0019FF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF8C00FF9900
FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000\
FFC000FFCC00FFD900FFE600FFFF00E6FF00B3FF0066FF0000F3FF000000000000
19FF00C000FF00000000000000000000B3FF00FFE600000000FF0000D9FF99FF0073FF00A6FF00\
33FF0000FF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300\
FFC000FFCC00FFD900FFF30099FF00B3FF008CFF0000E6FF00FF8C00FF0026FF00
8CFF0073FF0000000000FFE6C000FF3FFF000CFF0000FFD999FF0066FF00C0FF00CCFF00C0FF00\
A6FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFC000FFCC00FFF300FFFF0059FF0000FF4099FF0073FF0099FF0080FF0099FF00
CCFF00B3FF004CFF00E600FF00BFFFA6FF0000FF3333FF00CCFF00C0FF00D9FF00D9FF00CCFF00\
00FF4C33FF000C00FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300\
FFB300FFCC00FFF300D9FF0026FF00A6FF00E6FF00E6FF00E6FF00D9FF00F3FF00
F3FF00B3FF0026FF0099FF00A6FF00E6FF00D9FF00B3FF00E6FF00F3FF00F3FF00F3FF00E6FF00\
CCFF008CFF000CFF000000FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300\
FFB300FFC000FFD900E6FF0000FF8C00FF33F3FF00FFF300FFFF00F3FF00FFF300
FFFF00CCFF004CFF0099FF00F3FF00FFFF00F3FF0080FF00FFFF00FFF300FFFF00FFFF00E6FF00\
C0FF0000FFBF00B3FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300\
FFB300FFC000FFE600E6FF0026FF00C0FF00FFF300FFD900FFD900FFD900FFD900
FFE600FFFF004CFF00F3FF00FFF300FFE600FFF300C0FF00FFF300FFE600FFF300FFFF0080FF00\
B3FF0073FF004C00FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300\
FFC000FFCC00FFE6000026FFFFFF00FFFF00FFE600FFCC00FFCC00FFCC00FFCC00
FFD900FFF300CCFF00FFF300FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFFF00\
E6FF008CFF0000FFE619FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300\
FFCC00FFE600D9FF00FFE600FFCC00FFCC00FFD900FFC000FFC000FFC000FFC000
FFCC00E6FF00D9FF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300\
F3FF00D9FF0099FF0000FF0C0066FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFCC00\
FFE60080FF00FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFC000
FFCC000CFF00F3FF00FFD900FFCC00FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFF300\
F3FF0026FF0000FFBF00FFCC000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000000000000026FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFB300FFD900\
99FF00FFF300FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFD900FFE600FFCC00FFC000FFC000FFC000FFC000FFC000FFCC00FFD900FFF300F3FF00\
D9FF0026FF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000000000FFCC3F00FF
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300FFCC00FFE600\
CCFF00FFD900FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFCC00FFC000FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD9008CFF0059FF00\
E6FF00A6FF0000FFBF00E6FF1900FF00FF002600FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000000000F3FF99FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900D9FF00CCFF00E6FF00E6FF00\
FFF300F3FF00FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFE600FFFF00FFF300\
FFF300FFFF00B3FF0000FFBF99FF0000FF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000000073FF00A6FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFC000FFE600FFF300\
FFCC00FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFCC00FFD900\
FFE600FFF300F3FF00D9FF00C0FF008CFF0000FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000007300FF99FF00C0FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FFA600FFC000FFE600FFE600\
FFC000FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFCC00\
FFD900FFE600FFFF00E6FF00C0FF0073FF0000FF0000FF59000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000073FF00C0FF00CCFF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FFA600FFD900E6FF00FFFF00\
FFC000FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00\
FFD900FFE600FFFF00E6FF00A6FF00A600FF004CFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000FFF3000000A6FF00CCFF00D9FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFB300A6FF00FFB300FFB300\
FFFF00FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00\
FFD90000FF26D9FF00C0FF0099FF0000FF8C000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000099FF00C0FF00D9FF00E6FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFFF00FFA600FF9900FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFC000FFCC00\
FFD900FFF300CCFF0000FF1959FF0000BFFF000000000000000000000000000CFF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000FF0C00FF40C0FF00E6FF00E6FF00F3FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFCC00FFCC00\
FFE600FFFF00D9FF004CFF007300FF00CCFF00000000000000000000000000FF26
CC00FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000FF0C00FF26C0FF00F3FF00F3FF00F3FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFD900FFE600\
FFF300CCFF008CFF0000FF5900FF9900FF400000FF00FF400000004CFF003FFF00
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000FF9900FF73000000D9FF00F3FF00FFFF00FFFF00FFFF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFC000FFD900B3FF0000FFE6\
D9FF0099FF0066FF00C0FF0000FF6600FFF373FF0099FF008CFF00A6FF008CFF00
3FFF0000FFA6000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000FFA63FFF000CFF00A6FF00F3FF00FFFF00FFFF00FFF300FFF300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFFF0099FF000CFF00F3FF00\
FFE600FFE600F3FF00FFFF00F3FF000CFF008CFF00D9FF00D9FF00D9FF0073FF00
00FF0C000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000FF3300FF330CFF00FFFF00FFF300FFF300FFF300FFF300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFD90080FF00A6FF00FFD900\
FFCC00FFCC00FFCC00FFD900FFF300A6FF00CCFF00FFFF00FFFF00E6FF00C0FF00
000000000000CC00FF00FF80000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00FF8000000000FF996600FFE6FF00FFFF00FFF300FFF300FFE600FFE600FFE600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFCC00D9FF0099FF00FFCC00FFC000\
FFC000FFC000FFC000FFCC00F3FF00FFF300FFE600FFE600FFF300B3FF0000FFB3
73FF003F00FF73FF00A600FF0000002600FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000FF59\
4CFF0059FF0019FF00CCFF00FFFF00FFF300FFE600FFE600FFE600FFE600FFE600
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFE600FFC000FFD900FFB300FFB300\
FFB300FFB300FFB300FFC000FFCC00FFCC00FFCC00FFD900FFE60000FFBFF3FF00
E6FF00CCFF00C0FF0000FF8C00FF8C000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000E600FF\
80FF0026FF0000FF40E6FF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300
FFFF00F3FF00D9FF00C0FF0099FF0066FF00CC00FF00FFCC000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0026FFCCFF000000000CFF00FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600
FFF300F3FF00D9FF00C0FF0080FF0066FF0019FF0000FF5900FFFF000CFF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000CCFF19FF0019FF0019FF00000000\
4CFF00FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFD900
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFE600
FFF300CCFF00A6FF00B3FF0073FF0000FF404C00FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FFB30000008CFF008CFF0073FF0000FFA6\
59FF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFE600
FFF300E6FF00B3FF0000FF4000FF000040FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000BFFF0000000000000000000CFF00B3FF00A6FF002600FF00FF26\
FFF300FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFCC00FFD900FFE600FFF300
FFFF00E6FF0000FF33000000000000000000000000000000000000000000000000000000000000\
00000000FFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000059FF0000000000000000000000003FFF00D9FF00CCFF0073FF00A6FF00\
FFFF00FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FFA600FFA600FFB300FFC000F3FF00F3FF00C0FF00F3FF00
E6FF00CCFF00A6FF003FFF00000000000000000000000000000000000000000000000000000000\
00000000FF5900FF19000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0080FF00FF4000000066FF0000FF0C00000000FF5900FF992600FFF3FF00FFF300D9FF00D9FF00\
FFF300FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FFA600FFA600FFB300FFD900D9FF00C0FF00E6FF0026FF00
73FF0066FF0033FF0000FFB3000000000000000000000000000000000000000000000000000000\
00000000B3FF59FF0026FF0000000000FFB3000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
19FF0059FF0000FF0CB3FF0099FF0099FF00CC00FF0C00FF00FFFFFFF300FFD900FFD900FFD900\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FFA600FFA600FFC000FFD90099FF00FFF300FFE600F3FF00
B3FF000000FF0073FF00FF80000000000000000000000000000000000000000000000000000000\
00000000FFFF80FF000019FF80FF0000FFE60080FF00FF2600FF80000000000000
D900FF000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000FF59000000000000000000000000
00FF26A6FF0000F3FFD9FF00CCFF00B3FF0080FF0000FF330040FFFFE600FFCC00FFCC00FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFCC00FFCC00FFD900FFE600
F3FF0099FF0000CCFF0CFF0000FF40000000000000000000000000000000000000000000000000\
00000000FF0066FF00C0FF0080FF0066FF008CFF0073FF00000000000000000000
00FF4000FF33000000D900FF00000000FFBF00BFFF000000000000000000008CFF000000000000\
00000000FF5900000000000019FF0059FF0000FF8C000000000000000000000000
0026FFA6FF00E6FF00E6FF00D9FF0000D9FF66FF00A6FF00FFE600FFCC00FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFC000FFCC00FFD900
33FF0066FF00B3FF0000000000FF2600FFCC000000000000000000000000000000000000000000\
00FF99000000C0FF00D9FF00C0FF00D9FF00CCFF0033FF0000FF26004CFF00FF8C
4CFF0066FF0000000066FF004CFF0000FF4000000000000000000000000000000000FF663FFF00\
00FF1959FF0000000000000080FF008CFF004CFF006600FF0059FF000000000000
4CFF0000FFBFFFFF00FFFF00CCFF008CFF00C0FF00FFFF00FFD900FFCC00FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00FFD900
FFE600FFFF00E6FF00B3FF0073FF0000FF66000000000000000000000000000000000000000000\
4CFF0000FF00D9FF00F3FF00FFFF00F3FF00E6FF00C0FF0026FF004C00FF00FF19
A6FF0066FF00B3FF0099FF003FFF0000FFFF00000000000000000000000000000000000066FF00\
A6FF0099FF0000FF2626FF00CCFF0000000073FF0000FF8C00FF0C0099FF8C00FF
C000FF0000FFFFF300FFE600FFFF0059FF00C0FF0000FF4CFFE600FFC000FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00FFCC00
FFD900FFF3002600FF4CFF0000FFB300000000000000000000F3FF00FF590033FF00F3FF000000\
59FF00CCFF0073FF00FFF300FFF300FFFF00E6FF00A6FF000073FFB3FF00D9FF00
E6FF00E6FF00D9FF00B3FF0000B3FF00FFFF00000000000000000000000000000000A6FF33FF00\
CCFF00C0FF0099FF00E6FF00F3FF00C0FF00D9FF00CCFF008CFF004CFF007300FF
00FF1973FF00FFE600FFD900FFD900B3FF0099FF00B3FF00FFCC00FFC000FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00FFD900
FFE600FFF300F3FF00CCFF0019FF0000FF8C000000F300FF00FF4C59FF004CFF0059FF0000FFD9\
33FF00E6FF00FFF300FFE600FFE600FFF30073FF00D9FF00FFFF00FFFF00FFF300
FFFF00F3FF00CCFF00B3FF0059FF0000000000000000000000000000000000000000FFFF00FFA6\
E6FF00F3FF00E6FF00FFFF00FFFF00FFFF00F3FF00D9FF008CFF0000000099FF00
73FF00FFF300FFCC00FFC000FFC000FFC000FFCC00FFE600FFC000FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00FFE600
FFE600FFF300F3FF00D9FF0000FFBF00FF4C00FF403FFF0000FF40B3FF00C0FF0073FF0059FF00\
C0FF00D9FF00FFE600FFD900FFD900FFD9004CFF0099FF00FFE600FFE600FFE600
FFE600F3FF0000FF4C004CFF00FF260040FF00FF2600FFF300000000000000FF4C33FF000C00FF\
F3FF00FFF300FFE600FFE600FFF300FFFF00F3FF00D9FF00B3FF0000FF80E6FF00
80FF00FFD900FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFCC00C0FF003FFF00
E6FF00F3FF00CCFF00A6FF008CFF0000FF2600FF0099FF0073FF00E6FF00E6FF00CCFF004CFF00\
FFFF00FFE600FFD900FFCC00FFCC00FFCC00FFD900FFE600FFD900FFD900FFD900
FFD900FFFF003FFF00F3FF0066FF008CFF0080FF000073FF0019FF00000000FFBFA6FF0033FF00\
D9FF00FFE600FFD900FFD900FFE600FFF30073FF00C0FF0099FF00A6FF00FFF300
FFD900FFCC00FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFE600FFFF00
99FF00C0FF00C0FF0000FFD900F3FF00FFF3A6FF00D9FF00B3FF00FFFF00FFF300F3FF0073FF00\
FFE600FFD900FFCC00FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFD900FFE600FFE600FFF300FFFF00E6FF00C0FF008CFF0000FF595900FF59FF00C0FF00F3FF00\
FFF300FFD900FFCC00FFCC00FFD900FFFF0080FF000CFF0099FF00FFF300FFCC00
FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFE600FFFF00
8CFF0000FF804CFF008CFF00CCFF004CFF000CFF00E6FF00FFFF00FFE600FFE600FFF30000FF73\
FFE600FFCC00FFC000FFC000FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFCC00FFD900FFD900FFE600FFFF00D9FF00C0FF0000000026FF000099FF00FFD919FF00F3FF00\
FFD900FFCC00FFC000FFCC00FFCC00FFFF0073FF00E6FF00FFF300FFD900FFCC00
FFB300FFB300FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900\
FF9900FFA600FFB300FFB300FFC000FFC000FFCC00FFCC00FFE600FFF300C0FF00
4CFF0000FF66CCFF00F3FF00F3FF00C0FF0000FF00A6FF00FFFF00FFD900FFCC00FFD9004CFF00\
19FF00FFCC00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFCC00FFCC00FFD900FFE600FFFF0000FF1966FF003FFF0000FF264CFF00A6FF00E6FF00D9FF00\
FFCC00FFC000FFC000FFC000FFC000FFF30033FF00CCFF00F3FF00FFF300FFCC00
FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600\
FFA600FFB300FFC000FFF300FFE600FFE600FFD900FFE600D9FF00E6FF0000FF19
D9FF00B3FF00FFF300FFE600FFE600F3FF00E6FF0000FF26FFF300FFCC00FFC000FFC000FFC000\
FFF300FFB300FFB300FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000
FFC000FFCC00FFD900FFE600FFF300E6FF0073FF0000FFCCCCFF00A6FF000CFF00FFE600FFCC00\
FFC000FFB300FFB300FFB300FFB300FFC000F3FF0000FF73A6FF0073FF00FFF300
FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFCC00\
FFC000FFC000FFD900D9FF0059FF00FFFF00CCFF00B3FF00A6FF00CCFF0099FF00
FFF300FFF300E6FF00FFCC00FFCC00FFD900F3FF00C0FF00A6FF00FFC000FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000
FFC000FFD900FFE600FFF300FFFF00CCFF004CFF00B3FF00FFFF00FFFF0099FF00FFCC00FFC000\
FFB300FFA600FFA600FFA600FFA600FFB300FFCC00FFCC00FFE600C0FF00FFC000
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFC000\
4CFF00FFE600D9FF00E6FF00FFD900FFCC00FFD900FFE600FFE600FFD900FFFF00
FFE600FFC000FFC000FFC000FFC000FFCC00FFFF00FFF300FFC000FFB300FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFC000
FFCC00FFE600D9FF008CFF00E6FF0000FF00A6FF00CCFF00FFD900FFD90073FF00FFD900FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFE60080FF00FFA600
FFA600FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300\
FFD900E6FF00FFFF00FFE600FFCC00FFC000FFC000FFC000FFC000FFC000C0FF00
FFC000FFB300FFB300FFB300FFB300FFC000B3FF00FFD900FFB300FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000
FFD900A6FF00C0FF00D9FF0019FF00CCFF00FFF300FFD900FFC000FFC000FFC000FFB300FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FF9900
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFC000\
FFD900F3FF00FFE600FFCC00FFC000FFB300FFB300FFB300FFA600FFA600FFB300
FFB300FFA600FFA600FFA600FFA600FFB300D9FF00CCFF00FFB300FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFB300FFC000
FFE60080FF00F3FF00FFE600FFD900FFD900FFCC00FFC000FFB300FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FF9900FFA600FFB300FFD900\
99FF003FFF00FFE600FFC000FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FFA600FFB300B3FF00FFA600FF9900FF9900FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFC000
CCFF003FFF00FFFF00FFE600FFCC00FFC000FFB300FFB300FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFB300FFC000FFB300FFC000FFD900\
D9FF00FFFF00FFE600FFC000FFB300FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFB300FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300
FFD900E6FF00A6FF00FFD900FFCC00FFC000FFB300FFA600FFA600FF9900FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FFC000FFE600FFCC00FFFF00C0FF00FFFF00\
FFF300FFCC00FFC000FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFB300
FFD900F3FF00D9FF00FFF300FFD900FFC000FFB300FFA600FF9900FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFE600FFD900FFE600\
CCFF00FFCC00FFB300FFA600FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFCC00
FFE600FFFF00E6FF00CCFF00F3FF00FFCC00FFB300FFA600FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300FFCC00\
99FF00FFCC00FFB300FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFA600
FFA600FFC000FFCC00FFFF0059FF0099FF00FFC000FFA600FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FF9900FFB300FFD900\
FFF300FFCC00FFB300FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900
FF9900FFA600FFB300FFCC00FFF300FFF300FFD900FFA600FF9900FF8C00FF8C00FF8C00FF8C00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFB300FFD900\
B3FF00FFF300FFCC00FFA600FF9900FF9900FF8C00FF8C00FF8C00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF9900FFA600C0FF00E6FF00FFC000FFA600FF9900FF8C00FF8C00FF8C00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF9900FFCC00CCFF00\
4CFF00E6FF00FFD900FFA600FF9900FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF9900FFB300FFFF00FFC000FFA600FF9900FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFC000\
FFE600E6FF00FFB300FF9900FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF9900FFCC00FFB300FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300\
C0FF00FFCC00FFA600FF9900FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FFB300FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFC000\
FFFF00FFD900FFB300FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFA600FFB300D9FF00\
FFCC00FFCC00FFC000FF9900FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FF9900FFCC00FFCC00FFE600FFC000\
FFA600FFA600D9FF00FFC000FF8C00FF7F00FF7F00FF7F00FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF9900FFD900FFD900FFB300FFB300FFB300\
FF9900FF8C00FF9900FFA600FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF8C00FFB300FFB300FF9900FF8C00FF8C00\
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF9900FFC000FFA600FF8C00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7F00E6FF00FFA600FF9900FF7F00FF7F00FF7F00\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7F00FF8C00FF7F00FF7F00FF7F00FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF8C00FF8C00FF9900FFA600FFB300FFCC0059FF00F3FF00FFD900FFC000FFA600
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FFA600FFB300FFCC00FFF300FFF300FFC000FFC000
FF9900FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF9900FFA600FFB300FFCC0000FF40FFD900FFC000FFB300FFA600
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FFA600FFA600FFB300FFCC00FFE600F3FF00F3FF00FFC000
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00\
FF8C00FF9900FF9900FFA600FFB300FFCC00F3FF00FFD900FFC000FFB300FFA600
FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FFA600FFB300FFC000FFCC00FFE600F3FF00B3FF00FFE600FFB300
FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00\
FF9900FF9900FFA600FFC000FFC000FFD900FFFF00F3FF00FFC000FFB300FFA600
FFA600FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FFA600FFD900FFC000FFD900CCFF00FFF30000FF8C80FF00FFE600FFD900FFB300
FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900\
FFB300FFB300FFC000D9FF00CCFF00D9FF00D9FF00FFD900FFC000FFB300FFB300
FFA600FFA600FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FFA600FFCC00B3FF0099FF0073FF00A6FF00FFFF00FFFF00FFCC00FFC000FFB300
FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF9900FFD900\
F3FF00FFE6008CFF00FFD900FFE600FFE600E6FF00FFE600FFCC00FFC000FFB300
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FFA600FFB300FFCC00FFF3008CFF00FFFF00FFE600FFCC00FFC000FFB300FFB300
FFA600FFA600FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900\
FFA600FFB300FFB300FFB300FFC000FFCC00FFFF00C0FF00CCFF00FFE600FFC000
FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFB300FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600\
FFA600FFB300FFCC00FFFF0000FFFFE6FF00FFD900FFCC00FFC000FFB300FFB300
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00\
FF9900FF9900FFA600FFA600FFB300FFCC00CCFF00000000E6FF00FFE600FFC000
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFB300FFE600FFA600FF9900FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600\
FFB300FFC000FFF30066FF0059FF00FFF300FFD900FFCC00FFC000FFC000FFB300
FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF9900FF9900FFA600FFA600FFC000FFD900E6FF00E6FF00FFD900FFCC00
FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFCC00E6FF0099FF00FFC000FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFB300FFD900F3FF00C0FF0099FF00FFF300FFE600FFD900FFCC00FFC000FFC000
FFB300FFB300FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF9900FF9900FFA600FFB300FFC000FFE600D9FF00FFF300FFCC00
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFCC00FFC000FFB300FFA600FFA600\
FFA600FFB300FFB300FFD90073FF00FFD900FFC000FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFB300FFC000FFD90080FF0099FF00F3FF00FFFF00FFFF00D9FF00FFD900FFD900
FFCC00FFB300FFB300FFB300FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FF9900FF9900FF9900FF9900FF8C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF9900FF9900FFA600FFB300FFCC00D9FF00A6FF00FFFF00A6FF00
FFD900FFCC00FFC000FFC000FFC000FFCC00FFC000FFCC0033FF00FFCC00FFC000FFB300FFB300\
FFB300FFB300FFC000FFF300FFFF00FFCC00FFC000FFB300FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFC000FFCC00A6FF008CFF00CCFF0019FF008CFF0019FF00F3FF00CCFF00
FFD900FFCC00FFC000FFC000FFCC00FFC000FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFC000FFB300FFA600FF9900FF9900FF9900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF9900FFA600FFC000FFD900FFE600FFE600CCFF00CCFF00
FFE600FFD900FFD900FFE600FFE600D9FF00FFE600FFE600F3FF0099FF00FFCC00FFC000FFC000\
FFC000FFC000FFCC00FFD900E6FF00D9FF00FFCC00FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFC000FFCC00FFD900F3FF00B3FF00E6FF00E6FF00C0FF0000FF2666FF00
3FFF00FFD900FFD900CCFF00CCFF00FFCC00FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFC000CCFF00FFCC00FFA600FFA600FF9900FF9900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF9900FFA600FFFF00FFE600FFC000FFCC00FFE600F3FF00
E6FF00FFFF00FFF30080FF0066FF0099FF00C0FF00E6FF0059FF00FFFF00FFE600FFFF00FFD900\
FFCC00FFCC00FFD900FFE600E6FF00CCFF0099FF00FFCC00FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFC000FFC000FFCC00FFD900FFE600FFF300FFFF00CCFF00B3FF0000FF40
CCFF00FFFF00FFF300D9FF00F3FF00FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600\
FFB300FFB300FFC000FFC000FFD900D9FF00C0FF00FFC000FFA600FFA600FF9900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF9900FFA600FFA600FFB300FFB300FFCC00CCFF00
F3FF0066FF00C0FF00FFE600FFF300F3FF008CFF0099FF008CFF00E6FF00F3FF00F3FF00FFE600\
FFD900FFD900FFF300FFF300E6FF0033FF00FFFF00FFCC00FFC000FFC000FFB300
FFB300FFC000FFC000FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFC000FFC000FFCC00FFD900FFE600FFE600FFF300F3FF00C0FF0000FFF3
00FF00E6FF00E6FF00D9FF004CFF00FFD900FFCC00FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFCC008CFF00B3FF00FFFF00E6FF00CCFF00E6FF00FFB300FFA600FFA600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000FFCC00
FFCC00FFD900FFCC00FFCC00FFD900FFFF00FFFF00F3FF00A6FF00B3FF00B3FF0099FF00FFFF00\
FFF300FFF30066FF00CCFF003FFF0019FF0000FF59FFD900FFCC00FFC000FFCC00
FFD900FFE600FFD900FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFCC00FFD900FFD900FFE600FFF300E6FF00C0FF0000CCFF
00FF4000BFFF99FF0000FF0CB3FF00FFF300FFFF00FFCC00FFC000FFB300FFB300FFB300FFC000\
FFC000FFD900E6FF0066FF00C0FF00A6FF0099FF00FFCC00FFB300FFA600FFA600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFA600FFB300
FFB300FFC000FFC000FFC000FFCC00FFD900FFE600FFF30099FF004CFF0000000080FF0073FF00\
E6FF00F3FF00D9FF0059FF0026FF0080FF00FFFF00FFE600FFD900FFD900FFE600
CCFF003FFF00FFF300FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFFF00A6FF0080FF008CFF00
73FF00CC00FF3FFF0000FF3300FF4CCCFF00F3FF00FFD900FFC000FFC000FFC000FFC000FFC000\
FFD900B3FF0033FF00CCFF00FFFF00FFF300FFD900FFC000FFB300FFB300FFA600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFA600
FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFE600F3FF0099FF0000FF4073FF0000FF19\
66FF00C0FF0019FF000040FF66FF00E6FF00FFFF00FFF300FFE600FFE600F3FF00
B3FF00FFF300FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFD900FFE600FFE600FFFF00F3FF00CCFF00B3FF00
0019FF33FF0000F3FF8C00FF0059FF00FF73E6FF00FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD90000FF6699FF00E6FF00FFFF00FFE600FFD900FFC000FFC000FFB300FFB300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600
FFA600FFB300FFB300FFB300FFC000FFCC00FFD900FFE600FFFF0033FF00CCFF00C0FF0080FF00\
00FFBF19FF004CFF004CFF00B3FF00D9FF00D9FF00E6FF00FFF300FFF300F3FF00
3FFF00FFF300FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFD900FFE600FFE600FFF300FFFF00E6FF00D9FF00B3FF00
8CFF0000FF4000B3FF00FF4080FF00C0FF00F3FF00FFF300FFD900FFCC00FFCC00FFCC00FFD900\
FFE600CCFF0099FF0099FF008CFF00D9FF00FFD900FFCC00FFC000FFB300FFB300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFB300FFB300FFC000FFC000FFD900C0FF0099FF00B3FF00F3FF00E6FF00C0FF00\
8CFF0059FF0033FF004CFF0080FF00B3FF0080FF00E6FF00F3FF00F3FF00D9FF00
0CFF00D9FF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFCC00FFCC00\
FFCC00FFD900FFD900FFE600E6FF00F3FF00FFFF00C0FF00CCFF0099FF0000FF8C
008CFF00FF9900000000FF334CFF00C0FF0000FF3373FF00FFF300FFD900FFD900FFD900FFD900\
FFE600E6FF0000FF2600FFA699FF0000FF4C4CFF00FFD900FFCC00FFC000FFB300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFB300FFB300FFC000FFD900FFE600FFFF00FFFF00FFFF00F3FF00D9FF00\
CCFF00A6FF0000FF330000004CFF0066FF0000FFCC80FF00D9FF00B3FF0066FF00
000000CCFF00F3FF00C0FF00FFD900FFCC00FFCC00FFCC00FFD900FFF30073FF00FFE600FFD900\
FFD900FFD900FFE600FFF30000D9FFCCFF00CCFF00B3FF00C000FF5900FF19FF00
0000FF0000000000000000FF4CFF0019FF0000FF66E6FF00FFF300FFE600FFE600FFE600FFE600\
FFF300FFFF00E6FF00D9FF00C0FF0000FF4000FFFFFFFF00FFF300A6FF00FFC000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFCC00FFD900FFE600FFF300FFFF00F3FF00\
D9FF00A6FF004CFF0000FF8C00FF8000FF2600FF7359FF004CFF00B3FF0000FF19
33FF0000FFF373FF00FFFF00FFE600FFD900FFD900FFD900FFF30019FF0000FF99FFF300FFE600\
FFE600FFE600FFF300FFFF00CCFF0059FF003FFF0000000000FF3300FFD900FFBF
5900FF0000000000000066FF00000000D9FF19FF0033FF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFFF00F3FF00E6FF00CCFF0073FF0033FF00D9FF0099FF00FFF300FFCC00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFD900FFE600FFFF00E6FF00\
C0FF0000FFB326FF0000A6FF00000000000000FF8059FF0000FF0C80FF003FFF00
00FF8C4CFF0026FF00F3FF00FFF300FFE600FFE600FFE600FFFF0066FF00CCFF00F3FF00FFFF00\
E6FF00FFFF00FFFF00FFFF00E6FF00CCFF00B3FF0066FF003300FF000000000000
0000000000000000000000001900FF0026FF0099FFA6FF00F3FF00F3FF0099FF00FFFF00FFFF00\
FFFF00F3FF00E6FF00D9FF0000FFCC00D9FF00FFFF8CFF0059FF00E6FF00FFE600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600CCFF00B3FF00\
33FF0000F3FF000CFF00000000000000000000000000FFCC0059FF00FF0000FF99
0059FF00BFFFB3FF00CCFF00A6FF00FFF300FFF300FFF300FFFF00D9FF00A6FF0000FFCCB3FF00\
73FF00E6FF00E6FF00E6FF00E6FF00CCFF00B3FF003FFF000059FF000000000000
00000000000000000000000000000000000059FF00C0FF00D9FF00A600FF73FF00E6FF00F3FF00\
F3FF00D9FF00D9FF00CCFF0099FF0066FF0000FF0C00FF730CFF004CFF00FFF300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFF300F3FF00CCFF00\
A6FF0066FF0000FFD9000000000000000000000000000000000000000000000000
00000000FFD900FFF300FFCCD9FF00F3FF00FFFF00FFFF00F3FF00E6FF00C0FF0066FF00000000\
00000073FF00B3FF00CCFF00C0FF00C0FF000CFF0000FF66000000000000000000
0000000000000000000000000000000099FF00FF66A6FF00B3FF0059FF0000B3FFCCFF00D9FF00\
D9FF00000000B3FF0080FF0059FF004CFF0019FF0000FF8C0066FF8CFF0033FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900F3FF00F3FF00E6FF00CCFF00\
A6FF0066FF000CFF0000FFD9000000000000000000000000000000000000000000
0026FF00FF330000000CFF00C0FF00E6FF00F3FF00E6FF00E6FF00D9FF00A6FF00D900FF000000\
000CFF0C00FF73FF0099FF0080FF0099FF008CFF0059FF0000FF80000000000000
00000000000000000000000000000000000059FF0000FF6699FF0080FF00B300FF00FF8099FF00\
B3FF000C00FF00FF0000FFD900D9FF00FF590000000066FF00FF1900FFD9F3FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFE600E6FF0019FF0073FF0099FF00\
66FF0000FFB300BFFF000000000000000000000000000000000000000000000000
000000000CFF00000059FF00C0FF00D9FF00C0FF0080FF00CCFF00C0FF0099FF004CFF0000FFD9\
00000000FFCC00FF000C00FF00000000000026FF0033FF0000FF0000FFF3000000
00000000000000000000000000000000FF260CFF0000FF1919FF0026FF0000FFE6000000000000\
8CFF0080FF004CFF0000FF8C0000000000000000007300FF33FF0000FF40CCFF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600
FFA600FFA600FFB300FFC000FFCC00FFCC00FFD900FFD900FFE600FFFF00C0FF003FFF0019FF00\
33FF0000FF19000000000000000000000000000000000000000000000000000000
00000000000000FFFF0CFF0099FF00C0FF00B3FF0000FF0073FF0080FF0080FF00000000000000\
00000000000000FFBF00FF400000000000000000FFA600FF00000000F3FF000000
0000000000000000000000000033FF00000000000000D9FF00000000FF6600000000000000FF0C\
0000004CFF0000FF5900000000000000000000000000000000FFD93FFF00D9FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600
FFA600FFB300FFC000FFD90080FF00FFF300FFE600FFE600E6FF00CCFF0000FFE600FF1900FF99\
00FF8CA600FF000000000000000000000000000000000000000000000000000000
000000000000000000008CFF8CFF008CFF0099FF0000FFBFD900FF0026FF19FF0000FF0C000000\
0000000000000073FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000FF7300000000000000000000000000000000000000000080FF00B3FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600
FFA600FFB300FFCC00FFE600A6FF004CFF00F3FF00FFFF0066FF0000FF4C00FF0C73FF0000FF0C\
F300FF000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF6666FF0019FF000CFF0019FF0000000000000000FFD9000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000008000FF00000000000000000000000000FF8C73FF002600FF
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFB300FFC000FFCC00F3FF000CFF0026FF0019FF00D9FF00CCFF00A6FF00B3FF0000FF4C\
00000000FFFF000000000000000000000000000000000000000000000000000000
0000000000007300FF00FF0C00FFE60CFF000000000099FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000FFB300FF3333FF0000FF19
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFB300FFB300FFC000FFD900FFE600FFFF00FFFF00FFFF00F3FF00E6FF00CCFF0099FF00\
26FF0000FFA6000000000000000000000000000000000000000000000000000000
00000000000000000000FF3300FF8C000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000008000FF0073FF000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFB300FFB300FFC000FFCC00FFD900FFD900FFE600FFF300FFFF00F3FF00D9FF0080FF00\
00000000BFFF000000000000000000000000000000000000000000000000000000
00000000000000FFF3000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFD900FFE600FFF300F3FF00D9FF000059FF\
0CFF0000FF2600FFF3000000000000000000000000000000000000000000000000
0000008C00FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFD900FFE600FFF30080FF0000E6FF99FF00\
99FF0033FF007300FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFD900FFE600FFF300F3FF00D9FF00CCFF00\
C0FF0073FF0026FF0000FF3300FFD98C00FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFE600FFF300FFFF00E6FF00D9FF00\
C0FF00A6FF0080FF003FFF0000FF0000FF4000FFB3000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300FFF300FFFF00F3FF00E6FF00CCFF00\
B3FF0099FF004CFF0033FF0000FF73000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFB300\
FFCC00FFB300FFC000FFCC00FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFCC00FFCC00FFCC00FFCC00FFD900FFE600F3FF00CCFF00F3FF00F3FF00B3FF00CCFF0099FF00\
59FF0000000000FF190000000033FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600\
FFE60073FF00F3FF00FFE600FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFD900C0FF00FFD900FFD900FFE600FFE600F3FF0000FF8CCCFF00C0FF00000CFF8CFF008CFF00\
0CFF00000000000000F300FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600\
FFB300FFD900CCFF00FFFF00FFFF00FFCC00FFC000FFC000FFC000FFCC00FFCC00
FFE60033FF00FFF300FFF300FFF300FFF300FFFF00D9FF0099FF0000BFFF000000F300FF19FF00\
00FF99000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600\
FFB300FFCC00F3FF0000FF0CD9FF00FFD900FFCC00FFCC00FFCC00FFD900FFD900
FFF300E6FF0099FF0099FF00F3FF00F3FF00F3FF00D9FF00B3FF0000FF4C000000000000000000\
3300FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600\
FFB300CCFF00F3FF00B3FF0099FF00E6FF00FFE600FFE600FFF300FFFF00FFFF00
F3FF00B3FF0000FF1999FF00D9FF0000FFB3D9FF00CCFF008CFF0000FF26000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600\
FFB300FFC000FFCC00FFE60099FF0073FF00E6FF008CFF00A6FF0066FF00CCFF00
00FFD966FF003300FF80FF00A6FF003FFF00A6FF00B3FF0099FF0059FF00000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600\
FFA600FFB300FFC000FFD900FFE600F3FF00FFFF00C0FF0000FF199900FF00FFD9
19FF0000FF7300FF0000FF2600FF8000000000FFF380FF003FFF0000000000FFD9000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFB300FFC000FFC000FFCC00FFD900FFE600FFF300D9FF00000CFF73FF00
00FF26000000000000CC00FF0000002600FF00FF8C19FF0019FF00000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFA600FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFFF00C0FF004CFF00
00FF4C00FF1900000000000000000000000000000000000000FF99000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFCC00FFB300FFA600FF9900FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFFF00A6FF0000FF00
59FF0033FF0000FFCC000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FFB3008CFF00FFC000FFB300FFA600\
FFB300FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFFF000019FFCCFF0059FF00
B3FF0000FF800066FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FFA600FFB300F3FF00FFD900FFCC00\
FFE600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFF300FFFF00E6FF00
C0FF0033FF00000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFB300FFD900FFFF00FFF300\
FFC000FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFD900FFE600FFFF00E6FF00
00FF4066FF0000FF190000007300FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFC000F3FF00FFFF00\
FFC000FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300FFFF00F3FF00
CCFF00B3FF0080FF003FFF0000FF26000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300FFCC00FFF300FFF300\
FFCC00FFC000FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFC000FFC000FFCC00FFD900FFD900FFE600FFE600F3FF00E6FF00D9FF00
CCFF0080FF0066FF0000FF40000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600D9FF00D9FF00B3FF00D9FF00\
FFFF00FFF300FFD900FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFCC00FFFF00FFFF00FFF300FFF300FFF300F3FF008CFF0066FF00
99FF0080FF00000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600FFB300FFC000FFD900FFFF00\
C0FF00FFF300FFCC00FFC000FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFCC00FFE60099FF00A6FF00F3FF00E6FF00D9FF0080FF004C00FF
4CFF0033FF0000FF00000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFC000FFD900\
C0FF00FFFF00FFD900FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFCC00FFE600FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFE600FFFF0066FF0066FF0000FF0C3FFF0000000000FF99
00BFFF00000000FF80000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFC000FFE600\
C0FF00A6FF0000FF0CFFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFD90059FF0000FF00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFD900FFE600FFFF00F3FF00C0FF0000FF193300FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFCC00\
FFD900FFFF00E6FF00FFD900FFCC00FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFC000FFCC00F3FF00A6FF00FFF300FFD900FFCC00FFCC00FFC000FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF0099FF0073FF0000000000FF80
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300\
FFC000FFE600F3FF00FFFF00FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFCC00FFE60080FF00FFFF00FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00C0FF008CFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300\
FFC000FFC000FFD900FFFF0059FF00FFF300FFE600F3FF00FFE600FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFE6008CFF00FFFF00FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFF300FFFF00F3FF00E6FF00B3FF0080FF003FFF00
1900FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300\
FFB300FFC000FFCC00FFE60059FF0099FF00E6FF00D9FF00FFE600FFD900FFCC00
FFCC00FFCC00FFD900FFD900FFE600F3FF00E6FF00FFF300FFE600FFE600FFE600FFE600FFF300\
FFE600FFE600FFE600FFE600FFF300D9FF00D9FF00CCFF008CFF0000000000FF0C
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300\
FFB300FFC000FFCC00FFD900FFFF00C0FF0033FF00E6FF00FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFF300D9FF000CFF00C0FF00FFFF00FFF300FFF300E6FF0099FF00\
FFF300FFF300FFF300FFF300FFFF00CCFF000CFF00008CFF0000000066FF000000
7300FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300\
FFB300FFC000FFCC00FFD900FFFF000CFF00000000B3FF00F3FF00FFF300FFF300
3FFF00FFFF00FFF300FFFF0000FF0C99FF0000FF804CFF00F3FF00FFFF00FFFF00CCFF00C0FF00\
FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00CCFF0099FF0000E6FF0059FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFB300FFC000FFD900FFE600FFFF00A6FF0000FF8CC0FF00E6FF00F3FF00F3FF00
80FF00F3FF00F3FF00F3FF00D9FF000CFF0066FF00A6FF00C0FF00D9FF00E6FF00CCFF00CCFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00CCFF00B3FF0073FF0000FF0000CCFF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFB300FFC000FFE600D9FF00E6FF00B3FF0000FF598CFF00C0FF0073FF00C0FF00
00FF40CCFF0066FF00D9FF00C0FF0059FF0000FF330073FF00FF40A6FF00B3FF0000FF0000FF99\
D9FF00E6FF008CFF00E6FF00E6FF00D9FF0099FF0099FF0000FF0C0059FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFCC00FFE600FFF300F3FF0059FF0000FF3300FF3300FF804CFF00
00FF5980FF0000FF99B3FF0099FF0080FF0033FF0000FF9900000066FF0066FF0000FF4C00FF33\
A6FF00C0FF008CFF00CCFF00D9FF00CCFF00A6FF0033FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF8C00FF8C00FF7F00FF7F00FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFB300\
FFC000FFC000FFCC00FFD900FFE600F3FF00E6FF00C0FF0099FF000CFF0000FFA6
0000FF00FF0C00FFB373FF008000FF4CFF0000FF8C8C00FF00000000FF3326FF0000FF730040FF\
66FF000CFF008CFF00C0FF00C0FF00C0FF00B3FF008CFF000CFF0000F3FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF9900FF9900FF8C00FF7F00FF7F00FF7F00\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFB300FFC000\
FFC000FFCC00FFCC00FFD900FFE600FFF300F3FF00D9FF00B3FF0073FF0000FF80
0000000000000000000CFF0000FF4CD900FF00FFB30000000000000000000000000026FF000000\
00FF0C00E6FF59FF008CFF008CFF00A6FF0099FF003FFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFC000FF8C00FF8C00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFCC00FFD900FFE600FFF300FFFF00F3FF008CFF008CFF0000FFCC000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000FFE600BFFF80FF008CFF008CFF0066FF0000FFA6000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFFF00FF9900FF8C00FF8C00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFE600FFE600FFD900FFCC00FFCC00\
FFCC00FFD900FFE600E6FF00F3FF00F3FF00E6FF00CCFF0000FF260CFF003300FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000A600FF0019FF59FF0066FF0026FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFCC00FFA600FF8C00FF8C00FF8C00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FFC000FFB300FFA600FFA600FFA600FFA600
FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFCC00D9FF00FFFF00FFD900FFD900\
FFD900FFD900FFE600F3FF000CFF00D9FF00C0FF0099FF008CFF004CFF0000FF26
00E6FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000004CFF26FF003FFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFCC00FFB300FF9900FF8C00FF8C00\
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FFA600FFB300FFFF00FFC000FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFE60066FF00FFFF00FFE600\
FFE600FFE600FFF300FFFF00E6FF0099FF0000FF8C73FF0000FF0000FF19000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000FF2600FF19000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFC000FFB300FFA600FF9900FF8C00\
FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FFB300FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FFA600FFCC00F3FF00FFE600FFC000FFB300FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFD900FFF30019FF00FFFF00\
F3FF00FFFF00FFFF00F3FF00E6FF00B3FF0059FF0000FF8CC000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000FF9900FF33000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600FFB300FFC000FFA600FF9900FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FFC000FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FFA600FFA600FFC000FFF300FFE600FFCC00FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFE600F3FF0000FF33\
73FF00E6FF00E6FF00C0FF00CCFF00B3FF008CFF0019FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000C000FF00FF73000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFF300FFB300FFA600FFA600\
FFA600FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFA600\
FFCC00FFB300FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFB300FFC000E6FF00E6FF00FFD900FFC000FFC000
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600E6FF008CFF00\
66FF00C0FF00CCFF008CFF00B3FF0099FF000C00FF00FF330033FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000FFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000FFF300FFD900FFCC00FFC000\
FFD900FFB300FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600B3FF00\
FFE600A6FF00FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFB300FFC000FFD9008CFF00FFD900FFCC00FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFF300F3FF00CCFF00\
008CFF80FF0099FF0066FF0066FF0059FF003FFF0000FF99000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FFCC00FFB300FFB300FFD900FFD900FFFF004C00FFE6FF00FFE600\
FFCC00FFB300FFA600FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFC000\
FFE600FFCC00FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFC000FFC000FFD900FFFF00FFE600FFD900FFCC00
FFCC00FFCC00FFD90099FF00FFD900FFD900FFD900FFD900D9FF00FFF300FFFF00F3FF00D9FF00\
A6FF0000FF8033FF0019FF0000FF2600FF4000FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FFA600FFB300CCFF00FFCC00FFE600E6FF00A6FF0000000080FF0000FF40\
FFD900FFC000FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000\
FFF300FFD900FFC000FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFC000FFC000FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFC000FFC000\
FFB300FFB300FFC000FFC000FFC000FFCC00FFD900F3FF00F3FF00FFF300FFFF00
FFD900FFD900FFE600A6FF00FFF300FFE600FFE600FFE600F3FF00D9FF00F3FF00C0FF00B3FF00\
99FF0019FF00008CFF0066FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FFA600\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FFA600FFB300FFC000FFD900F3FF00D9FF0080FF0000000000000000000000FF59\
FFFF00FFCC00FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFC000FFA600FFA600FFA600FFA600FFA600FFB300FFC000FFD900\
FFE600FFF300FFD900FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFD900FFD900FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFD900FFD900\
FFC000FFC000FFCC00FFE600FFD900FFE600E6FF00E6FF00B3FF00D9FF00FFFF00
FFF300FFF300FFF300D9FF00FFFF00FFF300FFFF00FFFF00F3FF0073FF00C0FF00C0FF004CFF00\
0CFF0000FF66000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFB300\
FFB300FFA600FFA600FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFA600FFB300FFB300FFC000FFFF00D9FF004CFF00000000000000000000000000000000000000\
F3FF00FFD900FFC000FFC000FFB300FFB300FFC000FFF300FFB300FFB300FFB300
FFB300FFB300FFB300FFCC00FFE600FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFFF00\
C0FF0066FF00FFFF00FFCC00FFCC00FFC000FFC000E6FF00FFCC00FFCC00FFCC00
FFF300FFE600FFCC00FFCC00FFCC00FFD900FFC000FFC000FFCC00FFCC00FFCC00FFE600FFF300\
FFD900FFE600FFE600E6FF00FFF300FFFF00D9FF008CFF0000000080FF00E6FF00
F3FF0099FF00E6FF0080FF00CCFF00D9FF00D9FF00D9FF00C0FF008CFF0073FF004CFF0026FF00\
00FF990033FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFB300FFC000FFC000FFCC00FFC000FFCC00FFC000FFCC00FFCC00FFC000FFCC00FFD900FFF300\
FFE600FFE600FFCC00FFCC00FFCC00FFE600FFE600FFCC00FFCC00FFD900FFF300
FFD900FFD900FFE600FFF30099FF0059FF00000000000000000000000000000000000000000000\
D9FF00F3FF00FFF300FFF300FFE600FFF300FFE60073FF00FFE600FFFF00FFE600
FFF300FFE600FFF300FFFF00D9FF00FFF300B3FF00FFFF00FFF300CCFF00FFF300FFFF00D9FF00\
000000000000D9FF00F3FF00F3FF00FFFF00F3FF00CCFF00FFFF00A6FF00F3FF00
CCFF00D9FF00D9FF00D9FF00F3FF00F3FF00F3FF00FFF300F3FF008CFF00C0FF00CCFF00C0FF00\
D9FF00CCFF0019FF003FFF00B3FF00B3FF003FFF0000000000000033FF0066FF00
8CFF003FFF0000FF4C00FF4C4CFF0059FF0059FF0073FF0033FF0000FF0C00FF6600D9FF00FFBF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFB300\
FFB300FF9900FF9900FF9900FF9900FF9900FFA600FF9900FF9900FFA600FFA600
FFA600FFA600FFB300FFC000FFE600C0FF0033FF003300FF000000000000000000000000000000\
E6FF00FFCC00FFC000FFB300FFB300FFB300FFB300FFE600FFB300FFB300FFA600
FFB300FFB300FFB300FFCC00FFF300FFC000FFB300FFC000FFC000FFB300FFC000FFCC00E6FF00\
C0FF000CFF00FFFF00FFCC00FFC000FFC000FFC000FFE600FFC000FFC000FFCC00
FFF300FFE600FFCC00FFC000FFC000FFCC00FFC000FFC000FFC000FFCC00FFCC00FFE600FFF300\
FFD900FFD900FFE600F3FF00FFE600FFF300E6FF00A6FF0000FF8C80FF00E6FF00
FFFF0073FF00F3FF004CFF00CCFF00E6FF00E6FF00E6FF00D9FF0026FF008CFF0080FF0059FF00\
00000000FFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FFA600FFA600FFC000FFD900FFF300F3FF00B3FF00000000000000000000000000\
D9FF00FFCC00FFB300FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FFA600FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFCC00\
FFE600FFE600FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFD900FFD900FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFB300FFB300FFE600FFD900\
FFC000FFC000FFCC00FFD900FFCC00FFD900FFFF00E6FF00CCFF00E6FF00FFFF00
FFE600FFE600FFF300D9FF00FFFF00FFF300FFF300FFF300F3FF0000FFE6CCFF00C0FF003FFF00\
66FF0000FF4C0059FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FFA600FFB300FFE600FFCC00FFD900FFFF00CCFF00000000B3FF00D9FF00\
FFCC00FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000\
FFE600FFD900FFC000FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFC000FFB300\
FFB300FFB300FFB300FFC000FFC000FFCC00FFD90059FF00F3FF00FFE600FFE600
FFD900FFD900FFE600C0FF00FFE600FFD900FFD900FFE600E6FF00E6FF00F3FF00C0FF00C0FF00\
99FF0000FF1900000000FFD9000000E600FF00FF8C0026FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF9900CCFF00FFB300FFB300FFCC00FFCC00FFF30073FF00FFF300FFD900\
FFCC00FFB300FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFC000\
FFFF00FFD900FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFC000FFD900FFFF00FFE600FFD900FFCC00
FFCC00FFCC00FFCC0026FF00FFD900FFCC00FFCC00FFD900FFF300FFF300FFF300F3FF00D9FF00\
A6FF0000FF594CFF0000FFA600FF2600FF730CFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFC000FFFF00FFCC00FFCC00FFB300\
FFCC00FFB300FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFB300\
FFD900FFE600FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFB300FFC000FFD90000FF40FFD900FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600F3FF00CCFF00\
2600FF99FF00A6FF003FFF0073FF0080FF004CFF0000FFF3000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000073FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFE600FFB300FFA600FFA600\
FFA600FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFA600\
FFCC00FFB300FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFB300FFC000FFE600CCFF00FFD900FFC000FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFD900FFE600F3FF00A6FF00\
8CFF00CCFF00D9FF0059FF00C0FF0099FF003FFF0000FFE6000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000FFCC000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300FFC000FFA600FF9900FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900\
FFC000FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FFA600FFA600FFCC00FFFF00FFE600FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFE600F3FF00A6FF00\
99FF00F3FF00F3FF00D9FF00D9FF00C0FF008CFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000019FF00FF66000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFC000FFB300FF9900FF9900FF8C00\
FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FFA600FFC000FFFF00FFF300FFC000FFB300FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFD900FFFF00C0FF00FFFF00\
FFFF00FFF300FFFF00FFFF00E6FF008CFF0000FFE60C00FF000CFF00A6FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000FF3300FF26000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFC000FFB300FF9900FF8C00FF8C00\
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FFA600FFB300FFFF00FFC000FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFC000FFCC00FFF30033FF00FFF300FFE600\
FFE600FFE600FFF300FFFF00D9FF0000FF1980FF008CFF004CFF0000FF80000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000FFCC00FF000CFF001900FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFD900FF9900FF8C00FF8C00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FFC000FFB300FFA600FFA600FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFCC00A6FF00FFF300FFD900FFD900\
FFD900FFD900FFE60000FF0CA6FF00E6FF00D9FF00C0FF0099FF0059FF0000FF33
008CFF000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000059FF33FF004CFF0033FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FFC000FF9900FF8C00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300F3FF00FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFFF00FFFF00FFFF00E6FF00C0FF0080FF0000FF5900FF80
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000CFF0040FF4CFF0066FF0073FF00D900FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF9900FFE600FF8C00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFC000\
FFC000FFCC00FFD900FFD900FFE600FFF300F3FF00C0FF0099FF0059FF0000A6FF
00000000000000000000FFFF000000000000000000000000000000000000000000000000000000\
00000000F3FF00000000FF4C80FF0099FF008CFF0059FF00D900FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF9900FF9900FF7F00FF7F00FF7F00FF7F00\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFB300FFC000\
FFC000FFC000FFCC00FFD900FFE600FFF300F3FF00D9FF0099FF0066FF0000FF19
00000000000000A6FF26FF0000FF6600FF8000FF8000000000000000FFCC000000000000000000\
00FF199900FF73FF0099FF008CFF00B3FF0099FF0066FF000033FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300\
FFC000FFC000FFCC00FFD900FFE600A6FF00D9FF0099FF008CFF0000FF000000FF
00FF9926FF0000FF4C80FF003FFF0059FF0000FF190066FF00000000FF0C3FFF0000FF2600FF73\
4CFF0080FF0099FF00C0FF00CCFF00C0FF00B3FF008CFF0019FF0000B3FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFCC00FFE600FFF300E6FF0066FF0000000000FF662600FF73FF00
00FFCC99FF0000FF73C0FF00A6FF008CFF0019FF0000E6FF00FFE673FF0080FF0000FF198CFF00\
C0FF00C0FF0066FF00D9FF00D9FF00CCFF0099FF0000FF19000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFB300FFC000F3FF0026FF008CFF0080FF0000FF198CFF00CCFF0059FF00CCFF00
00FF33D9FF00B3FF00D9FF00CCFF0026FF0000FFF30000FF00D9FFC0FF00C0FF0080FF0099FF00\
D9FF00E6FF00B3FF00E6FF00E6FF00D9FF00C0FF00A6FF000080FF0066FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFB300FFC000FFCC00FFE600FFFF00CCFF0033FF00CCFF00F3FF00F3FF00F3FF00
00FF0CF3FF00FFFF00F3FF00D9FF0000FFFF66FF00C0FF00D9FF00E6FF00E6FF00CCFF00CCFF00\
F3FF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00B3FF0073FF0000000000BFFF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300\
FFB300FFC000FFCC00FFD900FFF300C0FF0000FFFF00FF4CF3FF00FFF300FFF300
CCFF00FFF300FFF300FFF300C0FF0059FF0033FF00C0FF00F3FF00FFFF00FFFF00D9FF0080FF00\
FFFF00FFF300FFF300FFFF00FFFF00E6FF00CCFF0099FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300\
FFB300FFC000FFCC00FFE600FFFF00B3FF0000FF4CE6FF00FFF300FFE600FFD900
FFD900FFD900FFD900FFE600FFF30073FF0099FF00E6FF00FFF300FFE600FFF300FFFF00D9FF00\
FFF300FFF300FFF300FFF300FFFF00B3FF0000FF2680FF005900FF00E6FF000000
0033FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300\
FFB300FFC000FFCC00FFE600B3FF00D9FF00F3FF00D9FF00FFE600FFD900FFCC00
FFCC00FFCC00FFD900FFD900FFE600F3FF00F3FF00FFF300FFE600FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300F3FF00E6FF00D9FF008CFF0000FFA619FF00
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300\
FFC000FFCC00FFD900FFFF00D9FF00FFE600FFD900F3FF00FFE600FFCC00FFC000
FFC000FFC000FFCC00FFD900FFE600B3FF00F3FF00FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFF300FFF300F3FF00E6FF00C0FF008CFF004CFF00
00FFCC000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFB300\
FFC0008CFF00E6FF00FFF300FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFE600A6FF00F3FF00FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFE600FFF300FFFF00D9FF00C0FF0080FF0000FF66
0040FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFD900\
FFD900F3FF00D9FF00FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFCC00A6FF0066FF00FFF300FFD900FFCC00FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFD900FFD900FFE600FFF300F3FF00CCFF004C00FF0080FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFC000FFD900\
8CFF00E6FF00FFFF00FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFCC0000FF19FFF300FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFD900FFF300FFFF00E6FF00A6FF0019FF00A600FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFC000FFD900\
00FF26E6FF00FFCC00FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFC000FFD900FFC000FFC000FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFCC00FFE600E6FF00000000C0FF008CFF0080FF000080FF00FFB3
0000000099FF00FF66000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600FFC000FFC000FFD900D9FF00\
66FF00FFFF00FFCC00FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFCC00FFE6003FFF0073FF00FFFF00F3FF00E6FF0099FF0000BFFF
59FF0066FF00000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFF300FFE60000FF80F3FF00\
FFE600FFD900FFF300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFCC00FFD900FFE600FFE600FFE600FFF300F3FF0099FF00A6FF00
A6FF0080FF001900FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFB300FFC000FFF300FFFF00\
FFCC00FFC000FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFFF00F3FF00E6FF00
CCFF00A6FF003FFF0026FF00000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFC000FFF300FFFF00\
FFC000FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300FFFF00F3FF00
CCFF00B3FF0080FF0026FF0000FF40000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFB300FFF300D9FF00D9FF00\
FFC000FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFD900FFF300FFFF00E6FF00
8CFF00000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FFA600FFC000F3FF00FFCC00FFC000\
D9FF00FFA600FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFFF00F3FF00E6FF00
C0FF0000FF9900A6FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FFC000FFF300FFB300FFA600FFA600\
FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFF30000FFA6B3FF0019FF00
A6FF004CFF0000FFF3000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFE600FFB300FF9900FF9900FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFFF00C0FF00000000
3FFF0033FF000C00FF0000000000000000000000000000000080FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF9900FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFB300FFB300FFC000FFCC00FFCC00FFD900FFE600FFFF00CCFF0033FF00
00E6FF00FF40A600FF00000000000000000000000000FFBF00FF8C000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFB300FFC000FFC000FFCC00FFD900FFE600FFFF00C0FF0099FF0033FF00
00FF4C0026FF00FF5900000000FF4000BFFF00FF5933FF0019FF00000CFF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600\
FFB300FFB300FFC000FFE600FFF300CCFF00E6FF00B3FF0059FF0000FF4066FF00
0CFF0000FF3300FF0C4CFF0000FF3300FFB300FFA68CFF000CFF0000000000FF8C000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600\
FFB300FFC000FFD900FFF30019FF0000FF66FFFF00F3FF0033FF0000FF33E6FF00
26FF004CFF000000008CFF00B3FF008CFF00C0FF00C0FF0099FF0059FF003300FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600\
FFB300FFD90099FF0080FF00B3FF0073FF00FFE600FFD900FFE600FFF300FFF300
FFFF004CFF0000FFBF8CFF00D9FF00A6FF00E6FF00CCFF003FFF0000FF5900FFCC000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600\
FFB300FFCC00FFFF00CCFF00E6FF00FFD900FFCC00FFCC00FFCC00FFD900FFD900
FFE600E6FF00C0FF0019FF00FFFF00FFFF00F3FF00D9FF00B3FF0000FF4C0C00FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600\
FFC000FFD90073FF00FFF300FFD900FFCC00FFC000FFC000FFC000FFCC00FFCC00
FFE600A6FF00FFF300FFE600FFE600FFF300FFFF00D9FF0066FF0000FF4000FFF300CCFF59FF00\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600\
80FF00FFFF00FFE600FFE600FFC000FFC000FFB300FFB300FFC000FFC000FFC000
FFD900FFF300FFD900FFD900FFD900FFE600CCFF0059FF00D9FF00CCFF004CFF00A6FF0099FF00\
26FF0000000000FF59000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFA600\
FFB300FFB300FFB300FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFCC00FFCC00FFCC00FFD900FFD90000FF33E6FF00FFFF00F3FF00D9FF00D9FF00000000\
8CFF0000FF003FFF000000001900FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFE600FFF300FFFF00F3FF00E6FF00CCFF00\
C0FF00A6FF0080FF004CFF0000FF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFE600FFF300FFFF00E6FF00D9FF00\
C0FF0099FF0080FF000059FF00FF4000FFE600FFBF0080FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFD900FFE600FFF300F3FF00D9FF00CCFF00\
B3FF0080FF0000FF4CF300FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFD900FFE600FFF300C0FF000CFF0080FF00\
66FF004CFF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFE600FFF300F3FF00D9FF0073FF00\
00FF0C00000000A6FF000000000000000000000000000000000000000000000000
000000A600FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFB300FFB300FFC000FFCC00FFD900FFE600FFE600FFF300FFFF00F3FF00D9FF004CFF00\
00D9FF00FFFF000000000000000000000000000000000000000000000000000000
00000000000000FFD9000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFB300FFB300FFC000FFF300FFF300E6FF00E6FF00FFFF00E6FF00D9FF00CCFF0099FF00\
33FF0000E6FF000000000000000000000000000000000000000000000000000000
00000000000000000000FF1900FF330000005900FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000D900FF0000000066FF
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFB300FFC000FFCC00F3FF0000FFA680FF00C0FF00C0FF00B3FF0099FF00A6FF0000FF8C\
004CFF000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF0C00FF1919FF0000000000FFE60033FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000FFCC00FF193FFF0000FF19
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600
FFA600FFB300FFCC00FFFF008CFF00CCFF00FFFF00FFFF00CCFF00008CFF0019FF66FF0000FF66\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000073FF00008CFF33FF0033FF000099FF00000000FF99C000FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000026FF73FF000CFF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600
FFA600FFB300FFC000FFCC00FFFF00FFE600FFD900FFE600B3FF00D9FF0000FF40A600FF00FF33\
00FF330099FF000000000000000000000000000000000000000000000000000000
0000000000000000000099FF99FF00A6FF0099FF003FFF00F300FF00000033FF0000FF19000000\
00000000000000FFFF0000003300FF000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000FFB3\
00000000FF2600FF8000000000000000000000000000000000000080FF00C0FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FFA600FFA600FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFFF0099FF0000FF3326FF00\
4CFF0000FF73000000000000000000000000000000000000000000000000000000
0000000000000026FF4CFF0073FF00C0FF00B3FF0026FF0099FF0099FF008CFF0019FF000059FF\
0000000000000000000CFF000066FF00000000FFFF00000000000000FFB3000000
00000000000000000000000000FFF300000000000000FFF35900FF00FF4C00000000000000FF40\
26FF0059FF000000000000000000000000000000000000008000FF3FFF00D9FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFCC00FFE600B3FF0033FF0099FF00B3FF00\
00A6FF00FF8C00FFA6000000000000000000000000000000000000000000000000
00000000F3FF00FFE68C00FFC0FF00D9FF00CCFF000CFF00D9FF00CCFF0080FF0019FF0000FF59\
00000000FF730CFF0066FF0000FF590000004CFF004CFF0000FF0C000000000000
000000000000000000000000000000A600FF33FF0000FF0059FF0000FF000000000000000CFF00\
99FF0080FF003FFF000000000000000000000000000000003FFF00000000C0FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFF300FFFF00F3FF00D9FF00\
B3FF0073FF000CFF0000FFCC000000000000000000000000000000000000000000
00000000FF4C00000059FF00D9FF00F3FF00F3FF00F3FF00E6FF00D9FF00B3FF000033FF00D9FF\
0C00FF00000059FF00A6FF0099FF00A6FF008CFF0059FF00000000000000000000
00000000000000000000000000000000FFD966FF0080FF0099FF008CFF0000FF3319FF00B3FF00\
C0FF0000FF0000FF7300000000000000FF4C0026FFA600FF00FF000033FFF3FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFF300F3FF00A6FF00\
99FF0059FF0000FF99000000000000000000000CFF000000000000000000000000
00000026FF008CFF003FFF00D9FF00FFFF00FFFF00FFFF00F3FF00E6FF00C0FF003FFF0019FF00\
8000FF99FF00C0FF00D9FF00CCFF00C0FF003FFF0000FF6600F3FF000000000000
00000000000000000000000000000000FFF300CCFFB3FF00C0FF0000FF4C33FF00D9FF00E6FF00\
D9FF0000FF40C0FF00A6FF008CFF0066FF0000FF0000FFA600FFB38CFF00FFFF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600E6FF00CCFF00\
99FF0000FF0C0066FFA600FF00000000000000FFF300FF19E600FF26FF000026FF
5900FF26FF00C0FF00E6FF00E6FF00FFF300FFF300FFF300FFFF00CCFF0073FF0073FF00CCFF00\
3FFF00E6FF00F3FF00F3FF00E6FF00CCFF00B3FF008CFF00B300FFC000FF000000
00000000000000000000000000000000000059FF00C0FF00D9FF00B3FF0000FF8CF3FF00F3FF00\
F3FF00E6FF00E6FF00CCFF0080FF004CFF000CFF0019FF0000FF4CA6FF00FFF300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFE600FFFF00F3FF00\
A6FF0066FF0000B3FF0000000000001900FF00FF1966FF0066FF008CFF003FFF00
00F3FF00000059FF00F3FF00FFF300FFE600FFE600FFE600FFF30000FFB3D9FF00F3FF00FFFF00\
FFFF00FFF300FFF300FFFF00E6FF00C0FF00A6FF000CFF0000FF19000000000000
00000000000000000000000000CCFF00FF8C0C00FFCCFF00F3FF00FFFF00F3FF00FFFF00FFF300\
FFFF00FFFF00F3FF00D9FF008CFF0000BFFF0019FFA6FF0099FF00E6FF00FFD900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFD900FFE600FFE600FFF300FFFF00F3FF00\
D9FF0099FF0019FF000059FF00FF5926FF0000FFA673FF00C0FF00B3FF0066FF00
00FF263FFF00B3FF00FFFF00FFE600FFD900FFD900FFD900FFE60000E6FFB3FF00FFF300FFE600\
FFE600FFE600FFE600FFF30000FF1999FF0000F3FF00FF4C00FF8C00FFA600FF73
00BFFF00000000000000FFE600FF0000FF0C0CFF0000FF4CFFFF00FFF300FFE600FFE600FFF300\
FFF300FFFF00F3FF00E6FF00CCFF0080FF003FFF00E6FF00000000FFF300FFCC00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600
FFA600FFA600FFB300FFB300FFB300FFC000A6FF00FFFF00F3FF00FFFF00FFFF00F3FF00B3FF00\
C0FF00A6FF003FFF000080FF4CFF004CFF0000FF00CCFF00E6FF0059FF0099FF00
19FF00C0FF00FFFF00FFFF00FFD900FFCC00FFCC00FFCC00FFD900FFF30099FF00FFE600FFD900\
FFD900FFD900FFE600FFF300B3FF00CCFF00E6FF00C0FF00008CFF00FFBF4CFF00
00FF1900000000000000000019FF0059FF0073FF00E6FF00FFF300FFE600FFE600FFE600FFE600\
FFF300FFFF00E6FF00CCFF00C0FF0000FFF300FF59FFF300FFE600FFF300FFC000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFB300FFB300FFC000FFC000FFD900E6FF00CCFF0033FF00E6FF00E6FF00C0FF00\
73FF003FFF0019FF0059FF003FFF00C0FF0080FF00E6FF00FFFF00F3FF00E6FF00
4CFF0000FF26FFE600FFD900FFCC00FFCC00FFC000FFC000FFCC00FFCC00FFD900FFCC00FFCC00\
FFCC00FFCC00FFD900FFE600FFFF00FFFF00FFFF00E6FF00D9FF00B3FF0000FF8C
33FF0000FF4C00000000FF0C00FFCCC0FF0000FF7300FFFFFFF300FFD900FFD900FFD900FFD900\
FFE60000FF1900FF0000FF008CFF0000FF0C00FF33FFD900FFCC00FFC000FFB300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600
FFA600FFB300FFB300FFB300FFC000FFCC00FFD900FFE600FFFF0019FF00B3FF00B3FF0080FF00\
00000059FF0000FF8C3FFF00B3FF00D9FF00E6FF00F3FF00FFF300FFF300F3FF00
CCFF00FFF300FFD900FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFD900FFE600FFE600FFF300FFFF00F3FF00D9FF00B3FF00
8CFF004CFF0000FF8C00FF4080FF00B3FF00FFFF00FFE600FFD900FFCC00FFCC00FFCC00FFD900\
FFE600C0FF0099FF00CCFF00CCFF00FFF300FFD900FFCC00FFC000FFB300FFB300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFA600
FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFE600F3FF008CFF00B300FF59FF000099FF\
73FF00CCFF0073FF000CFF008CFF00E6FF00FFFF00FFE600FFE600FFE600FFFF00
A6FF00FFFF00FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFD900FFE600FFE600FFFF00E6FF00C0FF00B3FF00
73FF0000FF400099FF00FF4000FF8059FF0000FF73FFD900FFCC00FFCC00FFC000FFC000FFCC00\
FFD90099FF000CFF00E6FF00FFFF00FFE600FFD900FFC000FFC000FFB300FFA600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFB300
FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF30000FF8C00FFA600A6FF8CFF00B3FF00\
F3FF00F3FF00D9FF0019FF0000FFD9B3FF00FFFF00FFE600FFD900FFCC00FFD900
D9FF0099FF00F3FF00FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFFF0066FF0099FF0080FF00
59FF0000E6FF33FF0000FFBFB3FF00D9FF00E6FF00FFD900FFC000FFC000FFC000FFC000FFC000\
FFD90000FF5959FF008CFF00F3FF00FFF300FFE600FFCC00FFB300FFB300FFA600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000FFE600
FFCC00F3FF00FFD900FFD900FFD900F3FF00F3FF00F3FF0059FF00C0FF00C0FF00C0FF00FFF300\
FFE600FFF30019FF00E6FF00A6FF008CFF00E6FF00FFD900FFCC00FFC000FFC000
FFCC00FFD900FFCC00FFB300FFB300FFB300FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFCC00FFD900FFD900FFE600FFF300F3FF00CCFF0000FF80
00FF9999FF008CFF0059FF003FFF00FFF300FFE600FFCC00FFC000FFB300FFB300FFB300FFB300\
FFC000FFD900F3FF0073FF008CFF0073FF0033FF00FFCC00FFB300FFA600FFA600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF9900FF9900FFA600FFB300FFB300FFC000FFCC0066FF00
E6FF008CFF003FFF00FFF300FFFF00E6FF008CFF008CFF0099FF00F3FF00F3FF00E6FF00FFE600\
FFD900FFD900FFE600FFF300E6FF0000FFA600FF4CFFCC00FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFC000FFCC00FFD900FFE600FFE600FFFF00F3FF00CCFF000CFF00
0CFF00E6FF00F3FF00D9FF00A6FF00FFD900FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFCC00F3FF00A6FF00FFF300F3FF00D9FF00A6FF00FFB300FFA600FFA600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF9900FFA600B3FF00FFFF00FFCC00FFCC00F3FF00E6FF00
F3FF00FFF300FFE600C0FF008CFF00C0FF00CCFF00FFFF0066FF00FFFF00FFD900FFE600FFCC00\
FFCC00FFCC00FFCC00FFE600F3FF00CCFF00FFE600FFCC00FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFC000FFC000FFCC00FFE600FFF300FFFF00FFFF0066FF00A6FF000CFF00
CCFF00FFF300FFE6004CFF00FFFF00FFCC00FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFC000FFCC008CFF00FFF300FFB300FFA600FFA600FF9900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF9900FFA600FFB300FFD900FFFF00FFF300B3FF00D9FF00
FFE600FFD900FFCC00FFD900FFD900FFE600FFD900FFD900F3FF00FFE600FFC000FFC000FFC000\
FFC000FFC000FFCC00FFE600C0FF00FFE600FFC000FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300\
FFB300FFC000FFCC00FFE600E6FF0019FF00CCFF00D9FF0099FF0000FF7326FF00
A6FF00FFD900FFCC00FFF30073FF00FFCC00FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFC00059FF00FFCC00FFA600FFA600FF9900FF9900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF9900FF9900FFA600FFB300FFCC00D9FF00B3FF00FFFF00FFE600
FFD900FFC000FFC000FFC000FFC000FFC000FFC000FFC000C0FF00FFCC00FFB300FFB300FFB300\
FFB300FFB300FFC00000FF0CFFFF00FFCC00FFC000FFB300FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFB300FFC000FFCC0066FF006600FFD9FF008CFF0033FF0073FF00FFFF0000FF19
FFD900FFC000FFC000FFC000FFC000FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFB300FFA600FF9900FF9900FF9900FF9900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF9900FF9900FFA600FFB300FFCC00FFE600E6FF00FFF300FFCC00
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFB300FFA600FFA600FFA600\
FFA600FFA600FFB300FFD90099FF00FFE600FFC000FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFB300FFC000FFD900E6FF00A6FF00FFFF00FFF300FFF300FFE600FFD900FFCC00
FFC000FFB300FFB300FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF9900FF9900FFA600FFB300FFCC00FFE600F3FF00F3FF00FFD900FFCC00
FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FFA600FFA600FFA600FFB300FFCC004CFF00FFC000FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFB300A6FF00D9FF00A6FF00D9FF00FFF300FFE600FFD900FFCC00FFC000FFC000
FFB300FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00\
FF9900FFA600FFA600FFA600FFB300FFCC00F3FF0000CCFFCCFF00FFFF00FFC000
FFB300FFB300FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFB300FFD900FFA600FF9900FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600\
FFA600FFC000FFE60059FF00A6FF00FFF300FFD900FFCC00FFC000FFC000FFB300
FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900\
FFB300FFCC00FFC000FFC000FFC000FFD900E6FF0059FF00B3FF00FFD900FFC000
FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FFA600FFB300FFCC00FFF300000000FFFF00FFD900FFCC00FFC000FFB300FFB300
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF9900FFD900\
3FFF00FFD900FFFF00FFD900FFFF00FFF300C0FF00FFD900FFCC00FFC000FFB300
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FFA600FFB300FFCC00FFF30099FF00F3FF00FFE600FFD900FFC000FFB300FFB300
FFA600FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900\
FFA600FFA600FFC0003FFF00FFF300FFFF00B3FF00FFD900FFC000FFB300FFB300
FFA600FFA600FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FFA600FFCC00F3FF00A6FF0099FF00CCFF00F3FF0066FF00FFCC00FFC000FFB300
FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00\
FF9900FF9900FFA600FFB300FFC000FFCC00FFF300F3FF00FFC000FFB300FFA600
FFA600FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FFC000FFC000FFCC00A6FF00FFE600CCFF00B3FF00FFF300FFF300FFB300
FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00\
FF8C00FF9900FF9900FFA600FFB300FFCC008CFF00FFD900FFC000FFB300FFA600
FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FFA600FFB300FFC000FFC000FFD900FFFF004CFF00FFF300FFB300
FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF9900FFA600FFB300FFD900CCFF00FFD900FFC000FFB300FFA600
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FFA600FFA600FFB300FFCC00FFE600FFFF00F3FF00FFCC00
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF8C00FF8C00FF9900FFA600FFB300FFCC00A6FF00B3FF00FFE600FFC000FFA600
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF9900FFA600FFB300FFE600FFFF00CCFF00FFB300FFA600
FF9900FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF8C00FF8C00FF9900FFA600FFD900FFE60000FF730059FFFFF300FFF300FFB300
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF9900FF9900FFC000FFF300FFCC00FFB300FF9900FF9900
FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF8C00FF8C00FF9900FF9900FFB300FFE600D9FF00CCFF00FFCC00FFB300FFA600
FF9900FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF9900FFB300FFFF00FFC000FF9900FF9900FF8C00
FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF8C00FF8C00FF9900FF9900FFA600FFB300FFCC008CFF00FFCC00FFA600FF9900
FF9900FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF9900F3FF00FFA600FF9900FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF8C00FF8C00FF9900FF9900FFA600FFB300FFE600FFE600FFC000FFA600FF9900
FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF8C00FF8C00FF8C00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF8C00FF8C00FF9900FF9900FFA600FFC000FFE600FFE600FFC000FFA600FF9900
FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF8C00FF9900FF9900FFA600FFB300FFE600FFE600FFD900D9FF00FFB300FF9900
FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00\
FF8C00FF9900FFA600FFB300FFC000FFFF00FFC000FFB300FFCC00FFC000FFA600
FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00\
FF9900FFC000E6FF00FFE600FFF300FFC000FFA600FFA600FFA600FFC000FFCC00
FF8C00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF9900\
FFFF00FFF300FFB300FFB300FFA600FFC000FF9900FF8C00FF8C00FF8C00FF9900
FF8C00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF8C00\
FFB300FFC000FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00FF7F00FF9900\
FFB300FFB300FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FFB300\
FFE600FFC000FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF8C00FFB300\
FF9900FF8C00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300F3FF00
E6FF00CCFF0099FF0000FF5900FFBF00000000000000000000000000BFFF19FF0000FFBF0026FF\
00FF2633FF0000FF5900FF998CFF00CCFF00F3FF00FFFF00FFF300FFF300FFE600
FFF300FFFF00E6FF003FFF003FFF00C0FF00E6FF00CCFF00E6FF00F3FF00FFFF00F3FF00E6FF00\
D9FF00CCFF00B3FF008CFF0026FF0000FFA6000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300E6FF00
0CFF000CFF000059FF00FF0000FF660000000000000000000000002600FF1900FF00B3FF000000\
00FF590000000080FF00FFF38CFF00C0FF0000FF1900FF33FFFF00FFF300FFF300
FFF300FFFF00F3FF00CCFF00A6FF00000CFF66FF008CFF003FFF00C0FF00D9FF00E6FF00E6FF00\
D9FF00C0FF00A6FF0080FF005900FF000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFD900FFE600FFF300F3FF00
D9FF00B3FF0066FF0059FF0000FF736600FF000000000000000000000000000000000000000000\
0000000000000000000080FF66FF0066FF0000FF33D9FF00F3FF00FFFF00FFFF00
FFFF00F3FF00E6FF00D9FF00B3FF0000FF5900BFFF0000000000003FFF0059FF00CCFF00A6FF00\
C0FF00B3FF003FFF000CFF0000FF26000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFF300FFFF00F3FF00E6FF00
D9FF00B3FF0099FF0059FF0000FF0000FFA63300FF000000000000000000000000000000000000\
0000000000000000008C00FF00FF0C00FF7380FF00CCFF00E6FF00F3FF00F3FF00
E6FF00E6FF00E6FF00B3FF0099FF000000000000003300FF0080FF00000080FF00A6FF0073FF00\
99FF0099FF008CFF0066FF0026FF00B300FF000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900F3FF00C0FF0073FF0099FF00
B3FF0080FF0000FFA600FFFF00FF66000000000000000000000000000000000000000000000000\
0000000000000000000000000040FF3300FF000000C0FF00D9FF00D9FF00CCFF00
A6FF00D9FF00CCFF00B3FF0073FF0019FF0000FF4C0000000000000073FF4CFF0073FF00000000\
B300FF00FF4C4CFF004CFF0000FF0000FFE6000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300\
FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300E6FF003FFF0000FF8C
00E6FF73FF003FFF00000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000FFFF73FF0099FF00CCFF00CCFF0059FF00
99FF00B3FF00B3FF00A6FF0080FF0026FF008C00FF000000000000000000008CFF26FF0000B3FF\
00000000A6FF00FF3300000000FF4C00FF5900FFFF000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000\
FFC000FFD900FFD900FFD900FFD900FFE600FFF300FFFF00D9FF008CFF0026FF00
00D9FF26FF000099FF000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000FF8C00000099FF00B3FF00B3FF0099FF00
004CFF00F3FF26FF0033FF0059FF0000FF7300000000000000000000000000FF7300000000FFD9\
0000000000000099FF000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFCC00\
FFE600B3FF00FFF300FFE600FFE600FFF300F3FF008CFF0099FF008000FF00FF00
2600FF0066FF0000009900FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000C000FF00FF338CFF0099FF008CFF008CFF00
00FF6600000000000000FF5900FF2600FF26004CFF0000000000000000003F00FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFE600\
FFF30000FF0C80FF00F3FF00FFFF00FFFF00C0FF0000FF0C0CFF0000FF0C73FF00
00E6FF000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000CCFF00FF1973FF0066FF0033FF004CFF00
19FF00000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000\
FFD900FFFF0000FF2673FF00C0FF00CCFF0073FF00C0FF0019FF00A6FF00A6FF00
00FF0000FF260000005900FF000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000019FF0033FF003FFF00000000000000
00FF9900D9FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000\
FFCC0066FF00FFFF00C0FF00A6FF00D9FF00F3FF00E6FF0026FF00CCFF00C0FF00
8CFF0000000000FF59F300FF000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000FFB300FF0000FF0C00000000D9FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000\
FFC000FFCC00FFD900FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF00
66FF0000FF4000FF2600CCFF000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000FFA600FF59000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFC000FFCC00FFCC00FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF00
99FF00D900FF00FFE6000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000FFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFC000FFC000FFCC00FFCC00FFD900FFE600FFE600FFF300FFFF00E6FF00D9FF00
00FF8C00000000FF1900FFD9000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF0000FF5999FF00
59FF0073FF0080FF0000FFB300D9FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000\
FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00D9FF00A6FF00
C0FF00B3FF00A6FF003FFF0000FF3300F3FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000\
FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00F3FF00E6FF00
D9FF00CCFF0033FF000059FF66FF0026FF0000FF0C00FFD9000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00E6FF00
D9FF00CCFF00B3FF0099FF0080FF004CFF0033FF0000FF0C00FF5900FFCC000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFD900FFD900FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00
CCFF00C0FF00B3FF0099FF0073FF004CFF0000FF2600FF66000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFE600E6FF00F3FF00FFFF00FFFF00E6FF00D9FF00D9FF00
A6FF0099FF0080FF0066FF0033FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FFA600E6FF00FFD900FFCC00FFCC00FFFF00
FFC000FFC000FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFE600FFD900FFD900\
FFD900FFD900FFE600FFF300CCFF0099FF00E6FF00E6FF00CCFF008CFF00B3FF00
A6FF0066FF003F00FF008CFF00FF8C000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FFA600FFC000FFD900CCFF00B3FF0099FF00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFD9008CFF00FFF300FFE600\
FFE600FFE600FFE600FFF300F3FF0026FF008CFF0000FFFF0000000000003FFF00
80FF001900FF0C00FF0000000080FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFC000D9FF00D9FF00F3FF00
FFF300FFE600FFCC00FFC000FFC000FFC000FFCC00FFCC00FFD900FFE60033FF00F3FF00FFF300\
FFF300FFF300FFF300FFFF00F3FF00D9FF00B3FF0019FF000019FF00000000FFE6
00FF190CFF0000FFF3000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFC000FFD900F3FF008CFF00
0073FFFFE600FFD900FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600F3FF0026FF00B3FF00\
B3FF00F3FF00FFFF00F3FF00F3FF00D9FF00C0FF004CFF00000000000000C000FF
00000000FF8C000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FFA600FFB300FFC000FFE60066FF0000FF26
B3FF00F3FF00FFF300FFD900FFD900FFE600E6FF00FFE600FFF300FFFF00CCFF000073FF00FF33\
0CFF00E6FF00D9FF00E6FF00D9FF00CCFF004CFF003300FF00FF66000000000000
0000000026FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FFA600FFB300FFC000FFE600FFE600FFFF00
C0FF0000FF19F3FF00FFF300FFF300FFFF00CCFF00C0FF00E6FF00B3FF00C0FF0000FF3300E6FF\
8CFF00C0FF0000FF0CC0FF00CCFF00C0FF00A6FF0066FF000CFF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFCC00FFE600
D9FF00D9FF0000FF7380FF0000FFD966FF0000FF0CA6FF00B3FF004CFF004CFF0000F3FF00FF00\
80FF0019FF0000FFA68CFF0080FF00A6FF0073FF0000FF5919FF0000FF730033FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFCC00
FFD900FFE600FFF300FFFF00F3FF00A6FF0066FF000019FF00FF9900FF2600FFA600FF8026FF00\
33FF0019FF0000FFE6000CFF00FF0C80FF004CFF000000000040FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFC000
FFCC00FFD900FFD900FFE600FFF30000FF00CCFF0073FF0059FF0000FF0C004CFF0073FF00FF80\
00000000FFA600FFD900000000000033FF0026FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFB300FFC000
FFC000FFCC00FFD900FFD900FFE600FFFF00E6FF00C0FF004CFF000026FF00FF33000000000000\
00000000000000000000000000000000FF6600FF33000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FFFF00FFD900FF9900FF9900FF9900FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000
FFC000FFCC00FFCC00FFD900FFE600FFF300E6FF0059FF0000FF2600000033FF00008CFF000000\
00000000000000000000000000000000000000E6FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FFC000FFE600FFB300FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000
FFC000FFC000FFCC00FFD900FFE600FFFF00E6FF005900FF4CFF0000FF5959FF0000FF0C00FFE6\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFCC00FFE600FFCC00FFB300FFA600\
FFB300FFB300FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000
FFC000FFC000FFCC00FFD900FFF300B3FF0099FF00D9FF00B3FF00B3FF004CFF001900FF00FFD9\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFB300FFD900E6FF00FFCC00FFCC00\
A6FF00FFC000FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000
FFC000FFC000FFCC00FFD900FFE600FFF300FFFF00F3FF00E6FF00CCFF0080FF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600D9FF00F3FF0080FF0059FF00\
FFCC00FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000
FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00E6FF0099FF0000FFFF00FF0C00FF19\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFB300FFCC00FFF300FFF300\
FFCC00FFB300FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00E6FF00C0FF00B3FF0000A6FF59FF00\
00FF1900FF6600FFD9000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFCC00CCFF008CFF00\
FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00F3FF00E6FF00D9FF00C0FF00A6FF0073FF00\
33FF009900FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFB300FFC000FFCC00FFFF00FFF300\
FFD900FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00
FFCC00FFD900FFD900FFE600FFE600FFF300CCFF00E6FF00CCFF00CCFF0080FF0080FF0000FF4C\
00FF33000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600FFD900C0FF000CFF00CCFF0099FF00\
FFFF00FFE600FFFF00FFCC00FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFE600
FFE600FFF300FFE600FFF300FFF300FFFF00CCFF0033FF0073FF0099FF0099FF004CFF00000000\
0000003F00FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600FFB300FFC000FFCC00FFE600C0FF00\
C0FF0099FF00FFE600FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFE600
26FF00C0FF00F3FF00FFFF00FFFF00E6FF00CCFF0019FF00000CFF66FF0066FF004CFF00000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFC000FFCC00FFD900\
F3FF00CCFF00FFE600FFCC00FFC000FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFE600FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900
D9FF0000FFB366FF00E6FF00CCFF0059FF0073FF0000FF2600FFA600FF0C00000000FF40000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000FFD900\
FFFF00D9FF00FFF300FFD900FFCC00FFC000FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFCC00F3FF00FFD900FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900
FFF300D9FF00C0FF00C0FF0000FF403300FF00FFCC0000000040FF00BFFF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFC000FFF300\
E6FF00C0FF00B3FF00F3FF00FFCC00FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFD900F3FF00C0FF00FFE600FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900
FFE600FFF300FFFF00F3FF00CCFF000073FF0073FF00BFFF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFCC00\
FFCC00FFE6008CFF00F3FF00FFD900FFCC00FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00C0FF004CFF00E6FF00FFE600FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFE600FFF300FFF300F3FF00C0FF0059FF0000FFD900000000FFA6000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFB300\
FFC000FFD900FFFF00C0FF00FFF300FFD900FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFE600D9FF0019FF00FFFF00FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFE600FFF300FFF300FFFF00E6FF00CCFF0000FF4066FF00000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFC000FFC000FFCC00FFE600F3FF00F3FF00B3FF00FFD900FFD900FFD900FFFF00
FFCC00FFC000FFC000FFC000FFC000FFC000FFCC00FFD900FFE600CCFF00C0FF00FFF300FFE600\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600
FFE600FFF300FFFF00F3FF00E6FF00CCFF00B3FF0080FF003FFF0000FF19000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300\
FFB300FFC000FFCC00FFD900FFE600D9FF00C0FF00FFFF00FFF300D9FF00FFF300
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFE600E6FF0000FF26FFFF00FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFF300FFF300FFFF00F3FF00E6FF0000FFF38CFF0026FF0000FF0C0000009900FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300\
FFB300FFC000FFC000FFCC00FFE600CCFF0066FF0000FF33CCFF00CCFF00FFF300
FFD900FFD900FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFFF0099FF00E6FF00FFF300\
FFE600FFE600FFE600FFE600FFE600FFFF00FFE600FFE600FFE600FFE600FFE600
FFF300E6FF00A6FF00D9FF00CCFF00A6FF0000000000FF3300FF26000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFC000FFCC00FFD900FFF300E6FF0099FF0059FF00E6FF00FFFF00
FFE600FFE600FFD900FFE600FFE600FFD900FFE600FFE600FFF300F3FF004CFF0099FF00CCFF00\
FFFF00FFF300FFF300FFF300F3FF008CFF00FFFF00FFF300FFF300FFF300FFF300
FFFF00F3FF00A6FF0000FF0019FF000CFF00000CFF0080FF0000000033FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFC000FFCC00FFD900FFE600D9FF0099FF0000FFA6A6FF0059FF00
FFF300FFF300FFF300E6FF00FFFF00FFF300FFF300FFF30080FF00D9FF0073FF000066FFCCFF00\
F3FF00FFFF00FFFF00FFFF00D9FF0080FF00F3FF00FFFF00FFF300FFF300FFFF00
FFFF00F3FF00E6FF00CCFF0099FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFCC00FFD900FFF300F3FF000080FF59FF00C0FF00E6FF00
FFFF00FFFF00FFFF0099FF00F3FF00FFFF00FFFF00FFFF00D9FF0000FF7300FF594CFF00C0FF00\
E6FF00E6FF00F3FF00F3FF00C0FF00C0FF00F3FF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00E6FF00CCFF00A6FF0066FF0000BFFF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFB300FFC000FFCC00FFE600FFFF00FFFF00C0FF0033FF0033FF00A6FF00D9FF00
E6FF00E6FF00E6FF0080FF00D9FF00F3FF00E6FF00E6FF00CCFF0066FF0000FF0066FF003FFF00\
B3FF00C0FF00D9FF00CCFF0080FF00A6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00D9FF00CCFF00B3FF0080FF0000FF0C00FF4C000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300\
FFB300FFC000FFCC00FFE600F3FF00F3FF0099FF00B3FF0000FF4C80FF00B3FF00
B3FF00B3FF00B3FF0000FF26B3FF00CCFF0099FF00D9FF00CCFF008CFF0000FF4000FF2600FF80\
00FF8C99FF00C0FF0080FF0000B3FF00D9FFCCFF00D9FF00D9FF00B3FF00E6FF00
E6FF00D9FF00CCFF004CFF0099FF0033FF00000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFCC00FFCC00FFE600FFF300FFFF00D9FF0000FF5900FFE626FF00
00FFD926FF0066FF0000FF0066FF0033FF008CFF00B3FF0099FF0099FF0066FF0000FF6600FFE6\
0059FF19FF0080FF0026FF0000FF1973FF00A6FF00C0FF00A6FF0059FF00CCFF00
D9FF00D9FF00CCFF0099FF0066FF000033FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFC000FFC000FFCC00FFD900FFE600FFF30080FF00CCFF0059FF0099FF00
66FF0000F3FF008CFF2600FF00FFF300FF5966FF008CFF000CFF0073FF0000BFFF00E6FF004CFF\
0000000000003FFF0033FF0000FF33B300FF66FF0099FF0033FF00A6FF00C0FF00
CCFF00CCFF00C0FF00B3FF008CFF0033FF0000FF4C0026FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF9900\
FF9900FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300FFFF00F3FF00D9FF00B3FF00
59FF0033FF0000FF260000000099FF0040FF00FF4C3FFF0000FFF3B300FF00FF0C00FFBF000000\
0000000019FF00CCFF00FF3300FFE600000000FF8C00FF0000FF808CFF00A6FF00
3FFF00B3FF00B3FF0099FF0080FF0019FF0000D9FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900\
FFA600FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300FFFF00F3FF00D9FF00C0FF00
99FF004CFF0000FF5900000000000000000000000000FF33000000000000000000C000FF000000\
000000000000CC00FF000CFF00000000000000FFA600FF4000CCFF3FFF0080FF00
73FF0099FF00A6FF008CFF004CFF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FFA600\
FFC000FF9900FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFD900FFE600FFE600FFF300FFFF00E6FF003FFF0099FF00
33FF0000FF006600FF000000000000000000000000008CFF000000000000000000000000000000\
0000000000000000000000000000000000000000000080FF00000000FF6600FFE6
59FF0080FF008CFF0080FF0066FF000CFF000026FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF9900\
B3FF00FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFE600FFE600FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFE600F3FF00F3FF00FFFF00F3FF00E6FF00CCFF00A6FF00
33FF000CFF0000A6FF000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000000000BFFF004CFF
26FF0000CCFF73FF0073FF0000FF0C000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900\
FFC000FFA600FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FFA600FFF300FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFCC00F3FF00D9FF00FFE600FFD900FFD900\
FFD900FFD900FFD900FFE600E6FF000059FFD9FF00E6FF00D9FF00C0FF00A6FF00
80FF0026FF0000FF4C00B3FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00FFFF0CFF003FFF004CFF0033FF0000FF59000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900\
FFC000FFB300FF9900FF9900FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FFA600FFCC00FFC000FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00D9FF004CFF00CCFF00FFE600FFD900\
FFD900FFD900FFE600FFF300FFFF00E6FF00A6FF003FFF00A6FF00A6FF0066FF00
4CFF0000FF1900FF8CC000FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000FFD900FF2633FF0019FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600\
F3FF00FFC000FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600\
FFB300FFCC00D9FF00FFE600FFC000FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFD900F3FF0033FF00F3FF00FFF300\
FFE600FFE600FFF300FFF300FFFF00F3FF00CCFF0000FF4C26FF0033FF0000FFB3
00FFA600D9FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFB300FF0000FF0C000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600\
FFB300FFCC00FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FFA600FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600\
FFB300FFE600C0FF00FFE600FFC000FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFCC00FFD900FFE600FFFF0033FF00F3FF00\
FFFF00F3FF00FFFF00FFFF00F3FF00E6FF00CCFF00A6FF004CFF0000FF33000000
0000004C00FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FFBF00FF33000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600\
FFB300FFD900FFB300FFA600FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FFA600FFC000FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFB300FFCC00FFFF00FFF300FFCC00FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFF300F3FF003FFF00\
99FF00D9FF00F3FF00F3FF00CCFF00D9FF00CCFF00B3FF0080FF0000FF2600FFBF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF66000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600\
FFB300FFE600FFC000FFB300FFA600FFA600FFA600FFA600FF9900FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FFA600FFB300FFF300FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFB300FFC000FFE6003FFF00FFE600FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFF300F3FF00B3FF00\
00FF73A6FF00D9FF00D9FF0066FF00C0FF00B3FF0000FF0C00FF0C00FF1900FF99
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FFD900B3FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300\
FFC000FFD900FFCC00FFC000FFB300FFB300FFB300FFFF00FFA600FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FFA600FFC000FFF300FFC000FFA600FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFB300FFC000FFE60066FF00FFE600FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFF300CCFF00A6FF00\
4CFF0080FF00B3FF00C0FF0099FF004CFF0099FF0080FF0000FF260099FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000073FF0073FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFA600FFA600FFB300FFB300\
FFC000FFD900FFFF00FFE600FFD900FFC000FFE600FFC000FFA600FF9900FF9900
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600
FFC000C0FF0099FF00FFD900FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFC000FFC000FFD900F3FF00FFF300FFD900FFCC00FFCC00FFC000FFC000FFC000
FFCC00FFD900FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300F3FF00D9FF00\
A6FF0000FF0059FF0080FF0073FF0019FF0059FF0059FF0000FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000003300FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFC000FFC000FFB300FFC000FFFF00\
FFD900E6FF00C0FF0000FF80E6FF00FFE600FFD900FFC000FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFB300FFCC00FFF300FFCC00FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFC000FFCC00FFD900FFF300FFFF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00
FFD90080FF00FFE600FFD900FFD900FFD900FFD900E6FF00FFFF00FFF300FFFF00F3FF00D9FF00\
B3FF0066FF000080FF19FF000CFF0000F3FF00FF1900FF0000FF0C00FFCC000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFE600FFCC00FFCC00FFE600\
E6FF00D9FF0019FF000000008CFF0099FF00FFE600FFC000FFB300FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300
FFC000FFCC008CFF00FFCC00FFC000FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFCC00FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFCC00FFC000FFB300FFB300FFB300FFB300FFC000FFC000\
FFCC00FFCC00FFD900FFFF00CCFF00FFF300FFE600FFE600FFD900FFD900FFD900
FFE60073FF00FFF300FFE600FFD900FFE600FFE600F3FF0099FF00F3FF00F3FF0019FF00B3FF00\
A6FF0066FF0000FF336600FF6600FF000000D900FF0073FF00FFA6008CFF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFC000FFCC00E6FF00FFF300F3FF00\
C0FF00000000000000000000000000000000E6FF00FFE600FFC000FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFCC00FFD900C0FF00FFD900FFCC00FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFB300FFB300FFD900FFF300FFC000FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFC000C0FF00FFD900FFC000FFC000FFC000FFCC00FFD900FFCC00\
FFCC00FFE600FFF300F3FF0059FF00F3FF00B3FF00FFFF00FFE600FFE600FFE600
FFF3003FFF00FFFF00FFF300FFF300FFF300FFF300F3FF00CCFF00C0FF00D9FF00C0FF0066FF00\
66FF0019FF0000FF4C1900FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFCC00FFE600B3FF008CFF008CFF00\
33FF00000000000000000000000000000000C0FF00FFD900FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFC000FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFCC00FFFF00FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
F3FF00FFF300C0FF00FFFF00D9FF00FFCC00FFC000FFC000FFB300FFC000FFCC00FFC000FFC000\
FFC000FFC000FFE600F3FF00FFCC00FFC000FFC000FFC000E6FF00FFB300FFB300
FFB300FFB300FFC000FFC000FFCC00FFE600FFF300FFCC00FFCC00FFCC00FFD900F3FF00FFE600\
FFE600FFF300A6FF00CCFF0080FF0099FF00C0FF00F3FF00FFFF00FFFF00FFFF00
F3FF0099FF003FFF00F3FF00C0FF00F3FF00F3FF00E6FF00B3FF004CFF00A6FF0099FF0080FF00\
00FF4C00FF4C00D9FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FFB300FFE600FFB300FFB300FFB300FFC000FFCC00FFFF00E6FF0059FF00000000000000\
9900FF000000000000000000000000000000CCFF00FFE600FFD900FFCC00FFCC00
FFC000FFCC00FFC000FFCC00CCFF00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFD900FFF300FFCC00FFC000FFCC00FFD900FFD900FFCC00FFCC00FFCC00FFD900
FFF30080FF0000FFCC3FFF00FFFF00FFD900FFD900FFCC00FFE600FFCC00FFF300FFD900FFD900\
FFD900FFD900FFF300F3FF00FFD900FFD900FFD900FFD9004CFF00FFD900FFD900
FFCC00FFCC00F3FF00FFD900FFE600FFF300F3FF00FFF300F3FF00FFF300FFFF00B3FF00FFFF00\
E6FF00E6FF008CFF0019FF0000000000000099FF00CCFF00D9FF00D9FF00CCFF00
CCFF0066FF0000FF9900FF0080FF00C0FF00CCFF008CFF008CFF0000FF6659FF0026FF000CFF00\
4C00FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFC000FFC000FFF300FFCC00FFE600FFCC00FFD900FFE600CCFF0073FF0000FF40000000000000\
000000000000000000000000000000000000CCFF00FFFF00FFE600FFE600FFE600
FFD900FFF300FFD900FFD900C0FF00FFD900FFD900FFD900FFD900FFD900FFE600F3FF00FFD900\
FFF30099FF00F3FF00FFE600FFE600FFF300FFF300FFE600FFE600FFE600FFF300
F3FF0026FF000000000066FFF3FF00E6FF00FFFF00FFE600E6FF0099FF00F3FF00FFF300FFF300\
FFFF00FFF300F3FF0073FF00FFF300FFF300FFFF00FFF300CCFF00F3FF00F3FF00
FFE600FFF300D9FF00FFFF00F3FF00E6FF00A6FF00D9FF00D9FF00E6FF00E6FF0066FF00D9FF00\
C0FF00A6FF00A6FF0000FFA600000000000080FF0099FF0099FF00A6FF0099FF00
80FF0000FF3373FF0000FFA633FF0080FF0073FF0059FF0033FF000033FF00FF0000FF4C00FF66\
00E6FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFFF00FFF300CCFF0000FFFF00FFFF\
00FF73000000000000000000000000000000C0FF00FFE600FFCC00FFC000FFC000
FFB300FFB300FFB300FFB300FFE600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFD900FFF300FFC000FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00
FFFF00E6FF00A6FF00CCFF00FFF300FFCC00FFCC00FFC000FFC000FFC000FFE600FFCC00FFC000\
FFC000FFCC00FFE600FFFF00FFCC00FFCC00FFC000FFCC00D9FF00FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFE600FFF300FFD900FFD900FFD900FFE600D9FF00FFF300\
FFF300FFFF00D9FF00A6FF0000FF5926FF00B3FF00E6FF00F3FF00E6FF00E6FF00
E6FF000CFF00C0FF00E6FF00B3FF00E6FF00E6FF00CCFF00B3FF0000FF808CFF0073FF003FFF00\
00FF2600D9FF000CFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFD900FFFF00E6FF00D9FF00\
73FF00000000000000000000000000000000D9FF00FFD900FFC000FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFCC00FFB300FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000
FFD900FFE600A6FF00FFE600FFE600FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFCC00FFF300FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFE600FFE600FFCC00FFC000FFCC00FFD900FFFF00FFD900\
FFD900FFF300E6FF00E6FF0033FF00CCFF0000FFA6FFFF00FFF300FFF300FFF300
FFFF00B3FF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00C0FF0019FF00C0FF00B3FF0073FF00\
26FF0019FF009900FF000000000000000000000000000000000000C000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFB300FFD900FFE600FFD900FFF300\
D9FF0033FF0000FF4C0000003F00FF33FF00FFF300FFD900FFB300FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300
FFC000FFCC00D9FF00FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFCC00FFE600FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFD900FFCC00FFC000FFB300FFC000FFC000FFC000FFCC00\
FFCC00FFD900FFE600FFFF00B3FF00FFFF00FFFF00FFF300FFE600FFD900FFE600
FFF30099FF00FFF300FFE600FFE600FFE600FFF300FFFF0026FF00E6FF00E6FF00CCFF008CFF00\
8CFF0059FF0000FF3300000000000000000000000000000000FFFF000CFF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFF300FFC000FFC000FFE600\
FFF300F3FF008CFF0000D9FFE6FF00F3FF00FFD900FFC000FFB300FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFB300FFCC00FFFF00FFCC00FFB300FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FFA600FFA600FFB300FFC000FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFCC00FFD900FFF300E6FF00FFE600FFD900FFD900FFCC00FFCC00FFD900
FFE60080FF00FFE600FFD900FFD900FFD900FFE600F3FF00E6FF00FFFF00F3FF00D9FF00CCFF00\
A6FF0000FF1900000000FF9900FF739900FF00FFBF00FF4C00FF33000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFF300FFB300FFB300FFB300FFC000\
FFCC00FFE600D9FF00E6FF00FFE600FFD900F3FF00FFC000FFA600FFA600FF9900
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600
FFB300FFD900FFF300FFCC00FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFC000FFC000FFD900FFFF00FFF300FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFFF00FFD900FFCC00FFCC00FFCC00FFD900FFE600FFE600FFF300FFFF00F3FF00D9FF00\
B3FF0059FF0000000059FF003FFF0000FF4033FF0026FF0000FF0C8C00FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300\
FFC000FFD900FFD900FFCC00FFC000FFC000FFC000FFCC00FFA600FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600
FFC000FFCC00E6FF00E6FF00FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300\
FFB300FFC000FFD900D9FF00FFF300FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFCC00FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300F3FF00CCFF00\
00FF004CFF0099FF00A6FF0073FF003FFF0080FF0073FF003FFF0000FF73000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000026FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600\
FFB300FFFF00FFC000FFB300FFB300FFA600FFA600FFB300FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FFA600FFB300FFE600FFB300FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300\
FFB300FFC000CCFF00CCFF00FFE600FFCC00FFC000FFC000FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300D9FF0033FF00\
00FF0C80FF00CCFF00CCFF00A6FF00A6FF00A6FF0080FF0000D9FF00FF330026FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000E6FF0059FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600\
FFB300FFFF00FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF8C00FF8C00
FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FFB300FFC000FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFB300FFCC00FFF300F3FF00FFD900FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFF300F3FF0099FF00\
00FF00CCFF00E6FF00E6FF000CFF00CCFF00C0FF0099FF0080FF0033FF0000FF99
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF8C00B3FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600\
FFB30066FF00FFB300FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF9900FFA600FFC000FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600\
FFB300FFFF0080FF00FFE600FFCC00FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFE600FFF300E6FF00C0FF00\
E6FF00E6FF00FFFF00F3FF00E6FF00E6FF00CCFF00B3FF0080FF0019FF0000B3FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF4C00FFE6000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600\
FFC000FFC000FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600\
FFB300FFCC00CCFF00D9FF00FFC000FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFCC00FFD900FFF300D9FF00E6FF00FFF300\
FFF300FFF300FFF300FFFF00FFFF00F3FF00C0FF0000FF0C00000000000000BFFF
00F3FF000CFF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000002600FF00FF2600FF1900FF99000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900\
FFC000FFD900FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FFA600FFC000FFF300FFC000FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFE600F3FF00CCFF00FFF300FFE600\
FFE600FFE600FFE600FFF300FFFF00E6FF00CCFF0000FF2600FF0C8CFF0000A6FF
33FF0000FFB30C00FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000080FF00FF400CFF000CFF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900\
FFC000FFA600FF9900FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FFA60099FF00FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFC000FFCC00FFFF00B3FF00FFF300FFD900FFD900\
FFD900FFD900FFD900FFE600FFFF0073FF00C0FF00CCFF00C0FF00B3FF0099FF00
0CFF0033FF0000FF4000F3FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
8000FF00FF598C00FF3FFF0000FF1900FFFF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900\
FFF300FFA600FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFCC00A6FF0000FF4CFFD900FFCC00FFCC00\
FFCC00FFCC00FFD900FFE600D9FF00D9FF00F3FF00F3FF00E6FF00CCFF00A6FF00
73FF0033FF0000FFD9000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00FF3300FF0C59FF0066FF003FFF0000FFCC000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FFA600\
FFC000FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFE600FFCC00FFCC00FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFD900FFE600FFF300FFFF00FFFF00E6FF00B3FF0080FF00
00F3FF00BFFF000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000000000FF800099FF
4CFF004CFF0080FF0073FF004CFF0000FF19000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900\
FFE600FF9900FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00F3FF00CCFF00B3FF00
8CFF0000FF1900FFB3000000000000000000D900FF00FF80000000000000000000000000000000\
00000000000000000000000000000000000000CCFF00FFCC000CFF00FF7326FF00
73FF0099FF0099FF008CFF0066FF000026FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF9900\
FF9900FF8C00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300FFFF00F3FF00D9FF00C0FF00
8CFF0059FF0000FF400000008C00FF00000000FF7319FF0000FF33C000FF00FF73000000000000\
0000000066FF00E6FF00FFBF6600FF00000000000000FF5900FFBF73FF0099FF00
00FF73A6FF00A6FF008CFF0059FF0000FF337300FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF8C00\
FF8C00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300F3FF00E6FF00C0FF00B3FF00
66FF000080FF0059FF0000FF00FF6600FFD900FF1973FF0000FFB33FFF0000FFD9000000000000\
00000000000000FF0000FF0000FF590000000080FF66FF0000FF1980FF00B3FF00
C0FF00C0FF00B3FF00A6FF008CFF004CFF0000FF80000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFC000FFCC00FFD900FFE600FFFF00D9FF0066FF0000FF8C0CFF00
00FF4CB300FF0CFF000066FF4CFF0000FF0073FF00A6FF0073FF008CFF0059FF0019FF0000FF99\
00000000FF5966FF0033FF0000FFB333FF004CFF00B3FF0099FF00A6FF00CCFF00
CCFF00CCFF00C0FF00A6FF0080FF0000FFF30073FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFCC00FFD900FFF300FFF300F3FF0080FF0073FF0059FF0099FF00
73FF0080FF0099FF0019FF0000FF0CB3FF00A6FF00CCFF00C0FF0099FF0059FF0019FF00000000\
00D9FF26FF00A6FF0066FF0000FF2666FF00C0FF00CCFF00C0FF0019FF00D9FF00
D9FF00D9FF00CCFF0000FFFF73FF0000FF0C000CFF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300\
FFB300FFC000FFCC00B3FF00A6FF00CCFF0000FF0C66FF0000FF4C73FF00CCFF00
CCFF00CCFF00CCFF004CFF00C0FF00E6FF00CCFF00E6FF00CCFF0080FF0000FF4000FF7359FF00\
3FFF00C0FF00CCFF0000FF1980FF008CFF00CCFF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00C0FF00B3FF004CFF0000BFFF00FF66000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFB300FFC000FFC000FFD900FFE600FFF300E6FF00A6FF004CFF00C0FF00E6FF00
F3FF00F3FF00F3FF00B3FF00E6FF00FFFF00FFFF00F3FF00D9FF008CFF0000BFFF8CFF00C0FF00\
CCFF00C0FF00E6FF00E6FF00CCFF00CCFF00E6FF00F3FF00F3FF00FFFF00F3FF00
F3FF00F3FF00E6FF00CCFF00B3FF008CFF003FFF000033FF0099FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFCC00FFD900FFE600B3FF0073FF0000FFFFB3FF00E6FF00
FFFF00FFF300FFF300C0FF00F3FF00FFF300FFF300FFFF00B3FF00A6FF003FFF003FFF0066FF00\
F3FF00FFFF00FFFF00F3FF00C0FF00B3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00E6FF00CCFF0099FF0026FF0000A6FF0040FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFC000FFCC00FFD900FFF300F3FF00C0FF0000FF40D9FF00F3FF00
FFF300FFE600FFE600FFF300FFE600FFE600FFE600FFF300FFFF00E6FF0099FF0026FF00B3FF00\
FFFF00FFF300FFF300FFF300CCFF0000FF19FFFF00FFF300FFF300FFF300FFF300
FFFF00F3FF00D9FF00A6FF0000CCFF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300\
FFB300FFB300FFC000FFCC00FFE600F3FF00B3FF004CFF008CFF00D9FF00FFF300
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFF300FFFF00A6FF00D9FF00FFFF00\
FFF300FFE600FFE600FFE600FFF300E6FF00FFF300FFE600FFE600FFE600FFF300
FFF300F3FF001900FFB3FF00B3FF008CFF0000000000FF80000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300\
FFB300FFC000FFC000FFCC00FFE600D9FF00C0FF00D9FF00FFFF0000FF33FFF300
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFFF00A6FF00FFFF00FFF300\
FFE600FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFFF00F3FF00E6FF00D9FF00A6FF0000FFD900FF4C19FF00000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFB300FFC000FFCC00FFD900FFF300A6FF00E6FF00FFE600FFE600FFF300E6FF00
FFCC00FFCC00FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600E6FF0099FF00FFF300FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFF300FFFF00F3FF00E6FF00CCFF00A6FF0080FF003FFF00000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFB300\
FFC000FFCC00FFE600D9FF00F3FF00FFE600FFD900FFCC00FFCC00FFCC00FFD900
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFE600B3FF00C0FF00FFF300FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600
FFE600FFF300FFF300FFFF00E6FF00CCFF00A6FF0080FF0000FF5900FF8C000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFC000\
FFCC00FFD900D9FF00B3FF00FFE600FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFE60059FF00C0FF00FFF300FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFE600FFF300FFF300F3FF008CFF00B3FF0073FF0000FF00000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFC000FFFF00\
FFE60059FF00C0FF00FFFF00FFD900FFCC00FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFCC00FFE600D9FF0000FF40FFE600FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900
FFE600FFF300FFFF00F3FF00D9FF000040FF00FF0C00FFBF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFC000FFD900\
F3FF00C0FF00FFFF00FFFF00FFCC00FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFCC00FFFF00FFF300FFD900FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900
FFE600FFFF00F3FF00E6FF0080FF000080FF00FFB3000000CC00FF0000000000000000000C00FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000FFD900\
C0FF0000FF59FFE600FFCC00FFC000FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000C0FF00FFCC00FFC000FFC000\
FFC000FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900
F3FF00CCFF0026FF00B3FF0073FF003FFF0000000000FFE600FF7300FFB300000000FF99000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFC000FFD900FFF300\
E6FF00E6FF00FFE600FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFE600
E6FF0000FFFFD9FF00F3FF00E6FF00D9FF008CFF004CFF000066FF3FFF0026FF0033FF0000FF40\
0040FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600FFD900FFFF00FFE600FFF300C0FF00\
C0FF00FFFF00D9FF00FFCC00FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00F3FF00
CCFF00F3FF00FFF300FFF300FFFF00F3FF00D9FF0026FF000040FF80FF008CFF000040FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600FFB300FFCC00FFE600E6FF00FFFF00\
FFE600FFCC00FFCC00FFCC00FFB300FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00
FFD900FFE600FFE600FFE600FFF300FFFF0000FF4CCCFF004CFF00C0FF0099FF0000FF190040FF\
00000000BFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFCC0099FF00F3FF00\
FFD900FFC000FFB300FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFCC00
FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00F3FF00E6FF00CCFF00B3FF0099FF0059FF00\
26FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFB300FFCC00F3FF00E6FF00\
FFCC00FFC000FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFE600FFE600FFF300FFFF00E6FF00CCFF00C0FF0099FF0073FF00\
33FF0000FF19000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFCC00FFD900FFFF00FFFF00\
FFCC00FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000
FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00D9FF000000008CFF004CFF0033FF00\
000000000000000000A600FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFCC00D9FF00E6FF00FFD900\
FFF300FFC000FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000
FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00E6FF00CCFF0000FF26000CFF004CFF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600FFB300FFF300FFFF00FFC000FFB300\
FFCC00FFC000FFA600FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000
FFC000FFC000FFCC00FFD900FFE600F3FF00E6FF00E6FF00D9FF00C0FF0059FF00000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFC000CCFF00FFC000FFB300FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000
FFC000FFC000FFCC00FFD900FFE600C0FF00B3FF0000FF0080FF0099FF0073FF0019FF00000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FFCC00FFC000FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000
FFC000FFCC00FFCC00FFD900FFE600FFF300F3FF0059FF0000FF3326FF0059FF003F00FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FFB300FFA600FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFB300FFC000
FFC000FFCC00FFCC00FFD900FFE600FFF300E6FF0033FF0033FF0000FF4C0CFF0000FF8C000000\
00000000000000000000000000000000000000FF66000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFC000
FFCC00FFCC00FFD900FFE600FFF300F3FF00E6FF00B3FF0073FF0000A6FF00FFCC000000000000\
0019FF0000000033FF0000000000003300FF00FF3300FFA6000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFCC00
FFCC00FFD900FFE600FFF300FFFF00C0FF00A6FF000040FF00FF4C004CFF1900FF00FF5900FF26\
00FF0C0CFF000080FF00000026FF0059FF000CFF00E600FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFC000FFD900
FFF300FFFF00B3FF00C0FF00C0FF0066FF0000FFBF59FF0080FF003FFF0000FF3300000000FF19\
66FF0026FF000033FF00D9FF59FF0099FF0000FF260CFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFCC00FFD900FFE600
80FF0000FFCC99FF00F3FF00E6FF00D9FF0099FF00C0FF00D9FF0000FF9999FF0000000000FF73\
99FF00B3FF0073FF00B3FF00B3FF00B3FF0099FF0073FF0000FF0000F3FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FFA600FFB300FFC00080FF00FFFF00A6FF00
0000008CFF00FFFF00FFE600FFE600FFE600A6FF00FFFF00FFFF00F3FF00D9FF0066FF0000FF26\
A6FF00CCFF0000FF4CCCFF00D9FF00C0FF0099FF000019FF00FF0C000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FFA600FFB300FFC000FFD900C0FF004CFF00
B3FF00FFF300FFE600FFD900FFD900FFD900FFE600FFD900FFE600FFF300F3FF008CFF003FFF00\
B3FF00F3FF00F3FF00F3FF00E6FF00CCFF00A6FF0000FFF300E6FF000000000000
00000000FFD9000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFC000FFE600CCFF00D9FF00
E6FF00FFE600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFE600E6FF00CCFF00F3FF00\
CCFF00FFFF00FFFF00FFFF00F3FF00D9FF00B3FF003FFF0000000000000000FFA6
00000000FF4000FFCC000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFCC00FFFF0080FF00FFFF00
FFD900FFCC00FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFE60000FF4CFFFF00FFE600\
FFE600FFE600FFF300FFF300F3FF00C0FF0080FF0000FF999900FF00F3FF9900FF
66FF000CFF0000FFE6000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FFA600FFD900D9FF00CCFF00FFF300FFF300
FFCC00FFC000FFC000FFB300FFB300FFC000FFC000FFC000FFCC00FFD900B3FF00FFE600FFD900\
FFD900FFD900FFE600FFF300CCFF0000FFB3D9FF00C0FF00C0FF0000CCFF99FF00
99FF0066FF000000000000FF00FF809900FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FFA600FFCC00FFC000FFC000FFC000F3FF00
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFE600C0FF00CCFF00F3FF00F3FF00CCFF00CCFF00CCFF00
A6FF0033FF0033FF0000FF0C00FF0000000000B3FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFA600FFA600FFB300
FFB300FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFD900FFE600FFF300FFF300FFF300FFFF00F3FF00E6FF00E6FF00
A6FF00B3FF0099FF008CFF0019FF006600FF00FF267300FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFF300FFFF00F3FF00E6FF00
D9FF00CCFF00B3FF0099FF0080FF0059FF0033FF0000FF0C00FF73000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00E6FF00
D9FF00CCFF00A6FF0080FF0073FF000059FF19FF0000FF4000FF8C00FFF3008CFF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00E6FF00D9FF00
CCFF00C0FF00A6FF004CFF000CFF0000FF665900FF8C00FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000\
FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300F3FF0000FFF300FF59
99FF00A6FF0099FF0000FF800000004C00FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00E6FF00CCFF00
4CFF006600FF59FF0000FF0000FFCC000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFC000FFC000FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00D9FF00
99FF0000FF99000000000000F300FF000000000000000000000000000000000000000000000000\
0000000000000000000000000080FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFC000\
FFC000FFCC00FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00CCFF00
00E6FF00FF8C00FF66000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000FFA6000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000\
FFCC00FFE600FFE600E6FF00F3FF00F3FF00FFFF00F3FF00D9FF00D9FF00CCFF00
A6FF0059FF0000FF59000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000F3FF00FF2600FF400000000019FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000\
FFCC00FFF300CCFF00A6FF0000FF4C00FF4CD9FF00D9FF00A6FF00B3FF00B3FF00
00FF2626FF0000D9FF000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000CFF0000FF0000FFD900FF66000000
00A6FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFCC00\
FFD900D9FF0066FF00CCFF00F3FF00F3FF0000FF4C80FF0000CCFF66FF008CFF00
0080FF00B3FF000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000005900FF00000059FF0059FF00A600FF00FF80
00FF33000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC00000FF8C\
99FF0033FF00CCFF00FFF300FFF300FFF300F3FF00D900FF26FF0000FF003FFF00
4C00FF0019FF000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000033FF0080FF0073FF0073FF0073FF00
33FF00000CFF00000000000000000000000000B3FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000\
FFCC00B3FF00FFD900FFD900FFD900FFE600FFFF00F3FF0099FF0059FF0000E6FF
00FF3300FF0000000000FFE6000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000FFFF0000008CFF00A6FF00A6FF0099FF00
4CFF000000000000000000003FFF0000FF66C000FF00000000000000000000A6FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300\
FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300E6FF0099FF0019FF00
004CFF26FF0026FF0000FF73000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000FF593FFF0066FF00C0FF00C0FF008CFF00
00FF198CFF008CFF008CFF000CFF0000FF990C00FF00000000000000000000FF4C00FF0000FF73\
00000000000000000000000000000000FFFF00FFF3000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFFF00CCFF0000FF0059FF00
8CFF008CFF000CFF0000FFCC00BFFF000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000073FF00C0FF00CCFF00D9FF008CFF00
A6FF00CCFF00CCFF00B3FF008CFF003FFF000C00FF0000000000001900FF00FFD926FF00B300FF\
00000000FFBF00FF1919FF000CFF0000FFA6000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFCC00FFCC00FFD90099FF00F3FF0099FF00CCFF00
CCFF004CFF0080FF0000FF2600FF5900D9FF000000000000000000000000000000000000000000\
0000000000000000001900FF00FF334C00FF4CFF0000FFCCE6FF00E6FF00E6FF00
D9FF00E6FF00D9FF0073FF0000FFB300FFF300FFCC00000000F3FF00FF004CFF008CFF0019FF00\
66FF0073FF0080FF0066FF0000FF0C0099FF000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFE600FFF300FFFF00F3FF00
D9FF00C0FF0099FF0000FF800000000019FF000000000000000000000000000000000000000000\
00000000000000000000FF6633FF0000A6FF4CFF00D9FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00CCFF00B3FF004CFF0000FFCC00000000FFCC00FFA699FF00B3FF0000FF0C\
B3FF00B3FF0080FF004CFF0019FF0000B3FF000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300F3FF00
4CFF0099FF0000FFF33FFF0000FF330000000000000000000000000080FF000000000000000000\
00FFA600000000000000FF8C80FF00A6FF0080FF00CCFF00F3FF00FFFF00FFFF00
FFFF00FFFF00F3FF00D9FF00A6FF0026FF0033FF000CFF0059FF008CFF00CCFF00D9FF00D9FF00\
CCFF00C0FF000000004CFF000000FF000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300C0FF00
C0FF00B3FF0000E6FFC000FF000000F300FF0000000000000000000026FF00D9FF00FF4C00FF33\
00FF1900FF33004CFF00FF0033FF00CCFF00D9FF00D9FF00FFFF00FFF300FFF300
FFF300FFFF00E6FF008CFF0066FF0000BFFF00FF26C0FF00CCFF00E6FF00F3FF00F3FF00E6FF00\
D9FF00CCFF00B3FF008CFF0000FF4C00F3FF000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFD900FFE600FFF300FFFF00
F3FF00D9FF0080FF0000FF660CFF0000FFD900000000000000000000FFFF4CFF0019FF000019FF\
73FF0033FF0000FF8019FF0000FF0059FF00F3FF00FFF300FFE600FFE600FFE600
FFE600FFF300CCFF0080FF00D9FF00F3FF00FFFF00F3FF00F3FF00FFFF00FFFF00FFFF00F3FF00\
D9FF00C0FF00A6FF0073FF006600FF000000000000000000000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFE600FFF300FFFF00
F3FF00D9FF00C0FF008CFF004CFF0000FF660059FF00FF7300FFF300FF0C73FF0073FF00A6FF00\
8CFF0000FF9900FF0000FF5966FF0099FF00FFFF00FFE600FFE600FFD900FFD900
FFE600FFF300D9FF0066FF00E6FF00FFFF00FFF300FFF300FFE600FFF300FFF300FFFF00F3FF00\
008CFF00FF4C59FF0000FF5900FF0C3F00FF000000004CFF000000000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFF300FFF300FFF300FFFF00
E6FF00D9FF00C0FF0080FF00D900FF00FFBF00FF003FFF0000FF2626FF0000FF33CCFF00CCFF00\
A6FF0026FF0000FF33A6FF00D9FF004CFF00F3FF00FFE600FFD900FFD900FFD900
FFD900FFE600FFFF008CFF0073FF00FFF300FFE600FFE600FFE600FFE600FFE600FFF300A6FF00\
0CFF00C0FF0080FF0000FF3300FFE600000000FF2600000000FFA6CC00FF000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFCC0099FF00F3FF00D9FF00E6FF00FFFF00FFFF00F3FF00
8CFF00B3FF00B3FF0099FF003FFF0000FFA600FF0C8CFF0066FF003FFF00CCFF00E6FF00E6FF00\
66FF0059FF0066FF0059FF00FFFF00FFF300FFF300FFD900FFCC00FFCC00FFCC00
FFCC00FFD900FFE600B3FF00FFFF00FFD900FFD900FFD900FFD900FFD900FFE600FFE600F3FF00\
66FF00E6FF00E6FF00CCFF003FFF003FFF0000FF194CFF0000FF1900F3FF000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFC000FFCC00FFF30080FF004CFF008CFF00E6FF00E6FF00E6FF00
C0FF003FFF008CFF003FFF0000FF993FFF0026FF00B3FF00B3FF00A6FF00D9FF00F3FF00FFFF00\
F3FF00D9FF000066FFB3FF00FFF300FFE600FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE60059FF00\
C0FF00FFFF00FFFF00E6FF00D9FF0000FF73B3FF003FFF0000FF0C000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFC000FFCC00FFD900FFF300FFFF00B3FF00C0FF00C0FF00CCFF00
99FF0000FF0000FF0000FF0026FF0059FF00A6FF00CCFF00D9FF00C0FF00CCFF00FFF300FFF300\
FFFF00E6FF0000FF0CFFFF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600\
FFE600FFF300FFF300FFFF00F3FF00D9FF00CCFF00B3FF008CFF0059FF00004CFF
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFC000FFC000FFCC00FFCC00FFD900FFE600FFFF0000B3FF3FFF003FFF0099FF00
26FF004CFF0080FF00B3FF0080FF0000FF408CFF00C0FF00F3FF00FFFF00FFF300FFE600FFE600\
FFF3008CFF00CCFF00FFFF00FFE600FFD900FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900\
FFE600FFE600FFF300FFFF00F3FF00E6FF00CCFF00B3FF0080FF004CFF000C00FF
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFCC00FFD900FFD900FFF300E6FF00A6FF0000FF4C00000000FF26
00BFFFC0FF00C0FF00D9FF00B3FF0066FF0073FF00C0FF00E6FF00FFF300FFE600FFD900FFD900\
FFD90059FF0000FF2666FF00FFFF00FFD900FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900\
FFD900FFE600FFE600FFF300F3FF00004CFF8CFF00A6FF008CFF00004CFF00D9FF
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFD900FFE600FFE600FFFF00A6FF004CFF000CFF0000000099FF00
CCFF00F3FF00FFFF00F3FF00CCFF0000FF0C00FF993FFF00D9FF00FFFF00FFE600FFD900FFCC00\
FFCC00FFD900E6FF000CFF0000FFB3FFFF00FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFD900FFE600FFE600FFF30059FF00A6FF0000FFCC73FF004CFF0000FF8C73FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFD900FFD900FFCC00FFD900FFD900FFCC00\
FFD900FFD900FFE600D9FF00FFFF00F3FF004CFF008CFF0033FF0099FF00A6FF00
FFFF00FFF300FFE600FFFF00B3FF00D9FF0033FF003FFF00B3FF00C0FF00FFD900FFCC00FFC000\
FFC000FFC000FFCC00FFD900CCFF00FFCC00FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFE600FFE600FFF300F3FF00D9FF0099FF0000FF5900CCFF00FF80C0FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFD900F3FF00FFF300F3FF00CCFF00FFF300\
FFE600FFE600FFF300D9FF00CCFF008CFF003FFF008CFF00F3FF0099FF00F3FF00
FFE600FFD900FFD900FFE600FFFF00FFF300F3FF00B3FF00B3FF00FFF300FFCC00FFC000FFC000\
FFC000FFB300FFC000FFC000FFCC00FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFE600FFE600FFF300FFFF00E6FF0000FF4C8C00FF00FF73CCFF00E6FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900
FF9900FFB300FFC000FFC000FFC000FFC000FFCC00FFE600CCFF00B3FF00C0FF00F3FF00E6FF00\
D9FF0000FF00B3FF0099FF0033FF00B3FF0026FF00F3FF00FFF300FFF30059FF00
FFE600FFCC00FFCC00FFCC00FFD900FFE600CCFF0059FF00C0FF00D9FF00FFCC00FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900\
FFE600FFE600FFF300FFFF00F3FF00D9FF00A6FF0033FF00A6FF0059FF00FFF300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FFB300FFF30000FF19FFD900FFD900F3FF00CCFF00CCFF00FFFF00FFF300FFD900FFE600\
E6FF004CFF0066FF00FFFF00F3FF00FFF300D9FF00E6FF00FFD900FFCC00FFCC00
FFCC00FFC000FFC000FFCC00FFCC00FFD900FFF300A6FF00FFF300FFCC00FFC000FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFCC00FFE600\
FFF300FFFF00FFFF00F3FF00D9FF0080FF0080FF001900FF4CFF00FFF300FFE600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FFA600FFC000FFD900E6FF00FFFF00CCFF0099FF00D9FF00FFE600FFD900FFCC00FFCC00\
FFCC00FFD900F3FF00FFD900FFCC00FFD900FFFF00FFF300FFCC00FFC000FFC000
FFC000FFB300FFC000FFC000FFCC00FFD9008CFF00C0FF00FFD900FFC000FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFE600FFFF00\
99FF0059FF00B3FF00D9FF00C0FF0059FF00C0FF0033FF00F3FF00FFD900FFCC00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900
FFA600FFA600FFB300FFCC00FFFF0019FF00E6FF00FFF300FFF300FFD900FFCC00FFC000FFC000\
FFC000FFC000FFCC00FFC000FFC000FFCC00E6FF00FFD900FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFF30026FF00FFE600FFCC00FFC000FFB300FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFD90000FF1999FF00\
A6FF00D9FF0000FF1973FF008CFF008CFF00FFFF008CFF00FFD900FFCC00FFC000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FFA600FFA600FFB300FFCC00FFD900F3FF00E6FF00FFE600FFCC00FFCC00FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFCC00FFB300FFB300FFA600
FFA600FFA600FFA600FFB300FFB300FFCC00CCFF00FFF300FFCC00FFB300FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFD9008CFF0000FF4C\
E6FF00FFFF00FFFF00C0FF00FFFF00FFE600FFD900FFD900FFCC00FFC000FFB300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FFA600FFB300FFC000FFCC00FFE600E6FF00FFFF00FFD900FFCC00FFC000FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFD900FFF300C0FF00FFF300FFB300FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFE600FFF300B3FF0033FF00\
E6FF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFB300FFB300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600
FFA600FFB300C0FF00E6FF00CCFF00D9FF00FFF300FFD900FFC000FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFD900FFE600FFB300FFA600FF9900FF9900\
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFC000FFE60099FF0099FF00CCFF00\
FFFF00FFE600FFD900FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFA600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300
FFB300FFC000FFD900F3FF0000FF2680FF00C0FF00D9FF00FFC000FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600A6FF00FFC000FFA600FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFF3004CFF00A6FF00\
F3FF00FFF300FFD900FFCC00FFCC00FFC000FFB300FFB300FFB300FFA600FFA600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF8C00FF9900FFA600F3FF00FFC000FFC000FFC000
FFC000FFCC00FFD900F3FF00A6FF00FFFF00FFE600FFFF00FFC000FFB300FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FF9900FF9900FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFB300FFC000FFCC00FFF3008CFF00\
00FF19FFF300FFD900FFCC00FFC000FFC000FFB300FFB300FFA600FFA600FFA600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF8C00FF9900B3FF00FFC000FFF300C0FF00FFFF00FFCC00
FFE600FFD900FFF300F3FF00FFE600FFD900FFCC00FFC000FFB300FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFC000FFCC00FFE600CCFF00\
D9FF00FFF300FFE600FFCC00FFCC00FFC000FFB300FFB300FFA600FFA600FF9900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF8C00FFA600FFE600FFC000FFC000FFE600D9FF00
00FFB380FF0099FF00F3FF00FFD900FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFCC00FFF300FFFF00CCFF00\
8CFF00B3FF00FFF300FFE600FFCC00FFC000FFB300FFB300FFA600FFA600FF9900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF8C00FF9900FF9900FFA600FFA600FFB300FFF300
FFD900FFE600FFF30000FF26FFE600FFCC00FFC000FFB300FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFB300F3FF00FFE60000FF0CE6FF00\
CCFF0073FF00B3FF00D9FF00FFD900FFCC00FFC000FFB300FFA600FF9900FF9900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300
FFC000FFC000FFD900FFFF00FFF300FFCC00FFB300FFB300FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFB300FFC000A6FF00\
FFE600FFE600C0FF00CCFF00FFFF003FFF00F3FF00FFB300FFA600FF9900FF9900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600
FFB300FFC000FFD90099FF00FFD900FFC000FFB300FFB300FFA600FFA600FF9900FF9900FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000\
FFC000FFCC00FFE600FFF3000CFF00E6FF00FFCC00FFB300FFA600FF9900FF9900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600
FFA600FFC000FFD900B3FF00FFD900FFCC00FFC000FFB300FFA600FFA600FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600\
FFB300FFC000FFCC00FFE600C0FF00FFFF00A6FF00FFB300FFA600FF9900FF8C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900
FFA600FFC000FFFF00B3FF00FFE600FFD900FFC000FFB300FFA600FF9900FF9900FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600\
FFA600FFC000FFCC00FFE60000FFBFFFCC00FFF300FFF300FF9900FF9900FF8C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900
FFB300FFC000FFE6008CFF004CFF00FFFF00FFF300FFC000FFA600FF9900FF9900FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FFA600FFCC00CCFF00F3FF00E6FF00FFB300FFA600FF9900FF9900FF8C00FF8C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900
FFCC00FFFF00FFFF0000000000F3FFFFFF00FFE600B3FF00FFA600FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900\
FFA600FFD900FFF300FFCC00FFB300FFA600FF9900FF9900FF8C00FF8C00FF8C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900
FFA600FFC000FFE600CCFF00CCFF00FFE600FFC000FFB300FFA600FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900\
FFA600FFCC00C0FF00FFC000FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900
FFA600FFB300FFC000FFD900F3FF00F3FF00FFC000FFA600FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF9900FFA600FFE600D9FF00FF9900FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900
FFA600FFB300FFC000FFD90080FF00FFCC00FFB300FFA600FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FFA600FFD900FF9900FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900
FFA600FFB300FFC00033FF00FFE600FFC000FFB300FFA600FF9900FF9900FF8C00FF8C00FF8C00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900
FFA600FFB300FFC000FFE600FFF300FFCC00FFB300FFA600FF9900FF9900FF8C00FF8C00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600
FFB300FFCC00FFE600FFF300FFE600FFFF00FFF300FFA600FF9900FF8C00FF8C00FF8C00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFB300
FFB300FFD900B3FF00FFC000FFC000FFC000CCFF00FFB300FF9900FF8C00FF8C00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF8C00FF9900FF9900FFC000FFCC00FFC000
FFCC00E6FF00FFC000FFB300FFA600FFB300FFE600FFE600FFC000FF8C00FF8C00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF8C00FFA600FFB300FFF300FFCC00FFFF00
FFCC00FFE600FFB300FF9900FF9900FF9900FFA600FFA600FFB300FF8C00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF9900FFC000FFF300FFCC00FFB300FFA600
FFA600FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF8C00FFA600FFF300FFB300FFA600FF9900
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF8C00FFA600FFFF00FFA600FF9900FF8C00
FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7F00FF8C00FF9900FFA600FFFF00FFA600FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7F00FF8C00FFC00073FF00FFB300FFB300FF8C00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7F00FF9900FFC000FF9900FF8C00FF8C00FF7F00FF7F00
FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000\
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000
FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4000FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FFA600FFA600FFB300FFCC00FFE6004CFF00CCFF00FFF300FFD900FFD900FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD90059FF0059FF00FFFF00
FFF300FFE600FFE600FFE600FFF300FFF300FFFF00E6FF00C0FF001900FF00A6FF00FF190000FF\
00FF6600000059FF003FFF0000FFF3000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FFA600FFA600FFB300FFC000FFE600FFFF0000FF8CF3FF00F3FF00F3FF00FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFF30000FF26E6FF00
FFFF00FFFF00FFFF00FFF300FFF300FFFF00F3FF00E6FF00D9FF0066FF0059FF00000000000000\
00B3FF00FF660000000CFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FFA600FFA600FFB300FFC000FFCC00FFF300D9FF0000FF9900FF59FFFF00FFE600FFD900\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFF300E6FF00000000
3FFF00A6FF00E6FF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00B3FF004CFF0000000000B3FF\
0000001900FF00000000FF8C000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FFA600FFA600FFB300FFC000FFD900E6FF003FFF000CFF00B3FF00F3FF00F3FF00FFE600\
FFD900FFD900FFD900FFE600FFFF00FFE600FFF300FFF300FFFF00B3FF003FFF00
00FFA60CFF00CCFF00E6FF00D9FF00E6FF00E6FF00D9FF0099FF0073FF000080FF3F00FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFB300FFC000E6FF00FFF300FFF300E6FF008CFF0080FF00CCFF00FFF300\
FFE600FFE600FFF300FFFF00CCFF00FFFF00F3FF00B3FF00D9FF00C0FF0073FF00
E600FF59FF00C0FF00CCFF0000FF26CCFF00CCFF00CCFF00C0FF0099FF0000FF2626FF00000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFB300FFB300FFC000FFCC00FFD900FFF3003FFF0000FF1900FF00C0FF00\
F3FF00E6FF00A6FF0099FF0000B3FFCCFF00D9FF0099FF0026FF0080FF0000FF73
00FFCC66FF00A6FF00A6FF0000FF00A6FF00B3FF00B3FF00B3FF0099FF0073FF0026FF002600FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFE600F3FF00FFFF000CFF00B3FF00\
B3FF00B3FF0066FF0000FFF326FF0073FF0099FF0073FF0000CCFF00FF0C0040FF
26FF0073FF0080FF0059FF001900FF00FF0C3FFF0099FF008CFF0059FF003FFF0000FF0C00FF40\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFF300FFF300\
FFF300F3FF00D9FF0000CCFF0CFF0000CCFF00F3FF00F3FF00E6FF00D9FF00FF59
19FF0000FF263FFF0000FF4000B3FF00B3FF0026FF66FF0073FF004CFF00000000E600FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFD900\
FFE600FFF300D9FF00CCFF00C0FF0073FF003FFF0000FF0000FF8C6600FF000000
00FF590000003300FF00FF400073FF00000000FF406600FF4CFF0019FF00000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900\
FFD900FFE600FFFF00F3FF00D9FF00B3FF0080FF0000FF3300B3FF00FF660C00FF
3F00FF000000000000000000000000000000000CFF00000000FF0C00FF590080FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FFB300FFB300FFA600FF9900FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900\
FFD900FFE600FFF300FFFF00CCFF0000FF8C3FFF0000E6FF00FF0000FF0000FFB3
00000000000000000000000000000000000000000000000000FFBF00FF80000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FFA600F3FF00FFCC00FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFE600FFF300FFFF00D9FF0000FF8000000000FF8C3FFF0033FF00000000
3F00FF0000000000000000000000000000000000000000000000000080FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FFA600FFD900E6FF00FFC000FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFE600FFFF00F3FF00C0FF003FFF0000FF2680FF0080FF003FFF0000FF80
00F3FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFB300E6FF00FFE600FFCC00FFCC00FFB300FFA600\
FFA600FFB300FFA600FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFE6003FFF0000BFFF66FF00D9FF0080FF00C0FF0099FF0000FF59004CFF
00CCFF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600FFB300FFCC00F3FF00FFD900FFC000FFC000\
FFCC0099FF00FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFE600FFF300FFFF00F3FF00F3FF00E6FF00CCFF00A6FF004CFF00008CFF
00B3FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFC000FFE600FFFF00FFFF00FFE600\
C0FF00FFCC00FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFD900FFE600FFF300FFFF00F3FF00E6FF00CCFF00B3FF0000FF0C000000
00D9FF9900FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFC000FFE600FFFF00D9FF00CCFF00\
FFD900FFC000FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFD900FFD900FFE600FFF300FFF300FFFF00E6FF0000FF0C00FF4C3FFF0000FFD9
00FF0000B3FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFC000FFD900FFFF00FFFF00\
FFD900FFC000FFB300FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFD900FFD900FFE600FFF300FFF300FFFF00F3FF00CCFF00C0FF00A6FF003FFF00
66FF0000FF4C00FF2600FF7300FFBF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFC000FFD900B3FF00C0FF00\
FFE600FFC000FFC000FFB300FFB300FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900\
FFD900FFE600FFE600FFF300FFFF00F3FF00E6FF00D9FF00CCFF00B3FF0099FF00
80FF004CFF0019FF0000FF66000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFC000FFD900F3FF00FFFF00\
FFD900FFCC00FFC000FFC000FFB300FFB300FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFD900\
FFE600FFE600FFF300FFFF00F3FF00E6FF00E6FF00D9FF00C0FF0099FF008CFF00
0080FF00FF0000FF4C000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFB300FFCC00FFCC00FFF300D9FF00FFFF00\
FFE600FFD900FFCC00FFCC00FFCC00FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFD900FFE600FFE600FFE600\
FFE600FFF300FFF300E6FF002600FFCCFF0099FF00B3FF00B3FF003FFF0000FF33
00000000000000FFB34C00FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600F3FF0019FF00E6FF00FFF300F3FF0099FF00\
F3FF00FFFF00FFF30073FF00FFD900FFC000FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC0000FF19FFFF0019FF00FFF300FFF300\
FFF300FFF300FFFF00F3FF00CCFF009900FF19FF003FFF0099FF0080FF0026FF00
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFC000FFC000FFCC00FFE600CCFF00\
D9FF00A6FF00D9FF00FFE600FFCC00FFC000FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFE60019FF008CFF00A6FF00F3FF00\
FFFF00FFFF00E6FF00D9FF00C0FF00000000000CFF33FF0000FF0C66FF003FFF00
F300FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFB300FFC000FFCC00FFE600\
FFF300C0FF00F3FF00FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFC000FFF300FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFD900FFE600F3FF003FFF0033FF00B3FF00\
E6FF00D9FF004CFF00B3FF000066FF0000000000000CFF0000E6FF00FF5900FF0C
00FFA63300FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00\
FFF30080FF00E6FF00FFE600FFD900FFCC00FFC000FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFC000FFE600FFE600FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFF300F3FF00A6FF0000FF0C\
00FF7300FF8000FF5933FF00000000B300FF00FF9900FF800019FF000000000000
00FFBF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFD900\
FFF30099FF00CCFF00FFFF00FFFF00FFD900FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFCC00FFE60099FF00FFE600FFD900FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00F3FF00\
D9FF0000FFBF73FF0000FF0C0000000000006600FF000000000000000000000000
0040FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFC00059FF00\
FFFF00FFF300CCFF0080FF00FFFF00FFD900FFCC00FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFCC00\
FFD900FFF300B3FF00D9FF00FFE600FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFF300FFFF00\
F3FF00D9FF0073FF0000FFFF0033FF00F3FF6600FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000\
FFCC00FFD900FFF300C0FF00F3FF00FFE600FFD900FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00\
FFFF0000FF0CB3FF00F3FF00FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00\
F3FF00A6FF0059FF0080FF00008CFF00FFE600FF80000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300\
FFC000FFCC00FFE600F3FF00C0FF00FFFF00FFE600FFD900FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFE600F3FF008CFF000CFF00FFF300FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00\
F3FF00E6FF00CCFF00B3FF0059FF0059FF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFB300FFC000FFCC00FFD900C0FF0080FF00FFFF00FFE600FFE600FFD900FFCC00
FFCC00FFD900FFF300FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900\
FFE600C0FF0080FF00E6FF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00\
F3FF00E6FF00D9FF00C0FF00A6FF0026FF0026FF000000000000000080FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFB300FFC000FFC000FFCC00FFD900FFE600D9FF00A6FF00F3FF00FFE600FFE600
FFE600CCFF00CCFF00FFD900FFCC00FFCC00FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900\
FFE600FFFF0080FF00E6FF00FFF300FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00\
F3FF00E6FF00CCFF00C0FF008CFF0073FF004CFF0000FFB300FFB3000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFCC00FFD900FFFF0073FF00CCFF00F3FF00FFFF00
FFFF00B3FF00FFF300FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFE600FFF300B3FF00E6FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900
FFD900FFE600FFE600FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00\
E6FF00D9FF00C0FF0000FF6600FF2600FF4C26FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFC000FFC000FFCC00FFD900F3FF0033FF004CFF0033FF00C0FF00
26FF00F3FF00FFF300FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFF300E6FF008CFF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFE600
FFE600FFFF00FFF300FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF0000FF4CA6FF00\
CCFF00CCFF00B3FF0066FF00008CFF00FF3300FF4000FF804C00FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFFF00E6FF0026FF0000FF26
99FF00F3FF00FFF300FFE600FFE600FFD900FFD900FFE600FFD900FFD900FFD900FFE600FFE600\
FFF300FFFF0000FFA63FFF00B3FF00E6FF00F3FF00FFF300FFF300FFE600FFF300
FFFF00B3FF00E6FF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00CCFF003FFF00\
73FF0026FF0000FF730066FF000000004CFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFF300E6FF00C0FF004CFF00
A6FF00C0FF0000FF8CFFF300FFE600FFE600FFE600F3FF00FFF300FFE600FFE600FFE600FFF300\
F3FF00F3FF00CCFF0080FF0033FF00B3FF00F3FF00FFFF00FFF300FFF300FFFF00
F3FF0000FF19CCFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00E6FF00CCFF00\
C0FF0000FFF300FF197300FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFF300C0FF004CFF00000000
33FF00CCFF00F3FF00FFFF00FFF300FFF300FFFF0073FF00F3FF00FFF300FFF300FFF300FFFF00\
CCFF00A6FF0059FF0000FFF359FF0026FF00E6FF00F3FF00FFFF00FFFF00F3FF00
E6FF0000FF33D9FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00\
CCFF00A6FF000099FF0000000000FF3300FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFFF00E6FF00B3FF0000FF19
A6FF00CCFF00E6FF00F3FF00FFFF00FFFF00F3FF0000FF40E6FF00FFFF00FFFF00FFFF00F3FF00\
E6FF00B3FF0000FF4C3FFF008CFF00C0FF00D9FF00C0FF00E6FF00F3FF00E6FF00
D9FF000066FFD9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00\
CCFF00C0FF0099FF0066FF0026FF000000000099FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFCC00FFE600FFFF00FFFF00E6FF0099FF000066FF00FF40
8CFF000CFF00D9FF00E6FF0066FF00E6FF00D9FF003FFF00CCFF00E6FF00E6FF00E6FF00E6FF00\
D9FF0080FF0000FF8026FF0026FF0000FF00A6FF0080FF00CCFF00D9FF00C0FF00
C0FF0000FF66CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00\
CCFF00B3FF0080FF004CFF007300FF00FFCC000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFCC00FFE600C0FF00CCFF00E6FF004CFF00B3FF0000FF66
0CFF0099FF00C0FF00C0FF008CFF00C0FF00B3FF0000FFCCB3FF00CCFF00B3FF00CCFF00D9FF00\
CCFF00B3FF0000FF4C0033FF00FF4C00000033FF0073FF00A6FF00C0FF0099FF00
00FF4000FF2673FF00CCFF00D9FF00D9FF00CCFF00D9FF00E6FF00E6FF00E6FF00D9FF0033FF00\
99FF00A6FF0080FF0000FFA600FFB3000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFC000FFCC00FFD900FFE600FFF300FFF300F3FF00D9FF0099FF00
00F3FF19FF0019FF004CFF0000FF8C00FFBF00E6FF00FF1900FF66A6FF0080FF00B3FF00C0FF00\
B3FF00A6FF008CFF0059FF0000FF196600FF00FFCC00FF1973FF0099FF0033FF00
00FF593FFF0099FF00C0FF00CCFF00CCFF0000A6FFC0FF00D9FF00D9FF00D9FF00CCFF00C0FF00\
59FF0026FF0000FF99000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFE600FFFF00D9FF0080FF00
8CFF0000FF333FFF0000D9FF00FFF300FF730CFF000040FF33FF004CFF0000FF0C8CFF0099FF00\
3FFF008CFF0000FFFF4CFF000CFF0000FF8000000000FFD900FF0C66FF003FFF00
00BFFF000CFF66FF0080FF00B3FF00A6FF0000FF26C0FF00CCFF00CCFF00CCFF00CCFF00C0FF00\
A6FF008CFF005900FF2600FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFFF00D9FF00E6FF00
CCFF00B3FF00A6FF0080FF0000FF0000FF590059FF00FFF300FF8000FF2600FF4C00000073FF00\
0CFF0059FF004CFF00D900FF0040FFB300FF0000000066FF0059FF0CFF0026FF00
00FF1900D9FF0080FF26FF0080FF0000FF0059FF00A6FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
A6FF008CFF0066FF0000FF0000FF80A600FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00F3FF00
E6FF00CCFF00A6FF0059FF003FFF0019FF0000FF730000000033FF00FFD90033FF0CFF003FFF00\
00000000FF4000FF2600FF333F00FF00000000000000000000FF990C00FF00FF33
00FFF30033FF00000000FF0C00FF9900FF663FFF0099FF00A6FF0073FF00B3FF00B3FF00B3FF00\
8CFF0080FF0059FF008C00FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00F3FF00
E6FF00CCFF00C0FF0099FF0066FF0019FF000040FF000000000000000000CC00FF00FF9900FF26\
00FF4C0000005900FF000000008CFF0000000000000000005900FF0000000026FF
00000000000000000000FF5900FF3300FFBF00FF0C73FF0080FF004CFF0099FF00A6FF0099FF00\
8CFF0033FF0000BFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00
CCFF00B3FF00A6FF0080FF0059FF0000F3FF0099FF000000000000000000000000C000FF00FFB3\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000019FF00E6FF00000000000026FF0000000059FF008CFF008CFF008CFF00\
80FF0066FF0033FF0000FF590000FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFB300FFB300FFE600FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFF300FFF300FFFF00FFFF00F3FF00
D9FF00A6FF0059FF000080FF00FF4C00FFCC000000000000000000000000000000000CFF000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FF800000003FFF0066FF004CFF0080FF00\
73FF0026FF0026FF00000000D900FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFB300FFC000FFD900CCFF00FFE600FFE600FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFE600F3FF00CCFF00F3FF00F3FF00F3FF00E6FF00
D9FF00C0FF00A6FF0073FF003FFF0000FF009900FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000008000FF00FF4000FFCC59FF0066FF00\
66FF003FFF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFB300FFCC00FFB300FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFF300A6FF00FFF300FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFFF00C0FF008CFF00D9FF00D9FF00D9FF00
CCFF00B3FF00A6FF0080FF004CFF0000FF2600FF8000A6FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FFF300FFBF33FF0026FF00\
4CFF0033FF0000FF000033FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300D9FF00FFC000FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFC000FFCC0059FF00B3FF00C0FF00A6FF00FFE600FFD900\
FFD900FFD900FFD900FFE600FFE600FFF300F3FF00CCFF000CFF00A6FF0099FF00
B3FF008CFF0073FF0059FF0000FF4C0026FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000019FF00\
33FF0026FF0000FF59C000FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFB300F3FF00FFE600FFCC00FFC000\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFC000FFCC00FFD900FFF300B3FF00D9FF00FFF300FFE600\
FFE600FFE600FFE600FFE600FFF300FFFF00F3FF00E6FF00CCFF0000FF260CFF00
80FF0073FF0000FF8C0CFF0000FF33000000F300FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000FF19\
0CFF000CFF0000FF33000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFC000FFD900C0FF00E6FF00FFCC00\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFFF0099FF00E6FF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00E6FF0099FF0073FF0000E6FF
00FF1900FFA60059FF00B3FF00FFD9000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00FF3300FF1900FF4C5900FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFCC00FFA600\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300F3FF00B3FF00C0FF00FFE600FFCC00\
FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFFF00CCFF008CFF00\
F3FF00A6FF00F3FF00FFFF00FFFF00F3FF00E6FF00E6FF00CCFF00B3FF008CFF00
59FF0000FFB37300FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000007300FF\
00FF6600FF4000FF73000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFD900FFB300\
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFD900D9FF00FFFF00FFD900\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300D9FF0073FF00\
A6FF00A6FF00E6FF00F3FF00E6FF00B3FF00D9FF00D9FF00CCFF00B3FF0099FF00
59FF000CFF00008CFF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000FF7300FF99000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFD900FFC000\
FFA600FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFCC00FFF3004CFF00D9FF00\
FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300F3FF00C0FF00\
00FF6699FF00A6FF00D9FF00D9FF00B3FF00A6FF00C0FF00B3FF0033FF0073FF00
4CFF0000FF1900FFE6000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000D9FF00FFCC000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFCC00FFCC00\
FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFFF0059FF00FFE600\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFFF004CFF0066FF00\
26FF0000FF80A6FF00C0FF00C0FF00B3FF0000FF7380FF00A6FF008CFF000CFF00
00FF4C000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000D9FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFD900FFE600E6FF00\
F3FF00FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFD900E6FF00A6FF00\
FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300F3FF00D9FF00\
99FF0000FF4C80FF0099FF00A6FF0099FF0000FFBF33FF0073FF0073FF004CFF00
00FF330099FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000099FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFE60073FF00FFE600\
FFCC00FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFD900FFF300E6FF00\
FFE600FFD900FFCC00FFCC00FFCC00FFC000FFCC00FFCC00FFCC00E6FF00FFD900
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFE600FFF300FFFF00F3FF00E6FF00\
C0FF0099FF0000A6FF00FF1973FF0066FF0026FF0026FF003FFF0019FF0026FF00
00FFBF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000026FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFCC00FFE600FFD900\
FFC000FFB300FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFF300A6FF00\
FFF300FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFD900E6FF0073FF00
FFD900FFD900FFD900FFD900FFD900FFE600D9FF00F3FF00FFFF00FFFF00FFFF00E6FF00D9FF00\
C0FF008CFF0033FF0000FF9900FF0000FF0000FF8000FFA600FF4000FF2600FF0C
00FF4CF300FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000009900FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFCC00FFF300F3FF00\
FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFD900FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFFF0000FF0C\
FFFF00FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFE600E6FF00F3FF00
FFE600FFE600FFD900FFD900FFE600FFF300E6FF00A6FF00F3FF00F3FF00E6FF0059FF00C0FF00\
B3FF008CFF003FFF0000FF730000000C00FF00BFFF000000004CFF00F3FF00FF80
00FFB3000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFB300FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFC000FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFE600FFF300\
FFCC00FFC000FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFFF00E6FF00FFC000FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFCC00FFFF00FFCC00
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFF300FFFF00C0FF00\
A6FF00FFFF00E6FF00F3FF00FFE600FFE600FFE600FFE600FFF300E6FF00E6FF00
FFF300FFE600FFE600FFE600FFF300FFF300F3FF00CCFF00CCFF00D9FF00D9FF00C0FF004CFF00\
73FF0073FF0000FFD900FF595900FF000000000000000000000000000000000000
00E6FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFE600FFC000FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFD900FFD900FFF300FFFF00\
FFE600FFE600FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFD900FFFF00FFCC00FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFCC00A6FF00FFD900
FFCC00FFC000FFC000FFCC00FFE600FFF300FFD900FFD900FFE600F3FF00E6FF00E6FF00B3FF00\
C0FF00D9FF0099FF00FFFF00FFF300FFF300FFF300FFF300FFFF00E6FF00CCFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00CCFF0026FF00B3FF00C0FF00B3FF0080FF00\
00FFF30CFF0000FF0C0033FF000000000000000000000000000000000000000000
CC00FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFCC00FFB300FFB300FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFC000D9FF00FFD900FFC000FFB300
FFB300FFB300FFC000FFC000FFB300FFB300FFC000FFC000FFCC00E6FF00F3FF00C0FF00C0FF00\
E6FF00FFFF00FFD900FFCC00FFC000FFC000FFC000FFC000FFC00099FF00FFC000
FFC000FFC000FFC000FFCC00FFE600E6FF00FFD900FFCC00FFC000FFC000FFC000FFD900FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFD900CCFF00FFE600
FFD900FFD900FFD900FFD900FFF300F3FF00FFE600FFE600FFF300FFFF00CCFF00B3FF0080FF00\
00FFCC0CFF00CCFF00F3FF00F3FF00FFFF0000FF66F3FF00E6FF0066FF000099FF
D9FF00E6FF00CCFF00E6FF00F3FF00CCFF00D9FF00C0FF0000FF998CFF008CFF008CFF0059FF00\
0CFF0000FFFFA600FF000CFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFCC00B3FF00FFCC00FFC000FFC000FFC000\
FFC000FFC000F3FF00FFC000FFC000FFCC00FFD900FFFF00FFE600FFCC00FFCC00
FFCC00FFCC00F3FF00FFD900FFCC00FFCC00FFCC00FFD900FFD900FFF300CCFF0059FF00000000\
4CFF00FFFF00FFE600FFD900FFD900FFCC00FFE600FFD900FFD900B3FF00FFD900
FFD900F3FF00FFD900FFE600F3FF00D9FF00FFE600FFD900FFD900FFE600FFD900FFFF00FFE600\
FFD900FFD900FFCC00FFD900FFE600FFE600FFE600FFE600FFF300D9FF00FFFF00
FFF300FFFF00FFF300FFFF00F3FF0066FF00F3FF00CCFF00F3FF00D9FF004CFF0033FF0000FF8C\
00000000FFFFA6FF00CCFF00C0FF00D9FF00B3FF00CCFF00C0FF0080FF0066FF00
B3FF0099FF0073FF00C0FF00C0FF00B3FF0099FF0073FF0033FF0000FF193FFF0033FF0019FF00\
00FF400073FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFFF00FFFF00FFE600FFE600FFE600FFF300FFF300FFFF00B3FF00FFF300FFE600FFF300FFD900\
FFD900FFE600D9FF00FFE600F3FF00FFE600FFFF008CFF00F3FF00FFFF00FFF300
E6FF00FFF300E6FF00FFF300FFF300FFF300FFF300E6FF00A6FF00E6FF004CFF00000000000000\
0CFF00D9FF00F3FF00F3FF00FFFF00FFFF00F3FF00FFFF00FFFF008CFF00FFFF00
FFFF00B3FF00FFFF00F3FF00D9FF0026FF00E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00F3FF00\
FFFF00FFFF00FFF300D9FF00F3FF00E6FF00E6FF00E6FF00CCFF0000FF0CCCFF00
D9FF00C0FF00D9FF008CFF0099FF004CFF00C0FF0099FF00B3FF00A6FF0080FF0000BFFF000000\
0000000080FF73FF0073FF0080FF008CFF0066FF0080FF0080FF003FFF0000FFF3
73FF0019FF003FFF003FFF0066FF0059FF0033FF0000FF2600FF9900FFCC00FF5900FF6600FF8C\
0080FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFE600FFC000FFB300FFB300FFB300\
FFB300FFB300FFCC00FFC000FFC000FFC000FFCC00FFFF00FFD900FFCC00FFC000
FFC000FFC000FFE600FFCC00FFC000FFC000FFC000FFCC00FFD900FFF300B3FF00A6FF0000FFB3\
A6FF00FFFF00FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00C0FF00FFCC00
FFCC00FFCC00FFCC00FFD900FFF300E6FF00FFD900FFCC00FFCC00FFCC00FFCC00FFF300FFD900\
FFCC00FFCC00FFC000FFCC00FFD900FFD900FFD900FFD900FFE600E6FF00FFF300
FFE600FFF300FFE600FFE600FFFF00E6FF00FFFF00F3FF00FFFF00F3FF00CCFF0026FF0000FF19\
00000000FF1966FF00D9FF00CCFF00E6FF00C0FF00D9FF00D9FF00A6FF0080FF00
CCFF00CCFF00C0FF00CCFF00D9FF00C0FF00C0FF00A6FF0066FF0059FF0066FF0059FF0033FF00\
00FF330099FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFC000FFF300FFE600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFCC00FFFF00FFF300FFFF00E6FF00\
FFFF00A6FF00FFCC00FFC000FFC000FFB300FFB300FFB300FFC000F3FF00FFC000
FFB300FFC000FFC000FFCC00FFE600F3FF00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900A6FF00FFD900
FFCC00FFCC00FFCC00FFD900FFF300FFFF00FFE600FFE600FFE600FFFF0000FF26CCFF00A6FF00\
33FF00A6FF00CCFF00F3FF00FFFF00FFFF00E6FF00FFFF00F3FF00CCFF00B3FF00
E6FF00F3FF00D9FF00F3FF00F3FF00E6FF00E6FF00C0FF0000FF8C99FF0099FF0099FF0080FF00\
33FF0000FF4C00FFB300B3FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFD900FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFD900FFF300FFFF00\
FFD900FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFD900FFF300FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC003FFF00FFCC00
FFC000FFC000FFC000FFC000FFD900FFD900FFCC00FFCC00FFD900E6FF00FFFF00F3FF00B3FF00\
CCFF00E6FF0099FF00FFFF00FFF300FFE600FFE600FFF300FFF300F3FF00E6FF00
FFFF00FFF300FFF300FFF300FFF300FFFF00F3FF00D9FF0099FF00C0FF00CCFF00C0FF0073FF00\
00FF3359FF0000FF6600FF8C0000FF000000000000000000000000000000000000
0040FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFC000FFCC00FFE600FFF300\
FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFCC00FFE600FFC000FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFC000FFD900FFC000
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFFF00A6FF00\
F3FF00FFF300FFFF00FFFF00FFE600FFD900FFD900FFE600FFF300E6FF00F3FF00
FFF300FFE600FFE600FFE600FFE600FFF300F3FF008CFF00E6FF00E6FF00E6FF00C0FF0099FF00\
99FF004CFF004CFF0000FF4C000CFF000000000000000000000000000000000000
00FFCC000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFE600FFE600\
FFCC00FFC000FFB300FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FFA600FFA600FFA600FFA600FFB300FFCC00FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFF30000FF0C\
F3FF00FFE600FFD900FFD900FFD900FFCC00FFD900FFD900FFE600D9FF00FFFF00
FFE600FFD900FFD900FFD900FFD900FFE600D9FF00D9FF00FFFF00FFFF00F3FF00CCFF00CCFF00\
C0FF0080FF0019FF0000000000FFD900FFCC00FF990000000000FF00FF8C00FF4C
00FF99000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFCC00FFF300FFD900\
FFC000FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFF300F3FF00\
FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900F3FF00FFE600
FFD900FFCC00FFCC00FFD900FFD900FFE600FFFF00FFF300FFF300FFF300FFFF00F3FF00D9FF00\
CCFF0099FF003FFF0000FF803FFF0033FF0000FF2600FF3300FF000CFF000CFF00
00FF40000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000003300FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFC000CCFF00F3FF00FFFF00\
FFD900FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFD900F3FF00FFFF00\
FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFCC00FFE600FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00D9FF00\
A6FF003F00FF00FF0026FF008CFF0080FF0000FF264CFF0059FF0059FF0000FF19
00FF0C0099FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000059FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFC000FFD900FFE600\
FFCC00FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFE600D9FF00FFF300\
FFD900FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFFF00E6FF00CCFF00\
8CFF0000FF0C66FF00B3FF00B3FF0099FF0000FF1980FF008CFF0080FF004CFF00
00FF00000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000BFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFCC00FFC000\
FFB300FFA600FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFC000FFCC00E6FF00A6FF00FFF300\
FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300E6FF0026FF00\
00FF5973FF00A6FF00CCFF00CCFF00B3FF008CFF00B3FF00A6FF008CFF0000FF40
26FF000080FF00F3FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000FFFF00FFF3000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFCC00FFB300\
FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFCC00FFF300E6FF00FFF300\
FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFF300F3FF00A6FF00\
00FFA6B3FF00D9FF00E6FF00E6FF0066FF00C0FF00CCFF00C0FF0073FF008CFF00
66FF000CFF0000FFB37300FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000FF9900E6FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFD900FFA600\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFD900D9FF00E6FF00FFCC00\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300E6FF0059FF00\
CCFF0059FF00E6FF00F3FF00F3FF00D9FF00E6FF00D9FF00CCFF00B3FF0099FF00
3FFF0000FF66000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0059FF00FF5900FFCC000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FFCC00FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFB300FFC000FFE60000FF26FFE600FFCC00\
FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFF300F3FF00C0FF00F3FF00\
FFFF00E6FF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00CCFF00A6FF0073FF00
3FFF00000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00FF5900FF26000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFD900E6FF00FFF300FFCC00\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFF300E6FF0000FF33FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00E6FF00CCFF0066FF0000A6FF
4CFF000CFF0000FF9900FF5900FF66000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00FF0C00FF0C00FF66000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFB300FFE600FFD900FFC000FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFE600F3FF0066FF00F3FF00FFF300FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300F3FF00E6FF00C0FF0000A6FF66FF00
99FF008CFF0000FF0C3FFF0000FF66000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000003300FFA600FF0CFF00\
19FF0019FF0000FF19000CFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFF300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFFF004CFF00F3FF00FFF300FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFF300E6FF008CFF00C0FF00CCFF00A6FF00
C0FF0026FF008CFF0033FF0026FF0000FF0000FF7300B3FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF0C26FF00\
3FFF0019FF0000FFB3000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFB300FFB300FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFC000FFCC00E6FF00C0FF00FFF300FFD900FFD900FFCC00\
FFCC00FFCC00FFD900FFD900FFE600FFFF004CFF00A6FF00E6FF00E6FF00D9FF00
D9FF00C0FF00A6FF0080FF004CFF0000FFE600FFCC000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FF997300FF3FFF0059FF00\
59FF003FFF000CFF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFB300FFC00000FF00FFE600FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900F3FF00F3FF00FFFF00FFFF00F3FF00E6FF00
D9FF00C0FF0099FF0033FF000CFF0000FF26000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FFE6B300FF19FF003FFF0059FF0073FF00\
66FF0019FF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00
C0FF000080FF59FF000CFF0026FF009900FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FF00000000000000FF4C00FF9959FF0073FF0073FF008CFF00\
80FF0066FF000000000073FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFE600FFF300FFFF00F3FF00
D9FF00CCFF00B3FF0099FF003FFF00004CFF0040FF00000000000000000000000000FFF300FFA6\
00FFB3000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF803300FF0000004CFF004CFF0073FF008CFF0099FF0099FF00\
8CFF0066FF000040FF0059FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00F3FF00
E6FF00D9FF00C0FF0099FF0073FF0000FF0CD900FF000000000000E600FF00000000FF8000FF00\
00FF2600000000000000FF8C00CCFF000000000000000000000000000000004CFF
00B3FF00000000000000FF9900FF1900F3FF26FF0073FF008CFF0000E6FFA6FF00A6FF00A6FF00\
80FF000CFF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00F3FF00
D9FF00CCFF00B3FF0066FF0000FF5900FF0C00FF80CC00FF0073FF00FF8000FFE633FF0059FF00\
00000026FF0026FF0000FF5900BFFF00000000000000000000FF6600000000FF0C
00FF4000FFF300000019FF003FFF0000FFD97300FF99FF00B3FF00A6FF00B3FF00B3FF00B3FF00\
A6FF008CFF0033FF0000000000FFB3000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFFF0000FFBFCCFF00
C0FF0099FF0099FF0066FF0000FFD900FFFF00FFCC00FFFF00FF0C26FF0026FF0073FF008CFF00\
00FF3373FF0059FF003F00FF00E6FF00D9FF00000000FFE600FF193FFF003FFF00
00FF1900FFBF00FF2680FF0099FF008CFF0066FF00B3FF00C0FF00CCFF00CCFF00C0FF00C0FF00\
A6FF008CFF0059FF0000FF000000002600FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300FFFF00E6FF0073FF00
66FF0000FF9900FF5900FFCC00FFD90CFF0026FF0000FF7319FF0080FF0000FF6699FF00A6FF00\
73FF0099FF0073FF0059FF0000FF0C00FF99000000B300FF59FF0080FF0026FF00
00FF660066FF80FF0033FF00C0FF00B3FF0000FFBFC0FF00CCFF00D9FF00D9FF00CCFF00C0FF00\
A6FF0080FF0000FFB3000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFC000FFCC00FFD900FFF300FFF300FFFF00E6FF00CCFF008CFF00
00FF7359FF0099FF0099FF0059FF0059FF0099FF0000FF8080FF00C0FF0080FF00C0FF00CCFF00\
C0FF00A6FF0080FF004CFF0000FF0000000000CCFF19FF0066FF00A6FF0080FF00
00000000FF0C59FF00CCFF00D9FF00CCFF0019FF008CFF00D9FF00E6FF00D9FF00D9FF00C0FF00\
1900FF80FF000CFF000000FF0080FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFCC00E6FF0000FF19A6FF0080FF0026FF008CFF0000FF66
00FF00A6FF00CCFF00CCFF008CFF00D9FF00B3FF000CFF00C0FF00D9FF00CCFF00D9FF00D9FF00\
CCFF00A6FF0000FF0000FF1900000000FF2673FF003FFF00C0FF00CCFF0073FF00
26FF0000FF80A6FF00D9FF00E6FF00E6FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00\
C0FF00B3FF008CFF0000000000FF8C00FF80000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFCC00FFD900FFE600FFF300FFFF00D9FF008CFF00000000
99FF00C0FF00D9FF00E6FF00E6FF00F3FF00E6FF00A6FF00D9FF00F3FF00F3FF00F3FF00F3FF00\
D9FF00B3FF000026FF3FFF0080FF008CFF00C0FF0000B3FFD9FF00E6FF00D9FF00
CCFF0000FF66CCFF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00\
CCFF00C0FF0099FF0066FF0019FF0000FF330099FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFF300E6FF00A6FF000CFF00
99FF00CCFF00E6FF00FFFF00FFFF00FFFF00F3FF000CFF00E6FF00FFFF00FFFF00FFFF00FFFF00\
E6FF008CFF0000FF1919FF0000FFD9C0FF00D9FF00E6FF00F3FF00F3FF00F3FF00
D9FF00008CFFD9FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00\
CCFF00B3FF008CFF003FFF0000FF19000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFF300C0FF0099FF0000FFE6
66FF0080FF00E6FF00FFFF00FFF300FFF300FFF300C0FF00E6FF00FFF300FFF300FFF300FFFF00\
59FF00D9FF003FFF0000FFCC00FFD9C0FF00E6FF00FFFF00FFFF00FFFF00FFFF00
E6FF0033FF0066FF00F3FF00FFFF00FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00\
CCFF00A6FF000059FF00000000A6FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFF300F3FF00C0FF0000FF66
C0FF00E6FF00F3FF00FFF300FFE600FFE600FFE600FFF300FFE600FFE600FFE600FFE600FFF300\
FFFF00F3FF00D9FF0000FF4C33FF0000FFB3F3FF00FFFF00FFF300FFF300FFF300
F3FF0000FF40B3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00E6FF008CFF00\
8CFF0033FF006600FFC000FFA600FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFC000FFC000FFCC00FFD900F3FF00F3FF00C0FF0080FF008CFF00
99FF00F3FF00FFF300FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFF300FFFF00D9FF0026FF00E6FF00F3FF00FFFF00FFF300FFE600FFE600FFE600
FFF300F3FF00FFFF00FFF300FFE600FFE600FFE600FFF300FFF300FFF300FFFF00CCFF0000FFB3\
A6FF00B3FF0080FF003300FF4C00FF00FFFF00000000FFE6000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFCC00FFD900FFF30073FF00A6FF0099FF00E6FF00
D9FF00F3FF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFE600FFF300E6FF00CCFF00FFFF00FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFFF00E6FF00D9FF00\
D9FF00D9FF00C0FF00B300FF00000000FF1900FF0000FF80000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFCC00FFCC00FFE600F3FF00A6FF00D9FF00FFF300FFF300
FFF3000CFF00FFF300FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFE600FFFF000CFF00E6FF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00\
F3FF00E6FF00B3FF0099FF0066FF004CFF0019FF000000008000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFB300FFC000FFCC00FFCC00FFD900FFF300A6FF00F3FF00C0FF00FFE600FFD900
FFD900FFF300FFF300FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900\
FFE600F3FF003FFF008CFF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00\
F3FF00E6FF00D9FF00C0FF00A6FF0080FF004CFF000CFF00000000B300FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300\
FFC000FFC000FFE600FFE600F3FF003FFF00FFF300FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFE600F3FF006600FFE6FF00FFF300FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00\
F3FF00E6FF00D9FF00C0FF0099FF0073FF006600FF0000000000003300FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000\
FFC000FFCC00FFE60099FF00B3FF00E6FF00FFD900FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00\
FFE600E6FF0000FF26E6FF00FFF300FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00\
F3FF00C0FF00C0FF00A6FF0000000033FF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFD900\
FFD900FFE600FFFF00B3FF00E6FF00FFE600FFCC00FFCC00FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00\
A6FF00E6FF003FFF00E6FF00FFE600FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00\
F3FF00D9FF004CFF0000FFFF00FF4000FF80000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFE600\
99FF00E6FF0099FF00C0FF00D9FF00FFD900FFCC00FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFCC00FFF30000FF33D9FF00FFE600FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00FFFF00\
E6FF00CCFF0080FF008000FF00FFBF00E6FF000000000000000000000000000000
D900FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFCC00\
FFE600D9FF00F3FF00FFF300FFE600FFCC00FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFCC00FFE600F3FF00FFD900FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFFF00E6FF00D9FF00\
CCFF0000CCFF00FF002600FFCC00FF0019FF00CCFF5900FF000000000000000000
0099FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFD900\
FFFF003FFF0000FF19FFE600FFCC00FFC000FFC000FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFC000FFF300FFD900FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE6008CFF00C0FF0000FF9959FF00\
C0FF0073FF0000FFF373FF0000FF4000000000FF9900FF330000000066FF00FFFF
00FFE6000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000FFC000FFE600FFF300\
FFFF0019FF00FFFF00FFD900FFCC00FFC000FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFD900FFE600F3FF003FFF0000FF00D9FF00\
F3FF00E6FF00C0FF00C0FF0066FF0026FF0000000033FF0000FF2626FF0026FF00
00FF3300F3FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFC000FFF300FFD900FFD900FFF300A6FF00\
73FF00D9FF00A6FF00FFF300FFCC00FFC000FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFF30059FF0000FFB3F3FF00FFFF00\
FFFF00FFFF00F3FF00E6FF00C0FF0000FFCC00FF7359FF0066FF0073FF003FFF00
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFCC00FFE600FFFF00C0FF00CCFF00CCFF00\
FFF300FFE600FFE60066FF00FFD900FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFE600FFE60073FF00FFE600FFE600\
FFF300FFF300FFFF00F3FF008CFF0073FF008CFF008CFF00A6FF008CFF0033FF00
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFB300FFC000FFCC00FFD900FFFF00FFFF00\
FFE600FFCC00FFCC00FFC000FFC000FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300E6FF00CCFF00D9FF00CCFF00CCFF00C0FF000040FF73FF00
0CFF0000CCFF00FF80000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFC000FFD900CCFF00E6FF00\
FFD900FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFE600FFE600FFF300FFFF00F3FF00E6FF00D9FF00CCFF00B3FF0099FF00
66FF003FFF00000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFC000FFD900E6FF00D9FF00\
FFD900FFC000FFB300FFB300FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900\
FFD900FFE600FFE600FFF300FFFF00FFFF00F3FF00D9FF00CCFF00B3FF0099FF00
73FF003FFF0019FF0000FF407300FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFCC00FFD900FFFF00FFFF00\
FFCC00FFC000FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFD900FFD900FFE600FFF300FFF300FFFF00E6FF008CFF00A6FF00A6FF004CFF00
59FF000000002600FF000000000000004CFF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFC00080FF004CFF00B3FF00A6FF00\
FFD900FFC000FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFD900FFE600FFF300FFF300FFFF00E6FF00B3FF0099FF000033FF00FF99
00FF2600B3FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600FFA600FFC000FFF300FFE600E6FF00FFCC00\
F3FF00FFD900FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFD900FFE600FFF300FFFF00F3FF00E6FF00CCFF00B3FF004CFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600FFB300FFD9008CFF00FFD900FFB300FFB300\
FFC000FFD900FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFE600FFFF00D9FF00E6FF00E6FF00D9FF00CCFF0059FF0000FF731900FF
0080FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFC000FFF300FFCC00FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFE600E6FF0000FF3300FF8CB3FF0000FF4CA6FF0099FF004CFF0000FF00
0019FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FFA600FFC000FFD900FFB300FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFE600FFF300F3FF00CCFF002600FF19FF0059FF0073FF0026FF0000FF80
00A6FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FFA60099FF00FFF300FFA600FF9900FF9900FF9900FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFE600FFF300FFFF00CCFF0000000000FF0C0033FF26FF0000FF00000000
00000000000000000000000000000000000000000000000000FFF3000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FFE600FFA600FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900\
FFD900FFE600FFF300FFFF00D9FF00A6FF0019FF0000000000FFF300FF2600FFCC
00000000000000000000000000000000000000000000000000FF5900FF8C000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFD900\
FFE600FFF300E6FF00E6FF00CCFF00A6FF0080FF0019FF0000CCFF000000000000
00F3FF00000000FFF300000000000000000000FFE600000019FF000CFF0000FF66E600FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFCC00FFD900FFD900FFE600\
FFF300FFF300E6FF0099FF00A6FF0000FF8000FFA600FFF34C00FF008CFF00FF66
00FF266600FF00FF7300FF3300E6FFB300FF00FF260CFF0059FF0000FF0C0040FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFE600FFE600FFE60000FF0CF3FF00\
FFFF00E6FF00C0FF0000FFA600FF000059FF00FF0C3FFF0000FF6600FF40B300FF
26FF0026FF0059FF000073FF00A6FF00FFB300000073FF0080FF0033FF000033FF00000000FF99\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFB300FFC000FFC000FFCC00FFE600B3FF0099FF00A6FF0033FF00\
CCFF003FFF0033FF004CFF0000FF00A6FF00B3FF008CFF0000FFBF4CFF00004CFF
00FF0C73FF008CFF008CFF0000FF8C80FF0033FF00A6FF0099FF0080FF0033FF0033FF0000FF26\
00FFBF0C00FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFB300FFC000FFCC00FFD900FFE600FFF300CCFF0000FFCCC0FF0073FF00\
FFF300FFFF00F3FF00E6FF0019FF00D9FF00E6FF008CFF0026FF0033FF0019FF00
00D9FF73FF00B3FF00B3FF000CFF00C0FF00C0FF00C0FF00B3FF0099FF0073FF0026FF00000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FFA600FFA600FFB300FFC000E6FF00D9FF00F3FF00A6FF0000FF00CCFF00CCFF00FFF300\
FFE600FFE600FFE600FFF300C0FF00FFF300FFFF00E6FF00F3FF00C0FF003FFF00
00FFCC8CFF00CCFF00D9FF008CFF00CCFF00D9FF00CCFF00B3FF008CFF0000FF4C00FF19000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FFA600FFA600FFB300FFC000FFCC00F3FF00A6FF0000FF40B3FF00FFFF00FFF300FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00E6FF004CFF00
00FF3300FF73D9FF00F3FF00F3FF00F3FF00E6FF00D9FF00B3FF0099FF000040FF00000000D9FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FFA600FFA600FFB300FFC000FFCC00FFF300C0FF00CCFF00B3FF00FFF300FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300E6FF0073FF00
E6FF00CCFF00F3FF00FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00B3FF003300FF0033FF0000FF\
00000000CCFF00000000FF59000000D900FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FFA600FFA600FFB300FFC000FFE600B3FF0059FF00FFFF00FFF3008CFF00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFFF0000FF40F3FF00
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00E6FF00CCFF00A6FF0019FF000000009900FF\
0000001900FF00FF5933FF0000FF33000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FFA600FFA600FFC000FFCC00C0FF003FFF0000FF0CFFFF00FFD900FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFD900FFFF00B3FF00FFF300
FFE600FFE600FFE600FFE600FFE600FFF300FFFF00CCFF0000FF001900FF00D9FF33FF0019FF00\
00FF4C00000073FF0033FF000000000033FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FFA600FFB300FFE600CCFF00FFF300FFE600FFF300FFE600FFCC00FFC000FFC000FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00F3FF00FFF300FFE600
FFD900FFD900FFD900FFD900FFE600FFF300CCFF0000FF0CA6FF00D9FF00CCFF00CCFF008CFF00\
00FF73A6FF00A6FF0080FF0000FF2600000000000000FF6600CCFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FFA600FFC000FFF300FFC000FFC000FFC000FFC000FFD900FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600F3FF0026FF00D9FF00F3FF00F3FF00E6FF000099FF\
CCFF00CCFF00B3FF0000000000000000FF26000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFE600F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00\
E6FF00D9FF00B3FF008CFF00A6FF0000FF1973FF0000FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00\
F3FF00E6FF00D9FF00CCFF00C0FF00A6FF0099FF0073FF0059FF0033FF0000FF0C
00FF4C000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFE600FFF300FFFF00FFFF00\
F3FF00E6FF00D9FF00CCFF00C0FF00B3FF0099FF0080FF0066FF003FFF0026FF00
00FF0C00FF4C00FFB3000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFF300FFFF00\
F3FF00E6FF00D9FF00CCFF00C0FF008CFF0080FF0073FF0033FF0019FF0000FF00
00FF4C00FFCC00E6FF00CCFF0040FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFF300FFFF00\
E6FF00D9FF00CCFF00CCFF00B3FF008CFF0000FF190000FF00FF4C00CCFF00FFBF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFFF00E6FF00\
00FF4000FF73B3FF00B3FF00A6FF008CFF0000000000FF5900BFFF00BFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00\
8CFF00A6FF00D900FF8CFF0073FF0073FF0000000000A6FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00\
E6FF00CCFF008CFF0000FF8026FF0000FF8000FF4000F3FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00\
E6FF00D9FF00B3FF0000FF800019FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00A6FF000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFC000FFC000FFCC00FFD900FFD900FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00\
E6FF00C0FF003FFF0000FF400040FF00FF8C000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00FFFF00FFB3000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFC000FFC000FFCC00FFD900FFE600FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00\
D9FF00CCFF00A6FF003FFF0019FF0000FF4000A6FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000FF5900FF4C00000000BFFF000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300
FFC000FFC000FFD900B3FF00FFFF00D9FF00A6FF00008CFF59FF00F3FF00E6FF00CCFF00B3FF00\
CCFF00B3FF0080FF0066FF0019FF000000007300FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000FF4C00FF0000FF00CC00FF000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300
FFC000FFCC00FFD900B3FF0000FFFF00FF0C66FF00B3FF00A6FF00CCFF00C0FF00A6FF008CFF00\
B3FF00A6FF0000FF5926FF008000FF0033FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000D9FF19FF0033FF0033FF000CFF000C00FF00000000FFD9000000000000
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000
FFCC00FFD900FFFF00C0FF0000FF59D9FF00E6FF00F3FF00E6FF0000FF4066FF0000FF2619FF00\
00FFF380FF0000FF194C00FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000009900FF26FF0059FF0066FF0033FF0000000000FF4C00FF6600FFFF000000
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000
F3FF00E6FF0000FFF3B3FF0000FFE6FFFF00FFF300FFF300FFFF00E6FF0000FF1973FF00000000\
33FF004CFF000099FF1900FF7300FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000FF8019FF0073FF0080FF0000D9FF80FF0073FF003FFF008000FF000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300
FFC000FFCC00FFE600FFFF00FFE600FFE600FFE600FFE600FFF300E6FF00D9FF00C0FF000CFF00\
2600FF00FF3300FFCC00FF9900FF800066FF0073FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
C000FF0000000000008CFF0099FF0099FF0099FF008CFF0026FF00000000000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300
FFB300FFC000FFCC00FFD900FFCC00FFD900FFD900FFD900FFE600FFF300FFFF00E6FF00C0FF00\
80FF0019FF0000000033FF006600FF00D9FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000080FF8CFF00B3FF00B3FF00B3FF0099FF004CFF0000FF99000000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300
FFB300FFB300FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300F3FF00C0FF00\
66FF0000FFA600FF1973FF0059FF0026FF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000FF3366FF0000FF40C0FF00CCFF00C0FF0000FF268CFF00A6FF0000FF59
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300C0FF0099FF00\
00FF5900FF0C8CFF0099FF0059FF0000FFB300000000D9FF000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000001900FF\
00000000FF1966FF00B3FF00CCFF00D9FF00CCFF000099FF8CFF00CCFF00CCFF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900E6FF00D9FF00E6FF00\
B3FF00C0FF00CCFF00B3FF008CFF0066FF0000BFFF00FF6600FFFF000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000FF66\
00FFE600FFBF26FF0099FF00D9FF00E6FF00E6FF00D9FF00D9FF00E6FF00D9FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300FFFF00\
F3FF00E6FF00D9FF00C0FF00A6FF008CFF0059FF0000FF0C00B3FF000CFF000000
00000000000000000000000000000000000000000000000000000000000000000000FF5926FF00\
0000FF00FF9980FF00CCFF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300\
FFFF00F3FF00D9FF00C0FF0099FF0073FF0059FF0000FF40004CFF000000000000
000000000000000000000000000000000000000000000000F300FF0000000000000026FF4CFF00\
59FF0073FF0080FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600\
FFF300E6FF0000FF0080FF0059FF000CFF0019FF0000FF33000000000000000000
00000000000000000000D9FF00000000B3FF00000000FF6600FFCC000000E600FF0059FF00FF66\
A6FF00B3FF0019FF0026FF00F3FF00FFFF00FFF300FFF300FFFF00FFFF00F3FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFE600\
FFF300D9FF00C0FF00CCFF0099FF0033FF00000CFF0000000059FF000000000000
0000000000000033FF00FF4000FF0000FFB300FF4026FF0000FF0C00FF2600000000FF2659FF00\
A6FF00D9FF00E6FF00E6FF00FFFF00FFF300FFF300FFF300FFF300FFF300F3FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600\
FFF300FFFF00F3FF00D9FF00C0FF0066FF0000FF1919FF0000FF73000000000000
00000000000000FFB300FF004CFF0000FF733FFF0073FF0059FF0026FF0000FF4C00FF0073FF00\
99FF00E6FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFF300F3FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600\
FFF300FFFF00F3FF00E6FF00CCFF00A6FF0080FF003FFF0000FFE60040FF000000
0000000019FF00FF8C33FF0080FF0000FF0099FF0099FF0059FF0000FF3300FF5900FF7300FFB3\
00FF268CFF00FFFF00FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFFF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300\
FFF300FFFF00F3FF00E6FF00D9FF00B3FF003FFF0000FF6600FF198C00FF00FF73
CC00FF00FF00000CFF00FF7399FF00B3FF00C0FF00B3FF0080FF0000FF4C33FF0073FF0099FF00\
A6FF00D9FF00FFFF00FFE600FFD900FFD900FFD900FFD900FFD900FFE600FFFF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFF300FFF300FFF300FFF300FFF300\
FFFF00F3FF00E6FF00D9FF00CCFF00B3FF008CFF0019FF0000FFF300FF6633FF00
66FF0033FF0000FF8C8CFF0099FF00CCFF00CCFF00B3FF0066FF00008CFF00FF33A6FF00D9FF00\
E6FF004CFF00F3FF00FFE600FFD900FFD900FFCC00FFCC00FFD900FFD900FFE600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFC000FFC000FFCC00D9FF00FFFF00D9FF00C0FF00C0FF00F3FF00FFFF00\
F3FF00E6FF0000FF5980FF00B3FF00A6FF008CFF004CFF000000003300FF0CFF00
99FF0066FF0019FF00C0FF00D9FF00E6FF00E6FF00B3FF00C0FF00B3FF0066FF003FFF00F3FF00\
FFF300FFF300FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFC000FFC000FFCC00FFD90059FF00C0FF00A6FF0019FF00D9FF00E6FF00\
E6FF00E6FF00CCFF0080FF008CFF0080FF0059FF0033FF0000FF4C59FF0080FF00
B3FF00B3FF004CFF00CCFF00E6FF00F3FF00F3FF00F3FF00E6FF00C0FF0000FF0C8CFF00F3FF00\
FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFE600FFFF00F3FF00CCFF00C0FF00D9FF00\
CCFF00CCFF0099FF0066FF0026FF0019FF0000CCFF00FF003FFF008CFF00A6FF00
CCFF00CCFF008CFF0000FFF3F3FF00FFFF00FFFF00FFFF00F3FF00D9FF0000FF99E6FF00FFF300\
FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFE600FFF300FFFF00CCFF0073FF00B3FF00\
00FF33B3FF008CFF0000FF6600B3FF33FF0080FF0026FF0000FFD973FF00B3FF00
CCFF00E6FF00F3FF00F3FF00FFFF00FFF300FFF300FFF300FFFF0073FF00D9FF00FFFF00FFE600\
FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300FFFF00CCFF0059FF0000FF00\
3FFF0073FF0026FF0073FF0026FF00B3FF00C0FF0059FF0019FF0000FF1973FF00
CCFF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFF300A6FF00B3FF00FFFF00FFF300\
FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFC000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600F3FF00E6FF00C0FF0000FF99000000\
00F3FF3FFF003FFF00B3FF0099FF00D9FF00D9FF00C0FF0099FF000099FF8CFF00
C0FF00E6FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFE600CCFF004CFF008CFF00F3FF00\
FFE600FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF0000FFF380FF0000FF0000FF59\
00FF0CB3FF00C0FF00D9FF00F3FF00FFFF00F3FF00D9FF008CFF0033FF000099FF
59FF00CCFF00FFFF00FFF300FFD900FFD900FFCC00FFCC00FFD900FFE600D9FF0080FF00A6FF00\
00FFBFFFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FFA600FFA600FFA600FFB300FFB300FFD900FFCC00FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFE600FFFF00FFF300FFFF00E6FF00B3FF0000FF1999FF00A6FF00\
00FF59D9FF00F3FF00E6FF00FFF300FFF300FFFF0000FF80A6FF00B3FF0000D9FF
00FF734CFF00C0FF00CCFF00FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFE600FFE600FFFF00\
FFE600FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600\
FFA600FFA600FFB300FFB300FFC000FFE600F3FF00FFD900FFD900E6FF00FFE600
FFE600FFD900FFD900FFE600FFF300CCFF00CCFF00E6FF00D9FF004CFF00B3FF00D9FF00D9FF00\
0CFF00F3FF00FFF300FFE600FFE600FFE600FFF30073FF00F3FF00E6FF00CCFF00
0040FFC0FF00FFFF00FFE600FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC00080FF00\
FFD900FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFD900C0FF00FFFF00C0FF00A6FF004CFF00
D9FF00FFF300FFF300FFF300F3FF00CCFF0099FF00C0FF008CFF0080FF00C0FF00F3FF00FFFF00\
00FFCCF3FF00FFE600FFD900FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00
0CFF0073FF00C0FF00FFE600FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFC000\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFCC00FFC000\
FFC000FFC000FFC000FFCC00FFD900FFE600E6FF008CFF0099FF00F3FF00FFFF00
F3FF00D9FF00E6FF00C0FF0000FF73A6FF0099FF00B3FF00CCFF0066FF00E6FF00FFF300FFE600\
FFFF00B3FF00FFE600FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFF300C0FF00
19FF00E6FF00E6FF00E6FF00FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFCC0080FF00\
CCFF00FFD900FFCC00FFD90066FF00E6FF00D9FF00E6FF00FFF300FFF300FFE600
FFE600FFFF00E6FF00E6FF0066FF00F3FF00CCFF00FFF300FFFF00C0FF00D9FF00FFE600FFD900\
FFCC00FFD900FFCC00FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFFF00
99FF00FFFF00FFD900FFCC00FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFCC00\
FFF300FFF300FFF300FFF300E6FF00CC00FFD9FF00FFF300FFE600FFD900FFCC00
FFCC00FFD900FFD900FFE60000FF33FFE600FFD900FFD900FFE600F3FF00F3FF00FFD900FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFD900FFE600E6FF00
CCFF00FFF300FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFC000\
FFE600E6FF00C0FF0000FF80E6FF00E6FF0080FF00E6FF00FFD900FFCC00FFCC00
FFC000FFC000FFCC00FFCC00FFF300FFCC00FFCC00FFCC00FFD90000FF00FFE600FFCC00FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00E6FF00F3FF00
FFE600FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000\
FFCC00FFE600F3FF00B3FF00F3FF00FFE600FFE600FFD900FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC0099FF00FFF300FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFD90099FF00F3FF00
FFE600FFCC00FFC000FFB300FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFC000\
FFCC00FFD900FFF300C0FF00FFFF00FFD900FFCC00FFCC00FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFD900FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFF30073FF00
FFF300FFD900FFC000FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000\
FFCC00FFE600FFFF00A6FF00FFF300FFD900FFCC00FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFC000FFFF00F3FF00
00FF26FFFF00FFC000FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFCC00FFD900\
E6FF00F3FF0099FF00FFFF00FFE600FFCC00FFC000FFC000FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFC000FFCC00
FFE600FFFF00FFCC00FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFCC00E6FF00\
80FF004CFF0033FF00F3FF00FFF300FFD900FFC000FFC000FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300
FFF300FFCC00FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFE600\
FFFF0099FF0099FF00A6FF00CCFF00FFE600FFC000FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFC000FFC000FFA600FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF8C00FF9900FF9900FFA600FFCC00FFC000FFCC00FFC000FFC000FFC000FFCC00FFCC00FFE600\
D9FF00CCFF00FFF300A6FF00FFD900FFD900FFC000FFB300FFB300FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF8C00FFA600FFB300FFC000FFD900F3FF00D9FF00FFD900FFCC00FFD900FFD900FFE600E6FF00\
F3FF00FFE600FFD900FFCC00FFCC00FFC000FFB300FFB300FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF8C00FFA600FFC000D9FF00FFD900FFC000FFCC00CCFF00FFF300F3FF008CFF00FFFF00B3FF00\
FFFF00FFE600FFCC00FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF9900FFB300FFB300FFB300FFB300FFCC00B3FF00FFF3003FFF00FFFF00F3FF00\
D9FF00FFE600FFCC00FFC000FFC000FFB300FFB300FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFCC00FFCC00FFD900FFD900FFF300\
C0FF00FFF300FFD900FFC000FFB300FFB300FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00FFD900\
F3FF00FFF300FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000FFCC00FFD900\
CCFF00FFE600FFCC00FFC000FFB300FFB300FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFCC00FFFF00\
FFFF00FFD900FFCC00FFC000FFB300FFB300FFA600FFA600FF9900FF9900FF9900
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFD900FFFF00\
FFFF00FFE600FFCC00FFC000FFB300FFB300FFA600FFA600FF9900FF9900FF9900
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFCC00FFF300\
D9FF00F3FF00FFE600FFD900FFCC00FFB300FFA600FFA600FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFA600FFC000FFCC00FFFF00\
4CFF000CFF0019FF00E6FF00FFD900FFB300FFA600FFA600FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFB300F3FF00FFE600F3FF00\
0000000099FFE6FF00FFF300FFFF00FFE600FFB300FFA600FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFC000FFFF00FFFF00\
CCFF0073FF00E6FF00FFD900FFCC00FFC000FFA600FF9900FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFCC00FFCC00\
FFE600F3FF00FFF300FFCC00FFB300FFA600FFA600FF9900FF9900FF8C00FF8C00
FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000\
FFD900F3FF00FFF300FFCC00FFB300FFA600FF9900FF9900FF9900FF8C00FF8C00
FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000\
FFD900D9FF00FFD900FFC000FFB300FFA600FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFCC00\
E6FF00FFE600FFCC00FFB300FFB300FFA600FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFB300FFCC00\
FFF300FFF300FFCC00FFC000FFB300FFA600FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000FFE600\
F3FF00E6FF00B3FF00FFD900FFC000FFA600FF9900FF9900FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000CCFF00CCFF00\
FFD900FFCC00FFD900F3FF00FFC000FFA600FF9900FF9900FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFB300FFCC0099FF00FFE600\
FFC000FFC000FFC000FFD900FFCC00FFB300FFA600FF9900FF8C00FF8C00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF8C00FF9900FF9900FFB300FFB300FFC000FFC000FFCC00FFF300FFF300FFC000\
FFB300FFA600FFB300FFCC00E6FF00FFD900FFB300FF9900FF8C00FF8C00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF8C00FF8C00FF9900FFA600FFC000CCFF00FFF300FFE600F3FF00FFE600FFCC00FFA600\
FFA600FF9900FFA600FFA600FFC000FFC000FFC000FF9900FF8C00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF8C00FFE600FFD900FFC000CCFF00FFCC00FFC000FFC000FFB300FFB300FFD900FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FFC000FF8C00FF8C00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF8C00FF9900FFB300FFE600FFCC00FFB300FFA600FFA600FFA600FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00
FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF8C00FF9900FFA600FFCC00FFC000FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF8C00FF9900FFA60080FF00FFC000FFA600FF9900FF8C00FF8C00FF8C00FF8C00FF8C00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF8C00FF9900FFA600FFD900FFB300FF9900FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00
FF7F00FF9900FFA600FFC000FFD900FFB300FF9900FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7F00
FF8C00FFA600FFC000FFB300FFA600FFA600FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7F00
FF8C00FFC000FFA600FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7F00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FFB300FFC000B3FF00FFD900FFD900FFE600FFF300CCFF00\
C0FF00B3FF00E6FF00CCFF00FFF300FFD900FFC000FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFCC00FFD900FFFF00A6FF0000FF1900FF26F3FF00
FFFF00FFF300FFFF00FFFF00F3FF00E6FF00D9FF0080FF003300FF00FF734CFF0080FF0073FF00\
73FF0033FF00C000FF0019FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFB300FFC000FFC000FFCC00FFF300FFFF00\
F3FF00D9FF00A6FF00FFFF00FFE600FFCC00FFC000FFC000FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFCC00FFD900FFE600F3FF00A6FF0059FF0080FF00
F3FF00F3FF00F3FF00E6FF00D9FF00D9FF00A6FF0080FF0000FF2600000033FF004CFF003FFF00\
0CFF0033FF0000FF3300FFD9000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFD900\
FFE600F3FF0073FF00F3FF00FFE600FFCC00FFCC00FFC000FFC000FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFF300FFCC00FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFFF004CFF0000FF0C59FF00
99FF00D9FF00D9FF00CCFF0066FF00A6FF0059FF0000FF331900FF00FFBF00FF000019FF8000FF\
00000000FF0C000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFC000FFCC00\
FFE6008CFF0080FF00E6FF00FFE600FFD900FFCC00FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFCC008CFF00FFD900FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFF300FFFF00E6FF0073FF00
00FF0066FF0000FF0C00FF1900FF334CFF000000000000000000FF00FF8000FF663F00FF000000\
008CFF00FFB300FFB3000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFCC00\
FFE600FFFF0000FF19F3FF00FFF300FFE600FFE600FFCC00FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFF300D9FF00FFD900
FFD900FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00F3FF00
E6FF00D9FF00C0FF0000FF0C26FF000000000080FF0000000033FF0080FF000000000000000000\
00000000000000D9FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFD900\
FFFF00CCFF00C0FF00B3FF00C0FF00D9FF00FFFF00FFD900FFCC00FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900E6FF0033FF00E6FF00
8CFF00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00
FFFF00F3FF00D9FF00C0FF0066FF0000FF330000000000000066FF000000000000000000000000\
0000000000006600FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFFF00\
FFE600FFE600FFFF00F3FF00C0FF00E6FF00FFF300FFD900FFCC00FFCC00FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFF300C0FF0059FF00CCFF00
FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFF300
FFFF00F3FF00E6FF00CCFF0066FF0000FFBF00FF0C004CFF00FF8C000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000\
FFCC00FFCC00FFD900FFF300D9FF00D9FF00FFFF00FFE600FFD900FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFCC00FFE600F3FF0099FF00B3FF00F3FF00
FFF300FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300
FFFF00FFFF00E6FF0080FF008CFF0080FF0000FFCC00000000FF0C00FFD9000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300\
FFC000FFC000FFCC00FFF300D9FF008CFF00A6FF00FFF300FFD900FFD900FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFF300CCFF0073FF00A6FF00
19FF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300
FFFF00FFFF00E6FF00CCFF00CCFF00B3FF0066FF00D900FF0CFF00000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFCC00FFD900FFE600FFF300C0FF00E6FF00FFF300FFE600FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFD900FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFF300CCFF000CFF00D9FF00
FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300
FFFF00FFFF00F3FF00E6FF00D9FF00C0FF00A6FF008CFF004CFF0000FF660000003300FF0080FF\
0019FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300\
FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFFF0000FF0CF3FF00E6FF00
FFF300FFD900FFD900FFD900FFE600E6FF00FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFF300D9FF0000FF00C0FF00
FFFF00FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300
FFFF00FFFF00F3FF00E6FF00D9FF00C0FF00B3FF0099FF0073FF004CFF000CFF0000FF40000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFF300CCFF0080FF00CCFF00
FFFF00FFE600FFE600FFE600F3FF00CCFF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFF300E6FF0026FF00D9FF00
FFFF00FFF300FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00
FFFF00F3FF00E6FF00E6FF00C0FF00B3FF0099FF0073FF0066FF0000FF1900FF190000008C00FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFE600FFFF0073FF00B3FF00
E6FF00A6FF00FFFF00FFFF004CFF00FFFF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00B3FF00D9FF00
FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00
F3FF00E6FF00E6FF00D9FF00C0FF0066FF0000FF4C0040FF26FF0019FF00000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFE600F3FF0019FF0000FF80
33FF0000FF8CD9FF008CFF00D9FF00FFF300FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFF300FFFF00E6FF0000FFD9
E6FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFF300F3FF00FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300F3FF00B3FF00
B3FF00CCFF00D9FF00CCFF00B3FF0080FF0000000000FFF300FF2600FF2600FF660099FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFE600FFFF00F3FF00C0FF00
C0FF0000FFCC73FF008CFF00E6FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00CCFF0026FF00
CCFF00F3FF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFF300FFFF00A6FF00FFFF00\
FFF300FFF300FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00CCFF00
B300FF8CFF00B3FF00A6FF004CFF0000FF1900A6FF00FFF30000000000000099FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFE600FFF300F3FF00
D9FF00A6FF0026FF00B3FF00E6FF00F3FF00FFFF00FFE600FFE600FFE600FFE600FFE600FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFFF00F3FF00CCFF0000FF0C
00FF338CFF0099FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFFF00C0FF0033FF00D9FF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF00
B3FF0080FF0080FF0000FFFF0000000000000000008C00FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300E6FF00
CCFF0059FF000CFF008CFF00A6FF0080FF00F3FF00FFF300FFF300FFE600FFF300FFF30073FF00\
F3FF00FFF300FFE600FFE600FFF300FFF30080FF00E6FF00D9FF00B3FF0073FF00
00FF3300FF40D9FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00B3FF0000FFBFE6FF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00
D9FF00CCFF00B3FF008CFF0000FF660073FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300E6FF00
C0FF0080FF008C00FF3300FFC0FF00D9FF00F3FF00FFFF00FFF300FFF300FFF300F3FF0000FF80\
E6FF00FFFF00FFF300FFF300FFF300FFFF00E6FF0000FF4C80FF0026FF000000FF
26FF008CFF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00F3FF00E6FF0073FF00A6FF00E6FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00
E6FF00D9FF00C0FF0059FF0033FF000000000019FF00E6FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFD900FFE600FFF300F3FF00
D9FF0099FF0033FF0099FF00CCFF00D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00E6FF0026FF00\
E6FF00F3FF00FFFF00FFFF00FFFF00F3FF00E6FF00CCFF008CFF0000FF6633FF00
73FF00A6FF00CCFF00D9FF00D9FF00D9FF00F3FF00F3FF00E6FF00D9FF003FFF00C0FF00E6FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00
D9FF00D9FF00C0FF00B3FF0099FF0066FF0026FF0000FF33000000000CFF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFC000FFCC00FFD900FFE600FFF300FFF300F3FF00D9FF00
A6FF0000FF4C00FFF38CFF00B3FF00C0FF00E6FF00E6FF00D9FF00E6FF00E6FF00D9FF003FFF00\
D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00C0FF008CFF0000000033FF00
73FF008CFF0066FF00C0FF0066FF00CCFF00D9FF00E6FF00D9FF00CCFF008CFF00A6FF00D9FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
D9FF00CCFF00C0FF00B3FF0099FF0066FF0000FF4000FF0C00FF8C0026FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFCC0073FF004CFF00C0FF00C0FF0066FF0000FF4C
00FF6666FF0000FFCC00FF2680FF00C0FF00CCFF00CCFF0000FF80D9FF00CCFF0066FF0019FF00\
A6FF00D9FF00D9FF00A6FF00D9FF00E6FF00D9FF00C0FF008CFF000000FF00FF19
00FFFF00FF0066FF0073FF0033FF00C0FF00CCFF00CCFF0000000099FF0000FF1959FF0073FF00\
D9FF00E6FF00E6FF00E6FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
CCFF00C0FF00B3FF00A6FF0073FF00004CFF00FFBF00FF66004CFF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFC000FFC000FFCC00FFD900FFF300FFFF00F3FF00F3FF00CCFF00
D9FF00A6FF004CFF0000FF4C80FF00A6FF00A6FF00A6FF0000FFFFB3FF00B3FF0066FF004CFF00\
A6FF00C0FF00C0FF000CFF00CCFF00CCFF00CCFF00C0FF0099FF0066FF0026FF00
00FF0000FF990000000CFF0000BFFF8CFF00A6FF00B3FF008CFF0000FF66F300FF00FF4CB3FF00\
CCFF00D9FF00D9FF00CCFF0000F3FFCCFF00E6FF00E6FF00E6FF00D9FF00D9FF00
C0FF0000FFF38CFF008CFF0066FF0000F3FF0019FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFE600FFF300FFFF00
F3FF00CCFF0000FF4C00FF400059FF73FF003FFF0000FF330000FF00FF0C80FF0059FF0000B3FF\
3FFF00A6FF0099FF0059FF00B3FF00C0FF00A6FF00B3FF0099FF0080FF0066FF00
19FF0000FF730033FF00D9FF00FF6600FF008CFF008CFF0000FF0C00FF6626FF0073FF00A6FF00\
C0FF00CCFF00CCFF00A6FF0000CCFFC0FF00D9FF00D9FF00D9FF00D9FF00CCFF00
C0FF0099FF0000FFCC000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFD900FFE600FFE600FFF300
F3FF00CCFF003FFF008CFF0000FF0C00FFBF4CFF000033FF00CCFF00FFE600FF0C00FF4C000000\
19FF0073FF0000FF2619FF0099FF00A6FF004CFF008CFF008CFF0033FF004CFF00
26FF0000FF3300FFD900000000FFBF0CFF003FFF0073FF0033FF0000FFE600B3FF00FF6673FF00\
80FF00B3FF00B3FF0099FF008CFF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00B3FF0099FF0073FF000000000000000073FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300
C0FF00C0FF00D9FF00C0FF008CFF0099FF008CFF0066FF000CFF0000FFFF00000000FFCC00FFA6\
00FFD926FF0000FF660CFF003FFF008CFF0066FF0059FF0073FF004CFF003F00FF
00FF265900FF000CFF00000000CCFF00000033FF0000FF0033FF0000FF0C00FF66008CFF00FFCC\
73FF0099FF0080FF0000F3FF99FF00B3FF00C0FF00C0FF00CCFF00CCFF00C0FF00
C0FF00B3FF00A6FF0080FF0059FF0019FF0000FF7300D9FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300
FFFF00F3FF00E6FF00D9FF00CCFF00C0FF0099FF0066FF00CC00FF0CFF000C00FF00FFF30019FF\
0066FF00FF59E600FF00FF593FFF0059FF0000FF0C00FF6626FF0033FF0000FF4C
00FFCC00000000000000000000000000000000FF2600FFA600FF0C00FF3300B3FF0026FFF300FF\
33FF004CFF0000FFBF00FFCC3FFF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00
B3FF00A6FF0099FF0080FF00008CFF00FFFF00FFA6000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300
FFF300FFFF00F3FF00E6FF00D9FF00CCFF00A6FF008CFF0066FF0033FF0000FF196600FF000000\
0000000000000000000033FF0040FF26FF0000FF0000FFBF00BFFF00FF8C00FF59
00000000000000000000000000000000000000FFA600000000FF730099FF0000000000000019FF\
00FF3300FF0000FFFF00FF0C73FF008CFF0099FF0059FF0059FF00A6FF00B3FF00
A6FF0099FF000019FF66FF0033FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300
FFF300FFFF00F3FF00E6FF00D9FF00CCFF00B3FF0099FF0066FF0033FF0000FF4000CCFF000000\
0000000000000000000000FF0033FF00FF2600FF3300B3FF000000000000C000FF
0000007300FF000000000000000000000000000000000000000CFF000000000000000000000000\
00FF6600FF3300FF806600FF0080FF73FF0080FF000026FF8CFF0099FF00A6FF00
99FF008CFF0073FF003FFF0000D9FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300
FFF300FFFF00F3FF00D9FF00C0FF00B3FF0099FF0080FF0059FF0000FF260080FF3F00FF000000\
00000000000000000000000000F3FF00FF990000000080FF000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000001900FF\
0040FF00FFB3000000C000FF00000033FF0000F3FF33FF0080FF008CFF0099FF00
99FF008CFF0080FF0059FF0019FF0000FF66000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFB300FFC000FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFF300
FFFF00FFFF00F3FF00CCFF008CFF0000FF6619FF0000CCFF26FF0000BFFF7300FF000000000000\
0000000000000000000000000080FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000FF7300000033FF0066FF0073FF0073FF00
80FF0080FF0073FF0059FF0000FF0C00000000A6FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFCC00C0FF00FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00E6FF00D9FF00CCFF00B3FF0080FF000CFF0000FF4C00FF8C00FF809900FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000CC00FF00A6FF00A6FF4CFF0000FF4C59FF00
73FF0073FF0059FF000033FF0059FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FFA600FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFC000FFD90059FF00FFFF00F3FF00FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFF300E6FF0026FF00D9FF00F3FF00
F3FF00E6FF00E6FF00D9FF00CCFF00B3FF0099FF0080FF0059FF0019FF0000FF802600FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000000000FF8C4CFF00
59FF0066FF0059FF0033FF0000FF1900FFCCB300FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FFA600FFB300CCFF00FFB300FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFC000FFC000FFD900FFFF0000FF33F3FF00FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFF300D9FF00A6FF003FFF00CCFF00
D9FF00D9FF00CCFF00CCFF00C0FF00A6FF0099FF0073FF0059FF0026FF0000FF2600FFBF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000099FF00FF1933FF00
00FF734CFF004CFF0026FF0000FF0C000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FFA600FFB300FFE600FFCC00FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFC000FFC000FFD900C0FF00B3FF00B3FF00F3FF00FFFF00FFE600FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00CCFF0000FF40
A6FF00B3FF00A6FF00B3FF00A6FF004CFF0080FF0059FF0000FFB300FF0C00FF4C00D9FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000008C00FF000000
19FF0033FF0033FF000CFF002600FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600
FFA600FFB300FFCC00A6FF00FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFC000FFC000FFD900FFE600FFFF0033FF00B3FF00FFFF00FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00CCFF00
8CFF0000B3FF66FF008CFF008CFF0000FF0033FF0033FF0000FF26000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000000080FF000000
00FF0000FF0C19FF000CFF0000FF332600FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFB300FFCC00FFFF00FFF300FFE600FFD900FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFE60059FF0000FFD9B3FF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00E6FF00D9FF00
B3FF0000FFA600FF5959FF0000FF5900FF7300000000FF5900FF4C008CFF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
3300FF00FF0C00FF0000FF19000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FFCC00FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFB300FFC000FFCC00FFF300CCFF00FFE600FFCC00FFC000FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFE600FFF300F3FF00A6FF00E6FF00FFFF00\
FFFF00FFFF00E6FF00FFFF00FFF300FFFF00FFFF00FFFF00F3FF00E6FF00CCFF00
A6FF008CFF0026FF0000FF000066FF0000000000FF0000000080FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000FF4C00FF2600FF2600FF66000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FFA600FFE600FFA600FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFB300FFD900C0FF00C0FF00E6FF00FFE600FFCC00FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300FFFF00C0FF00A6FF00\
E6FF00E6FF00A6FF00F3FF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00
C0FF00A6FF008CFF0066FF0000FF4C000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000FFE600FF5900FF4000FF80B300FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FFA600F3FF00FFB300FFA600FF9900FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFB300FFC000FFCC00FFE60099FF00FFF300FFD900FFCC00FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFE600FFFF00C0FF0000FF00\
59FF0099FF00CCFF00E6FF00F3FF00F3FF00E6FF00CCFF00D9FF00D9FF00CCFF00
C0FF00A6FF008CFF0019FF0000FF0000FF4C000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000008C00FF00FF8C00FF6600FFCC000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FFA600FFB300FFD900FFC000FFA600FFA600FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFB300FFC000FFCC00FFD900F3FF00E6FF00FFFF00FFD900FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300F3FF0000FF33\
33FF0073FF00C0FF00CCFF00E6FF00E6FF00D9FF00008CFFC0FF00CCFF00C0FF00
99FF0080FF0080FF0066FF0026FF0000FF2600FFBF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF9900FFD9000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FFA600FFB300FFD900FFCC00FFB300FFA600FFA600FF9900FF9900
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300
FFB300FFC000FFCC00FFE600F3FF0073FF00FFF300FFD900FFCC00FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFFF00E6FF00C0FF00\
66FF004CFF0080FF00B3FF00CCFF00CCFF00CCFF00A6FF0099FF00B3FF00B3FF00
99FF0073FF0000FF8C26FF0000FF198C00FF0059FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FFD900FFFF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FFA600FFB300FFC000FFD900FFD900FFC000FFB300FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFC000FFC000FFD900FFF30000FF19FFF300FFD900FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300F3FF00C0FF00C0FF00\
99FF0026FF000CFF00A6FF00C0FF00C0FF00B3FF0099FF00000CFF59FF0099FF00
8CFF0080FF0033FF0000FF33000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000A6FF00CCFF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FFA600FFB300FFCC00FFD900FFF300B3FF00CCFF00FFCC00FFB300FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFC000FFC000FFCC00FFE600D9FF00CCFF00FFE600FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00D9FF00\
B3FF003FFF0000F3FF80FF008CFF008CFF0099FF0080FF000033FF19FF0080FF00
33FF0066FF004CFF000CFF0000FF8C000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000004C00FF0080FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFB300FFCC00FFF30066FF00F3FF00FFD900FFC000FFB300FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFC000FFC000FFC000FFCC00FFD900FFFF00D9FF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFCC00FFCC00FFD900F3FF00FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00\
CCFF00A6FF0080FF0000FFA626FF0066FF000019FF66FF0000FF0033FF004CFF00
00FF663FFF0019FF0000FF8000FFD9000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000026FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFB300FFC000FFCC00FFF300FFE600FFCC00FFC000FFB300FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFCC00FFCC00FFD900FFF300D9FF00FFF300FFE600FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFE6008CFF00FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFF300FFFF00FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00\
CCFF00B3FF008CFF000CFF000099FF26FF000019FF26FF0000FF8C00D9FF00FF00
00F3FF0CFF000CFF0000FF331900FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000004C00FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFB300FFC000FFCC00FFE600FFE600FFCC00FFC000FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFB300FFF300FFB300FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFCC00FFD900FFE600FFF3008CFF00C0FF00FFE600FFE600FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFD900FFD900FFFF003FFF00FFFF00FFE600FFD900FFD900
FFD900FFD900FFD900FFE600FFF30099FF00E6FF00FFFF00FFFF00F3FF00E6FF00CCFF00CCFF00\
C0FF0099FF0066FF0000FF0000000000FFBF0040FF00FF9900FFB300000000FFB3
0080FF00FF5900FF4000A6FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000F300FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFC000FFCC00C0FF00FFFF00FFCC00FFC000FFC000FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFC00099FF00FFC000FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFE600\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFE600FFFF00C0FF00E6FF00FFF300FFF300FFF300F3FF00FFE600\
FFD900FFD900FFD900FFD900FFE600FFF30080FF00E6FF00FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFFF00E6FF008CFF00E6FF00F3FF00E6FF00D9FF0099FF00A6FF00\
B3FF0099FF0080FF003FFF0000FF2600FFFF0000008000FF000000000000000000
0000000000000080FF00FFA6000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFC000FFCC00FFD900FFF300F3FF00FFD900FFCC00FFC000FFC000FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFE60080FF00FFFF00FFC000FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFE600\
F3FF00FFCC00FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFE600FFE600FFF300FFFF00C0FF0026FF00F3FF00FFFF00D9FF00CCFF00FFE600\
FFE600FFE600FFE600FFE600FFF300FFFF00B3FF00F3FF00FFF300FFF300FFE600
FFE600FFE600FFF300FFF300FFFF00F3FF00C0FF00CCFF00D9FF00D9FF00D9FF00C0FF0073FF00\
0CFF0080FF004CFF0000FF0C00FF2600A6FF000000000000000000000000000000
0000000000000000000099FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFC000FFCC00FFD900FFE600FFF300F3FF00FFE600FFE600FFE600FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFD900CCFF00FFD900FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFCC00FFE600\
FFF300FFCC00FFCC00FFC000FFC000FFC000FFCC00FFD900FFF300FFD900FFD900
FFD900FFD900FFF300B3FF00F3FF00E6FF00C0FF00A6FF00CCFF00D9FF00B3FF00F3FF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00CCFF00E6FF00FFFF00FFFF00FFFF00
F3FF00FFFF00FFFF00FFFF00F3FF00E6FF00CCFF0019FF00A6FF00C0FF00C0FF00B3FF0080FF00\
00FF0C3FFF0033FF0000FF190066FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFCC00FFD900B3FF00FFFF00F3FF00CCFF00F3FF00E6FF00FFFF00FFCC00FFC000
FFC000FFC000FFC000FFB300FFC000FFC000FFC000FFCC00FFC000FFC000FFC000FFC000FFC000\
FFCC00FFE600C0FF00CCFF00FFCC00FFC000FFC000FFC000FFC000FFC000FFCC00
FFC000FFC000FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFF300\
F3FF00FFD900FFD900FFCC00FFCC00FFCC00FFD900FFE600B3FF00FFE600FFE600
FFE600FFE600FFF300E6FF00C0FF00CCFF00A6FF003FFF0080FF0059FF00D9FF00F3FF00FFFF00\
FFFF00FFFF0080FF00FFFF00F3FF000073FFA6FF00B3FF00D9FF00F3FF00F3FF00
59FF00F3FF00F3FF00F3FF00E6FF00D9FF00B3FF003FFF004CFF00A6FF004CFF0099FF0080FF00\
4CFF0000FF8C00FF4000FF73000CFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFCC00FFC000FFC000FFC000FFC000FFC000FFE600FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFE600F3FF00CCFF003FFF000CFF0099FF00E6FF00FFF300FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFF300FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFE60099FF00FFF300FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFFF00
FFD900FFCC00FFC000FFC000FFC000FFC000FFCC00F3FF00FFCC00FFCC00FFD900FFD900FFF300\
D9FF00FFF300FFE600FFE600FFF300FFE600FFE600FFF300A6FF00FFFF00FFF300
F3FF00FFFF00FFFF00E6FF00B3FF0080FF0019FF0000FFCC00FFE64CFF003FFF00D9FF00D9FF00\
F3FF00E6FF00A6FF00D9FF00E6FF00CCFF0080FF008CFF00CCFF00D9FF00D9FF00
00FF0CD9FF00D9FF00D9FF0099FF00C0FF00A6FF0073FF0059FF0073FF003FFF0066FF004CFF00\
26FF0000FF40000000000000CC00FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFE600FFD900FFD900F3FF00FFD900FFE600E6FF00FFD900FFD900FFFF00FFD900FFD900FFFF00\
FFE600FFF300A6FF0066FF0000FF73000000000000CCFF00FFFF00FFF300FFF300
FFE600FFD900FFE600E6FF00FFE600FFE600FFF300E6FF00FFE600FFE600FFFF00FFE600FFFF00\
FFF300F3FF0099FF00E6FF00FFF300FFF300FFE600F3FF00FFE600FFE600C0FF00
FFF300FFF300FFF300FFE600FFD900E6FF00FFE60099FF00FFF300FFF300FFFF00E6FF00E6FF00\
99FF00F3FF00E6FF00F3FF00D9FF00FFFF00D9FF00CCFF0099FF00CCFF00E6FF00
8CFF00D9FF004CFF00C0FF0000FF1900FF400099FF00000000000000FF5999FF0066FF003FFF00\
C0FF00B3FF000CFF00B3FF008CFF00A6FF0019FF0000FF1999FF008CFF008CFF00
00FF4099FF00A6FF0080FF000CFF0066FF003FFF0000FF590000000CFF0000FF5900FF0000FF26\
00E6FF00FFF3000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFF300FFE600FFE60073FF00FFE600FFF300D9FF00FFE600FFE600D9FF00FFE600FFE600B3FF00\
FFFF00FFFF00CCFF0019FF00000000000000000000CCFF00F3FF00FFFF00FFFF00
FFF300FFE600FFF300E6FF00FFF300FFF300FFFF00E6FF00FFF300FFF300F3FF00FFF30059FF00\
FFF300E6FF004CFF00E6FF00FFFF00F3FF00FFFF00E6FF00FFF300FFFF00D9FF00
FFFF00B3FF00FFFF00FFF300FFE600D9FF00FFFF0099FF00FFFF00FFFF00F3FF00D9FF00D9FF00\
73FF00D9FF00D9FF00E6FF00CCFF00E6FF00CCFF00C0FF008CFF00B3FF00CCFF00
66FF00A6FF0073FF00B3FF004CFF0000FFB300000000000000000000FF2680FF0033FF0033FF00\
99FF0099FF0059FF0099FF0059FF008CFF0000FFBF00FF198CFF0059FF0033FF00
00FF3366FF008CFF0019FF0000FF993FFF0026FF0000FF192600FF00FF1900FF3300FF7300FF40\
0033FF0066FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFCC00FFC000FFC000FFC000FFC000FFCC00FFF300FFCC00FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFE600F3FF00B3FF008CFF000019FF59FF00D9FF00FFF300FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFE600FFF300FFCC00FFCC00FFD900FFCC00FFCC00\
FFD900FFF300B3FF00FFF300FFD900FFD900FFCC00FFD900FFCC00FFD900FFFF00
FFD900FFCC00FFCC00FFCC00FFC000FFCC00FFCC00A6FF00FFD900FFD900FFD900FFE600FFF300\
D9FF00FFF300FFE600FFE600F3FF00FFE600FFF300FFFF00C0FF00FFFF00FFFF00
A6FF00FFFF00F3FF00E6FF00B3FF0059FF0019FF000019FF00000059FF00A6FF00D9FF0099FF00\
E6FF00E6FF00B3FF00D9FF00D9FF00C0FF0073FF008CFF00C0FF00C0FF00CCFF00
00FF66CCFF00D9FF00CCFF008CFF00B3FF0099FF0066FF0026FF0066FF0033FF0059FF0033FF00\
0CFF0000FF59000000000000A600FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFC000FFB300FFB300FFB300FFB300FFB300FFC000FFB300FFB300FFB300FFB300FFC000FFC000\
FFCC00FFD90099FF00FFFF00E6FF00C0FF00D9FF00A6FF00FFF300FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFD900FFC000FFC000FFC000FFC000FFC000\
FFCC00FFE6003FFF00FFF300FFCC00FFC000FFC000FFC000FFC000FFC000FFD900
FFCC00FFC000FFC000FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFD900FFF300\
F3FF00FFE600FFD900FFD900FFD900FFD900FFD900FFE6004CFF00FFF300FFE600
FFE600FFE600FFF300E6FF0080FF00C0FF008CFF0000FF2666FF0033FF00D9FF00F3FF00F3FF00\
FFFF00FFFF003FFF00F3FF00F3FF00B3FF0080FF0080FF00D9FF00F3FF00E6FF00
4CFF00E6FF00F3FF00E6FF00D9FF00D9FF00B3FF0033FF0073FF0099FF0059FF008CFF0066FF00\
3FFF0000000000FF6600FFCC000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFC000FFFF00FFD900FFE600FFF300F3FF00FFF300FFF300D9FF00FFCC00FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFD900CCFF00FFD900FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFE600\
FFFF00FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFE600E6FF00FFD900FFD900
FFD900FFE600FFF30033FF00E6FF00E6FF00C0FF0099FF00A6FF00CCFF00C0FF00F3FF00FFF300\
FFF300FFF300FFF300FFF300FFFF00F3FF0099FF00D9FF00F3FF00FFFF00FFFF00
59FF00FFFF00FFFF00FFFF00F3FF00E6FF00C0FF0000FF99A6FF00C0FF00B3FF00B3FF008CFF00\
00FF0019FF0026FF0000FF263F00FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFCC00FFD900FFF300F3FF00FFD900FFCC00FFCC00FFC000FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFC000FFD900A6FF00FFE600FFC000FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFFF00\
E6FF00FFCC00FFC000FFC000FFC000FFC000FFC000FFCC00FFD900FFCC00FFCC00
FFCC00FFD900FFE600FFF300FFF300F3FF0080FF00B3FF00F3FF00F3FF00C0FF00F3FF00FFF300\
FFE600FFE600FFE600FFE600FFF300FFFF00CCFF00F3FF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00F3FF00CCFF00B3FF00B3FF00D9FF00CCFF00C0FF008CFF00\
00FF0C73FF0059FF0000FF6600FF3300FFF3000000000000000000000000000000
0000000000000000005900FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFC000FFCC00FFF300FFF300FFD900FFC000FFC000FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFC000FFFF00FFC000FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFD900\
FFCC00FFC000FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFD900FFD900FFE600FFFF008CFF00E6FF00FFFF00FFF300FFFF00F3FF00FFE600\
FFD900FFD900FFD900FFD900FFE600FFFF0099FF00F3FF00FFF300FFE600FFE600
FFE600FFE600FFE600FFF300FFFF00E6FF0073FF00E6FF00E6FF00E6FF00D9FF00A6FF0099FF00\
A6FF0099FF0073FF003FFF0000FF0C00FFCC000000000000000000000000000000
0000000000000099FF00FFBF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFB300FFB300FFC000FFCC00FFF300FFF300FFCC00FFC000FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFF300FFB300FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFCC00FFCC00FFD900FFE600FFFF00B3FF00B3FF00FFF300FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFF30066FF00FFFF00FFE600FFD900FFD900
FFD900FFD900FFE600FFE600FFF30033FF00D9FF00F3FF00FFFF00F3FF00E6FF00B3FF00CCFF00\
C0FF00A6FF0073FF0026FF000C00FF0033FF4C00FF00FFCC0C00FF000000000000
0066FF00FF8000FF4C00FF73000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFB300FFC000FFCC00FFF300FFE600FFCC00FFC000FFB300FFB300FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFCC00FFCC00FFD900FFF300B3FF00FFF300FFE600FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFE6004CFF00F3FF00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFF300F3FF00FFFF00FFF300FFFF00FFFF00F3FF00E6FF00D9FF00\
CCFF00A6FF0080FF0026FF0000A6FF0CFF000000000CFF001900FF00FF7300FF19
00FF9900FF0000FF0000FF3300FFF3000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000006600FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFB300FFC000FFE6008CFF00FFF300FFCC00FFC000FFB300FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFC000FFC000FFCC00FFCC00FFD900FFFF00D9FF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900F3FF00FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00\
CCFF00B3FF008CFF0000FF8C00FFA659FF0000FF7359FF000CFF0019FF003FFF00
9900FF3FFF0026FF000000000040FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000019FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FFA600FFB300FFFF00FFE600FFFF00D9FF00FFFF00FFCC00FFB300FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFC000FFC000FFCC00FFE600B3FF00F3FF00FFE600FFD900FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00D9FF00\
8CFF0080FF0000B3FF73FF0080FF0080FF0099FF0080FF0000FF8C4CFF0073FF00
33FF0066FF0033FF000CFF0000FF66000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000073FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FFA600FFB300FFC000FFD900FFE600FFCC00FFC000FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFC000FFC000FFD900FFF300B3FF00FFF300FFD900FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFFF00D9FF00CCFF00\
A6FF0000FF0C4CFF008CFF00B3FF00B3FF00B3FF008CFF000000FF73FF0099FF00
8CFF0073FF004CFF0000FF001900FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000008CFF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FFA600FFA600FFB300FFD900FFCC00FFB300FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300
FFB300FFC000FFCC00FFF300B3FF00CCFF00FFF300FFD900FFCC00FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00D9FF00B3FF00\
19FF0033FF0026FF00B3FF00CCFF00CCFF00C0FF00A6FF008CFF00A6FF00A6FF00
99FF0080FF0000FFBF0CFF0000FF590000000066FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000D9FF00FFFF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FFA600FFB300FFD900FFC000FFA600FFA600FF9900FF9900FF9900
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFB300FFC000FFCC00FFD900FFFF00A6FF003FFF00FFD900FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300F3FF00C0FF00\
66FF0066FF00B3FF00C0FF00D9FF00D9FF00CCFF0080FF00B3FF00C0FF00C0FF00
99FF0059FF0073FF0059FF000CFF0000FF3300FFF3000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000CCFF00FFA600FFD9000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FFA600FFD900FFB300FFA600FF9900FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFB300FFC000FFCC00FFE60099FF00FFF300FFD900FFCC00FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFE600FFFF00D9FF0099FF00\
66FF0000A6FFCCFF00E6FF00F3FF00F3FF00E6FF008CFF00CCFF00CCFF00CCFF00
B3FF00A6FF008CFF0066FF0026FF0000FF40000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000D900FF00FF9900FF7300FFA6000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FFA600F3FF00FFA600FF9900FF9900FF9900FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFB300FFCC00FFF300FFFF00D9FF00FFE600FFCC00FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300FFFF00CCFF0059FF00\
E6FF00D9FF00B3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00
C0FF00B3FF008CFF0066FF0000FF00008CFF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF4C00FF80000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FFE600FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFB300FFC000FFD900FFF30099FF00FFE600FFCC00FFC000FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFD900FFE600FFFF00D9FF00D9FF00F3FF00\
FFFF00FFFF00B3FF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00
B3FF0099FF0059FF003FFF0000FF998C00FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000FF8C00FF2600FF3300FF99000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFB300FFCC00E6FF00FFFF00F3FF00FFD900FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFE600E6FF00C0FF0080FF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00
A6FF0000FF4C0000003FFF0000FF4000FF7300000000FF8000FF730073FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0059FF00FF1900FF0000FF1900FF8C0026FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600
FFA600FFB300FFCC0080FF00FFCC00FFC000FFC000FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFC000FFC000FFCC00FFE600FFF300D9FF00A6FF00F3FF00FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00D9FF00
A6FF0000FF5919FF008CFF0080FF003FFF0000FF9926FF0000FF19000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000000026FF000000
00FF0C00FF4019FF0000FF0C00FF33000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FFA600FFB300FFCC00FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFC000FFC000FFE6008CFF00D9FF00A6FF00D9FF00FFFF00FFE600FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00F3FF00D9FF00B3FF00
59FF0099FF0099FF00B3FF00A6FF0026FF0073FF0059FF0000CCFF00FF2600FF73000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000000000CCFFB300FF
19FF0033FF0033FF000CFF00B300FF000CFF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FFA600FFB300F3FF00FFC000FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFC000FFC000FFD900FFFF0019FF00D9FF00FFF300FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFF300F3FF00D9FF0000FFD9B3FF00
D9FF00CCFF00CCFF00CCFF00B3FF0099FF0099FF003FFF004CFF0026FF0000FF2600FF8C00CCFF\
9900FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000059FF008CFF00000026FF00
00FF264CFF003FFF0000FF7300FF19000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FFA600FFB300FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFC000FFD900A6FF00E6FF00FFFF00FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300F3FF0026FF00CCFF00E6FF00
E6FF00E6FF00E6FF00D9FF00CCFF00B3FF0099FF0080FF0059FF0000FF0000000000FFE6000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000008CFF0073FF0000004CFF00
59FF0059FF004CFF0033FF0000FF0000FFFF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFCC00E6FF00FFE600FFD9003FFF00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600F3FF00E6FF00FFFF00FFFF00
F3FF00F3FF00E6FF00D9FF00CCFF00B3FF0073FF004CFF0000FF4C00FF1900FF99000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000001900FF00000000000000000033FF0000FF0C59FF00
73FF0073FF0059FF000C00FFD900FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFCC00FFCC00FFCC00FFC000FFCC00FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFF300FFF300
FFFF00FFFF00F3FF00D9FF00A6FF008CFF0026FF000000000CFF007300FF0059FF000000000000\
000000000000000000000000004CFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000BFFF00FF8C0059FF33FF0066FF0066FF0066FF00
80FF0080FF0066FF004CFF0019FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300
FFF300FFFF00F3FF00C0FF00A6FF00B3FF008CFF0073FF0059FF0000FF26000000CC00FF000000\
00000000000000000000000000BFFF00FFBF0000002600FF000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000008C00FF\
00000000FFF3E600FF3F00FF00000019FF0000000019FF0080FF008CFF008CFF00
8CFF008CFF0080FF0066FF0033FF0000FF4C00F3FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300
FFF300FFFF00F3FF00E6FF00D9FF00C0FF00B3FF0099FF0033FF0026FF0000FF4000D9FF000000\
000000000000000000CC00FF00FFCC00FF5900FF5900FFD9000000000000000000
B300FF0000000000000000000000000000000000000000000000000019FF000000000000000000\
00FFCC00FF4C00FFA600000000000066FF0073FF0026FF008CFF0099FF0099FF00
99FF008CFF0073FF004CFF000000FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300
FFF300FFFF00F3FF00E6FF00D9FF00CCFF00A6FF008CFF0073FF0026FF0000FF338C00FF000000\
00000000000000000000FFF300FFB319FF0000FF0000000000000000BFFF00FFBF
00CCFF0000000000000000000000000099FF00FFCC00000000FFCC00CCFF0000000000000080FF\
00FF4C00FF0C008CFF00FF8C66FF008CFF0099FF004CFF0080FF00A6FF00A6FF00
A6FF0099FF0000D9FF59FF0000FF26000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300
FFFF00F3FF00F3FF00E6FF00CCFF00C0FF0099FF004CFF000099FF19FF000099FF00FFF32600FF\
7300FF00FF8CE600FF00FFE633FF0059FF0000FF0000FF0C0CFF000CFF0000FF26
0059FF00000000000000000000000000E6FF00FF4C00FF5900FF1900FF5900FFA6000000CC00FF\
00FF263FFF0000000000FFE666FF00A6FF00B3FF00A6FF00A6FF00B3FF00B3FF00
B3FF00A6FF008CFF0080FF0033FF0000000000FFCC000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300
D9FF00D9FF00D9FF00CCFF00A6FF00A6FF0099FF0073FF000CFF0000FF80004CFF0059FF00FFB3\
0019FF0CFF0000FF8033FF0000FF2680FF0059FF0026FF0066FF004CFF000099FF
00FF660000000000000000000059FF00A6FF26FF0000FF0026FF0000FF0C00FF730000000000FF\
19FF008CFF0066FF0000BFFF8CFF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF0099FF008CFF0066FF0019FF0000FF4C00CCFF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFD900FFE600FFE600FFF300
F3FF00C0FF00A6FF00A6FF0033FF0019FF0066FF0000FF0C00FF735900FF00FF3300FF2600A6FF\
26FF0059FF000080FF33FF0099FF0099FF003FFF008CFF0080FF00004CFF3FFF00
19FF0000FF3300FFD90000000000004C00FF4CFF0066FF0033FF004C00FF00FFBFF300FF4CFF00\
8CFF00B3FF00B3FF008CFF0099FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00B3FF0099FF0073FF0000FF19000CFF00CCFF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFE600FFF300FFFF00
F3FF00D9FF008CFF0019FF0000FF8033FF0000FF1900FF6600FFBF00FF0066FF003FFF0000FF59\
3FFF0099FF0080FF0059FF00B3FF00B3FF000CFF00A6FF0099FF0080FF0066FF00
00FF1900FFA600D9FF0026FF00FF993FFF0080FF008CFF003FFF0000FF8019FF0073FF00A6FF00\
B3FF00C0FF00C0FF0099FF0000FFA6C0FF00CCFF00D9FF00D9FF00D9FF00CCFF00
C0FF00A6FF0073FF0000FF19A600FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFF300FFFF00FFFF00D9FF00
D9FF008CFF003FFF0000FF2673FF0099FF0099FF0099FF0019FF00A6FF00A6FF0080FF0000FF0C\
99FF00C0FF00C0FF0000FF00C0FF00CCFF00CCFF00C0FF0099FF0073FF003FFF00
00FF0000E6FF00E6FF00FF2600FF0073FF00A6FF00A6FF0080FF000033FF00BFFF0033FFB3FF00\
CCFF00D9FF00D9FF00C0FF0000FFBFC0FF00D9FF00E6FF00E6FF00D9FF00D9FF00
C0FF0000FF2680FF008CFF004CFF00A600FF0033FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFCC00FFFF00D9FF003FFF000CFF00C0FF0073FF00
26FF008CFF0026FF0000CCFF8CFF00C0FF00CCFF00CCFF003FFF00CCFF00CCFF008CFF0000F3FF\
B3FF00D9FF00D9FF0080FF00D9FF00D9FF00D9FF00C0FF0099FF0000FF3300FF40
00FF9900FF4000FF193FFF0000FF19B3FF00C0FF00C0FF0059FF0073FF0033FF0033FF0000FFE6\
D9FF00E6FF00E6FF00E6FF00CCFF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
CCFF00C0FF00B3FF00A6FF0080FF002600FF0019FF00FF8C00FFF3000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFC000FFCC00FFD900FFF300FFFF00FFFF00F3FF00C0FF00
99FF0000FF1900FF0C8CFF00A6FF00C0FF00D9FF00E6FF00B3FF00E6FF00E6FF00D9FF0000FF19\
CCFF00E6FF00F3FF00E6FF00F3FF00E6FF00E6FF0099FF000CFF00000CFF19FF00
66FF0080FF008CFF00B3FF0000FF40CCFF00D9FF00D9FF00CCFF00C0FF0033FF0073FF00D9FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
D9FF00CCFF00C0FF00B3FF008CFF0066FF0000000000FF1900FFCC000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFE600FFF300F3FF00
CCFF0099FF0000FFA699FF00C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00F3FF00E6FF0033FF00\
E6FF00F3FF00FFFF00FFFF00FFFF00F3FF00E6FF00CCFF0099FF0000FF5926FF00
80FF00A6FF00C0FF00CCFF00C0FF00CCFF00E6FF00E6FF00E6FF00D9FF00A6FF00C0FF00E6FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00
D9FF00D9FF00CCFF00B3FF0099FF0073FF003FFF0000000000FFA600BFFF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300F3FF00
CCFF008CFF0000FF4059FF00C0FF00E6FF00F3FF00FFFF00FFFF00FFF300FFFF00F3FF0059FF00\
E6FF00FFFF00FFF300FFF300FFF300FFFF00E6FF00C0FF0026FF0000FF4000FF99
0CFF00A6FF00CCFF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF0099FF008CFF00E6FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00
E6FF00D9FF00C0FF0000000073FF00000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300CCFF00
C0FF0059FF0000FFCC73FF0000FF80B3FF00F3FF00FFF300FFF300FFF300FFF300FFFF00C0FF00\
C0FF00FFF300FFF300FFF300FFF300FFF300D9FF00CCFF00D9FF0099FF004CFF00
00F3FF80FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF0059FF0000FF00D9FF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00
D9FF00CCFF00C0FF0099FF00F300FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFE600FFF300F3FF00
D9FF00B3FF0000FFBFA6FF00D9FF00E6FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFFF00\
FFF300FFE600FFE600FFE600FFE600FFF300FFFF00FFFF00F3FF00CCFF003FFF00
00FFCC33FF00C0FF00F3FF00FFFF00FFF300FFF300FFF300FFF300F3FF0059FF003FFF00E6FF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00
C0FF0099FF0099FF0000FF8C008CFF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFF300FFFF00E6FF00
C0FF003FFF0033FF0000FF26E6FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300F3FF00A6FF0000FF26
C0FF00E6FF00CCFF00F3FF00FFF300FFF300FFE600FFE600FFF300FFF300F3FF0000D9FFF3FF00\
FFF300FFF300FFF300FFE600FFF300FFF300FFF300FFF300FFFF00F3FF00C0FF00
00FFA60CFF00A6FF008CFF0019FF0000FFBF00000000FFFF0059FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFE600D9FF00B3FF0073FF00
3FFF0080FF00C0FF0000FF40C0FF00FFF300FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFFF00E6FF0059FF00
99FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFF300B3FF00FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF0000FF80
00FF99C0FF00CCFF00C0FF00B3FF0073FF0000FF4C00FFE600FFA600FF5900FF800C00FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFFF00C0FF00A6FF00
D9FF0026FF00F3FF00F3FF00B3FF00FFFF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFFF00D9FF00D9FF00
FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00
E6FF00E6FF00E6FF00D9FF00C0FF0080FF009900FF00FF8C19FF0019FF000000FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600E6FF00A6FF00CCFF00
FFFF00FFF300FFE600FFF300CCFF00E6FF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFF30059FF0000FF66D9FF00
FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00
FFFF00F3FF00E6FF00D9FF00004CFFA6FF008CFF0059FF0059FF005900FF00FF4C0000002600FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFCC00FFCC00FFD900FFE600FFFF00A6FF00E6FF00CCFF00
FFF300FFD900FFD900FFD900FFF300B3FF00FFE600FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFF300E6FF0073FF008CFF00
FFFF00FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300
FFFF00F3FF00F3FF00E6FF00D9FF00C0FF00A6FF008CFF0073FF004CFF000CFF0000FF59000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFC000FFCC00FFD900FFF300E6FF0073FF00FFF300FFE600FFE600
FFD900FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFFF00A6FF008CFF00E6FF00
FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300
FFFF00FFFF00F3FF00E6FF00D9FF00C0FF00A6FF008CFF0000CCFF0CFF0000FF7300000000FFFF\
0C00FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300\
FFC000FFC000FFCC00F3FF00F3FF00D9FF00A6FF00FFF300FFE600FFD900FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFF300D9FF0080FF0000FF59
E6FF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300
FFFF00FFFF00F3FF00D9FF00CCFF00B3FF0000FFCC66FF004CFF000000FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000\
FFC000FFCC00FFD900FFE600D9FF00CCFF00F3FF00FFE600FFD900FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFCC00FFD900FFFF0099FF0099FF00F3FF00
FFF300FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300
FFFF00FFFF00E6FF0000FFA6A6FF0099FF0059FF000000000CFF00000000000CFF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFD900\
FFD900FFD900FFFF00FFFF00C0FF00D9FF00FFF300FFD900FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFCC00FFFF00FFFF0099FF0019FF0033FF00
FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300
FFFF00F3FF00E6FF00CCFF0000FF0C00FF8000FF0000000000FF66000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFFF00\
D9FF00F3FF00E6FF0019FF0099FF0066FF00FFF300FFD900FFCC00FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900F3FF0080FF00B3FF00
FFF300FFD900FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00
FFFF00F3FF00E6FF00C0FF0066FF0000FF3300FF9900000000BFFF000000000000000000000000\
000000000000F300FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00\
FFE600F3FF0033FF00E6FF00FFFF00FFF300FFF300FFCC00FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFF300C0FF00FFE600
FFD900FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00F3FF00
E6FF00E6FF00CCFF0066FF0059FF0000FF1900FFCC000000B300FF0000FF000000000000000000\
00000000000000A6FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFCC00\
FFE600F3FF0026FF00F3FF00FFE600FFD900FFCC00FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFCC0000FF26FFD900FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFF300FFFF00E6FF00C0FF00
0CFF000040FF00FF73004CFF00FF4026FF00000000000000D900FF00FFA600FFE600FFF3F300FF\
0033FF0000FF00FFB36600FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00FFD900\
FFE600E6FF0000FFE6E6FF00FFE600FFD900FFCC00FFC000FFC000FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFCC004CFF00FFCC00FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600F3FF00C0FF008CFF0000FF80
00FFA6D9FF00CCFF00A6FF0000FFD999FF004CFF0000FFA600A6FF00FF8000FF0C00FF99000000\
00000000FF2600FFBF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000FFC000FFCC00FFFF00FFF300\
FFFF00E6FF000CFF00FFFF00FFE600FFCC00FFC000FFC000FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFFF00A6FF000CFF0059FF00
E6FF00F3FF00F3FF00E6FF00CCFF00CCFF008CFF0066FF0000FFB33300FF26FF0033FF0000FFD9\
00FF2626FF0000FF1900FFB3000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FFA600FFC000FFE600FFCC00FFCC00FFD900FFF300B3FF00\
80FF0066FF00D9FF00B3FF00FFF300FFD900FFC000FFC000FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFCC00FFD900FFF300B3FF0000FFE6C0FF00E6FF00
FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00CCFF0066FF0000E6FF00FF4C4CFF0073FF0066FF00\
66FF0033FF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FFA600FFC00099FF0099FF00A6FF00FFFF00E6FF00E6FF0073FF00\
F3FF00CCFF00FFF300FFF300B3FF00FFF300FFC000FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFCC00FFD9004CFF00FFF300FFFF00F3FF00FFF300
FFF300FFF300FFF300FFF300FFFF00F3FF00D9FF0080FF003FFF000CFF004CFF0099FF0099FF00\
80FF000CFF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFCC00FFCC00FFE600FFFF00CCFF00F3FF00\
FFF300FFE600FFD900FFCC00FFD900FFD900FFC000FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFF300FFF300F3FF0000FFF3C0FF00CCFF0080FF00B3FF00B3FF00A6FF00\
26FF00000000000000CC00FF00FFFF00FFE6000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000FFCC00FFE600F3FF00FFFF00\
FFE600FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFF300E6FF00D9FF00E6FF00E6FF00D9FF00CCFF00C0FF0099FF00\
80FF0080FF004CFF00000CFF00FF1900FFE6000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000FFCC00FFE600CCFF00D9FF00\
FFE600FFCC00FFC000FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFE600FFE600FFE600FFF300FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF00\
A6FF0099FF0073FF004CFF0000FF3300FF664C00FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFC000FFCC00FFE600CCFF00CCFF00\
FFF300FFCC00FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00D9FF00CCFF00C0FF00\
B3FF0099FF0080FF0059FF0033FF0000FF0000FF66000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFC000FFCC00FFD900FFFF00FFFF00\
FFD900FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00CCFF00C0FF00B3FF00\
99FF0000FF0C66FF0033FF0000FF1900FF3300FFB300FFD90C00FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFC000FFD900FFE600FFF300D9FF00CCFF00\
FFE600FFCC00FFC000FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFE600FFF300FFF300FFFF00F3FF00D9FF0000D9FF00D9FF80FF00\
73FF00008CFF19FF00000000000000000000000000000000000000F300FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFC000FFD90066FF0059FF00FFFF0080FF00\
E6FF00FFD900FFC000FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFE600FFF300FFF300FFFF00F3FF00E6FF00CCFF00B3FF0073FF00\
CC00FF5900FF00FF8000FF99CC00FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFC000FFD9008CFF00FFD900FFD900FFCC00\
FFE600E6FF00FFE600FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00
FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00F3FF00E6FF00D9FF00C0FF0099FF00\
00FF33000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFCC00E6FF008CFF00FFCC00FFB300FFB300\
FFC000FFCC00FFD900FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00
FFCC00FFD900FFD900FFE600FFFF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00A6FF0059FF00\
00FF9900000000FFF3000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF9900FFA600FFB300B3FF00FFE600FFCC00FFC000FFB300FFA600FFA600\
FFA600FFA600FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00
FFCC00FFD900FFD900FFF3003FFF0000FF8C00FF0CCCFF00CCFF008CFF00B3FF00A6FF0000FFE6\
0CFF0000FF33000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF9900FFB300C0FF00E6FF00FFC000FFB300FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00
FFCC00FFD900FFD900FFE600FFFF00E6FF00D9FF0000FF1980FF000000008CFF008CFF0073FF00\
3FFF0000FF260000006600FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF9900FFB300FFE600FFCC00FFB300FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900FFD900FFE600FFF300FFFF00E6FF00B3FF0000FFE600FF2600FF2659FF0059FF00\
00FF191900FF000000000000000000000000000000000000000000000000000000
0000003F00FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF9900FFCC00FFCC003FFF00FFA600FF9900FF9900FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900FFD900FFE600FFF300FFFF00E6FF0099FF0000FF660CFF0000000000FF0033FF00\
0000000066FF000000000000000000000000000000000000000000000000000000
00000000FFFF00FFA6000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FFA600FFB300FFA600FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00
FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00CCFF0099FF0019FF0000BFFF00FFB300FF19\
00FF6600FFCC000000000000000000000000000000000000000000000000000000
0040FF00FFD900FF4C000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFD900FFE600FFF300FFFF00F3FF00E6FF00CCFF00A6FF0073FF0000FF0C004CFF00FF80\
000000000000004CFF5900FF1900FF00FFFF0000000000000000000000000C00FF
0C00FF00FF3300FF2600FF66B300FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFD900
FFD900FFE600FFE600FFFF00B3FF00CCFF00CCFF0066FF0080FF0059FF000CFF0000FF4C000000\
0000000080FF00FF73F300FF00000000FF4000FF8000FFCCC000FF5900FF00A6FF
0C00FF3FFF0033FF0000FF33000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600
FFE600FFF300FFF300FFFF00D9FF00E600FF99FF0066FF000073FF00FFA6D900FF00FF99000000\
00BFFF00FF4000FF0000FF0026FF0026FF000000000000006600FF00FF8C0CFF00
4CFF0066FF004CFF0000FF33000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFF300FFE600FFF300A6FF00
F3FF00F3FF00F3FF008CFF00A6FF004CFF0026FF000080FF00E6FF4CFF0059FF0000FF1900FF66\
000000008CFF19FF004CFF0059FF004CFF0000D9FF008CFFB300FF00FFBF00FF4C
80FF008CFF004CFF000000000000FF0000FF00FF8C000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFB300FFB300FFC000FFCC00FFCC00FFE600E6FF00F3FF00D9FF0000FF0C
00FFD999FF000CFF0000FF194CFF004CFF0000B3FF8CFF0019FF00B3FF0099FF0000FF3300FFA6\
19FF000059FF00FF0059FF008CFF0073FF0080FF0000FF003FFF008CFF0073FF00
A6FF0099FF001900FF73FF0033FF000CFF0000FF1900FF8000BFFF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFB300FFB300FFC000FFCC00FFCC00FFD900FFF300CCFF0000FF4000FF3333FF00
B3FF00F3FF00FFFF00E6FF00D9FF0099FF0099FF0066FF00D9FF00D9FF00B3FF0000FF0C99FF00\
00000000FF4000000059FF0099FF00B3FF00B3FF0066FF00A6FF00C0FF00B3FF00
C0FF00B3FF00A6FF008CFF0066FF0000FFB300FF4C00BFFF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFB300FFC000FFF300FFFF00FFE600FFF300E6FF00B3FF0073FF0080FF00B3FF00
FFFF00FFF300FFE600FFF300FFF300FFFF00C0FF00E6FF00FFFF00F3FF008CFF00D9FF00CCFF00\
A6FF0066FF0000FF9919FF005900FFC0FF00C0FF000099FFB3FF00CCFF00CCFF00
CCFF00C0FF00A6FF0080FF004CFF0026FF00000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFB300FFC000FFD900FFF300B3FF00CCFF0000FFF33FFF0099FF00E6FF008CFF00
FFE600FFE600FFD900FFD900FFE600FFE60080FF00FFF300FFF300FFF300FFFF00FFFF00E6FF00\
33FF0000FF7300000000FF26B3FF00D9FF00D9FF00CCFF00CCFF00D9FF00D9FF00
D9FF00B3FF0000FF0000FF0C00000000FF8000FFA63F00FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFB300FFB300FFCC00FFD9008CFF00B3FF003FFF0066FF00D9FF00FFF300FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300F3FF00\
D9FF004CFF0000FF2600FF4CC0FF00E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00
D9FF00C0FF00A6FF0073FF0000000000000000FFCC0000000000000000000000000000000066FF\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFB300FFC000FFCC00FFD900FFF300CCFF00C0FF00A6FF00C0FF00FFE600FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFFF00\
CCFF0000FF40D9FF00E6FF0000FF0CF3FF00FFFF00FFFF00FFFF00F3FF00F3FF00
E6FF00D9FF00C0FF0099FF0019FF0000FFBF000CFF00000000000000B3FF00000000FFA600FFA6\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFB300FFC000FFCC00F3FF00F3FF000CFF00E6FF00FFFF00B3FF00FFE600FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFF300CCFF00\
00FF40F3FF00FFFF00FFFF00F3FF00FFF300FFF300FFF300FFFF00FFFF00F3FF00
E6FF00D9FF00C0FF0066FF0019FF00004CFF0000000C00FF00FFD900FF400019FF19FF0000FF0C\
00FF73000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFB300\
FFB300FFC000FFD90073FF0099FF00CCFF00FFFF00FFE600FFD900FFD900FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFF30066FF00\
D9FF00FFF300FFF300FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00
E6FF00C0FF00A6FF0000BFFF00F3FF3300FF00000000FFCC00FFA60099FF59FF004CFF00000000\
00FFA6000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFB300\
FFC000FFD900FFF300A6FF0066FF00B3FF00F3FF00FFD900FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFE60000FF0C\
E6FF00FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFFF00F3FF00
0CFF00004CFFA6FF0059FF0080FF0073FF0066FF000C00FF59FF0066FF0080FF0000FF4C000000\
D900FF000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFB300\
FFFF00F3FF00FFE6000CFF00FFD900FFF300FFE600FFCC00FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFE600FFFF00\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFFF002600FF
0099FF000000D9FF00D9FF00D9FF00CCFF00A6FF000CFF0099FF00A6FF00A6FF008CFF0033FF00\
7300FF00000000000000FF5900FFD9000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFF300\
F3FF00FFCC00FFC000FFC000FFC000FFCC00F3FF00FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFD900\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFF300C0FF00
66FF00CCFF00F3FF00F3FF00E6FF00D9FF00000000C0FF00CCFF00C0FF00B3FF0059FF00000000\
0000000000000026FF00FF009900FF000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300D9FF00
A6FF00F3FF00FFFF00FFFF00F3FF00F3FF00D9FF00D9FF00D9FF00CCFF00A6FF0066FF0099FF00\
8CFF0019FF0066FF004CFF000099FF00000000FF80C000FF000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00E6FF00D9FF00C0FF00B3FF00B3FF00\
A6FF0099FF008CFF0000CCFF4CFF0000FF190CFF00000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00\
B3FF00A6FF0099FF0080FF0073FF0059FF0026FF000CFF0000FF2600FFE6000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF00\
B3FF00A6FF0099FF0080FF0073FF004CFF003FFF0019FF0000FF0C00FF3300FF73
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF00\
A6FF0080FF0080FF0080FF0059FF0000FF9919FF0000FF0C00FF4000FF8000FF99
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00D9FF00D9FF00CCFF00C0FF00\
99FF004CFF0000000059FF004CFF0000FF0000FF7300FFD9000000E600FF000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00D9FF00CCFF00C0FF00C0FF00C0FF00B3FF00\
A6FF008CFF0000FF4C00FFBF00FF190000000000FF000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFE600FFE600FFF300FFFF00A6FF0073FF0000FF2600FFBF99FF00B3FF00A6FF00\
99FF0033FF0000FF00000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFE600FFE600FFE600FFF300FFFF00E6FF00A6FF00B3FF00B3FF0000FF9980FF0000FF99\
80FF0059FF0000A6FF0099FF0026FF000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFE600FFE600FFE600FFF300FFFF00F3FF00E6FF00D9FF00C0FF0073FF0000FF8C0059FF\
3FFF0000FF4C00FF3300FFBF000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900
FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF00A6FF00E600FF00FF33\
00CCFF4C00FF4C00FF000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00F3FF00D9FF00C0FF0099FF0033FF0000FFFF\
00FFE60000FF000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600
FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00B3FF003FFF0000FFFF000000\
00FF4C0000003F00FF000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFC000FFCC00FFD900FFD900FFE600FFF300A6FF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00E6FF00D9FF00D9FF00C0FF00A6FF0059FF0026FF00\
00FF1900FF730040FF000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFCC00FFFF00F3FF00FFFF00F3FF003FFF0000FF40
99FF00D9FF00F3FF00F3FF00E6FF0066FF00A6FF00CCFF00CCFF00A6FF008CFF0073FF0019FF00\
00FF0C000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFCC00FFE60066FF00C0FF00A6FF004CFF0059FF00
73FF0000FF00D9FF00D9FF00D9FF00C0FF0073FF00B3FF00B3FF0099FF0000CCFF4CFF0000FF73\
00FF8C000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFCC00FFD900FFFF00CCFF0000FF33A6FF0000FF40D9FF00
E6FF00D9FF0000FF4C00FFB3A6FF0000FF7366FF008CFF0099FF0080FF000CFF0000F3FF00D9FF\
CC00FF000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300\
FFB300FFC000FFCC00FFE600FFF300C0FF003FFF0000FF00D9FF00E6FF00FFFF00
FFFF00F3FF0000FF4059FF000059FF00FF4C4C00FF00FF5973FF0000FF330CFF002600FF000000\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFC000D9FF00F3FF0000FF6659FF00CCFF00C0FF00FFFF00FFF300FFF300
FFF300FFF300F3FF00C0FF0000D9FF73FF0000FF330CFF000066FF26FF0000E6FF0000000040FF\
000000000000000000000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFC000FFCC00FFCC00FFD900FFFF00FFFF00FFF300FFE600FFE600FFE600
FFE600FFF300FFFF00C0FF00CCFF00B3FF003FFF0000FF9900FF3300FF4000E6FF00A6FF00FF59\
0033FF0000000026FF000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFC000FFC000FFCC00FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFF300FFFF00F3FF0033FF00A6FF0000FF9919FF0000FF5900FF4C19FF0000FF33\
00000000FF8000FFFF000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFE600FFF300FFFF00F3FF00CCFF0099FF0033FF000026FF00FF3359FF0026FF00\
00FF6600FF0C00FF99000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFD900FFE600FFE600FFFF00F3FF00CCFF0000FF2600000000FF8C33FF0080FF0073FF00\
4CFF000CFF00CC00FF000000000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900FFD900FFE600F3FF0066FF008CFF0000FF0033FF0000FF8C99FF0099FF0066FF00\
0CFF000019FF004CFF0033FF000000000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFD900FFF300C0FF00D9FF00E6FF00A6FF00CCFF0073FF00C0FF00B3FF0000FF26\
80FF003FFF0000FF8000FF333300FF000CFF000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFD900FFE600FFF300FFFF00FFFF00F3FF00E6FF00E6FF00D9FF00C0FF00B3FF00\
99FF0073FF004CFF0019FF0000FF3300FFB30066FF000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00E6FF00D9FF00CCFF00B3FF00\
99FF0080FF0000FF0000BFFF00FF66000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFF300FFFF00E6FF00C0FF00B3FF00A6FF00\
4CFF0066FF004CFF007300FF008CFF000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00CCFF0000FF4C99FF0000BFFF\
00FF8C00FF3319FF0000FF4C4C00FF000000000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300F3FF0073FF00C0FF00CCFF0000FF8C\
19FF003300FF00FFE60099FF000000E600FF000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00E6FF00D9FF00CCFF00\
A6FF0019FF0000A6FF00FF2600FFBF0080FF000000000000000000000000000000
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00FFFF00F3FF00E6FF00CCFF00\
8CFF0000FF3359FF0000FF0000B3FF7300FF0000000000008000FF0019FF00F3FF
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFD900FFD900FFE600FFE600FFE600FFF300FFFF00FFFF00F3FF00E6FF00D9FF00\
C0FF00A6FF008CFF0059FF0000FF0C00CCFFE600FF0000FF00FF8C00FF8C004CFF
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00
FFCC00FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00\
CCFF00A6FF0000FFE633FF000CFF0000D9FF00FF8C00FF5900FF4019FF0000FF73
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900
FFD900FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00D9FF00\
C0FF00B3FF008CFF0026FF0000FF8CD900FF00FF4033FF0059FF000CFF0000FFE6
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFD900F3FF00
FFF300F3FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00F3FF00E6FF00B3FF00B3FF00C0FF00\
C0FF00A6FF008CFF003FFF0000FF408C00FF00FFF34CFF008CFF003FFF0000FF19
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFF300
A6FF008CFF0059FF004CFF00CCFF00E6FF00F3FF00F3FF00F3FF00E6FF00B3FF0080FF0099FF00\
A6FF0066FF0080FF003FFF0000FFA619FF0000FF8080FF00A6FF00A6FF0099FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFE600
F3FF00D9FF00D9FF00CCFF0066FF00D9FF00E6FF00E6FF00E6FF00D9FF00C0FF0080FF0073FF00\
80FF0059FF003FFF0019FF0000FF194CFF0073FF0026FF00B3FF00C0FF00B3FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900
FFE600FFF300FFFF00E6FF0033FF00C0FF00D9FF00CCFF00CCFF00CCFF0059FF0073FF0000FF26\
3FFF0000FF8000FF4026FF0000F3FF73FF0099FF00B3FF00CCFF00CCFF00CCFF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900
FFE600FFF300FFFF00F3FF0000FF6680FF00B3FF0099FF00A6FF00B3FF008CFF0000D9FF000000\
00FF2666FF0080FF0000FF000040FF3FFF008CFF00B3FF00CCFF00D9FF00E6FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900
FFE600FFF300FFFF00E6FF0059FF0000B3FF3FFF0019FF0080FF008CFF0033FF0033FF0000FF33\
80FF00A6FF00B3FF008CFF0000FF0000FFBF59FF0099FF00C0FF00E6FF00F3FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900
FFE600FFF300FFFF00E6FF0099FF0000FF6600F3FF0019FF3FFF0000000019FF0073FF0099FF00\
B3FF00CCFF00CCFF0073FF008CFF0033FF003FFF0099FF00CCFF00E6FF00F3FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600
FFE600FFFF004CFF00CCFF00A6FF000073FF0000000000003FFF008CFF0026FF0099FF00D9FF00\
C0FF00E6FF00E6FF00CCFF00B3FF0073FF0000FF008CFF0099FF00C0FF00F3FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600
FFF300FFFF008CFF000CFF0000FF0C19FF0000FF3300D9FF00FF40C0FF00CCFF00CCFF00F3FF00\
FFFF00FFFF00F3FF00D9FF00B3FF0000FF7326FF003F00FF4CFF00B3FF00E6FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFC000FFCC00FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFFF00FFF300FFF300
FFFF00F3FF00CCFF0059FF008CFF0080FF0099FF004CFF0099FF00E6FF00F3FF0099FF00FFF300\
FFF300FFF300F3FF0080FF0000E6FF99FF0099FF0000FFD900FF3359FF0073FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFCC0099FF00FFE600FFCC00FFD900FFD900\
E6FF00FFD900FFD900FFD900FFD900FFD900FFE600FFF300C0FF00A6FF00F3FF00
F3FF00E6FF00A6FF0000FF4CB3FF00CCFF00CCFF008CFF00CCFF00F3FF00FFF300FFF300FFE600\
FFE600FFE600F3FF0080FF00E6FF00E6FF008CFF00C0FF0066FF0099FF00D9FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFE600F3FF00FFE600FFF300FFFF00\
CCFF00FFFF00FFFF00FFE600FFE600FFE600FFE600FFF300F3FF00C0FF00CCFF00
D9FF00C0FF004CFF0080FF00C0FF00F3FF00F3FF0019FF00E6FF00FFFF00FFE600FFE600FFD900\
FFD900FFE600FFF300D9FF00FFFF00FFFF00F3FF00D9FF00A6FF0000FFA6D9FF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFF30099FF00E6FF00CCFF00CCFF00\
B3FF008CFF000CFF00FFFF00FFF300FFFF00FFFF00F3FF00CCFF0019FF0099FF00
8CFF0000FF0C00FFCCCCFF00F3FF00FFFF00FFFF00CCFF0099FF00FFFF00FFE600FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFF300FFFF00D9FF0099FF0000FF668CFF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFD900
FFCC00FFD900FFC000FFC000FFC000FFCC00FFD900FFD900FFF300E6FF0099FF00D9FF00C0FF00\
FFFF00FFFF00FFFF0059FF00CCFF00CCFF00C0FF00A6FF00A6FF008CFF0019FF00
80FF00D9FF00B3FF00B3FF00F3FF00FFF300FFE600FFF300F3FF0026FF00FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300D9FF0080FF00D9FF00FFFF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFD900
80FF0026FF00FFE600FFCC00FFCC00FFD90080FF00E6FF00F3FF00D9FF00CCFF00FFFF00FFFF00\
FFE600FFE600FFE600FFFF00B3FF00CCFF00CCFF0000FF00F3FF0099FF00F3FF00
FFF300FFFF00C0FF003FFF00F3FF00FFE600FFD900FFD900FFD900FFFF00FFCC00FFCC00FFC000\
FFC000FFC000FFCC00FFCC00FFD900FFD900FFF300F3FF00A6FF0026FF00FFE600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFC000
FFCC00FFE600FFFF00FFE600FFE600FFE600FFFF00B3FF0080FF00C0FF00FFFF00FFE600FFD900\
FFD900FFD900FFD900FFD900FFFF00FFE600FFF300A6FF00FFF300FFE600FFE600
FFE600FFE600FFFF00A6FF0080FF00FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFD900FFF300F3FF0000FF33CCFF00FFD900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300
FFC000FFD900B3FF00D9FF00F3FF00F3FF0080FF00B3FF0080FF00CCFF00FFF300FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFE600F3FF00FFD900FFCC00FFCC00
FFCC00FFD900FFF30066FF00FFE600FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFCC00FFE600C0FF00D9FF00FFFF00FFD900FFCC00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300
FFC000FFCC00FFF300E6FF0099FF00A6FF0019FF00FFFF00FFFF00E6FF00E6FF00FFD900FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFCC00FFD900FFCC00FFC000FFC000
FFCC00FFCC00E6FF00FFFF00FFD900FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFCC00FFE6008CFF00FFFF00FFE600FFCC00FFC000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300
FFB300FFC000FFD900FFF300FFFF00C0FF00E6FF00FFF300FFE600FFD900FFD900FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000A6FF004CFF00FFD900FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFCC00FFF30073FF00F3FF00FFE600FFCC00FFC000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFA600FFB300
FFC000FFC000FFCC00FFE600FFF300CCFF00E6FF00FFE600FFD900FFCC00FFCC00FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFE600FFCC00FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFC000FFD900FFFF0080FF00FFF300FFD900FFC000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300
FFC000FFCC00FFD900FFE600FFFF00B3FF00F3FF00FFE600FFD900FFCC00FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFC000FFE600CCFF00B3FF00D9FF00F3FF00FFCC00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000
FFCC00FFD900FFE600E6FF00C0FF00D9FF00FFF300FFD900FFCC00FFCC00FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFCC00FFCC00E6FF00FFF30000FF59FFFF00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFCC00
FFF300FFFF00E6FF00D9FF00B3FF00F3FF00FFF300FFD900FFCC00FFC000FFC000FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFD900C0FF00FFCC00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00
F3FF00CCFF00C0FF000000003FFF00E6FF00FFFF00FFE600FFCC00FFC000FFC000FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFF300FFD900FFB300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900\
FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFCC00
FFD900FFF3008CFF0000FF8CA6FF0059FF0059FF0059FF00FFD900FFC000FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFC000D9FF00FFA600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FF9900\
FFA600FFC000FFC000FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00
FFE600FFFF00D9FF00C0FF00F3FF00A6FF00FFE600FFE600FFFF00FFC000FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFA600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FF9900FFA600\
FFB300FFCC00FFE600FFE600FFD900FFCC00FFC000FFC000FFCC00FFCC00FFD900
99FF008CFF00F3FF00FFF300FFE600FFE600FFCC00FFCC00FFC000FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FFB300FFD900FFCC00\
FFD900FFF300FFF300FFF300FFFF00FFE600FFD900FFD900FFF300FFE600FFE600
E6FF00D9FF00FFF300FFE600FFD900FFCC00FFCC00FFC000FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF9900FFA600FFCC00\
E6FF00FFCC00FFC000FFC000FFD90099FF00FFFF00FFFF00C0FF00E6FF00F3FF00
C0FF00F3FF00FFF300FFD900FFCC00FFCC00FFC000FFC000FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF9900FFA600\
FFC000FFB300FFB300FFB300FFC000FFCC00F3FF00FFF300E6FF00D9FF00F3FF00
E6FF00CCFF00FFFF00FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900\
FF9900FFA600FFA600FFA600FFB300FFC000FFE600FFCC00FFD900FFE600FFE600
FFF3008CFF00F3FF00FFE600FFCC00FFC000FFC000FFB300FFB300FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFC000FFC000FFCC00FFD900
FFE600FFFF008CFF00D9FF00FFD900FFC000FFB300FFB300FFB300FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFB300FFC000FFCC00
FFD900FFF30099FF00FFE600FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00
FFD900D9FF00FFFF00FFD900FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFCC00
FFFF00E6FF00FFE600FFD900FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFCC00
FFF300A6FF00FFE600FFD900FFCC00FFC000FFC000FFB300FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000FFF300
CCFF0019FF00FFF300FFE600FFD900FFCC00FFC000FFB300FFB300FFA600FFA600FF9900FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFC000FFCC00
FFE60080FF00E6FF0000FF0CFFE600FFE600E6FF00FFC000FFB300FFA600FFA600FF9900FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFC000FFCC00
CCFF00B3FF0000000000FFCCB3FF00E6FF00FFF300FFCC00FFB300FFA600FFA600FF9900FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFCC00FFE600FFE600
F3FF0000FF0000000033FF00E6FF00FFFF00FFFF00FFE600FFCC00FFA600FFA600FF9900FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFC000FFE600D9FF00
C0FF00C0FF004CFF0019FF008CFF00FFD900FFCC00FFD900FFC000FFA600FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFC000FFF300
FFE600CCFF00E6FF00C0FF00FFF300FFCC00FFC000FFB300FFB300FFA600FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFC000
FFCC00FFD900FFE600C0FF00FFFF00FFCC00FFC000FFB300FFA600FFA600FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFB300
FFC000FFCC00FFE60080FF00FFE600FFCC00FFB300FFA600FFA600FF9900FF9900FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300FFB300
FFC000FFCC00FFF300E6FF00FFCC00FFC000FFB300FFA600FFA600FF9900FF9900FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFB300
FFC000FFE600E6FF00FFD900FFCC00FFC000FFB300FFA600FFA600FF9900FF9900FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFB300
FFC000FFE600F3FF00FFD900FFCC00FFC000FFB300FFA600FFA600FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFE600FFF300FFF300
FFF300FFFF00F3FF00E6FF00C0FF00A6FF0073FF008C00FF59FF0073FF0099FF0033FF0080FF00\
00FF198CFF003FFF0099FF0073FF0000FF3366FF0080FF00B3FF00B3FF0000FFBF
B3FF00C0FF00CCFF00C0FF00B3FF00A6FF008CFF0073FF004CFF0026FF0000FF4C00000000FFF3\
00FF9900FF4C33FF0080FF00A6FF0099FF0073FF000019FF00FF3300FF0066FF00
A6FF00C0FF00CCFF00CCFF00CCFF00C0FF0000FF5959FF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00C0FF008CFF0000FFF373FF0066FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFE600
FFF300FFF300FFFF00F3FF00D9FF00C0FF003FFF0033FF0000CCFF3FFF0000FF33004CFF00FF40\
00D9FF33FF0000FF0066FF0019FF0000FF2600FF2673FF0099FF0080FF0033FF00
99FF00B3FF00B3FF0080FF00A6FF0099FF008CFF0073FF0059FF00E600FF4C00FF00FFCC000000\
E600FFD900FF00FF2673FF0080FF0080FF004CFF000000FF00FF1933FF0073FF00
99FF00A6FF00C0FF00C0FF00C0FF00A6FF0000FF5919FF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00CCFF00C0FF00B3FF008CFF0080FF008C00FF00FFCC000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600
FFE600FFF300FFF300F3FF00D9FF008CFF0000FFA68CFF0026FF000CFF0019FF004CFF0000FF0C\
00BFFF00FFD900FF730CFF0000FF400026FF00FF0C59FF0059FF00A600FF00FF99
8CFF00A6FF0099FF0000FFF38CFF008CFF0073FF004CFF004CFF0026FF0000FF1900FF7300E6FF\
00000000FFFF00FF1900FF1959FF0066FF003FFF000C00FF00F3FF0000000CFF00
4CFF003FFF00A6FF00B3FF00B3FF0099FF0059FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00B3FF00A6FF0099FF0073FF0000000000CCFF0000000026FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900
FFE600FFE600FFF300E6FF0000FF4CCCFF00CCFF00C0FF004CFF0099FF0099FF0066FF0066FF00\
19FF000040FF0080FFCC00FF00FFD900FFE600FF1900FF0026FF000000FF33FF00
73FF0080FF008CFF0059FF0066FF0073FF0066FF0033FF000033FF00FF0C000CFF00F3FF000000\
0000007300FF00CCFF00FF003FFF0026FF0033FF000CFF0000FF3300FFA68C00FF
0000FF66FF008CFF008CFF008CFF004CFF0073FF00A6FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00B3FF00A6FF0099FF0080FF0059FF0026FF0000FF5900FFE6
008CFF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900
FFE600FFE600FFF300FFFF00F3FF00E6FF00E6FF00D9FF00C0FF00C0FF00B3FF0099FF0059FF00\
00FF1900FF7300FF2600FFBF00CCFF00000000FFCC00FF4C00FFA60033FF00FF0C
00FF0C66FF0066FF000CFF001900FF4CFF003FFF0026FF000000000000003F00FF000000000000\
00000000000000000000FF4000FF5900FF000CFF0000FF0C00FF400C00FF000000
F300FF00FF4073FF0059FF0000FFBF00FF333FFF0033FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00A6FF0099FF0080FF0066FF0019FF0000000000FFA6
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFE600FFE600FFF300FFF300FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF003FFF0066FF00\
0CFF0033FF0000FF0000FF3300F3FF00000000000000F3FF00FFB3000000000000
0CFF0000FF403FFF0000FF7300FF5900FF0C00FF0C00FF0000FF2600FF80000000000000000000\
000000000000E600FF00FF8000000000FFFF00FF260000FF3F00FF00D9FF2600FF
A600FF00FFB33FFF0000FF0C00FFA600FF3326FF008CFF00A6FF00A6FF00A6FF0080FF00B3FF00\
B3FF00B3FF00B3FF00A6FF008CFF0080FF0073FF0059FF000019FF0080FF00E6FF
0040FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00C0FF00A6FF008CFF00\
73FF004CFF0000FF0C00F3FF0000000000000000000000000000000000000080FF
00D9FF00FF0000FF4C00FF0C00FF99000000C000FF00FF7300FF8C00FFCC0066FF000000000000\
0000000000000000000019FF8000FF00000000000000FFE61900FF000000000000
0000FF00FFF300FF0000FF400026FF0073FF33FF0059FF008CFF0099FF0066FF0059FF00A6FF00\
A6FF00A6FF00A6FF0099FF0073FF0000BFFF4CFF0000FF197300FF7300FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00C0FF00A6FF0099FF00\
59FF003FFF0000FF0000FF731900FF0000000000000000000000000000005900FF
00000000FF3300FF8000FF4000D9FF5900FF0000000099FF0000000040FF8C00FF000000000000\
0000000000000000000000000000000000007300FF004CFF000000000000000000
00000000FF9900FF6600FF4C00FF8C004CFF00FFD94CFF0073FF0073FF00C000FF80FF0099FF00\
99FF00A6FF0099FF0099FF0080FF0066FF003FFF0000FFF3000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600
FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00D9FF00C0FF00C0FF00B3FF008CFF008CFF00\
66FF0000FF0C00000000FFE6E600FF000000000000000000000000000000000000
00000000FF8C00FFBF00000000A6FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
9900FF0099FF00BFFF00000000FFD90033FF0000000CFF0033FF0000FF4000FF0073FF008CFF00\
99FF0099FF0099FF008CFF0080FF0073FF0059FF0019FF0000FF6600FFBF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600
FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00C0FF0000FF2666FF008CFF004CFF0000FFCC\
3FFF0000FF40000000000000000000000000000000000000000000000000000000
00000000E6FF0019FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000040FF00000000000000000000FF4000000000FFA600FF6666FF0080FF00\
80FF0080FF008CFF0080FF0080FF0073FF0059FF0033FF0000FF6600E6FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFC000FFF300FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300
FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00C0FF00A6FF008CFF0000FF0C00F3FF\
00FF3300FF8000FFD90040FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000F3FF00FFCC008CFF0CFF004CFF0066FF00\
0C00FF66FF0080FF0080FF0073FF0033FF003FFF0019FF000080FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFC000FFE600FFFF00FFE600FFD900FFFF00FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFF300D9FF00F3FF00
E6FF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF00A6FF0000FF264CFF00\
00FF000CFF0000FF26000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000B300FF0C00FF00E6FFCC00FF6600FF26FF0033FF00\
26FF0059FF0073FF0073FF0066FF004CFF0019FF000040FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FFA600FFFF00FFB300FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFC000FFCC00FFFF00C0FF00F3FF00F3FF00FFE600FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300F3FF003FFF00
A6FF00D9FF00E6FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF008CFF0073FF00\
59FF0026FF0000FF990073FF00CCFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000D900FF00FFE6000000\
00FF264CFF0059FF0066FF0059FF004CFF0033FF0000FF0000FF73008CFF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FFA600FFC000FFD900FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFC000FFC000FFCC00FFE6000CFF00A6FF00F3FF00FFF300FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300F3FF00C0FF00
66FF00A6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF008CFF0073FF00\
59FF0033FF0000FF1900FF400000000073FF8000FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000008CFF00CCFF000000\
0CFF0033FF004C00FF4CFF004CFF003FFF0026FF0000FF000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FFA600FFA600FFC000D9FF00FFC000FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFC000FFC000FFCC00FFF300E6FF0000FF00CCFF00FFFF00FFFF00FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00
00FF4099FF004CFF00C0FF00C0FF0026FF00C0FF00C0FF00A6FF004CFF008CFF0080FF0000FF0C\
26FF0019FF0000FF0C00FF8C0059FF004CFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00FF3300FF0C0CFF0033FF003FFF0033FF00E600FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FFA600FFB300FFC000FFD900FFD900FFC000FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFC000FFC000FFCC00FFFF00FFFF00D9FF0099FF00B3FF00E6FF00FFF300FFE600FFE600\
FFE600FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFFF00F3FF00
E6FF00D9FF00C0FF0000FF2666FF0000FF5999FF00A6FF0099FF0073FF003FFF0066FF004CFF00\
00FFFF00FF4C0033FF00FFCC000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
E600FF0000000CFF0026FF0026FF0026FF000CFF0000FF2600FFE6000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFB300FFC000FFE600E6FF00FFD900FFCC00FFC000FFC000
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFCC00FFD900FFE600FFF300E6FF000CFF0026FF00FFFF00FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00
F3FF00E6FF00CCFF00B3FF0000FF2600FFBF33FF008CFF0066FF0066FF00C000FF00F3FF0CFF00\
00FF0C00FFA6000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0026FF00000000FF190000000CFF000CFF0000FF2600FF33000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFB300FFC000FFCC00F3FF00FFF300FFE600C0FF00FFCC00
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFCC00FFCC00FFD900FFF300A6FF00CCFF0033FF00CCFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00
F3FF00E6FF00CCFF00B3FF0059FF0000F3FF00FF194CFF000CFF0000FF0000FF590073FF00FFD9\
00FFA64C00FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000C00FF00FF4000FF0000FF0000FF1900FF66000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFB300FFC000FFD900FFF30073FF00FFFF00FFD900FFCC00
FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300FFFF000CFF0000FF40F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFFF00FFFF00FFFF00F3FF00
F3FF00E6FF00CCFF0099FF0099FF0066FF0000FF0000FF260033FF0000FF8C00FF0073FF000000\
4C00FF0080FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000FF4C0080FF00FF1900FF2600FF59000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFB300FFC000FFF300E6FF00E6FF00D9FF00FFF300FFD900FFCC00
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00E6FF0066FF00D9FF00\
F3FF00F3FF00E6FF00C0FF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
E6FF00D9FF00D9FF00C0FF00B3FF008CFF0073FF004CFF000CFF00C000FF3300FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000FF5900FF3300FF4000FF802600FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFB300FFC000FFCC00FFE600FFFF0059FF0099FF00FFD900FFCC00
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00D9FF0033FF00\
CCFF00D9FF00C0FF00CCFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
D9FF00D9FF00CCFF00C0FF00B3FF00A6FF0080FF004CFF0000FF8000FFF300FFFF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000FFA600FF6600FF5900FF99000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFB300FFB300FFC000FFCC00FFE600D9FF00F3FF00FFE600FFD900
FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00D9FF00B3FF00\
00FF338CFF0000FF33CCFF00E6FF00E6FF00F3FF00E6FF00D9FF0000FF0CCCFF00
CCFF00CCFF00CCFF00C0FF00A6FF0099FF0080FF0059FF0033FF0000FF0C00F3FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000FFCC00FF8000FFA6000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFC000FFCC00FFD900FFFF000CFF00F3FF00E6FF00
FFD900FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00A6FF00\
80FF0000FF738CFF00C0FF00CCFF00D9FF00E6FF00D9FF00CCFF0080FF0000FF80
C0FF00C0FF00C0FF00A6FF0059FF0080FF0073FF0059FF0026FF0000FF0C00FF6600E6FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000FFCC00FFA600FFCCF300FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFC000FFCC00FFE600FFFF0033FF00F3FF00FFE600
FFD900FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00CCFF00\
8CFF0000CCFF73FF008CFF00A6FF00CCFF00D9FF00CCFF00CCFF00A6FF0080FF00
B3FF00B3FF00B3FF00A6FF0080FF0000FF0C00FFD933FF0000FF000099FF00FFD9000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000FFCC00FFF3000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFC000FFCC00FFE600FFFF00CCFF00D9FF00FFE600
FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF30099FF0000FF0C8CFF00\
66FF0026FF0000FF8C66FF00A6FF00C0FF00C0FF00C0FF00C0FF00A6FF0026FF00
8CFF0099FF00A6FF0099FF008CFF004CFF0000FF7300FF8000BFFF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000F3FF00D9FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFE600F3FF00CCFF00FFF300
FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300F3FF00E6FF00D9FF00\
C0FF008CFF0000FF333FFF0080FF00A6FF0080FF00A6FF00A6FF0000FF0C00FF33
19FF0080FF008CFF0080FF0080FF0066FF003FFF0000FF00000000A600FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000A6FF00B3FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFE600B3FF00B3FF00FFFF00
FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00\
B3FF008CFF0073FF0000E6FF66FF0080FF004CFF008CFF0099FF0080FF0019FF00
00FF0066FF0073FF0000FF6666FF004CFF0033FF000CFF0000FF4C00E6FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000FF0073FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFF300C0FF00FFFF00
FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFD900FFF300FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00\
CCFF00C0FF00A6FF0080FF0000E6FF00FF3319FF0073FF0026FF0066FF0033FF00
00FF2600FF0C4CFF0000FF4C33FF003FFF0000FF000059FF00FFCC000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000026FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFB300FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600F3FF00FFFF00
FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFF300CCFF00FFE600FFD900FFD900FFD900FFCC00FFCC00FFD900FFD900
FFD900FFD900FFE600F3FF00FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00\
D9FF00C0FF00A6FF0080FF0033FF0000F3FF00BFFF33FF0000000033FF0000FF8C
004CFF00FF190CFF000040FF0CFF0000FF0000FF0000FF4000BFFF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000003F00FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFFF00FFB300
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600F3FF00D9FF00
FFFF00FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFE60000FF1900FF0CF3FF00FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFF300CCFF0099FF00F3FF00FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00D9FF00\
CCFF00C0FF0000FFF333FF0000FF0C0026FF00FF9900FF59008CFF00FFD900FF73
3F00FF00D9FF00FF590000FF00FF3300FF6600FF2600FFCC00CCFF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000D900FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFC0008CFF00FFC000
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFF300A6FF0059FF00
E6FF00FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFFF0000FF73F3FF00FFF300FFE600FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFF300D9FF0026FF00B3FF00F3FF00F3FF00F3FF00F3FF00D9FF003FFF00C0FF00\
C0FF00B3FF0099FF0073FF003FFF00004CFF00A6FF0000008C00FF00A6FF00E6FF
0026FF0000000040FF00000000FFCC00FFA600FFA600FF8C00BFFF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFCC008CFF00FFCC00
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000
FFD900FFD900FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300F3FF0000FF33
E6FF00FFFF00FFF300FFF300F3FF00FFFF00FFE600FFD900FFD900FFD900FFD900FFD900FFE600\
FFF300F3FF0033FF00F3FF00FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300F3FF00C0FF008CFF00E6FF00E6FF00E6FF00E6FF00D9FF0000FF4080FF00\
A6FF0099FF008CFF0066FF004CFF000CFF0000FF590040FF000000000000E600FF
00000000000000000000000000000000000000FFE600FFCC000CFF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFC000FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000D9FF0000FF73E6FF00
FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000
FFE600F3FF00FFD900FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFF300FFF300FFFF00CCFF0066FF00
A6FF00F3FF00F3FF00F3FF0026FF00F3FF00FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFFF00B3FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00F3FF00E6FF00A6FF00CCFF00CCFF00D9FF00D9FF00CCFF00C0FF0099FF00\
19FF0066FF0073FF004CFF0000FF4C00FF1900FF800080FF000000000000000000
00000000000000000000000000000000000000000000B3FF000CFF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFD900FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFCC00FFD900C0FF00FFD900
FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFCC00
FFE600A6FF00FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFCC00FFD900C0FF00FFE600\
FFD900FFD900FFD900FFD900FFE600FFFF00D9FF00F3FF00F3FF00D9FF0099FF00
B3FF00D9FF00E6FF00C0FF00CCFF00FFFF00FFF300FFF300FFE600FFE600FFF300FFF300FFF300\
FFFF00F3FF00C0FF00E6FF00F3FF00FFFF00FFF300FFF300FFFF00FFFF00FFF300
FFF300FFFF00FFFF00F3FF00D9FF00B3FF0066FF008CFF00C0FF00CCFF00C0FF00B3FF0059FF00\
33FF0000FF193FFF0033FF0000FF0C0000FF00CCFFB300FF000000000000000000
000000000000000000000000000000000000000000C000FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFE6008CFF00FFE600
FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00
FFF30073FF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFE600CCFF00FFF300\
FFE600FFD900FFD900FFE600FFE600FFFF0099FF00CCFF00D9FF00B3FF0099FF00
80FF0019FF00B3FF00A6FF00E6FF00F3FF00FFFF00FFF300FFF300FFFF00F3FF00FFFF00FFFF00\
F3FF00D9FF0099FF00C0FF00CCFF00F3FF00FFFF00F3FF00B3FF00F3FF00FFFF00
FFFF00F3FF00F3FF00E6FF00CCFF008CFF0000FF8C80FF00B3FF00A6FF0080FF00A6FF008CFF00\
66FF0019FF0000FF9900FF0C00FF4C00FF991900FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFE600FFD900\
FFCC00FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFF300C0FF00FFF300
FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFCC00FFF300FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFE60099FF00FFF300FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFE600D9FF00F3FF00\
FFF300FFE600FFF300FFF300FFF300FFFF00E6FF00B3FF00A6FF008CFF0066FF00
00FF660CFF000CFF00B3FF00D9FF00E6FF00F3FF00F3FF00FFFF00F3FF0059FF00E6FF00F3FF00\
E6FF00B3FF0033FF0000FF0CC0FF00E6FF00E6FF00E6FF0099FF00D9FF00E6FF00
E6FF00D9FF00B3FF00CCFF00C0FF00A6FF003FFF0059FF008CFF008CFF0059FF0080FF0000FF00\
4CFF000CFF0000A6FF00E6FF8000FF00E6FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFF300FFF300\
FFD900FFCC00FFCC00FFE600FFCC00FFD900FFD900FFE600FFFF00A6FF00FFF300
FFE600FFD900FFD900FFD900FFF300FFCC00FFCC00FFD900E6FF00FFE600FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900E6FF00FFD900FFD900FFE600FFD900FFE600
FFF300D9FF00FFFF00FFF300FFE600FFE600CCFF00FFF300FFE600FFF300FFFF00E6FF00E6FF00\
FFFF00FFFF00D9FF00FFFF00F3FF00F3FF00D9FF00B3FF003FFF000CFF0000FF59
00000000000000FF3359FF00C0FF00D9FF00C0FF00D9FF00E6FF00D9FF0099FF00CCFF00CCFF00\
CCFF00B3FF0000FF3373FF0099FF00CCFF00B3FF00CCFF0073FF00C0FF00CCFF00
D9FF00CCFF0059FF00B3FF000099FF8CFF0059FF0000FF0019FF0066FF000066FF59FF003FFF00\
00FF7300FF3300FF99000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600C0FF00FFE600FFF300FFF300E6FF00F3FF00\
FFF300FFFF00FFF30099FF00FFF300F3FF00FFF300FFF300C0FF004CFF00D9FF00
FFF300FFF300FFFF00FFF3003FFF00FFF300FFFF00FFF300CCFF00FFFF00FFF300FFE60099FF00\
FFE600FFD900FFE600FFE600FFF300C0FF00FFF300FFF300C0FF00FFFF0099FF00
E6FF00A6FF00B3FF00E6FF00E6FF00F3FF00C0FF00F3FF00F3FF00E6FF00D9FF00C0FF00A6FF00\
00FFB3D9FF00B3FF00D9FF00D9FF00C0FF00C0FF0066FF0000FF59000000000000
00000000000000000073FF0099FF0080FF008CFF00B3FF00B3FF00B3FF0000FF26A6FF0099FF00\
99FF008CFF0000FF0000FF4080FF0080FF0059FF0080FF0000FFB38CFF0073FF00
A6FF008CFF003FFF0066FF004CFF0000FF0000FFB300B3FF00FF0000FF9900FFBF00FF0C00FF0C\
00FFA600A6FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
F3FF0033FF00FFFF00F3FF00FFF300FFF300FFF30080FF00FFFF00E6FF00FFFF00D9FF00E6FF00\
FFFF00D9FF00FFFF0080FF00FFFF00D9FF00F3FF00F3FF00CCFF0000FF80CCFF00
F3FF00F3FF00E6FF00FFFF00C0FF00F3FF00E6FF00F3FF00C0FF00F3FF00FFFF00FFFF0099FF00\
FFF300FFF300FFF300FFFF00F3FF00C0FF00F3FF00F3FF00C0FF00D9FF00B3FF00
D9FF0059FF00B3FF00CCFF00D9FF00CCFF0080FF00D9FF00D9FF00CCFF00CCFF00A6FF0073FF00\
99FF00A6FF0099FF00C0FF00B3FF0099FF00A6FF004CFF0000FF73000000000000
00000000000000FFA666FF0080FF0073FF0000FF2699FF0099FF0033FF003FFF0080FF0066FF00\
73FF0066FF0000B3FF00FF9959FF0059FF0026FF0059FF0000FF1966FF0033FF00
80FF0033FF003FFF003FFF0026FF0000FF0C00FF6600000000FF4000000000BFFF00FF5900FF4C\
00FFD90073FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFFF00FFD900FFD900FFD900FFFF00FFF300\
FFD900FFD900FFD900CCFF00FFD900FFD900FFD900FFE600FFFF0099FF00FFFF00
FFE600FFD900FFD900FFD900F3FF00FFD900FFD900FFE600CCFF00FFE600FFD900FFCC00FFE600\
FFCC00FFCC00FFCC00FFCC00FFD900E6FF00FFE600FFD9003FFF00FFE600FFF300
FFFF00C0FF00F3FF00FFF300FFF300FFF300CCFF00FFF300FFF300FFF300FFFF00E6FF00D9FF00\
F3FF00F3FF00B3FF00F3FF00F3FF00E6FF00CCFF00A6FF0059FF0000FF0C00E6FF
00000000000000FF5980FF00C0FF00CCFF00B3FF00D9FF00D9FF00D9FF0073FF00CCFF00C0FF00\
CCFF000CFF0066FF0073FF0066FF00C0FF008CFF00C0FF003FFF00B3FF00B3FF00
CCFF00C0FF0066FF00A6FF0066FF0080FF004CFF0000FF0C26FF004CFF0000FF993FFF0033FF00\
00E6FF00FF4000FFCC000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFCC00F3FF00A6FF00\
FFCC00FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFF300B3FF00FFF300
FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFCC00FFCC0073FF00FFD900FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFD900FFCC00FFCC00FFCC00FFD900FFD900
FFE600C0FF00FFF300FFE600FFD900FFD900FFE600FFD900FFD900FFE600FFF300E6FF00F3FF00\
FFF300FFF300FFF300FFF300FFF300FFFF00E6FF00B3FF0066FF008CFF004CFF00
00FFA600FF263FFF00A6FF00C0FF00E6FF00E6FF00F3FF00F3FF00E6FF0026FF00E6FF00E6FF00\
E6FF00C0FF003FFF0073FF00C0FF00D9FF00E6FF00D9FF0099FF00D9FF00E6FF00
E6FF00D9FF0099FF00CCFF00C0FF00A6FF004CFF0059FF0080FF0080FF0000FF0C73FF004CFF00\
3FFF000CFF0000FF8CC000FF00000000A6FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFD900FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFFF0000FF0CFFFF00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFE60059FF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFE600D9FF00FFFF00\
FFE600FFE600FFE600FFE600FFF300FFFF00D9FF00B3FF00CCFF0080FF0099FF00
66FF0073FF0080FF0080FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00D9FF00FFFF00FFFF00\
F3FF00C0FF0099FF00B3FF0026FF00F3FF00F3FF00F3FF0099FF00E6FF00F3FF00
F3FF00F3FF00E6FF00E6FF00CCFF00A6FF0000FF0033FF00A6FF00A6FF0080FF0099FF008CFF00\
66FF0019FF00008CFF00FF3300FF800000003300FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFD900FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFCC00FFD900B3FF00FFD900
FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00
FFE600D9FF00FFE600FFCC00FFCC00FFC000FFC000FFC000FFCC00FFCC00FFD90019FF00FFE600\
FFD900FFD900FFD900FFD900FFE600FFFF0000FF19F3FF00F3FF00D9FF0099FF00
B3FF00C0FF00D9FF00B3FF00D9FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00F3FF0099FF00D9FF00F3FF00FFFF00FFFF00FFFF00F3FF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00D9FF00B3FF0019FF0099FF00C0FF00C0FF00B3FF00B3FF008CFF00\
4CFF008C00FF26FF0026FF0000FF0C0026FF8C00FF000000000000000000000000
000000000000000000000000000000000000000000000000E600FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFE600D9FF00FFE600
FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFCC00
D9FF00D9FF00FFD900FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFE600FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900F3FF00FFF300FFF300FFFF00CCFF003FFF00
C0FF00E6FF00F3FF00E6FF0099FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFFF0099FF00E6FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00F3FF00E6FF00B3FF00B3FF00B3FF00D9FF00D9FF00CCFF00C0FF0099FF00\
0080FF4CFF0066FF004CFF000C00FF00FF5900FF990080FF000000000000000000
0000000000000000000000000000000000000000000080FFA600FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC0080FF00FFD900
FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000
FFD900FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300F3FF008CFF00
D9FF00FFFF00FFFF00FFFF00D9FF00FFFF00FFE600FFE600FFD900FFD900FFD900FFE600FFE600\
FFF300FFFF0099FF00F3FF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFFF00F3FF00D9FF0099FF00D9FF00E6FF00E6FF00E6FF00D9FF00B3FF0000FF73\
99FF008CFF008CFF003FFF003FFF0000D9FF00FF8C0073FF000000000000000000
000000000000000000000000000000B300FF00F3FF00FFE6000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFC000CCFF00FFC000
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFF300CCFF008CFF00
F3FF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFFF0026FF00F3FF00FFF300FFE600FFE600FFD900FFD900FFE600FFE600
FFE600FFE600FFF300E6FF0066FF00CCFF00F3FF00F3FF00F3FF00E6FF00D9FF0000FFBFB3FF00\
C0FF00B3FF0099FF0080FF0033FF0000FF330080FF0000000000000026FF000000
000000000000B300FF00000000CCFF00FFE600FFB30000000059FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300D9FF00FFB300
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFF300F3FF00B3FF00
E6FF00FFF300FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFE600F3FF008CFF00FFFF00FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFF300E6FF0099FF00F3FF00FFFF00FFFF00FFFF00F3FF00D9FF00D9FF00CCFF00\
CCFF00C0FF0080FF0033FF0000FFA600FFFF00FFBF00FFBF00F3FF00000000FF66
0026FF0C00FF00FF993F00FF00FF6600A6FF00FF33008CFF7300FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFB300FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600F3FF00F3FF00
FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFF300C0FF00FFF300FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600CCFF00FFFF00FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00E6FF00\
D9FF00C0FF00A6FF0080FF0019FF000080FF00FF3319FF0000FFBF19FF0000FF4C
3F00FF00FF2600FF000019FF00FF0000FF3300FF0C00FF4000FFF3000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000005900FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFF300C0FF00FFFF00
FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFE600FFFF00FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00\
D9FF00C0FF00A6FF0080FF0000FF5900FFA626FF0066FF000CFF0059FF0033FF00
0000FF00FF0C3FFF0000FFE626FF0033FF000CFF000000000040FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000CFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFE600E6FF0080FF00FFF300
FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00\
8CFF00A6FF0080FF0026FF0000FF0C73FF0000FFF38CFF008CFF0080FF0000FF26
00FF1959FF0066FF0000FFFF59FF004CFF0019FF0000FF0000FFBF00D9FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000066FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFFF00B3FF00E6FF00
FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00E6FF00D9FF00\
C0FF0080FF0000FF734C00FF8CFF00A6FF0073FF00A6FF00A6FF0080FF0000FF40
19FF0073FF0080FF0066FF0073FF0066FF003FFF0000FF2600FFA62600FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000066FF00A6FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFC000FFCC00FFD900FFF300D9FF00E6FF00FFE600
FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300E6FF00B3FF00C0FF00\
99FF0000FF2600FF6666FF00A6FF00B3FF00C0FF00C0FF00B3FF00A6FF0033FF00
73FF008CFF0099FF0099FF0080FF0033FF000CFF0000FF66000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000B3FF00D9FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFC000FFCC00FFF300E6FF0080FF00F3FF00FFE600
FFD900FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300F3FF00D9FF00C0FF00\
80FF0000FFF300FFD959FF00A6FF00CCFF00CCFF00CCFF00C0FF00B3FF0066FF00
A6FF00B3FF00B3FF00A6FF0080FF0026FF0000BFFF19FF0000FF190000000059FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000FF00FFE600FFF3000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFC000FFCC00FFD900FFFF0099FF00D9FF00C0FF00
FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00CCFF00\
8CFF0000FF8033FF00B3FF00B3FF00D9FF00D9FF00D9FF00CCFF0099FF0099FF00
C0FF00C0FF00C0FF00A6FF0000FF5973FF004CFF0059FF0000FF0C00FF5900FFA6000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000FFD900FFB300FFCC000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFB300FFB300FFC000FFCC00FFE600F3FF00E6FF00FFE600FFD900
FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00C0FF00\
00FF0066FF0073FF00CCFF00D9FF00E6FF00E6FF00E6FF00D9FF004CFF00C0FF00
CCFF00CCFF00C0FF00B3FF0099FF0099FF0080FF0066FF003FFF0000FF4000FFE60059FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000FF8000FFB3000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFB300FFC000FFCC00FFD900FFF300C0FF00E6FF00FFD900FFCC00
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00D9FF0000FFFF\
B3FF00CCFF00B3FF00CCFF00E6FF00F3FF00F3FF00F3FF00E6FF00D9FF00D9FF00
D9FF00D9FF00CCFF00C0FF00B3FF00A6FF0080FF000CFF007300FF00FF8C00B3FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000FF6600FF6600FFCC000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFB300FFC000F3FF004CFF0059FF00E6FF00FFF300FFD900FFCC00
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00F3FF0099FF00C0FF00\
E6FF00F3FF00D9FF00B3FF00F3FF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00
E6FF00D9FF00D9FF00C0FF00B3FF0099FF0080FF0059FF0000FF330099FF0066FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000F300FF00FF5900FF4000FF4C00FF73000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFB300FFB300FFCC00FFD900FFFF00B3FF00FFF300FFD900FFCC00
FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300FFFF00D9FF0080FF00E6FF00F3FF00\
FFFF00FFFF00FFFF00E6FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
E6FF00E6FF00CCFF00B3FF00A6FF0066FF003FFF0026FF00000000000000000000000000000000\
3F00FF0033FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000FF7300FF6600FF2600FF3300FF73000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFB300FFC000FFCC00A6FF00F3FF00FFFF00F3FF00FFCC00
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600E6FF00E6FF0059FF00CCFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00
F3FF00E6FF00CCFF0099FF0000FFF300FFA600E6FF33FF0000FF0C00FF1900FFCC00CCFF00FFB3\
00FFBF00FFCC000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000CFF00000000FF3300FF0C00FF0C00FF1900FF59000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFB300FFC000FFF30099FF00FFD900FFCC00FFCC00FFC000
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFCC00FFD900FFE600FFF300E6FF0000FF26CCFF00F3FF00FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00
F3FF00E6FF00D9FF00B3FF003FFF0000FF8C3FFF0080FF0000FF6659FF0000FF1900FF6600FF19\
00FF3300FFF3000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000FF4000FFB30CFF000CFF0000FF4000FF59000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFB300FFC000FFD900FFF300FFCC00FFC000FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFCC00FFE600FFF300B3FF00C0FF0026FF00E6FF00FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00
E6FF00D9FF00CCFF0026FF0000FF9900FF3380FF0099FF0099FF0073FF00F300FF4CFF003FFF00\
00FF4000E6FF4C00FF00F3FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0066FF00FF9900FF0019FF0026FF0026FF000CFF0000FF26000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFC00099FF00FFC000FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFC000FFC000FFCC00F3FF0073FF008CFF00B3FF00F3FF00CCFF00FFF300FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00F3FF00
CCFF00B3FF0026FF00B3FF00B3FF004CFF00B3FF00B3FF00A6FF0000FFA680FF0073FF004CFF00\
00FF0C0CFF0000FF4000FFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00FF4C00FF5919FF0033FF0033FF0033FF0000FF0000FFB3000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FFA600FFA600FFC000CCFF00FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFC000FFC000FFCC00FFE600E6FF0033FF00E6FF00FFF300FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300F3FF00D9FF00
0CFF008CFF00CCFF00D9FF00D9FF00A6FF00CCFF00CCFF00C0FF00A6FF0099FF008CFF0066FF00\
59FF0033FF0000FF0000FF4000FFB300BFFF0000FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000003F00FF00CCFF000000\
00000026FF000066FF3FFF004CFF003FFF000CFF0000FF00000CFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FFA600FFCC00FFB300FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFC000FFC000FFCC00E6FF0073FF00CCFF00FFFF00FFE600FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFF300F3FF008CFF00
B3FF0033FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF0099FF0080FF00\
59FF0000FF1900000000FFA600BFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000099FF00000000FFF3\
19FF004CFF0059FF0059FF0059FF004CFF0033FF000CFF0000FFA600B3FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFC000FFD90019FF00F3FF00FFE600C0FF00FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF30099FF00D9FF00
E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF0073FF004CFF00\
3FFF0026FF0000FF1900A6FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000005900FFA600FF0CFF000CFF00\
33FF0059FF0066FF0066FF0066FF004CFF0026FF003300FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFC00099FF00FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFF300
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00C0FF00B3FF0099FF0059FF000059FF\
00000000FF2600FF6600FFFF000000000000000000000000000000000000000000
9900FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000003300FF00FFCC00FFBF1900FF00FF263FFF0059FF00\
00000066FF0073FF0073FF0073FF00C000FF26FF0000FF19000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600
FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF0073FF0000FFFF4CFF0000FF4C00FF66\
33FF000026FF0080FF000000000000000000000000000000000000000000000000
F300FF00B3FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FF000000000000000CFF00FF9900000000CCFF19FF0066FF0073FF00\
73FF0080FF0080FF0080FF0080FF0066FF0059FF0019FF0000000000CCFFD900FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600
FFE600FFF300FFF300FFF300FFFF00F3FF00E6FF00CCFF00B3FF00B3FF00A6FF0000FF7380FF00\
66FF0019FF0000CCFF00CCFFB300FF000000000000000000000000000000000000
00000000FFA60033FF0000000026FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000FF0000000000000000000019FF00000000FF4000FF4000000000000073FF008CFF00\
8CFF008CFF008CFF008CFF0080FF0073FF0059FF0033FF0000FF1900FFA60073FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00C0FF00A6FF0099FF00\
00BFFF00FF2600FF1900FF8C000000000000000000000000000000000000000000
00000000FFBF00000000000000FFBF0000000000000000FF000000000000000000000000000000\
000000000000000000000000000000000000000000CC00FF000000000000000000
00000000FFBF00FFB300FFB3000000B300FF00FFBF3FFF0066FF0066FF0019FF0080FF0099FF00\
99FF0099FF0099FF0099FF0080FF0073FF004CFF00D900FF000000C000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00C0FF00A6FF0099FF00\
73FF004CFF0000FF8CE600FF0033FF0000000000000000000000000000001900FF
00000000FF0CCC00FF00FF1900FF80CC00FF00000000FFA600FFFF00FFCC004CFF000000000000\
000000000000000CFF6600FF0000000000002600FF2600FF000000000000000000
3F00FF00FF8C00FF19004CFF00D9FF00000033FF000000FF8CFF008CFF0000000066FF0099FF00\
A6FF00A6FF00A6FF0099FF0073FF0000FFFF33FF0000BFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFE600FFE600FFF300FFF300FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF003FFF0073FF00\
00FF193FFF0019FF0000FF4C00D9FF00000000000000CCFF00FFFFB300FF00FFF3
00FF0C0CFF0033FF0000FF197300FF00000000FF4C00FF1900FF3300FFBF000000000000000000\
00000000000000000000FF8C00FFE600000000FF4000BFFF004CFF0C00FF000000
0C00FF00FF4C26FF0000000000FF9900FF0C59FF008CFF0099FF00A6FF0073FF0000FF26A6FF00\
B3FF00B3FF00B3FF00A6FF0073FF0073FF0073FF004CFF0000FFCC000000000000
0C00FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900
FFE600FFE600FFF300FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF00B3FF0099FF0059FF00\
008CFF00FFCC00FF1900FF8000F3FF00000000000000000000FF809900FF00FF40
0CFF0059FF0059FF0000FFBF00FF333FFF0033FF0026FF0000FF8C00FFD90059FF000000000000\
00000000000000000000FF4C00FF7300FF5900FF0000FF2600FF40000000D900FF
7300FF00FF6666FF0019FF00000CFF008CFF00FFE680FF00A6FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00A6FF0099FF0080FF0033FF000CFF0000BFFF00FFA6
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900
FFE600FFE600FFF30000FF7399FF00D9FF00D9FF00C0FF004CFF00A6FF00A6FF008CFF0066FF00\
19FF0000FFF300FF8C00000000D9FF00FFA600FF4C00B3FF00FF0000FFA619FF00
59FF0080FF0080FF004CFF003FFF0066FF0066FF0033FF0000BFFF00FF4C0000000C00FF000000\
0000001900FF00000000FF1933FF0019FF0033FF000CFF0000FF3300F3FF000000
00FFBF59FF0080FF008CFF0073FF0000FF0066FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00A6FF0099FF0080FF0066FF0033FF0000FF1900FF8C
00BFFF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFD900
FFE600FFF300FFF300F3FF00A6FF0080FF0019FF00A6FF004CFF0059FF0066FF0066FF0019FF00\
00FF408000FF00FF8000FF2600FF4C00A6FF00FF193FFF004CFF0000FFA63FFF00
8CFF0099FF0099FF0033FF0080FF008CFF0073FF0026FF0033FF000CFF0000FF4000FFA6000000\
0000000000FF00FF5900FFF359FF0066FF003FFF0000FF4000FFBF00000000FFA6
0CFF0073FF00A6FF00B3FF00A6FF0099FF0080FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00B3FF00A6FF0099FF004CFF000CFF0000FF8C000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600
FFE600FFF300FFFF00F3FF00E6FF0099FF0033FF0059FF0000FF0C00FF3300F3FF00FF3300B3FF\
00FFCC0CFF0026FF0059FF0000FF6600FF4C00FF260CFF008CFF004CFF0000FFCC
66FF00B3FF00A6FF0000FF6699FF0099FF008CFF0073FF0059FF0019FF0000FFFF00FF99000000\
0000000000000000FF66FF0073FF0080FF003FFF0000FFF300FF5900FF0059FF00
99FF0000FF19B3FF00C0FF00C0FF00A6FF0000F3FFA6FF00CCFF00CCFF00D9FF00D9FF00D9FF00\
CCFF00CCFF00C0FF00B3FF0099FF008CFF004CFF0000FFBF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFD900FFE600FFF300
FFF300FFFF00F3FF00E6FF00D9FF00B3FF0073FF0000FF6626FF0073FF0080FF0000FF264CFF00\
00FF7373FF0059FF008CFF0073FF0000FF0C19FF008CFF00B3FF00A6FF0059FF00
B3FF00C0FF00C0FF00C0FF00B3FF00A6FF008CFF0073FF0059FF0033FF0000FF1900000000B3FF\
00B3FF00FF330033FF80FF0099FF0099FF000000000C00FF00FF8000FF8073FF00
A6FF00C0FF00CCFF00CCFF00CCFF00C0FF0000FF8C99FF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00C0FF0000FFCC00FFD90C00FF00FF0000FF8C4C00FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFFF00FFFF00D9FF00
F3FF00F3FF00A6FF00CCFF00C0FF0059FF0000FF000CFF0080FF0099FF00B3FF004CFF00A6FF00\
33FF00B3FF0073FF00B3FF000019FF26FF0099FF00B3FF00CCFF00C0FF0000FFA6
C0FF00CCFF00CCFF00CCFF00C0FF00A6FF004CFF004CFF000CFF000CFF0000FFD9008CFF00FF33\
00FF0019FF008CFF0000FFA6B3FF00B3FF0099FF0000FF5900FFE600FFA64C00FF
A6FF00CCFF00D9FF00D9FF00D9FF00CCFF00B3FF00B3FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00C0FF004C00FF80FF0099FF008CFF0073FF0000000000000000E6FF
0000000040FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFC000FFC000FFCC00FFD900E6FF00B3FF0000FF0C66FF00
66FF008CFF0073FF000033FF80FF0059FF0000FF6600FF2680FF00B3FF00CCFF00CCFF00CCFF00\
E600FFCCFF00D9FF00CCFF0000F3FF00FF198CFF00CCFF00D9FF00D9FF00B3FF00
CCFF00D9FF00D9FF00D9FF00C0FF00A6FF0073FF0000000000FF1900FFD900FF6600000066FF00\
4CFF00C000FFB3FF00C0FF00CCFF00C0FF004CFF0099FF0080FF0000FFB373FF00
80FF00CCFF00D9FF00E6FF00E6FF00E6FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00CCFF00C0FF00C0FF00B3FF00A6FF0080FF0000FF0000000000F3FF
00FF6600FFCC000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFE600E6FF00FFFF00FFFF00
F3FF00E6FF00C0FF008CFF0019FF0000FFA63FFF008CFF0099FF0000FF40D9FF00D9FF00D9FF00\
C0FF00E6FF00E6FF00D9FF00CCFF0000FF73C0FF00D9FF00E6FF00F3FF00E6FF00
E6FF00E6FF00E6FF00D9FF0000FF808CFF0000FFFF00FF8019FF0059FF0066FF0066FF00A6FF00\
B3FF0066FF00C0FF00D9FF00D9FF00D9FF00CCFF00CCFF00008CFF00FFBFA6FF00
CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00D9FF00CCFF00CCFF00C0FF00B3FF008CFF0073FF0000000000FF4C
00FF2600FFBF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFE600
FFF300FFFF00E6FF00B3FF00A6FF0066FF0026FF0080FF00C0FF00CCFF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF0080FF00D9FF00E6FF00F3FF00FFFF00FFFF00
FFFF00F3FF00F3FF00E6FF00CCFF00B3FF004CFF0000FFE600FF0073FF0099FF00B3FF00C0FF00\
CCFF00B3FF0000FF66D9FF00E6FF00E6FF00E6FF00D9FF00CCFF0066FF00C0FF00
D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF0080FF0059FF0033FF00
00FF1900FF5900FFFF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFD900FFE600
FFF300FFFF00F3FF00D9FF008CFF0033FF0066FF0099FF00C0FF00D9FF00E6FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00E6FF0000FF80D9FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00E6FF00CCFF0066FF003FFF0000FFB300FF8066FF0026FF00C0FF00CCFF00\
D9FF00E6FF00D9FF00F3FF00F3FF00F3FF00F3FF00E6FF00CCFF0000FFD9C0FF00
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF008CFF0000FF193FFF0000FF0C
00FF59000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900
FFE600FFFF00C0FF00B3FF0080FF0000FF3300000033FF00B3FF00D9FF00E6FF00FFFF00FFFF00\
FFF300FFF300FFF300FFFF00F3FF0000FF0CD9FF00FFFF00FFF300FFF300FFF300
FFF300FFFF00FFFF00D9FF0073FF0099FF0066FF000066FF0080FF00FFE673FF0080FF00D9FF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00F3FF00F3FF00CCFF0000FF40B3FF00
D9FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00E6FF00D9FF00CCFF00B3FF0073FF0000FF2600B3FF00FF73000CFF
00D9FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900
FFE600FFFF00D9FF00CCFF00A6FF003FFF0000FFCC8CFF0099FF0059FF0073FF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFFF00D9FF00D9FF00FFF300FFF300FFE600FFE600
FFF300FFF300FFFF00B3FF00D9FF00D9FF00B3FF00A6FF0066FF0000FF9900FF26C0FF00E6FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00D9FF0073FF004CFF00
D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00D9FF00CCFF00C0FF00B3FF0080FF0000FFF300FFCC004CFF0059FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900
FFE600FFF300F3FF00D9FF00C0FF0080FF0000FF0099FF00D9FF00D9FF00E6FF00FFFF00FFF300\
FFE600FFE600FFE600FFE600FFE600FFFF00FFFF00FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFFF00FFFF00F3FF00E6FF00C0FF0066FF0000FF0C66FF0000FFCCD9FF00\
F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFFF00D9FF0026FF004CFF00
D9FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
F3FF00E6FF00CCFF00C0FF00A6FF008CFF0000FFA600D9FF6600FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600
FFF300FFFF00E6FF00CCFF0099FF0059FF0059FF00B3FF00E6FF00F3FF00FFFF00FFF300FFE600\
FFE600FFE600FFD900FFD900FFE600FFE600FFE600FFE600FFD900FFD900FFE600
FFE600FFE600FFE600FFF300FFF300FFFF00E6FF008CFF0000FF2699FF00CCFF00D9FF003FFF00\
F3FF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300F3FF00D9FF0026FF00
D9FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
F3FF0000FF808CFF0000E6FF00000080FF0026FF0000FF260080FF0000009900FF
000000000CFF0000000000005900FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFE600F3FF00
F3FF00E6FF00A6FF00B3FF0066FF0066FF008CFF0099FF00D9FF00FFFF00FFF300FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFF300FFFF00F3FF00CCFF004CFF00C0FF00F3FF00F3FF00FFFF00\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFF300FFF300F3FF00E6FF00
FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00\
E6FF00A6FF0000FF0073FF00C0FF00C0FF0099FF0099FF0059FF000026FFA600FF
00000000FFFF00000000000000FFD9000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFE600FFFF00
E6FF0033FF003FFF0073FF0059FF00C0FF00D9FF0099FF00CCFF00FFFF00FFF300FFE600FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFF300FFF300F3FF00D9FF0073FF00E6FF00FFFF00FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFFF00
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00\
A6FF00C0FF0099FF00CCFF00D9FF00D9FF00CCFF00B3FF0099FF0000FF0000D9FF
00FFB300FF1900FF2600FF3300FFA6004CFF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300
E6FF0099FF00B3FF00E6FF00D9FF00F3FF00FFFF00F3FF0000FF73F3FF00FFF300FFE600FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFF300F3FF0080FF00E6FF00FFFF00FFF300FFF300FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFFF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF0099FF0000BFFF00FFF3
00FF9919FF0026FF0000FF8C000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600F3FF00
D9FF0080FF00CCFF00FFFF00FFF300FFF300FFF300FFF300C0FF008CFF00FFF300FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFE600FFE600FFFF00CCFF0019FF00D9FF00FFFF00FFF300FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00A6FF0000000099FF0066FF00
4CFF0059FF0033FF0000FF40000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300E6FF00
A6FF00CCFF00CCFF00FFF300FFE600FFE600FFD900FFE600FFF300B3FF00F3FF00FFD900FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFE600FFF300FFFF00CCFF003FFF00D9FF00FFFF00FFF300FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300\
FFF300FFFF00FFFF00FFFF00F3FF00E6FF00E6FF00D9FF00C0FF00B3FF0099FF00
8CFF0073FF0059FF0033FF0000FF6600FF99000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300F3FF00A6FF00
CCFF00FFF300FFFF00FFF300FFD900FFD900FFD900FFD900FFD900FFE600FFFF00FFD900FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFD900FFE600FFFF00D9FF0000FF1980FF00E6FF00FFFF00FFE600FFE600FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300\
FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF00A6FF00
8CFF0059FF004CFF0019FF0000FF0C00FF5900FFCC000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFC000FFCC00FFD900FFE600FFE600F3FF0080FF00E6FF00FFF300
FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFD900FFD900FFF300E6FF0080FF0099FF00D9FF00FFFF00FFE600FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF0099FF00
8CFF0059FF0000000000000000FFF3000000C000FF0040FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFB300\
FFC000FFC000FFCC00FFCC00FFF3000CFF00E6FF00CCFF00C0FF00FFF300FFE600
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFD900FFF300F3FF00A6FF0000FFA619FF0099FF00FFE600FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00C0FF0099FF004CFF00
59FF003FFF0000FF66000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFC000\
FFC000FFCC00FFCC00FFD900FFE600F3FF0066FF00D9FF00F3FF00FFF300FFD900
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFD900FFF300D9FF0073FF00B3FF00F3FF00FFF300FFE600FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFF300FFF300FFFF00FFFF00F3FF00A6FF002600FFA6FF00A6FF008CFF0000FF0C
2600FF19FF0000FFB3008CFF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFC000FFCC00\
FFCC00FFD900FFD900FFE600FFF300C0FF0000FF4CD9FF00FFF300FFD900FFD900
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFCC00FFF300C0FF00B3FF0000FF0CCCFF00F3FF00FFE600FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600\
FFF300FFF300FFFF00FFFF00F3FF00D9FF00C0FF004CFF0000F3FF4CFF0000FF40
2600FF00FF4000FFA600B3FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFCC00CCFF00\
D9FF00FFF300FFF300F3FF00D9FF00C0FF008CFF00F3FF00FFE600FFD900FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFCC00FFD900FFE600FFFF00CCFF004CFF00E6FF00FFF300FFD900FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600\
FFF300FFF300FFFF00F3FF00F3FF00E6FF00CCFF0080FF0000FFBF00D9FF00FFFF
0026FF00FFB3000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFD900\
FFF300E6FF003FFF00A6FF00B3FF00B3FF00E6FF0080FF00F3FF00FFD900FFCC00
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFCC00FFD900FFFF0080FF003FFF00F3FF003FFF00FFD900FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300\
FFF300FFFF00FFFF00F3FF00E6FF00CCFF00C0FF0080FF0019FF000059FF00CCFF
D900FF0059FF8000FF0000000000000000000000000000000000000000005900FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00\
FFD900FFF300D9FF0099FF00E6FF00FFFF00FFF300FFE600FFE600FFCC00FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFCC00FFE60000FF59FFFF00FFD900FFD900FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300\
FFFF00F3FF00E6FF00E6FF00D9FF00B3FF0066FF004CFF0000FF0C00FF800099FF
0000000000000000008000FF00000000000000000000000000000000000000A6FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00\
FFD900FFF300E6FF0099FF00F3FF00FFF300FFE600FFD900FFCC00FFCC00FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFCC00FFF300FFFF00FFD900FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00\
A6FF00C0FF0000FF4000FF00A6FF000019FF00FF9900FF8C00000000A6FF000000
B300FF00000000FFBF0099FF00000000CCFF00000000000000000000000000FFCC000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFD900\
FFE600FFFF008CFF0000FF0C00FF4CFFF300FFD900FFCC00FFCC00FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFC000FFCC00FFF300FFF300FFCC00FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600CCFF00D9FF00CCFF00\
A6FF0000FF994CFF00A6FF00CCFF0059FF0066FF0000FFE673FF0000D9FF00FF19
00FFBF3300FF8C00FF00FF4000FF406600FF0000000080FF00FF7300FF40008CFF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFD900FFE600\
FFE600FFFF00E6FF00CCFF00FFFF00FFE600FFD900FFCC00FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFC000F3FF00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFF300CCFF0026FF00\
00FF668CFF0033FF00E6FF00E6FF00E6FF00CCFF00A6FF00C0FF00A6FF000080FF
0CFF008000FF00000000FF3319FF0000000000FFBF00FF2600FF6600FF0000FF4C0026FF000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFCC00FFFF00F3FF00\
E6FF00E6FF00C0FF00A6FF00F3FF00FFE600FFD900FFCC00FFC000FFC000FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFFF00A6FF0000FF26\
80FF00B3FF00F3FF00F3FF00FFFF00F3FF00E6FF00D9FF00D9FF0066FF00B3FF00
80FF0000FF000C00FF00FF404CFF004CFF003FFF004CFF003FFF0019FF0000FF4000FFE65900FF\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FFA600FFB300FFC000FFF300FFCC00FFCC00FFD900FFE600FFF300D9FF00\
4CFF0080FF00B3FF00D9FF008CFF00FFFF00FFE600FFCC00FFC000FFC000FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFF300D9FF0059FF0033FF00\
E6FF00E6FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00D9FF00CCFF00
00FFD9A600FF00FFD90CFF0066FF0073FF0066FF0073FF0059FF0019FF000000000033FF000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FFB300FFFF00CCFF00C0FF008CFF00E6FF00FFF300E6FF00E6FF0026FF00\
E6FF00F3FF00E6FF00FFF300FFF300CCFF00C0FF00FFD900FFC000FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD9004CFF00FFFF00FFFF008CFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00E6FF00CCFF00
19FF0026FF0033FF000019FF73FF0099FF0099FF0080FF0059FF00000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FFA600FFB300FFD900FFD900FFD900FFE600D9FF00D9FF003FFF00E6FF00\
FFFF00FFF300FFE600FFD900FFD900FFD900FFE60059FF00FFC000FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00D9FF000099FF
B3FF00B3FF00B3FF008CFF00A6FF00B3FF00A6FF0080FF0059FF001900FF0000000000000040FF\
0000000033FF000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFC000FFCC00FFD900FFF300E6FF00F3FF00\
FFF300FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00C0FF00B3FF00
D9FF00D9FF00CCFF00C0FF00C0FF00C0FF00A6FF003300FF73FF004CFF00000000000000000000\
00FF66000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00FFD900FFE600D9FF00E6FF00\
FFF300FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00F3FF00F3FF00
F3FF00E6FF00E6FF00D9FF00CCFF00CCFF00B3FF0099FF0099FF0080FF000CFF003300FF0CFF00\
00FF4C000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFC000FFCC00FFF300C0FF00C0FF00\
FFFF00FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00FFFF00
F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF00A6FF008CFF0073FF0059FF0033FF00\
00FF0C00FFB30026FF000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00FFF300C0FF00A6FF00\
FFFF00FFD900FFCC00FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00
FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF00B3FF00A6FF008CFF0080FF0059FF003FFF00\
19FF0000FF1900FF99000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFC000FFCC00FFE600F3FF00E6FF00\
FFE600FFCC00FFC000FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300
FFFF00FFFF00F3FF00E6FF00CCFF00C0FF00C0FF00A6FF0073FF0080FF0073FF0000FF0C19FF00\
00FF3300FF5900FF9900FFA6B300FF000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFCC00FFD900FFF300F3FF00F3FF00\
FFE600FFCC00FFC000FFC000FFB300FFB300FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300
FFFF00FFFF00F3FF00CCFF0059FF0080FF00A6FF0099FF0080FF00008CFF4CFF0026FF000033FF\
000000C000FF0000000000000000000026FF000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FFA600FFB300FFC00099FF00FFE60073FF00F3FF00A6FF008CFF00\
F3FF00FFD900FFC000FFC000FFB300FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFE600FFF300FFF300
FFFF00F3FF00E6FF00CCFF0080FF0066FF0026FF0000FF4C3FFF0000BFFF00FF1900FFB3C000FF\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FFA600FFB300FFC000FFD900F3FF00E6FF00D9FF00FFF300FFFF00\
FFFF00FFE600FFCC00FFC000FFB300FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFF300FFFF00
FFFF00F3FF00E6FF00D9FF00CCFF00B3FF0080FF0000FFA600FF4C00F3FF00000000FFBF00BFFF\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FFA600FFA600FFB300FFC000FFD90000FF19FFF300FFD900FFD900FFCC00\
FFD900F3FF00FFE600FFCC00FFB300FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00FFFF00
F3FF00F3FF00E6FF00D9FF00CCFF00C0FF0099FF003FFF00B300FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FFA600FFB300FFB300FFCC00D9FF004CFF00FFD900FFC000FFC000FFC000\
FFC000FFD900FFE600FFCC00FFB300FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00D9FF00CCFF00A6FF008CFF0033FF0000FFF300000000BFFF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF9900FFA600FFA600FFB300FFCC00FFF300FFFF00FFD900CCFF00FFB300FFB300FFB300\
FFB300FFB300FFB3008CFF00FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFFF00F3FF0073FF00C0FF00D9FF00
D9FF00D9FF00C0FF00CCFF00C0FF00A6FF0066FF0000FFFF00000000FF9900FFB30019FF000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF9900FF9900FFA600FFB300FFCC00F3FF00FFCC00FFC000FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFF300D9FF0033FF0099FF0019FF00
C0FF00C0FF0080FF00A6FF00B3FF00A6FF0080FF003FFF0019FF0000FF400099FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF9900FF9900FFB300FFD900E6FF00B3FF00FFC000FFB300FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFFF00F3FF00E6FF00CCFF00
00FF8066FF000040FF8CFF004CFF0080FF0073FF003FFF0019FF0000FF5900F3FF000000000000\
0000000000000000000000000000000000000000000000000000000000000040FF
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF9900FF9900FFB300FFCC00FFE600FFC000FFB300FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFFF00F3FF00D9FF00
99FF0000FFFF00FF6600FFA600FFBF66FF0066FF0033FF008000FF000000000000000000000000\
00000000000000000000000000000000000000000000000000000000000000D9FF
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF9900FF9900FFB30000FF26FFE600FFB300FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFF300F3FF00D9FF00
A6FF0000FF1900FF1900FF9900FF590040FF3FFF0000FFCC004CFF000000000000000000000000\
00000000000000000000000000000000000000000000000000000000000000FFB3
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FFA600FFF300FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00A6FF00
99FF0059FF004CFF0000FFCC00FFE600FF0000FF0000FF0C00FF8C000000000000000000000000\
00000000000000000000000000000000000000000000000000000000000000FF66
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FFA600FFA600FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00E6FF00
CCFF00A6FF0019FF0000FF2600BFFF000CFF00FF3300FF3300FFF300A6FF000000000000000000\
00000000000000000000000000000000000000000000000000000000FF6600FF19
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00E6FF00D9FF00
C0FF00A6FF008CFF003FFF0000FF0C8C00FF00FF9900FF991900FF000000000000004CFF8000FF\
8000FF00A6FF0000000033FF000000000000008CFF00000000000000000019FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFE600FFE600FFF300FFFF0000FF66B3FF00D9FF00C0FF00
00FF0C8CFF003FFF000CFF000CFF0000FF4C5900FF0000FF008CFF00000000FF803300FF7300FF\
D900FF00FF5900FFCC00FFE6004CFF00000000FFCC0066FF0026FF33FF003FFF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900\
FFD900FFE600FFE600FFE600FFF300FFF300FFFF00E6FF0000FF738CFF00A6FF00
3FFF0019FF0000FF662600FF00E6FF2600FF00CCFF00000000FF7300FF7300FF1900FF6600FF59\
00FF8C0CFF0000FF80000000008CFF00000000FF4C19FF0019FF0059FF0059FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600\
FFF300FFF300FFF300FFF300FFFF00FFFF00E6FF00CCFF0059FF0000FFB30CFF00
00FF2600000000FF5900FF1919FF0000FF2600A6FF0000000099FF00FF2619FF0033FF0026FF00\
4CFF0026FF0000FFCC00FFFF0000000040FF0040FF00FF0073FF0080FF0073FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFE600C0FF00FFF300FFF300\
FFFF00CCFF00E6FF00CCFF00E6FF00D9FF0019FF0099FF004CFF0000D9FF00B3FF
7300FF000CFF80FF0073FF0066FF000000FF00FF4000FF190019FF00FFBF00FFA659FF0066FF00\
73FF004CFF000066FF00FFF300FF6600FFCC00FF334CFF008CFF008CFF0073FF00
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFE600F3FF00D9FF00CCFF00\
CCFF0073FF003FFF0000FF80CCFF0000FFA600FF1959FF0080FF0000FFF300FFB3
99FF0080FF00B3FF00B3FF0080FF0000FF8C3FFF004CFF0000FF5900FF6600FF0C4CFF0080FF00\
8CFF000000008CFF0019FF0000FF998CFF008CFF0073FF00A6FF00A6FF0080FF00
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFB300FFB300FFC000FFCC00FFCC00FFD900FFD900FFF30000FF0073FF004CFF00\
00FF1999FF0000FFBFF3FF00FFFF00F3FF00D9FF00C0FF00CCFF00B3FF0019FF00
99FF00D9FF00D9FF00CCFF0073FF000080FF8CFF0073FF0000FF3300000000FFF33FFF008CFF00\
A6FF00B3FF00A6FF0080FF008CFF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFB300FFB300FFC000FFD900FFE600FFD900FFE600F3FF00FFFF00E6FF00B3FF0026FF00\
0CFF00D9FF00F3FF00FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF0000FF00
CCFF00F3FF00F3FF00CCFF00B3FF00C0FF00C0FF0099FF0080FF0000FF8C00FF8C00E6FF80FF00\
B3FF00C0FF00C0FF0000FFCCA6FF00C0FF00CCFF00CCFF00CCFF00C0FF00B3FF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFB300FFB300FFC000FFFF00A6FF00F3FF00F3FF00E6FF0080FF00B3FF000059FFCCFF00\
C0FF00E6FF00FFF300FFE600FFE600FFE600FFE600FFE600FFF300FFFF00CCFF00
FFFF00FFF300FFFF00E6FF00E6FF00F3FF00E6FF00C0FF0073FF0026FF00A600FF00FF0099FF00\
C0FF00CCFF00CCFF0000FFBF80FF00CCFF00D9FF00D9FF00CCFF00C0FF00A6FF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFB300FFB300FFC000FFCC00FFE600CCFF0059FF00A6FF004CFF0073FF00C0FF00E6FF00\
F3FF00D9FF00FFE600FFE600FFD900FFD900FFD900FFD900FFE600FFF300F3FF00
FFF300FFE600FFE600FFF300FFFF00FFFF00E6FF00B3FF0000FF3300FF2600FF990080FF00FFCC\
CCFF00E6FF00E6FF00D9FF00D9FF00E6FF00E6FF00E6FF00D9FF00C0FF00008CFF
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFB300FFB300FFC000FFCC00FFD90033FF00CCFF00B3FF000CFF003FFF00A6FF00F3FF00\
FFF300FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFF300FFF300FFFF00E6FF00A6FF000C00FF00FFD959FF00008CFF\
D9FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF00B3FF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFB300FFB300FFC000FFCC00FFD900FFF300F3FF00B3FF00B3FF00C0FF0080FF00FFFF00\
FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFE600FFF300FFFF00E6FF008CFF0000FF8CD9FF00D9FF004CFF00\
E6FF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFB300FFB300FFC000FFCC00FFE600FFFF00C0FF0000FF99E6FF00F3FF0099FF00F3FF00\
FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFE600FFF300F3FF0000D9FFD9FF00E6FF00F3FF00FFFF00E6FF00\
FFFF00FFFF00FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFB300FFB300FFC000FFD900F3FF00C0FF00C0FF00A6FF00FFFF00FFF300FFF300FFFF00\
FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFF300D9FF0033FF00F3FF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFB300FFB300FFC000FFCC00FFE600F3FF00A6FF0080FF00D9FF00FFF300FFE600FFD900FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFD900E6FF004CFF0000FFBFFFFF00FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00D9FF0073FF0099FF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600
FFB300FFC000FFD900FFE600F3FF0080FF00D9FF00D9FF0000FF0CFFF300FFD900FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFD900FFE600A6FF0099FF00FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFFF00E6FF0073FF00004CFFA6FF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600
FFB300FFD90080FF00F3FF00FFF300F3FF00FFE600FFE600E6FF00FFE600FFCC00FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFE600E6FF00FFF300FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFF300F3FF00B3FF0000FF0066FF00CCFF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600
FFC000FFFF00FFFF00FFCC00FFCC00FFCC00FFCC00FFCC00CCFF0099FF00FFCC00FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFF300FFFF00CCFF0026FF00B3FF00E6FF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600
FFCC00FFC000FFCC00FFC000FFB300FFB300FFB300FFC000FFC000FFCC00FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFE600FFE600FFFF00A6FF0000FF40E6FF00F3FF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFE6008CFF00FFFF00F3FF00FFFF00FFFF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFF300FFF300FFF300
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFE600FFE600FFF300
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFF300FFF300FFF300FFF300
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFCC00FFD900FFD900FFE600FFE60026FF00F3FF00FFFF00F3FF00FFFF00FFFF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00\
FFD900D9FF00FFFF00FFF300FFFF00C0FF0099FF00C0FF0000FF00E6FF00F3FF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00\
FFD900FFF300B3FF00E6FF0026FF00B3FF0000FFB300FF4000FF6600FF33CCFF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFCC00\
FFD900FFF300B3FF0073FF0066FF0033FF0059FF00B3FF00C0FF00CCFF008CFF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900\
FFF300E6FF00CCFF0073FF0080FF00C0FF00C0FF00E6FF00F3FF00E6FF0099FF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFE600FFF300\
FFFF0000FFBF0033FF00FF40A6FF00F3FF00E6FF00FFFF00FFFF00FFFF00E6FF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFCC00F3FF00D9FF0073FF00\
4CFF0000FF59CCFF00CCFF00E6FF00FFFF00FFF300FFF300FFF300FFF300FFFF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFD900FFE600\
FFF300C0FF00F3FF00FFF300FFFF00FFE600FFE600FFE600FFE600FFF300FFF300
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFCC00\
FFD90073FF00FFE600FFE600FFD900FFD900FFD900FFD900FFE600FFE600FFF300
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFD900FFE600FFF300
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFE600FFE600FFF300CCFF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFCC00FFE600D9FF00F3FF0080FF0000FF66
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFF30080FF0080FF0066FF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFCC00FFD900FFE600FFFF00CCFF00E6FF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300B3FF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00E6FF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFC000FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFE600F3FF00F3FF00FFFF00FFFF00FFFF00F3FF00B3FF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000
FFCC00D9FF00FFFF00FFD900FFD900FFD900FFD90000FF00FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600F3FF000CFF00C0FF00F3FF00F3FF00E6FF00CCFF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000
FFCC00FFE600A6FF00FFE600FFE600FFE600FFF30099FF00FFFF00FFFF00FFF300FFE600FFE600\
FFE600FFE600FFE600FFF300FFFF00D9FF0099FF00D9FF00D9FF00CCFF00B3FF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFCC00FFF30066FF00CCFF00FFFF00A6FF00E6FF0099FF0073FF004CFF00CCFF00FFFF00FFF300\
FFF300FFF300FFFF00FFFF00E6FF00C0FF0059FF00B3FF00B3FF0059FF000CFF00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFD900FFE600C0FF00B3FF008CFF008CFF0033FF0080FF00E6FF00F3FF00E6FF00E6FF00F3FF00\
F3FF008CFF00E6FF00D9FF0073FF000CFF000080FF59FF0073FF0000FF19B3FF00
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600\
FFC000FFF300FFD900F3FF00FFCC00FFCC00FFC000FFC000FFCC00FFD900FFE600
FFE600FFF300F3FF00B3FF00CCFF00E6FF008CFF00FFFF00FFF300FFF300FFFF00C0FF0059FF00\
A6FF004CFF00B3FF0080FF00B3FF00CCFF00A6FF00E6FF00E6FF00E6FF00D9FF00
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600\
FFB300FFE600E6FF00D9FF008CFF00FFD900FFCC00FFCC00FFD900FFE6008CFF00
E6FF00F3FF00E6FF004CFF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFF300F3FF00\
CCFF004CFF00D9FF008CFF00E6FF00F3FF0000FF33F3FF00FFF300FFFF00C0FF00
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600\
FFB300FFC000FFCC00FFD900FFFF00FFF300FFE600FFD900FFE600FFF300F3FF00
99FF0080FF0099FF00C0FF00FFFF00FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFF300\
FFF300FFF300FFFF00CCFF00F3FF00FFE600FFF300FFF300FFE600FFE600FFF300
FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600\
FFA600FFB300FFC000FFCC00E6FF00CCFF00FFFF00FFFF00FFF300E6FF00C0FF00
8CFF0033FF00CCFF00F3FF00FFF300FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFE600E6FF00FFE600FFD900FFD900FFD900FFD900FFD900FFE600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFB300FFC000FFCC00FFF3008CFF00A6FF00C0FF00E6FF00B3FF00D9FF00
E6FF003FFF00A6FF0033FF00FFF300FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD90073FF00FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFE600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFB300FFB300FFC000FFD900FFE600D9FF00C0FF0000FF99C0FF00F3FF00
FFFF00FFF300F3FF00FFF300FFE600FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFC000FFC000FFC000FFC000FFC000FFCC00FFD900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFB300FFB300FFC000FFCC00FFD900FFF300FFFF00D9FF00A6FF00F3FF00
FFF300FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFC000FFC000FFC000FFCC00
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFB300FFB300FFC000FFCC00FFD900FFE600FFF3008CFF00A6FF00FFFF00
FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFF300F3FF0073FF00A6FF00
FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFC000FFCC00FFD900FFD900FFF300FFFF00D9FF0059FF00FFF300
FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300\
FFB300FFC000FFCC00FFD900FFFF00FFF300E6FF008CFF00E6FF00FFFF00FFE600
FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300\
FFC000FFD900FFFF00FFFF0099FF00E6FF00C0FF008CFF00E6FF00FFFF00FFE600
FFD900FFCC00FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFC000FFCC008CFF0073FF0099FF0000FFD900000000FF26D9FF00F3FF00FFF300
FFE600FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000\
FFC000FFCC00FFE600FFF300F3FF0026FF0000000059FF00B3FF0099FF0066FF00
4CFF00FFD900FFC000FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00\
FF4C00FF4C00FF4C00FF4C00FF4C00FF4C00FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFCC00FFD900FFF300FFFF00CCFF00B3FF008CFF00CCFF00E6FF00E6FF00
E6FF00FFD900FFC000FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFCC00FFE600FFFF003FFF00FFFF00\
FFE600FFE600FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00E6FF00CCFF00\
73FF0000FFFF0099FF99FF00C0FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00
B3FF0026FF00C0FF00CCFF00CCFF00CCFF00C0FF008CFF008CFF0099FF008CFF0073FF0066FF00\
3FFF0000FF338C00FF00FFBF008CFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000FFA600FF8C000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFF300D9FF00C0FF00\
A6FF00E6FF00FFD900FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00E6FF00CCFF00\
A6FF003FFF0000FF0C00FF4CB3FF00B3FF00CCFF00D9FF00D9FF00D9FF00D9FF00
C0FF0033FF00A6FF00C0FF00C0FF00C0FF00B3FF0099FF0026FF0066FF0073FF0059FF004CFF00\
00000000FF0C00FF4000FFBF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000FFD900FFB300FFCC000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFE600F3FF00C0FF00A6FF00\
FFFF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00E6FF00CCFF00\
99FF0059FF0026FF0073FF0080FF0080FF00C0FF00CCFF00D9FF00CCFF00CCFF00
C0FF008CFF008CFF00A6FF00B3FF00B3FF00B3FF0099FF0080FF0066FF0000FF260CFF0033FF00\
00FF0000F3FF5900FF00FFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000F3FF00FFD900FFE6000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFF300FFFF00CCFF00C0FF00\
FFFF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300CCFF0000FF264CFF0026FF00\
00FF0C4CFF0000A6FF00FF4C4CFF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00
B3FF00A6FF001900FF8CFF0000FF00A6FF00A6FF0099FF008CFF0073FF0000FFFF00CCFF00FF40\
0000000000005900FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000FFFF00E6FF000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFE600F3FF003FFF00\
FFFF00FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00E6FF00D9FF00CCFF00\
C0FF008CFF0059FF000040FF4CFF0066FF00A6FF00B3FF00A6FF00B3FF00B3FF00
A6FF008CFF0000FF6600FF2673FF008CFF008CFF008CFF0080FF0073FF004CFF0019FF0000FF19\
0040FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000BFFF00BFFF000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFE600FFF300CCFF00\
99FF00F3FF00FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00D9FF00\
CCFF00A6FF0000FF5926FF0000FF8066FF008CFF0099FF0000FF1999FF00A6FF00
99FF0073FF0000FF3300FF0000FF7380FF0073FF003FFF0073FF0066FF004CFF0033FF0000FF33\
00FF5900CCFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000066FF0099FF000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFFF00D9FF00\
C0FF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00\
CCFF0099FF00A6FF0080FF0026FF0026FF0000FF1966FF0026FF0080FF008CFF00
80FF0066FF0000FF0C00FF734CFF0066FF0059FF0000FF0059FF0059FF002600FF19FF0000FF0C\
00FF8000E6FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000006600FF0066FF000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFFF00\
8CFF00FFFF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFF300FFF300FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00F3FF00F3FF00E6FF00\
D9FF00CCFF00B3FF00A6FF0080FF0033FF0000FFA600FF4C33FF0066FF003FFF00
66FF0059FF0033FF0000FFA619FF003FFF0033FF003300FF19FF003FFF0026FF0000FF2600FFA6\
0066FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000026FF000000000000000000000000000000000000000000
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFF300\
C0FF00FFFF00FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFFF00A6FF00FFE600FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600
FFF300FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00\
D9FF00CCFF00C0FF00A6FF008CFF0059FF0000FF1900CCFF00F3FF3FFF000CFF00
26FF0026FF0000FF2600FFFF00FF4000FF0C0CFF000000FF0CFF0019FF0019FF0000FF0C00FF4C\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000003300FF000000000000000000000000000000000000000000
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300\
C0FF00E6FF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFF300E6FF00A6FF0099FF00FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFF3008CFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00E6FF00D9FF00\
D9FF00CCFF00A6FF0080FF0073FF003FFF0000FF6600B3FF00FF8C00FF4000FF40
00FF0C00FF0C00FF8C0073FF00000000FFD900FF730080FF00FF3300FF2600FF0C00D9FF00FF66\
9900FF5900FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000B300FF000000000000000000000000000000000000000000
FFC000FFD900FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFFF00\
D9FF00C0FF008CFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300E6FF0099FF00FFFF00FFF300\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFFF00CCFF008CFF00E6FF00F3FF00FFFF00FFFF00FFFF00F3FF00E6FF0073FF00C0FF00CCFF00\
CCFF00C0FF00B3FF008CFF0066FF0019FF0000FF2600E6FF00FFBF00CCFF00E6FF
00FF8C00FF7300FF8C00CCFF0000000C00FF00BFFF00BFFF00FF9900000000FF4C00FF4C00FFA6\
CC00FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFCC00FFD900FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFCC00FFCC00FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300F3FF00\
C0FF00A6FF00E6FF00FFFF00FFF300FFE600FFE600FFE600FFF300FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFF300E6FF004CFF00E6FF00FFF300\
FFE600FFE600FFE600FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300
FFFF00E6FF0099FF0099FF00E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00C0FF0019FF00B3FF00\
C0FF00B3FF00A6FF0099FF0080FF0059FF0000FFA600FF3300FF991900FF000000
7300FF00B3FF000000B300FF0000000000000019FF00000000A6FF00000000FF8C00FF8000FFF3\
3F00FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFD900FFE600FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFF300FFCC00FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00\
E6FF003FFF00E6FF00F3FF00FFFF00FFF300FFFF00F3FF00E6FF00FFF300FFE600
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300E6FF0026FF00E6FF00FFFF00\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFFF00F3FF00CCFF0000FF19D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00A6FF0033FF00\
99FF0073FF0099FF008CFF0059FF0059FF0033FF0000FF1900FF735900FF000000
00000000000000000000000000000000000000000000000000000000000000000000FFD900FFD9\
008CFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
CCFF00A6FF00FFFF00FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFD900C0FF00E6FF00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFF300FFF300F3FF00\
CCFF0073FF0019FF00E6FF00F3FF00FFFF00F3FF00A6FF00C0FF00FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFFF00F3FF0073FF00E6FF00FFFF00\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFFF00F3FF00E6FF00C0FF00B3FF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00B3FF0099FF00\
00FF2600FF0080FF0073FF004CFF0000FF4C00FF0000FF2600FF990026FF000000
00000000000000000000000000000000000000000000000000000000000000000000000000CCFF\
0000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFF300FFFF00FFD900FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFE60080FF00FFE600FFD900\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFF300
FFD900FFD900FFCC00FFCC00FFD900FFD900FFD900FFE60000FF59E6FF00FFFF00FFFF00F3FF00\
CCFF008CFF00B3FF00D9FF00E6FF00E6FF00CCFF0099FF00F3FF00FFFF00FFF300
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00C0FF00E6FF00F3FF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00F3FF00E6FF00CCFF0000FF19A6FF0080FF00CCFF00CCFF00CCFF00C0FF00B3FF008CFF00\
00FF5900FF593FFF0059FF004CFF000CFF0000FFB300FFA60099FF000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000C00FF\
1900FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFF300FFFF00FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFE600D9FF00FFFF00FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFF30073FF00
FFF300FFD900FFD900FFD900FFD900FFD900FFE600FFF300E6FF0073FF00E6FF00E6FF00E6FF00\
CCFF00A6FF0099FF00C0FF00C0FF00CCFF0026FF00D9FF00F3FF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00E6FF0099FF00CCFF00E6FF00\
F3FF00FFFF00FFFF00FFFF00F3FF00E6FF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00E6FF00D9FF00B3FF0073FF0000FF0099FF00B3FF00C0FF00B3FF00B3FF00A6FF0099FF00\
73FF0026FF0000FF1900FF0019FF0000FF0C00FF5900CCFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
B300FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
E6FF00D9FF00F3FF00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFD900FFE600E6FF00FFFF00FFE600\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFF300C0FF00
FFFF00FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFFF00D9FF00A6FF00CCFF00C0FF00\
A6FF0099FF0059FF0066FF00A6FF0080FF00A6FF00D9FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00FFFF00FFFF00F3FF00B3FF00CCFF008CFF00A6FF0099FF00\
D9FF00F3FF00F3FF00F3FF00CCFF00C0FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00D9FF00CCFF00B3FF0080FF0000FF6600FF59A6FF00A6FF0073FF0099FF0099FF008CFF00\
73FF004CFF0000FF1900FFE600FF330066FF00FF8000D9FF6600FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
F3FF00F3FF00FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFCC00\
FFFF00FFE600FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFE600CCFF00E6FF00FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFF300D9FF00
F3FF00FFF300FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00E6FF00C0FF008CFF00A6FF00\
59FF0059FF0000FF330066FF4CFF0080FF00B3FF00CCFF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00D9FF00CCFF00E6FF00F3FF00E6FF00D9FF00A6FF0000FF0C4CFF00B3FF00\
D9FF00E6FF00E6FF00E6FF00CCFF00C0FF00E6FF00E6FF00E6FF00E6FF0000FF0C
CCFF00CCFF00C0FF00B3FF0080FF0000FF0C4CFF008CFF008CFF0073FF0073FF0080FF004CFF00\
4CFF0033FF0000FF0C00E6FF00FFD900FFFF00F3FF0073FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
F3FF00E6FF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFD900FFCC00FFCC00FFCC00FFD900\
FFFF00FFF300FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFCC00FFCC00
FFCC00F3FF00FFE600FFD900FFD900FFD900FFD900FFD900FFE600FFF300F3FF00E6FF00FFF300\
FFF300FFE600FFE600FFF300F3FF00FFE600FFE600FFE600FFF300FFFF00E6FF00
E6FF00FFFF00FFFF00FFFF0099FF00FFFF00FFFF00F3FF00E6FF00D9FF00C0FF0080FF0066FF00\
3FFF0000FF800040FF00000000CCFF4CFF0000FF00C0FF00D9FF00D9FF008CFF00
E6FF00E6FF00E6FF00CCFF00B3FF00D9FF00D9FF00D9FF00CCFF00A6FF0059FF0000FFB3A6FF00\
C0FF00CCFF00C0FF00CCFF00B3FF00B3FF00CCFF00CCFF00D9FF00D9FF00B3FF00
A6FF00B3FF0000FF1999FF0080FF0033FF0000FF0000BFFF73FF003FFF0019FF0059FF004CFF00\
0073FF0CFF0000FF9900FFBF0000000000000000008000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
CCFF00CCFF00B3FF00FFF300FFE600FFE600FFE600FFE60099FF00FFE600FFE600FFE600FFE600\
E6FF00FFFF00FFE600FFE600FFD900D9FF00FFD900FFD900FFD900FFD900FFD900
FFE600FFFF00FFFF00FFE600FFE600FFFF00FFFF00FFF300F3FF00FFFF00D9FF00C0FF00E6FF00\
F3FF00F3FF00FFFF00F3FF00CCFF00FFFF00FFFF00C0FF00F3FF00E6FF00CCFF00
C0FF00D9FF00E6FF00E6FF008CFF00E6FF00E6FF008CFF00D9FF00C0FF003FFF0033FF0000FF66\
0040FF0000000000000000000000000CFF0080FF00B3FF00B3FF00C0FF0080FF00
CCFF00CCFF00C0FF0099FF0066FF00B3FF00B3FF00B3FF00B3FF0059FF0033FF0033FF0073FF00\
A6FF00A6FF0099FF00A6FF0073FF0080FF00A6FF0080FF00C0FF0073FF0099FF00
00FF0C8CFF0066FF0059FF003FFF0000FF0C00FF4C00FF4C26FF000CFF0000FF330CFF0019FF00\
00F3FF00FF9900FF8C0040FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
19FF00F300FFC0FF00C0FF00E6FF00D9FF00D9FF00D9FF0026FF00D9FF00D9FF00D9FF00D9FF00\
A6FF00D9FF0026FF00A6FF008CFF00A6FF00D9FF00E6FF00F3FF00E6FF00D9FF00
D9FF0080FF00C0FF00CCFF00CCFF00C0FF00C0FF00CCFF0019FF00B3FF0080FF0000FF3300FF0C\
A6FF0073FF00B3FF0099FF008CFF00B3FF00C0FF0000FF1999FF0080FF0073FF00
4CFF0073FF0059FF0099FF004CFF0099FF0099FF0066FF0073FF0080FF0033FF0000FFA6000000\
00000000000000000000000000000000FF0C3FFF004CFF004CFF0066FF000CFF00
4CFF0059FF0066FF0059FF0000FF8C59FF0059FF004CFF004CFF0026FF0000000000000000FF00\
4CFF0026FF0019FF0000FF3319FF0026FF0000FF730059FF19FF0033FF0000FFCC
00F3FF00FF0C00FF1900FF7300FF4C5900FF00000000A6FF00FF9900FFCC00000000FFD900FFB3\
00E6FF0000000C00FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
A6FF008CFF00E6FF00FFFF00FFF300FFF300FFF300FFF30059FF00FFF300FFF300FFF300FFF300\
D9FF00FFFF00FFF300FFFF00FFE600D9FF00FFE600FFE600FFD900FFE600FFE600
FFF300FFFF00F3FF00FFF300FFF300F3FF00F3FF00FFFF00C0FF00F3FF00A6FF00A6FF00D9FF00\
E6FF00E6FF00F3FF00E6FF00CCFF00F3FF00F3FF0080FF00E6FF008CFF00C0FF00
A6FF00C0FF00D9FF00D9FF0099FF00D9FF00D9FF00A6FF00C0FF00B3FF0080FF0033FF0000FF99\
00000000000000000000000000000000FF0080FF0059FF0099FF00A6FF0073FF00
B3FF00C0FF00B3FF0099FF0000FF00A6FF0099FF0099FF0099FF003FFF0000FF1900FF2666FF00\
99FF0099FF0066FF0000FF264CFF004CFF0026FF0059FF00A6FF0073FF008CFF00
00FF4C66FF0059FF003FFF0033FF0000FF590080FF00FF190CFF0000FF0C00FF9900FF1900FF0C\
00FF4C00FFF300FFCC000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
E6FF00E6FF00FFFF00FFE600FFD900FFD900FFD900FFD900E6FF00FFD900FFD900FFD900FFE600\
73FF00FFFF00FFD900FFCC00FFCC00FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFF300FFF300FFD900FFD900FFE600FFE600FFE600FFE600FFF300F3FF00E6FF00FFFF00\
FFF300FFF300FFF300FFF300D9FF00FFF300FFF300FFF300FFF300FFFF00D9FF00
D9FF00F3FF00FFFF00FFFF0066FF00F3FF00F3FF00E6FF00E6FF00CCFF00A6FF0080FF0033FF00\
00FF0000FFD900000000000000000000FF008CFF00C0FF00CCFF00CCFF003FFF00
D9FF00E6FF00D9FF00CCFF00A6FF00CCFF00CCFF00CCFF00C0FF0099FF0059FF0066FF0080FF00\
C0FF00C0FF00A6FF00C0FF008CFF008CFF00C0FF00B3FF00CCFF00CCFF00B3FF00
80FF00A6FF0066FF008CFF004CFF0026FF0019FF0000FF5959FF003FFF0000FF193FFF003FFF00\
00FF6600FF4C00FFCC00FFD93300FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
F3FF00F3FF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
F3FF00FFF300FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600F3FF00F3FF00FFF300\
FFE600FFE600FFD900FFE600FFE600FFD900FFD900FFE600FFE600FFF300CCFF00
F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00E6FF00C0FF0000FF3399FF00\
66FF0026FF0000B3FF0026FF0CFF0073FF00A6FF003FFF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00D9FF0059FF00E6FF00E6FF00E6FF00CCFF00B3FF0000FF4C73FF00B3FF00\
CCFF00D9FF00D9FF00D9FF00C0FF00C0FF00D9FF00E6FF00E6FF00D9FF00B3FF00
C0FF00CCFF00B3FF00A6FF008CFF0000FF1966FF0073FF0080FF0066FF0059FF0073FF0059FF00\
33FF0033FF0000FF0C00FFB30000000099FF0099FF004CFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
33FF00B3FF00FFF300FFD900FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600F3FF00FFFF00FFE600\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFD900FFD900FFD900FFF300CCFF00
E6FF00FFF300FFE600FFE600FFE600FFE600FFF300FFF300FFFF00E6FF0099FF00C0FF00C0FF00\
80FF0080FF0000FF0C00FF0C8CFF0000FF8CC0FF00D9FF00E6FF00F3FF00FFFF00
FFFF00FFFF00FFFF00E6FF00D9FF00F3FF00F3FF00F3FF00CCFF00A6FF0080FF0073FF0073FF00\
D9FF00F3FF00F3FF00E6FF00CCFF00C0FF00E6FF00F3FF00F3FF00F3FF0073FF00
D9FF00D9FF00CCFF00B3FF0080FF0000FFA673FF0099FF00A6FF0059FF008CFF008CFF0073FF00\
66FF0000000000FFD9008CFF00FF5900FFB300FF99000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFF300FFFF00FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFE600D9FF00B3FF00FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFF30059FF00
FFF300FFE600FFD900FFD900FFD900FFE600FFE600FFF300F3FF0099FF00D9FF00E6FF00D9FF00\
C0FF0099FF004CFF00A6FF00B3FF00B3FF00B3FF00D9FF00F3FF00FFFF00FFFF00
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00D9FF00A6FF00C0FF00D9FF00\
E6FF00F3FF00FFFF00FFFF00E6FF00D9FF00F3FF00FFFF00FFFF00FFFF00F3FF00
F3FF00E6FF00D9FF0000FF5900FF003FFF0099FF00B3FF00B3FF008CFF00A6FF00A6FF0099FF00\
73FF003FFF000C00FF00FF6600FF0000FF2600FF4C00FFD9000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFF300FFFF00FFD900FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFE600CCFF00FFF300FFD900\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFE600CCFF00
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFE600D9FF00D9FF00F3FF00F3FF00E6FF00\
D9FF008CFF0066FF00CCFF00D9FF00D9FF0073FF00CCFF00F3FF00FFFF00FFF300
FFF300FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00B3FF00D9FF00F3FF00\
FFFF00FFFF00FFF300FFF300FFFF00FFFF00FFF300FFF300FFF300FFFF00FFFF00
F3FF00F3FF00E6FF00CCFF0066FF008CFF0099FF00C0FF00CCFF00C0FF00C0FF00B3FF0080FF00\
00FF7300FF800CFF0033FF003FFF000CFF0000FF660000000066FF7300FF000000
0000000000000000000000000000000000000000000000000000000000000000000000002600FF\
8000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
E6FF00F3FF00FFE600FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFCC00E6FF00A6FF00FFFF00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFF300FFF300FFFF00F3FF00\
26FF0000FF0CB3FF00E6FF00F3FF00F3FF00E6FF0059FF00E6FF00FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFFF00F3FF0099FF00E6FF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00F3FF00E6FF00CCFF008CFF00CCFF00B3FF00D9FF00D9FF00CCFF00CCFF00B3FF0099FF00\
00FF4C26FF004CFF0073FF004CFF0000FF7300FF2600FF3300FF8C000000000000
0000000000000000000000000000000000000000000000000000000000000000003300FF00A6FF\
0026FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFE600FFF300FFD900FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFD900F3FF00FFCC00FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00\
E6FF0059FF00D9FF00F3FF00FFFF00FFFF00FFFF0073FF00E6FF00FFF300FFE600
FFE600FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300F3FF0066FF00E6FF00FFFF00\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFFF00F3FF00D9FF0066FF00CCFF00D9FF00E6FF00E6FF00E6FF00D9FF00CCFF00B3FF0073FF00\
80FF0000FF338CFF0080FF0000FF333FFF0026FF0000FF4C00FFA6000000000000
00000000000000000000000000000000000000000000000000000000000000000000BFFF00FFFF\
0080FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFD900FFFF00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFCC00FFD900FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00\
D9FF0099FF00E6FF00FFFF00FFF300FFF300FFF300FFF300D9FF00FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300CCFF003FFF008CFF00FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFFF00F3FF00B3FF00A6FF00E6FF00E6FF00F3FF00F3FF00E6FF00E6FF00C0FF0066FF0099FF00\
B3FF00B3FF00A6FF0099FF0080FF0059FF0026FF0000FF4C00FF80008CFF000000
0000000026FF0000008000FF0000000000000000000000000019FF0059FF00FFCC00FF9900FFCC\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFCC00FFCC00FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600F3FF00\
CCFF0033FF00D9FF00FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFF300E6FF0099FF00F3FF00FFF300\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300
FFFF0099FF000CFF00D9FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00C0FF0026FF00C0FF00\
C0FF00C0FF00B3FF0099FF0073FF004CFF000CFF000073FF004CFF0000006600FF
00FFFF00FFB300FFCC00BFFF0000000000FF00B3FF00000000FFA600000000FF5900FF5900FF8C\
0059FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFB300FFC000FFB300FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300\
D9FF00E6FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFFF00C0FF008CFF00F3FF00FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFF300C0FF00C0FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00D9FF00\
CCFF00CCFF00A6FF000099FF4CFF0000FF3300B3FF0099FF00FF5900FFB300FF8C
00FF2600FF4C00FF8C4C00FF00CCFF00FF8C00FFBF00000000FF3300FF4C00FF2600FF3300FFCC\
00FFF3000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFF300\
D9FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFFF00E6FF00FFF300FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFF300F3FF00FFFF00FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00E6FF00\
D9FF00CCFF00C0FF00A6FF008CFF0059FF0000FFBF8C00FF00FF3326FF0000FF26
19FF0026FF003300FF00000000FF6600FF7300FF0000000000FF0000FF190CFF0000FF0C00FF4C\
00FFCC0C00FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000006600FF000000000000000000000000000000000000000000
FF9900FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFFF00\
19FF00FFFF00FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFF300FFF300FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00\
D9FF00CCFF00C0FF00A6FF008CFF0000FF0C008CFF00CCFF33FF0059FF003FFF00
59FF0026FF0026FF0000000000000033FF0026FF008C00FF19FF0033FF0026FF0000FF73004CFF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000FF000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFF300F3FF00\
D9FF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFE600FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00\
D9FF00C0FF00B3FF0000FF1959FF0000FF590CFF004CFF0000A6FF80FF0073FF00
80FF0066FF0019FF0000FF194CFF0059FF0059FF000CFF004CFF004CFF0019FF0000FF0C00FF19\
00FF8C000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000004CFF000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFD900FFFF00C0FF00\
D9FF00FFFF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00F3FF00E6FF00\
CCFF0080FF0073FF0000FFD90080FF19FF0080FF008CFF0000FFB399FF0099FF00
8CFF0073FF0000FF0000FF6659FF0073FF0066FF0033FF0066FF0066FF003FFF0033FF0000FF00\
00FF4C00FFCC4C00FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000059FF008CFF9900FF000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFE600FFFF00B3FF00\
F3FF00FFF300FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00F3FF00E6FF00D9FF00\
CCFF00A6FF0073FF0000CCFF33FF0059FF00A6FF00A6FF0080FF00A6FF00B3FF00
A6FF003FFF000CFF0000FF1973FF008CFF008CFF0080FF0080FF0073FF0059FF0033FF0000FF00\
3300FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000B3FF00BFFF3F00FF000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFE600FFF300F3FF0026FF00\
FFFF00FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300F3FF00C0FF0080FF00B3FF00\
59FF0080FF0019FF0000FFE666FF0099FF00B3FF00C0FF00C0FF00C0FF00C0FF00
B3FF0099FF0000FF1980FF0000D9FF99FF0099FF0099FF008CFF0066FF0019FF0000FF8000FFB3\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000E6FF00E6FF000CFF000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFFF00CCFF0080FF00D9FF00\
FFFF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00D9FF00C0FF00\
80FF0000FF0000FF004CFF0026FF0099FF00C0FF00CCFF00CCFF00CCFF00CCFF00
C0FF0099FF0080FF00A6FF00A6FF00B3FF00A6FF0099FF008CFF0066FF0000FF0C00FF4C19FF00\
00FF1900FFF30033FF0073FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000E6FF00FFE600FFF3000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFE600FFF300D9FF008CFF00\
E6FF00FFF300FFD900FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00E6FF00CCFF00\
A6FF0000FF8000BFFF80FF00A6FF0080FF00C0FF00D9FF00D9FF00D9FF00CCFF00
C0FF0066FF0099FF00B3FF00C0FF00C0FF00B3FF0099FF004CFF003FFF0066FF004CFF004CFF00\
0CFF0000FF4000FF73000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000FFBF00F3FF000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFE600FFFF0080FF00F3FF00\
FFF300FFF300FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00E6FF00CCFF00\
33FF0019FF0026FF0099FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00D9FF00
B3FF0000FF0CB3FF00C0FF00CCFF00C0FF00C0FF0099FF0066FF008CFF0080FF0073FF0059FF00\
33FF000CFF0000FF4000FFB30026FF4C00FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000FFA600FF9900FFCC000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFD900FFF300D9FF0066FF00FFF300\
FFE600FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFF300FFFF00D9FF00B3FF00\
00FF7373FF008CFF0059FF00CCFF00D9FF00E6FF00E6FF00F3FF00E6FF00E6FF00
CCFF00B3FF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF008CFF0080FF0059FF00\
33FF000CFF0000FF66000000F300FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00FFA600FF9900FF8000FF990073FF000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFB300FFC000FFCC00FFD900FFE600FFF300C0FF0099FF00FFF300\
FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00CCFF0000D9FF\
B3FF000CFF00CCFF00B3FF00CCFF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF0099FF0066FF0033FF00\
00A6FF00FF7300FF8C3F00FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00FF8C00FF5900FF66000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFB300FFC000FFE600E6FF00D9FF00C0FF00D9FF00FFFF00FFE600\
FFCC00FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFF300FFFF00E6FF0019FF00B3FF00\
D9FF00E6FF00E6FF00CCFF00B3FF00F3FF00F3FF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF00A6FF008CFF0080FF0059FF00\
19FF000073FF000000CC00FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000B300FF00FF80\
00FF5900FF4000FF4C00FF73000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFB300FFB300FFCC00FFD900FFE600F3FF003FFF00FFFF00FFE600\
FFCC00FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300F3FF00E6FF0099FF00D9FF00F3FF00\
F3FF00FFFF00FFFF00F3FF00CCFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF003FFF0073FF003FFF003FFF00\
00FFB300FFE63300FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000073FF00FF80\
00FF3300FF2600FF4000FFBF000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFB300FFC000FFCC00FFD900FFFF00B3FF00CCFF00FFFF00\
FFD900FFC000FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00D9FF000059FFCCFF00F3FF00FFFF00\
FFFF00FFF300FFF300FFF300FFFF00FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00F3FF00F3FF00E6FF00D9FF0099FF0066FF008CFF0066FF0000FFCC00FFBF000000\
00000000FFFF3F00FF00000000BFFF0000008000FF00FFD9000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF7300FF33\
00FF1900FF1900FF2600FF4C9900FF8C00FF000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFCC00FFD900E6FF00FFFF00FFE600FFFF00\
FFF300FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFCC00FFCC00FFD900FFE600FFFF0099FF00D9FF008CFF0080FF00E6FF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF0066FF0000FF8000FFCC00FFBF4CFF00\
26FF0019FF0000FF1900FFFF00CCFF00000000FF4C00FF7300A6FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000008CFF0019FF00FF4C00FF0C\
00FF0000FF0000FF1900FF59000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFCC0073FF00E6FF00FFD900FFCC00FFCC00\
FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFCC00FFD900FFD900FFE600FFFF00E6FF0073FF0080FF00E6FF00FFFF00FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF0019FF0000B3FF00FF0C66FF0080FF00\
26FF0066FF0033FF000000000099FF00FF0000FF0000FF4C0059FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF260033FF00FF00\
0CFF000CFF0000000000FF408C00FF000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFF300FFF300FFCC00FFC000FFC000\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFCC00FFCC00FFE600FFE600FFF300E6FF00C0FF0000FF26CCFF00FFFF00FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFFF00F3FF00F3FF00E6FF00D9FF00C0FF003FFF0000FF8C00FF5973FF0000D9FF99FF00\
99FF0080FF0026FF0019FF0033FF003FFF000CFF000066FF00000000000000BFFF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000A6FF3300FF00FF4000FF000CFF0019FF00\
26FF0019FF000CFF0000FF1900FF8C0026FF000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFCC00FFFF00FFCC00FFC000FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFCC00FFD900CCFF00CCFF00D9FF00A6FF00A6FF00D9FF00B3FF00FFFF00FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300
FFF300FFFF00F3FF00E6FF00CCFF00B3FF0080FF0080FF00A6FF0099FF0099FF00B3FF00B3FF00\
A6FF0080FF0059FF0073FF0073FF0059FF0000FF0C00FF4C00FF1900FF6600FF8C
0000005900FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000E6FF3F00FF00000019FF0026FF0033FF00\
33FF0026FF000CFF0000FF40000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFC000FFFF00FFD900FFC000FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFCC00FFE600FFFF00C0FF0099FF00CCFF00FFFF00FFF300FFF300FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300
FFF300FFFF00E6FF00B3FF0066FF003FFF00C0FF00CCFF00CCFF00B3FF00B3FF00C0FF00C0FF00\
B3FF000000008CFF008CFF0080FF0000FF8C3FFF0033FF000CFF0000FF0C00FF4C
00FFA600D9FF0080FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000059FF00000000FF8C0CFF0000FF000CFF003FFF003FFF00\
3FFF0026FF00008CFF00FF33000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFB300CCFF00FFCC00FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000
FFC000FFCC00FFE600F3FF00B3FF00CCFF00FFFF00FFF300FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFF30080FF00C0FF0080FF0033FF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
C0FF00B3FF00A6FF0099FF008CFF0073FF0066FF004CFF0026FF0000FF1900FF40
00000000FFFF4C00FF8000FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000099FF4C00FF9900FF00FF0033FF0033FF000000004CFF004CFF00\
4CFF003FFF0026FF000CFF000000000019FF000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FFA600FFB300FFC000FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000
FFC000FFD900FFF30099FF00B3FF00D9FF00FFFF00FFE600FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFF300E6FF0066FF0099FF00CCFF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
CCFF00C0FF00B3FF00A6FF008CFF0080FF0066FF003FFF0000FF00004CFF00D9FF
00FFCC000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FFBF8000FF00B3FF00FF663FFF004CFF0059FF0059FF0059FF00\
59FF004CFF0033FF000CFF0000FF3300F3FF0066FF000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000
FFCC00FFD900F3FF00D9FF00FFE600FFF30099FF00FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600
FFFF0000FF59CCFF00D9FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00\
CCFF00C0FF00B3FF0099FF0080FF0066FF004CFF003FFF0019FF0000FF19000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000003300FF00000000000000FF0C000CFF00FF264CFF0066FF0066FF0066FF0066FF00\
59FF003FFF0026FF0000FF66000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000
FFCC00B3FF00FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00\
CCFF00C0FF00B3FF0099FF003FFF0000FF0000FF7300FF0C00FF3300FF400059FF
3300FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00FFD900FFD900CCFF3F00FFC000FF3FFF004CFF0000FF2633FF0066FF0073FF0073FF0073FF00\
59FF0000FF3300FF33000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00\
B3FF00A6FF0099FF0019FF0000FF0C00CCFF00FF0C00BFFF0099FF00FFE6E600FF
000000000000000000000000000000000000000000000000000000000000000CFF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000000000003300FF
00FF800000000059FF00FF4C33FF0059FF0066FF0059FF0019FF0073FF0080FF0080FF0073FF00\
66FF004CFF004CFF0033FF0000FF4C000000000000B300FF000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00D9FF00B3FF00\
00FF594CFF008CFF0073FF0026FF0026FF004CFF0000FF1900FF8C9900FF000000
00000000000000000000000000000000000000000000000000000000000000E6FF0000006600FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000040FF000000000000000000000000
00FF3300000000FFD900000033FF0066FF0080FF0080FF0080FF008CFF008CFF008CFF0080FF00\
73FF0066FF0059FF0033FF0000FF0C0033FF00FFFF000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF00\
B3FF00B3FF00B3FF00A6FF004CFF0080FF0073FF004CFF0000FF195900FF00E6FF
0033FF00000000000000000000000000000000000000000000000000000000FFD900FFA600D9FF\
0000000000003300FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000008C00FF0073FF7300FF00E6FF0000000073FF0066FF000000000000
E600FF00FF6600F3FF0000004CFF0073FF008CFF008CFF008CFF0099FF008CFF008CFF008CFF00\
80FF0073FF0059FF0033FF0000FF0C00FF5900E6FF0040FF000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00\
D9FF00CCFF00C0FF00B3FF00A6FF0099FF0066FF0019FF000CFF0000FF3300FFA6
00A6FF0000000000000000000000000000000000000000000000000066FF00FF7300FF4C00FFD9\
00FF9900BFFF5900FF0000000000000033FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000008CFF6600FF00FF5900FF8C00FFB300CCFF0019FF004CFF
26FF0066FF0059FF004CFF0059FF0080FF008CFF0099FF0099FF0099FF0099FF0099FF008CFF00\
80FF0066FF004CFF000000003300FF0000006600FF000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00\
D9FF00CCFF00CCFF00C0FF00A6FF0099FF0080FF0066FF003FFF0000FF4000FFE6
00CCFF0000000000000000000000000000000000000000000080FF00000000FF4C00FF0C00FF26\
00FF3300FFBF0000000000002600FF00FFE60000000000FF00CCFF3F00FF000000
0000000000000000000000003300FF000000D900FF0000000000000099FF00E6FF000000000000\
000000000000000000000CFF00FF4000FF2600FF4000FFB300BFFF0019FF00FF19
4CFF0080FF0080FF0073FF0000D9FF73FF0099FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF00\
66FF0019FF000026FF8000FF000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00\
D9FF00CCFF00CCFF00B3FF0099FF008CFF0080FF0066FF0033FF0000FF1900FF40
0040FFF300FF00000000000000000000000000000000000000BFFF00FF8C00FF8026FF0019FF00\
00FF0C00FF6600000000000000FFCC00FF4C00000000FF8C000000000000000000
0000000000000000000000000019FF00000000FFCC0080FF00000000FFD900D9FF000000000000\
00000000000000000000000000FF330CFF000066FF0033FF00000026FF0066FF00
80FF008CFF0099FF008CFF0000E6FF4CFF00A6FF00A6FF00B3FF00A6FF00A6FF00A6FF008CFF00\
0C00FF4CFF0059FF0033FF0000FF800000000C00FF000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00F3FF00E6FF00E6FF00\
D9FF00CCFF00C0FF00A6FF0000FF0059FF004CFF0033FF0033FF0000FF0000FF33
00FFD900000000000000000000F3FF00FFBF00BFFF00000000000000FF0019FF003FFF0033FF00\
00FF7300FF4C00FF663300FF00FF0000FF0000FF2600FF6600FFD9000000000000
00000000000000000000000000000000FF9900FF8C00CCFF00FF4000FF269900FF00FF8C0C00FF\
004CFF000000F300FF004CFF19FF003FFF0000FF8C00FFBF00FF4C00FF734CFF00
8CFF00A6FF00A6FF00A6FF0099FF008CFF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF00\
8CFF0080FF0073FF0059FF0000FF4CE600FF00FFFF00F3FF0066FF000000000000
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00\
CCFF00C0FF00C0FF00A6FF008CFF0066FF0000FF7300FFE600FF0C00FF4000FFCC
00FFCC00000000D9FFCC00FF00FFA600FF334C00FF9900FF00FF26E600FF59FF0066FF004CFF00\
6600FF00FF6633FF0000FF0C3FFF0019FF0000FFF300FFFF000000000000000000
00000000000000000000000000000000FFFF00FF1900FF9900FF0000FF0000FF1900FF3300FFD9\
00B3FF00000000000000BFFF4CFF0066FF003FFF0000FF6600A6FF00000033FF00
8CFF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00\
99FF008CFF0080FF0059FF0033FF0000000000000000FFA6000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFF300FFFF00CCFF0073FF00D9FF00D9FF00D9FF00C0FF00\
8CFF00B3FF00A6FF0099FF008CFF0073FF003FFF0000FF4000FF8C00FF99000000
000CFF008CFF00FF8C00FF7300FF400CFF0000FF2600FFE633FF004CFF0066FF0080FF0073FF00\
3FFF0019FF0059FF0066FF0059FF0033FF003300FF00FF3300A6FF0000003F00FF
00000000000000000000A6FF00000000FF4026FF0000FF0C33FF0026FF000CFF0000FF2600FF66\
0080FF00FFE600FF9926FF000000008CFF0080FF0066FF0059FF0000FF408CFF00
A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF00\
A6FF0099FF0080FF0066FF004CFF000CFF0000FF3300FF8000D9FF000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00A6FF008CFF00C0FF00C0FF00B3FF00\
73FF0080FF0000FF0C80FF004CFF004CFF000CFF0000FFE600000000B3FF008CFF
00FF4C8000FF00FFE60CFF0000FFF34CFF0000FF7300FF0059FF0080FF008CFF0099FF008CFF00\
33FF0073FF0080FF0080FF0059FF0000FF330CFF0019FF0000FF1900FFB38000FF
00000000000000000000FFB30040FF00FF663FFF0059FF004CFF0033FF0000FF0000000000FF73\
008CFF00FF8C00D9FF0CFF008CFF00A6FF00A6FF0099FF0099FF0000F3FF99FF00
B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00\
A6FF008CFF0000FF194CFF0000FF33000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900
FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF00C0FF0033FF0080FF0066FF00\
4CFF0000FF4C0066FF3FFF003FFF0000000000FF3300FFD900FFA600FF0026FF00
0026FF00CCFF00000000FF0C59FF0073FF004CFF0000B3FF0CFF008CFF00A6FF00A6FF0099FF00\
0073FF8CFF0099FF008CFF0033FF0059FF0059FF0033FF000CFF0000FF3300FF8C
00D9FF1900FF4C00FF00FFB300FF0033FF004CFF0073FF0066FF0033FF0000000000FFFF00D9FF\
00FF3333FF0080FF004CFF008CFF00B3FF00B3FF00B3FF00A6FF0026FF0073FF00
B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF00\
99FF008CFF0066FF000000000000009900FF0C00FF000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900
FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00CCFF0099FF0000FF4C00FF00\
00000000FF334CFF0000FF0C0066FF00FF6600FF4C0CFF0000FF0033FF0066FF00
0CFF0026FF0000FF8C0059FF73FF0099FF004CFF0073FF0059FF0099FF00B3FF00B3FF00B3FF00\
8CFF00A6FF00A6FF0099FF008CFF0073FF0059FF0000E6FF9900FF00FFBF00FFD9
0000000073FF0026FF00FF9900FF0073FF0073FF008CFF0080FF003FFF0000BFFF00FF3300FF00\
3FFF0073FF0099FF00A6FF00A6FF00C0FF00C0FF00C0FF00B3FF0019FF0000CCFF
8CFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0099FF00\
80FF0073FF0000FF8C00FFBF8C00FF000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900
FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00B3FF0099FF004CFF0000CCFF\
3FFF004CFF008CFF008CFF00000CFF00FF4C3FFF0033FF0080FF0073FF008CFF00
80FF004CFF000040FF3FFF0080FF00B3FF00B3FF00A6FF0073FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF0099FF008CFF0073FF0059FF003FFF000CFF0000FF59000000
B300FF00B3FF0000000CFF0000FF5980FF0099FF00A6FF0080FF0026FF0000000000F3FF0CFF00\
3FFF0073FF00A6FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF0099FF0000FF0C
99FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF0059FF0019FF00\
0080FF66FF003FFF0000FFCC0059FF000000F300FF000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600
D9FF00FFFF00F3FF00FFFF00F3FF00E6FF0099FF00D9FF00C0FF008CFF0059FF0000FF0000FF00\
73FF008CFF00A6FF00B3FF0066FF00A6FF0073FF0066FF00B3FF0099FF00B3FF00
80FF0000FF6659FF0099FF00A6FF00C0FF00CCFF00B3FF0000FF26B3FF00CCFF00CCFF00CCFF00\
CCFF00C0FF00B3FF008CFF0073FF004CFF0026FF0019FF0000FF4000FF7300FFD9
3F00FF00FF0000FF803FFF008CFF0000FF33B3FF00B3FF00A6FF008CFF0000FF0C4C00FF0099FF\
00F3FF26FF00A6FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00C0FF0019FF00
C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0059FF0000FFF3\
80FF0099FF008CFF0073FF0000FF0000FFBFA600FF00E6FF0000008000FF004CFF
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFF300F3FF00
8CFF00A6FF003FFF00A6FF00D9FF00CCFF0073FF0066FF00A6FF008CFF0033FF0000000000FF59\
59FF00A6FF00C0FF00C0FF00CCFF00C0FF00A6FF00B3FF00CCFF00CCFF00C0FF00
A6FF0000FF8026FF0099FF00CCFF00D9FF00D9FF00CCFF0000FF4CB3FF00D9FF00D9FF00D9FF00\
CCFF00C0FF00B3FF0099FF0059FF0000FF8000FFA600FF5900FF8000FFA600FF66
4CFF004CFF0000FF4C73FF00A6FF00B3FF00C0FF00C0FF00C0FF008CFF0073FF0033FF003FFF00\
00FF403FFF0000FFE6C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00D9FF00C0FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00\
B3FF00A6FF00A6FF008CFF0059FF0000000000000000FF8C00FFA600FFB3008CFF
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFF300F3FF00
CCFF00D9FF00E6FF00E6FF00CCFF0066FF0000FF4C59FF0059FF003FFF0000FF730CFF0059FF00\
66FF0080FF00C0FF00CCFF00D9FF00D9FF00B3FF00B3FF00D9FF00D9FF00D9FF00
8CFF0099FF0000FF0C8CFF00CCFF00E6FF00E6FF00E6FF00C0FF00D9FF00E6FF00E6FF00E6FF00\
D9FF00C0FF008CFF0059FF000073FF00D9FF0CFF000CFF0000FFF34CFF0000FF66
8CFF008CFF0080FF0080FF00C0FF00CCFF00CCFF00CCFF00CCFF004CFF00B3FF00A6FF0000FF33\
33FF00A6FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00\
C0FF00B3FF00A6FF0073FF003FFF0019FF0000000000FFE600FF3300FFA6000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600
FFF300FFF300FFFF00FFFF00F3FF0073FF00CCFF00A6FF0059FF0033FF0000FFBF59FF0099FF00\
A6FF0080FF00CCFF00D9FF00E6FF00E6FF00E6FF00D9FF00E6FF00E6FF00E6FF00
D9FF00C0FF008C00FFCCFF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
D9FF00C0FF00A6FF0080FF0000FFD900FF8C33FF0066FF0073FF008CFF004CFF00
A6FF00B3FF00B3FF0000FF8CC0FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF0099FF00\
00FF99A6FF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00\
C0FF00C0FF00B3FF0099FF0080FF003FFF0026FF0000FF0000FF0C00FF40000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900
FFE600FFE600FFE600FFF300FFFF00F3FF00E6FF00C0FF00B3FF008CFF000CFF0066FF00A6FF00\
C0FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00CCFF008CFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
E6FF00D9FF00C0FF008CFF003FFF000080FF00FF0C59FF008CFF00A6FF00B3FF00
C0FF00CCFF00CCFF0099FF0099FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00B3FF00\
99FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00\
CCFF00C0FF00B3FF0099FF008CFF0073FF004CFF0026FF0000FF1900FF4C00FFA6
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00D9FF00B3FF0073FF0000FF7373FF00A6FF00\
C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00CCFF0066FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
E6FF00D9FF0099FF003FFF0033FF0000FF7319FF0059FF0073FF00A6FF00C0FF00
CCFF00D9FF00D9FF00D9FF0099FF00E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00B3FF00\
3FFF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00\
CCFF00B3FF00A6FF0099FF0000FF8C59FF000000000CFF0000FF330000000059FF
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00
FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00CCFF00B3FF0059FF0000FF4C26FF0019FF00\
B3FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFFF00
F3FF00D9FF0019FF00CCFF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00\
E6FF00C0FF0059FF0066FF0000FF40004CFF00FF5900FF7366FF0099FF00B3FF00
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00F3FF00F3FF00F3FF00D9FF00A6FF00\
00FF4CB3FF00D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00\
C0FF00A6FF0000FFA673FF004CFF006600FF000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900FFD900FFE600FFF30059FF0080FF008CFF004CFF0000FF1900000000FF2626FF00\
99FF00C0FF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFFF00A6FF003FFF00CCFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00\
B3FF0000FF0CCCFF00C0FF0099FF0073FF000059FF00FF2600FF8C00FF59A6FF00
D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00D9FF0000FF99\
00FF5999FF00CCFF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00D9FF00CCFF00\
C0FF00B3FF008CFF008C00FF00FF4000000000000000BFFF000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900FFD900FFE600FFF300FFFF00E6FF00D9FF00B3FF0080FF0033FF003FFF00A6FF00\
B3FF0080FF0059FF00E6FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFF300
FFF300FFFF00C0FF00F3FF00FFF300FFF300FFE600FFE600FFE600FFE600FFF300FFF300FFFF00\
D9FF00E6FF00E6FF00D9FF00C0FF00B3FF0080FF003FFF0000FF2600FF00C0FF00
D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFFF00FFFF00FFFF00E6FF00C0FF00\
00FF808CFF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00\
B3FF0099FF0073FF0000FFF30000006600FF0000002600FF000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900FFE600FFE600FFF300FFFF00F3FF00D9FF00C0FF0099FF0000FF2680FF00B3FF00\
D9FF00E6FF00E6FF00F3FF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFF300D9FF00FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFFF00FFFF00F3FF00E6FF00D9FF00B3FF0000FF2619FF0059FF004CFF0066FF00
CCFF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00A6FF00\
00FF3326FF00D9FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00C0FF00B3FF00A6FF00\
99FF0066FF0000000000FF99CC00FF000000000000000000000000000000000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00
FFD900FFD900FFE600FFF300FFFF00F3FF00E6FF00CCFF0099FF0080FF0000FF6673FF00B3FF00\
D9FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFFF00F3FF00CCFF0000FF4C00FF0066FF0000FF66D9FF00CCFF00
26FF00E6FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300F3FF00E6FF00\
A6FF0033FF00CCFF00F3FF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF00B3FF0099FF0000FF4C00FF66\
80FF0000FF3300FF7300FF4C00FF80F300FF4C00FF3300FF0073FFE600FF000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00
FFD900FFE600FFFF00FFFF00F3FF00C0FF00CCFF00C0FF008CFF0000FF6680FF004CFF00A6FF00\
D9FF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFF300FFF300FFFF00F3FF00D9FF00B3FF0000FF0C73FF00D9FF00F3FF00F3FF00
F3FF00F3FF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00\
D9FF00D9FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF0033FF0000E6FF00A6FF66FF00\
B3FF00B3FF008CFF0073FF0019FF0000FF4C00A6FF00000000FFF300FFE6000000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00
FFD900FFE600C0FF0000FF19C0FF00A6FF0033FF0080FF0000FF0C8CFF00B3FF0026FF0066FF00\
99FF00F3FF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFF300FFF300FFFF00F3FF0099FF000CFF00B3FF00E6FF00FFFF00FFFF00
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
99FF00F3FF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFFF00F3FF00CCFF0000FFBF4CFF008CFF00CCFF00\
CCFF00CCFF00B3FF00B3FF0073FF004CFF0000FF0CC000FF00000000FF4C00D9FF
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFE600FFF300F3FF00B3FF0000FF0C99FF0099FF0099FF00CCFF00E6FF00CCFF00CCFF00\
73FF00F3FF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300FFFF00F3FF00CCFF00B3FF00E6FF00F3FF00FFFF00FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00E6FF00D9FF00D9FF00B3FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00C0FF00A6FF0066FF0000000000000000000000FF190C00FF
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900
FFD900FFE600FFF300F3FF0099FF0026FF00CCFF00E6FF00E6FF00CCFF00FFFF00FFFF00F3FF00\
C0FF00D9FF00FFFF00FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFE600FFE600FFF300FFFF00D9FF0059FF00D9FF00F3FF00FFFF00FFF300FFF300
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00C0FF0099FF0066FF0000FF3300FF9900000000FF0C26FF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900
FFD900FFE600FFFF00E6FF00B3FF0099FF00CCFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
E6FF000080FFF3FF00FFF300FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFE600FFE600FFF300E6FF00B3FF000059FFCCFF00FFFF00FFF300FFF300FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00F3FF00\
E6FF00E6FF00D9FF00C0FF0000FF0C99FF008CFF0059FF0026FF003FFF004CFF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900
FFE600FFF300D9FF0033FF003FFF0026FF00F3FF00FFF300FFE600FFE600FFE600FFE600FFE600\
FFF300B3FF00A6FF00CCFF00FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFE600FFE600FFF300E6FF0026FF008CFF00D9FF00FFFF00FFF300FFF300FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00\
F3FF00E6FF00D9FF00CCFF00C0FF00B3FF00A6FF0066FF0080FF0073FF0066FF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600
FFF300FFFF00A6FF00C0FF00F3FF00F3FF00B3FF00FFF300FFE600FFD900FFD900FFD900FFD900\
FFE600FFFF0099FF00FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFE600FFF300FFFF00CCFF004CFF0000FF3373FF00F3FF00FFF300FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF00A6FF008CFF0080FF0066FF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFFF00FFFF00
59FF00A6FF00E6FF00F3FF00FFF300FFE600FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00\
FFD900FFD900FFF300FFE600FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900\
FFE600E6FF000CFF0033FF0000FF00B3FF00E6FF00FFFF00FFF300FFE600FFE600
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00\
F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF00A6FF008CFF004CFF0033FF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFC000FFC000FFCC00FFD900FFE600FFE600FFF300FFFF0026FF00
66FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900\
FFD900FFF300FFFF0073FF003FFF0099FF00CCFF00FFFF00FFF300FFE600FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00\
F3FF00E6FF00E6FF00D9FF00CCFF00C0FF0099FF0099FF008CFF0073FF003FFF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFC000FFC000FFCC00FFCC00FFD900CCFF00F3FF00F3FF00D9FF0073FF00
F3FF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900\
FFD900FFE600FFFF00D9FF0099FF0033FF0000FF00CCFF00FFF300FFE600FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00\
F3FF00E6FF00D9FF00CCFF00C0FF00B3FF0033FF0066FF0059FF0066FF0033FF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000\
FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300C0FF0080FF00B3FF00D9FF00
CCFF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900\
FFD900FFF300F3FF0000FF8026FF0033FF00E6FF00F3FF00FFF300FFE600FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00\
E6FF00C0FF00A6FF00B3FF00B3FF00A6FF008CFF0000FFB37300FF33FF0000FF40
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000\
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFFF00D9FF008CFF00E6FF00FFFF00
FFF300FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFD900\
FFE600F3FF00C0FF0073FF00A6FF00CCFF00F3FF00FFF300FFE600FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00\
E6FF00C0FF0080FF0059FF0080FF0080FF004CFF0000FFFF00E6FF00000000FF33
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFCC00FFD900\
FFE600FFD900FFD900FFE600FFFF00FFFF00F3FF00CCFF0099FF00E6FF00FFF300
FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00\
E6FF00F3FF00F3FF0019FF0000FF00C0FF00C0FF00FFF300FFE600FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00\
E6FF00D9FF00C0FF00A600FF00FFBF00FF3326FF0000FF4C00000000FF7300FF66
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFCC00FFFF00\
73FF00CCFF00FFF300FFF300F3FF00B3FF00C0FF008CFF0080FF00F3FF00FFF300
FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00\
FFD900FFE600FFF300F3FF00C0FF0019FF00D9FF00FFF300FFE600FFD900FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00\
E6FF00D9FF00C0FF0080FF000040FF0080FF00FF6600000000000000FFE6000000
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFD900\
FFF300F3FF00B3FF00B3FF00C0FF0059FF00B3FF00B3FF00D9FF0019FF00F3FF00
FFE600FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFCC00FFD900FFE600E6FF004CFF0099FF00E6FF0080FF00FFE600FFD900FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00\
D9FF00CCFF00C0FF008CFF003FFF0000FF8000000000FFD900000000CCFF000000
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00\
FFD900FFE600F3FF00B3FF0059FF00CCFF00F3FF00F3FF00FFF300FFF300FFFF00
FFE600FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFCC00FFCC00FFE600FFFF0019FF00FFFF00FFE600FFE600FFE600FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00\
CCFF004CFF008CFF0073FF0026FF0000FF0000FF80000000000000000000000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00\
FFD900FFE600FFF300E6FF0000FF4CE6FF00FFFF00FFF300FFE600FFE600FFD900
FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFCC00FFD900FFFF00F3FF00FFE600FFD900FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00E6FF00E6FF00C0FF00CCFF00CCFF00\
A6FF003FFF0000FF2600FF4C000CFF0000000073FF0066FF00000000000000B3FF
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00\
FFD900FFE600FFFF00CCFF008CFF00D9FF00FFFF00FFE600FFD900FFD900FFCC00
FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFCC00FFE60033FF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFE600FFF300FFFF00F3FF00D9FF0066FF0099FF0000000000FF3333FF00\
0073FF00FF263300FF00FF8019FF003FFF0000FF4000FFFF1900FF7300FF0026FF
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00\
FFD900FFE600D9FF0080FF0000FF3300FF40CCFF00FFE600FFD900FFCC00FFCC00
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFD90073FF00FFD900FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFE60000FF00D9FF00CCFF00B3FF0059FF0000000073FF0066FF00CCFF00\
C0FF00A6FF0066FF000073FF3FFF0080FF0033FF0000FF4000E6FF00FF99000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFD900\
FFE600FFF300FFFF00D9FF008CFF00F3FF00FFF300FFE600FFD900FFCC00FFCC00
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFC000FFCC00FFD900FFCC00FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900FFD900FFE600FFFF00B3FF0033FF000066FF4CFF0033FF0026FF00D9FF00E6FF00\
E6FF00D9FF00CCFF0066FF0066FF00B3FF008CFF0000000000FF4000FFCC000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFC000FFCC00FFD9008CFF00FFFF00\
FFF300FFFF00F3FF00CCFF00A6FF00F3FF00FFF300FFE600FFD900FFCC00FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900FFD900FFF300FFFF00CCFF0066FF000CFF0000FF66CCFF00E6FF00F3FF00F3FF00\
F3FF00F3FF00D9FF00CCFF00D9FF00CCFF0000FF008CFF0073FF0033FF00000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FFA600FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFF300B3FF00\
D9FF00C0FF00CCFF004CFF00B3FF0099FF00FFFF00FFE600FFD900FFCC00FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900FFE600FFF300D9FF0026FF0073FF00C0FF00CCFF00CCFF00F3FF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF008CFF0000FFE600FFA6
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FFA600FFB300FFC000FFC000FFD900FFE600FFE600FFD900FFD900FFE600FFE600FFFF00D9FF00\
B3FF00C0FF0099FF00E6FF00F3FF00F3FF00C0FF00FFFF00FFE600FFD900FFC000
FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFD900FFF300B3FF0059FF00B3FF0019FF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300\
FFF300FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00CCFF008CFF0000FF59000000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FFA600FFB300FFD900C0FF0080FF00D9FF0066FF0080FF00FFFF00F3FF00F3FF00E6FF00000000\
D9FF00F3FF00F3FF00F3FF00FFF300FFE600FFF300CCFF00C0FF00FFD900FFC000
FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFD900CCFF00FFFF00FFF300FFFF00D9FF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF00C0FF0080FF0000E6FF0CFF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FFA600FFA600FFB300FFCC00FFE600FFD900FFE600FFE600FFFF00CCFF0026FF0059FF00D9FF00\
F3FF00FFF300FFF300FFE600FFD900FFD900FFD900FFE600FFE600B3FF00FFC000
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFFF00F3FF00CCFF0000FFBFA6FF0099FF00B3FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FFA600FFA600FFB300FFC000FFC000FFCC00FFCC00FFE600FFF300FFFF00C0FF00F3FF00\
FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFFF00F3FF0080FF0000FF19CCFF00D9FF00CCFF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFF300D9FF00F3FF00\
FFF300FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFF300FFFF00D9FF00CCFF00D9FF00E6FF00E6FF00D9FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFF30099FF00E6FF00\
FFFF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFE600FFFF008CFF0099FF00\
D9FF00FFE600FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFE600E6FF008CFF0073FF00\
E6FF00FFFF00FFCC00FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFF300E6FF00B3FF00\
FFFF00FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00FFCC00FFD900FFF300F3FF00E6FF00\
FFE600FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FFA600FFA600FFB300FFC000FFCC00FFD900FFD900FFE600FFF300E6FF00E6FF00\
FFF300FFD900FFCC00FFC000FFC000FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FFA600FFA600FFB300FFD90099FF00FFF300FFFF00F3FF00D9FF00CCFF00B3FF00\
E6FF00FFE600FFCC00FFC000FFC000FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FFA600FFA600FFB300FFC000FFD900F3FF00B3FF00CCFF00A6FF00FFF300FFFF00\
FFFF00FFFF00FFD900FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00FFFF00F3FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FFA600FFA600FFB300FFB300FFC000FFD900FFFF00F3FF00FFE600FFFF00FFD900FFD900\
FFD900FFFF00E6FF00FFD900FFCC00FFB300FFB300FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFE600FFE600FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FFA600FFA600FFB300FFC000FFCC00FFE600F3FF00FFF300FFD900FFCC00FFC000FFC000\
FFC000FFCC00F3FF0099FF00FFE600FFB300FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFE600FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FFA600FFB300FFB300FFC000FFE600CCFF00F3FF00FFF300FFCC00FFC000FFB300FFB300\
FFB300FFC000FFD900FFD900FFD900FFB300FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFE600FFE600FFF300F3FF00E6FF00E6FF00F3FF00E6FF00E6FF00E6FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FFA600FFA600FFB300FFCC00FFE600A6FF00FFF300FFCC00FFF300FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFD900FFB300FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFE600F3FF00E6FF00C0FF004CFF0000FFCCCCFF00D9FF00D9FF00CCFF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FFA600FFB300FFCC00F3FF00E6FF00FFCC00FFC000FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFE600FFF300D9FF0033FF0000FF000033FF26FF00C0FF00C0FF00B3FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFA600
FFC0008CFF00FFFF00B3FF00FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFE600FFF300FFFF00F3FF00D9FF00D9FF00C0FF0033FF008CFF00F300FF
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFA600
FFB300FFCC0099FF00FFCC00FFC000FFB300FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFE600FFE600FFF300FFFF00F3FF00E6FF00CCFF0000FF5900BFFF00FFD9
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFA600
FFB300FFD900FFF300FFC000FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF00A6FF0000FF00000CFF
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFA600
FFCC00FFF300FFCC00FFCC00FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF00B3FF0019FF0000FF4C
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFCC00
FFD900FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFE600FFE600FFF300FFF300FFFF00F3FF0080FF008CFF0000FF1959FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFCC00
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFE600FFE600FFF300FFFF00FFFF00F3FF00D9FF00CCFF00A6FF0080FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00D9FF00CCFF00B3FF008CFF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300E6FF00E6FF00E6FF00E6FF00CCFF00B3FF00A6FF0099FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFF300FFFF00B3FF000CFF00CCFF00CCFF00C0FF0059FF0080FF0073FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFF300FFF300FFFF00E6FF00B3FF0099FF00B3FF00A6FF0080FF0000B3FF3FFF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00F3FF00D9FF004CFF0000FF4073FF0000FF0033FF0000000000FF99
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFCC00FFD900FFF300FFE600FFE600FFE600FFF300B3FF00F3FF00FFFF00F3FF00FFFF00\
F3FF00E6FF00A6FF00C0FF0099FF0000FF0033FF0000FF0000FFCC00000000FF26
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFC000
FFCC00FFCC00FFD900A6FF00CCFF00FFFF00FFFF00FFFF00C0FF00B3FF00C0FF0080FF00B3FF00\
D9FF00C0FF0000FF2680FF0026FF0000FF4C00BFFF19FF0033FF004CFF0073FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFC000FFCC00
FFCC00FFD900FFD900FFF300C0FF0080FF00CCFF00CCFF00B3FF0019FF0073FF0059FF00CCFF00\
99FF003FFF0019FF0066FF0080FF004CFF0033FF0019FF008CFF00A6FF0000FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00
FFD900FFD900FFE600FFFF00A6FF0000FF2666FF0000FF4C00FF40A6FF008CFF00E6FF00F3FF00\
F3FF00E6FF00CCFF0099FF00D9FF0080FF00A6FF0000FF2699FF00CCFF00D9FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFD900FFD900FFD900
FFD900FFF300FFF300FFFF00D9FF00B3FF003FFF0026FF00B3FF00D9FF00D9FF00FFFF00FFF300\
FFF300FFF300F3FF00F3FF00F3FF00F3FF00CCFF0000FF66A6FF00D9FF00F3FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFCC00F3FF004CFF00CCFF00FFE600
FFF300F3FF00CCFF00E6FF0099FF0066FF0099FF0099FF0099FF00F3FF00FFFF00FFF300FFE600\
FFE600FFE600FFF300FFF300FFF300FFFF00E6FF00CCFF00F3FF00FFFF00FFFF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFE600E6FF00E6FF00E6FF00
CCFF00CCFF0026FF00B3FF0073FF0000FFB3CCFF00D9FF0080FF00F3FF00FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF30073FF00CCFF00FFFF00FFF300FFF300
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFD900FFF300B3FF00
73FF0099FF0066FF0000B3FFA6FF00CCFF00E6FF00F3FF00F3FF00F3FF00FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFFF00FFFF00FFE600FFE600FFE600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFD900FFE600B3FF00
CCFF00B3FF0066FF0059FF0000FFD9C0FF00F3FF00FFF300FFF300FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFD900FFE600FFE600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFCC00FFE600FFFF00
F3FF00CCFF0033FF00B3FF008CFF0099FF00F3FF00FFF300FFE600FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFD900FFE600FFF300
E6FF0000FF26CCFF00E6FF00D9FF0000FF66FFFF00FFE600FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00F3FF00FFFF00F3FF00
B3FF0000FF73D9FF00FFFF00FFFF008CFF00CCFF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFD900FFF30080FF00CCFF00
A6FF00CCFF00F3FF00FFF300FFE600FFF300FFF300FFE600FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFB300FFC000FFC000FFCC00FFD900FFF300CCFF000CFF00
A6FF00D9FF00FFFF00FFE600FFD900FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFB300FFB300FFC000FFCC00FFD900FFF300CCFF0000FF59B3FF00
C0FF0080FF0080FF00FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFB300FFC000FFE600F3FF0000FF1933FF000CFF00E6FF00D9FF00
FFFF00D9FF00FFFF00FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFB300FFCC00FFFF004CFF00FFE600FFD900FFE600FFE600FFD900
FFD900F3FF00FFFF00FFD900FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFC000FFE60066FF00FFE600FFCC00FFC000FFC000FFC000FFC000
FFCC00FFE60019FF00FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FFA600FFA600FFF300FFCC00FFCC00FFC000FFC000FFB300FFB300FFB300FFC000
FFC000FFC000FFF300FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFD900FFD900FFD900FFD900FFF30080FF00FFF300FFE600FFE600FFE600A6FF00FFF300FFF300\
FFFF00FFFF00F3FF00CCFF00D9FF00E6FF00FFFF00E6FF00FFFF00FFFF00FFFF00
A6FF00F3FF00FFFF00FFFF0073FF00FFFF00F3FF00E6FF00C0FF00B3FF00D9FF00B3FF00F3FF00\
E6FF0073FF00E6FF00E6FF00E6FF0073FF00D9FF00CCFF00A6FF0080FF003FFF00
00FF1900FF8000FFB3000000000000000000000000A600FF4CFF008CFF00B3FF00C0FF00C0FF00\
C0FF0099FF00CCFF00D9FF0026FF00CCFF00A6FF0033FF0099FF00C0FF0080FF00
B3FF00B3FF0080FF0000FF3300FF334CFF0059FF00A6FF00B3FF00A6FF00A6FF00B3FF0099FF00\
00FF8C99FF00B3FF0099FF00B3FF00C0FF00B3FF0099FF0000FF8C8CFF008CFF00
33FF0073FF004CFF0019FF0000FFFF00FF0C0CFF003FFF0033FF0000FF0C0CFF0019FF0026FF00\
00FF0000B3FF00FF5900000000A6FFCC00FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFCC00FFCC00FFCC00FFCC00FFE600A6FF00FFE600FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFF300FFFF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFF300
CCFF00FFF300FFE600FFE600FFE600FFF300FFF300FFFF00D9FF00D9FF00F3FF00FFFF00FFFF00\
FFFF00D9FF00F3FF00FFFF00FFFF00F3FF00E6FF00E6FF00CCFF00B3FF0073FF00
59FF0019FF000CFF004C00FF0000000000000066FF00A6FF59FF0059FF00B3FF00CCFF00D9FF00\
D9FF0000FF0CE6FF00E6FF00E6FF00D9FF00CCFF00A6FF00CCFF00D9FF00CCFF00
D9FF00CCFF00B3FF008CFF0000FF3366FF00A6FF00C0FF00CCFF00C0FF00C0FF00CCFF00B3FF00\
19FF00B3FF00CCFF00CCFF00D9FF00D9FF00CCFF00B3FF0099FF00B3FF00A6FF00
80FF0099FF0080FF0059FF0000FFB34CFF0000FF6666FF0059FF0000FF4C3FFF0059FF004CFF00\
8C00FF00000000FF0C00FF8000FF990026FF000000000000000000C000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFC000FFC000FFC000FFC000FFCC00FFE600FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFE600FFF300D9FF00F3FF00FFF300FFE600FFE600FFD900FFD900FFD900
FFE600FFE600FFD900FFD900FFE600FFE600FFF300FFFF00CCFF00E6FF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00E6FF00D9FF00A6FF0073FF00
99FF0080FF0019FF0026FF000040FF008CFF00FF0C26FF008CFF00B3FF00B3FF00D9FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00CCFF0099FF00E6FF00E6FF00E6FF00
E6FF00D9FF00C0FF004CFF0000FF1980FF00B3FF00CCFF00D9FF00E6FF00E6FF00D9FF00CCFF00\
59FF00CCFF00D9FF00E6FF00E6FF00E6FF00D9FF00A6FF00B3FF00CCFF00C0FF00
C0FF00A6FF008CFF003FFF000CFF0073FF0080FF008CFF0080FF000099FF66FF0073FF0066FF00\
33FF003FFF0026FF0000FF2600FF993300FF00F3FF0C00FF00A6FF0066FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFD900FFE600FFF300CCFF00FFFF00FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFFF00A6FF00E6FF00FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFFF00E6FF00CCFF008CFF00C0FF00
C0FF0066FF008CFF0066FF0000FF1919FF003FFF0073FF0080FF00C0FF00D9FF00E6FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00D9FF00B3FF00F3FF00F3FF00F3FF00
F3FF00D9FF0000FF1999FF004CFF003FFF0066FF00CCFF00E6FF00F3FF00F3FF00E6FF00D9FF00\
66FF00D9FF00E6FF00F3FF00F3FF00F3FF00E6FF00B3FF00D9FF00D9FF00D9FF00
CCFF00B3FF0080FF000CFF0033FF0080FF0099FF0099FF008CFF003FFF008CFF008CFF000019FF\
66FF0059FF0000FF9900FF99F300FF00FF8000FF6600B3FF00FFB3008CFF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFD900B3FF0073FF00F3FF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFFF0080FF00FFFF00FFE600FFE600FFD900\
FFD900FFD900FFE600FFE600FFE600FFF300FFFF0099FF0033FF00D9FF00D9FF00
CCFF00B3FF00B3FF0073FF0080FF0099FF0099FF00B3FF0019FF00C0FF00D9FF00F3FF00F3FF00\
FFFF00FFFF00FFF300FFF300FFF300FFFF00F3FF00F3FF00FFFF00FFFF00FFFF00
F3FF00E6FF00D9FF00CCFF0033FF00C0FF00CCFF0099FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
8CFF00D9FF00F3FF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00
CCFF0099FF004CFF008C00FF73FF0080FF00B3FF00B3FF0099FF0000FF0CA6FF0099FF008CFF00\
80FF0066FF003FFF0000FF8000FFE600FF2600FF2600FF4C00FFBF00FFCC0040FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFCC00FFD900FFF300B3FF00FFF300FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFF300D9FF00FFFF00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFF300B3FF0059FF00C0FF00E6FF00F3FF00
E6FF00D9FF00C0FF0066FF00A6FF00C0FF00A6FF00D9FF00CCFF0019FF00D9FF00F3FF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00F3FF00F3FF00CCFF0000FF19CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
D9FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00
CCFF00B3FF0080FF0000FF8C4CFF00B3FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF00\
80FF0026FF0000FF260CFF0019FF0019FF0000FF1900FF0C00FFFF0C00FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000004C00FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFCC00FFD900FFFF00E6FF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFE600FFF300FFD900FFD900FFD900FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFE600D9FF00B3FF00FFFF00FFFF00FFFF00
F3FF00D9FF00C0FF0000FF26B3FF00D9FF00E6FF00E6FF00E6FF00CCFF00A6FF00E6FF00FFFF00\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFFF00F3FF00E6FF0099FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00
D9FF00C0FF0059FF0080FF0099FF00B3FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF008CFF00\
3FFF0000FF2600FF404CFF0059FF004CFF0033FF0000FF4000FFB300FFF300FFBF
00BFFFCC00FF000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000C00FF0C00FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFE600FFFF00CCFF00D9FF00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFF300FFF300FFF300FFFF00
F3FF000CFF0099FF0000FF00B3FF00E6FF00F3FF00F3FF00F3FF00D9FF00A6FF00D9FF00FFFF00\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFFF00F3FF00D9FF00A6FF00E6FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00
D9FF00C0FF0099FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF00\
66FF0000FF1959FF0066FF0073FF0059FF0033FF0000FFBF00FF0C00FF3300FF66
00FFE60033FF000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000040FF00A6FF0073FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFC000FFCC00FFFF00FFE600FFD900FFCC00FFC000FFC000FFC000FFC000FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300
FFFF00E6FF00C0FF008CFF00CCFF00E6FF00FFFF00FFFF00FFFF00FFFF0080FF00A6FF00FFFF00\
FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFF300FFF300F3FF00D9FF00A6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00E6FF00
CCFF0059FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF008CFF00\
66FF0080FF0073FF008CFF0080FF0033FF003FFF0019FF0026FF0000FF263F00FF
5900FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000E600FF0059FFE600FF00FFF30073FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFC000FFC000FFFF00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300
FFFF00E6FF00A6FF0099FF00E6FF00FFFF00FFFF00FFF300FFF300FFF300FFFF00E6FF00FFF300\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFF300E6FF00A6FF00A6FF00E6FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF00
99FF00A6FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00C0FF0059FF0073FF00\
A6FF00A6FF00A6FF0099FF008CFF0080FF0066FF004CFF0026FF0000FF0000FF4C
00FFB34C00FF0000000000000000003300FF000000000000000000000000000000000000000000\
A600FF00000000D9FF1900FF00FFB300FFBF00BFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFC000FFF300FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300
F3FF0099FF0033FF00C0FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFF300FFFF00CCFF00C0FF00F3FF00FFF300FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFFF00F3FF00CCFF00
00FF7373FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF0099FF0000FFE6B3FF00\
C0FF00C0FF00B3FF00A6FF0099FF008CFF0073FF004CFF0000FF4000FF4000FFA6
00FFFF0000000000000033FF00A6FF00CCFF00CCFF0000000000000000000000FF0000FF000000\
00BFFF00000000FFBF00FF8C00FF7300FFE600FFE6000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600
FFFF00E6FF008CFF00CCFF0073FF00FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFE600FFF300F3FF00B3FF00B3FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300D9FF004CFF00
B3FF00E6FF00F3FF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00D9FF00C0FF00B3FF00CCFF00\
CCFF00C0FF00C0FF00B3FF0099FF0080FF0019FF0026FF0000FF1900FFCC0099FF
00F3FF00FFFF0073FF00FFA600FFBF00FF8C00FFB300A6FF00000000000000CCFF00000000BFFF\
00E6FF00FF8000FFD900FF4000FF4C00FF8C00CCFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600
FFF300F3FF0080FF00F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFF300CCFF00A6FF008CFF00F3FF00FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300E6FF00B3FF00
00FF4CF3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00D9FF00\
D9FF00CCFF00C0FF0099FF0026FF0066FF0019FF0019FF0000FF73000CFF3F00FF
00FF3300FF2600FF8C00FF3300FFBF00FF3300E6FF0059FF004CFF0026FF00FF5900FF8C0019FF\
00FF4000FF2600FF4000FF1900FF4C00FF8000FFA6000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600
FFF300F3FF00CCFF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFE600FFF300C0FF00F3FF00FFF300FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFF30073FF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00\
D9FF00CCFF00CCFF00B3FF00A6FF008CFF0073FF000CFF00008CFF00000000FF4C
0CFF0026FF0000FF660CFF0019FF0000FF0C000CFF0C00FF00FF6600FF2600FF0000FF1900FF99\
00FF0000FF0000FF1900FF0000FF1900FF4000FF9900A6FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600
FFF300D9FF00E6FF00FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFE600C0FF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00\
D9FF00D9FF00CCFF00C0FF00A6FF0099FF0033FF0026FF0000FF4C00000000FF00
00FF404CFF0026FF003FFF003FFF000CFF0000FF0C6600FF00E6FF19FF0026FF0000FF0000FFFF\
0CFF0026FF0026FF0019FF0000FF1900FF6600D9FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600
FFFF00B3FF0099FF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFE60073FF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00\
D9FF00CCFF00C0FF00B3FF0099FF008CFF0066FF0000FF2600FF190CFF0000FF0C
59FF0073FF0033FF0066FF0066FF004CFF000CFF0000FFBF26FF0019FF004CFF0033FF0000FF33\
26FF003FFF0033FF0019FF0000FF4C00A6FF00FFCC000000E600FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFFF00
E6FF0073FF00FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFD900FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00\
D9FF00B3FF00A6FF00A6FF0080FF000033FF00FF4000FF0C33FF0066FF0000FF26
73FF008CFF0080FF0080FF0073FF003FFF006600FF00FFBF4CFF0066FF0066FF004CFF0000FF19\
59FF0059FF003FFF0000FF800CFF0000FF0000FF6600FFB300BFFFCC00FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFFF00
D9FF00A6FF00E6FF00FFF300FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00\
D9FF00C0FF008CFF004CFF004CFF00000CFF26FF0073FF0080FF008CFF0073FF00
80FF0099FF0099FF0099FF0080FF004CFF0000FFFF008CFF3FFF0073FF0073FF003FFF004CFF00\
66FF0066FF0059FF003FFF0033FF0000FF0000FF3300FF9900CCFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFD900FFE600FFFF00
C0FF00D9FF00FFFF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00\
CCFF00C0FF0099FF0066FF0000FF7300FF00008CFF80FF00A6FF00A6FF008CFF00
59FF00A6FF00A6FF00A6FF0000FF0033FF0000FF9919FF0073FF0080FF008CFF0080FF0080FF00\
80FF0073FF0066FF004CFF0033FF0000FF0000FF8000BFFF7300FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFE600FFF300E6FF00
73FF00F3FF00FFF300FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00F3FF00C0FF00C0FF00CCFF00\
A6FF00A6FF003FFF004CFF0000FF8C26FF0080FF0099FF00B3FF00B3FF00B3FF00
B3FF00C0FF00B3FF00B3FF0099FF0080FF0000FFFF66FF0066FF008CFF0099FF0099FF008CFF00\
8CFF0073FF004CFF0033FF0000FF2600FF2600FFFFC000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFF300E6FF00F3FF0099FF00
A6FF00F3FF00FFF300FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00D9FF008CFF0099FF0099FF00\
008CFF00FF1926FF0000FF5900FF4C00FF003FFF00A6FF00C0FF00C0FF00CCFF00
CCFF00CCFF00C0FF00C0FF00A6FF008CFF0059FF0099FF008CFF00A6FF00A6FF00A6FF0099FF00\
8CFF0080FF0059FF0000FF4C0080FF00FF2600FF8000FFCC0000003F00FF000000
9900FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFE600FFFF00E6FF00B3FF00
33FF00F3FF00FFF300FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00E6FF00D9FF00CCFF00\
A6FF0080FF0026FF0033FF0066FF004CFF0033FF00A6FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00A6FF004CFF0099FF00A6FF00B3FF00B3FF00B3FF00A6FF0099FF00\
8CFF0073FF0019FF0000FF590CFF0026FF000CFF0000FF33000000008CFF00FFFF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFE600FFFF00D9FF00
4CFF00C0FF00F3FF00FFE600FFD900FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00D9FF00\
B3FF0066FF0000FFD90C00FF66FF00A6FF00B3FF0073FF00CCFF00D9FF00D9FF00
D9FF00D9FF00CCFF00C0FF0000FF194CFF00A6FF00B3FF00C0FF00C0FF00B3FF00B3FF0099FF00\
66FF0000FF1966FF0059FF004CFF004CFF0026FF0000F3FF00FF3300FF66000000
000CFF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600F3FF0073FF00
F3FF00FFFF00F3FF00FFFF00FFD900FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00CCFF00\
19FF0059FF0000FF004CFF0099FF00B3FF00CCFF00CCFF00D9FF00E6FF00E6FF00
E6FF00D9FF00D9FF00C0FF004CFF008CFF00B3FF00C0FF00CCFF00C0FF00C0FF00B3FF008CFF00\
3FFF0080FF008CFF0080FF0073FF0059FF0033FF0026FF0000FF0000FF4000FF8C
00FFF30066FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFFF00D9FF00D9FF00
FFFF00FFE600FFD900FFD900FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00CCFF00\
8CFF0000D9FF00FF334CFF0066FF00B3FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00CCFF0000FF99A6FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF00\
A6FF0099FF0099FF008CFF0073FF0066FF004CFF0026FF0000FF260C00FF000000
5900FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFE600F3FF0080FF00E6FF00
FFF300FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF0000BFFF99FF00\
33FF008CFF00B3FF00A6FF004CFF00C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00E6FF00D9FF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00\
B3FF00A6FF0099FF008CFF0066FF003FFF0026FF0000FFF300FF4000FFBF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFC000FFCC00FFD900FFE600FFF300E6FF00B3FF00E6FF00
FFF300FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00E6FF00C0FF0019FF00\
A6FF00CCFF00D9FF00D9FF00C0FF00A6FF00D9FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00\
B3FF00A6FF0099FF008CFF0073FF0059FF0000FF2600FF407300FF00FFE600A6FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFD900F3FF00A6FF00C0FF00B3FF0099FF00E6FF00FFF300
FFE600FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF0019FF00B3FF00\
B3FF00E6FF00F3FF00E6FF00D9FF0000FFBFD9FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00\
B3FF00A6FF0099FF008CFF0073FF0059FF0033FF0000D9FF0066FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFB300FFB300FFC000FFD900FFE600FFF300FFFF0080FF0059FF00FFF300
FFE600FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF008CFF0000FF80D9FF00E6FF00\
F3FF00F3FF00FFFF00FFFF00F3FF00C0FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00\
B3FF0099FF0059FF0073FF0059FF004CFF000026FF00FF5900FFD9D900FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFB300FFC000FFC000FFCC00FFD900FFF300E6FF00CCFF00FFFF00
FFF300FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900FFD900FFE600FFF300FFF300FFFF00D9FF00B3FF0033FF00CCFF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00FFFF00FFFF00FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF00A6FF00\
99FF008CFF003FFF0019FF0000FF7300FF1900FFE61900FF6600FF0026FF000000
004CFF0099FF000000000000008CFF0033FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFB300FFB300FFC000FFCC00FFD900D9FF0099FF00A6FF00FFFF00
8CFF00FFFF00FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900FFD900FFF300F3FF00F3FF00E6FF00CCFF0066FF00C0FF00F3FF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00CCFF00A6FF008CFF00\
00FF333FFF0000FF0C0059FF00FF3326FF0000FF0CC000FF00FF408C00FF5900FF
00000000FFA60073FF00FFB300FF9900FFE60059FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFB300FFB300FFC000FFCC00FFD900F3FF00C0FF00FFE600FFD900
FFE600FFFF00FFD900FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00
FFD900FFD900FFE600FFF300E6FF00B3FF00C0FF0000FF338CFF008CFF00F3FF00FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF00B3FF00\
80FF0000A6FF00000000FF2619FF0066FF0059FF0019FF0026FF000CFF00E600FF
0066FF00FF4C00CCFF00FF3300FF8000F3FF000CFF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFB300FFC000FFCC00E6FF00C0FF00FFE600FFD900FFCC00
FFCC00FFCC00FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00
FFD900FFE600FFE600FFF300F3FF00CCFF0059FF008CFF00E6FF00F3FF00FFFF00FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF00A6FF00\
3FFF0000FF0C00FF1900D9FF73FF0080FF0073FF0073FF0066FF0019FF0000F3FF
00FF0C00FF001900FF00FF0000FF4000FFBF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFB300FFC000FFCC00FFE600F3FF00FFF300FFCC00FFC000
FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFD900
FFE600FFE600FFF300F3FF00E6FF0000FF003FFF00CCFF00F3FF00FFFF00FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00A6FF0073FF00\
00FF00CC00FF00FF0C73FF0059FF0099FF0099FF008CFF0073FF0019FF0000FF19
3FFF003FFF0033FF0000FF0C00FFB30000000000000000000099FFD900FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFB300FFC000FFCC00FFFF00FFD900FFCC00FFC000FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00F3FF00
CCFF00F3FF00F3FF00CCFF0080FF0080FF00CCFF0099FF00F3FF00FFF300FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00C0FF0066FF00C000FF\
8CFF008CFF0019FF0099FF00A6FF00A6FF00A6FF0099FF0073FF0033FF0019FF00
66FF0059FF003FFF0000FF2600FF7300FF6600FF7300FFFF00FFA60033FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFB300FFC000FFD900FFFF00FFCC00FFC000FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900
FFFF00E6FF0059FF0066FF0099FF00D9FF00F3FF00F3FF00CCFF00FFF300FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00C0FF00C0FF0000000000FF40B3FF00B3FF00\
C0FF00B3FF0000E6FFB3FF00C0FF00C0FF00B3FF0099FF0000FF6680FF008CFF00
80FF0066FF0019FF000CFF000CFF000CFF0000FF2600FF3300FFCC00FFB300D9FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFB300FFC000F3FF00FFD900FFC000FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900
FFE600FFFF00CCFF008CFF00CCFF00E6FF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFF300FFF300FFFF00E6FF00D9FF00B3FF0000FFCC59FF00B3FF00CCFF00D9FF00\
CCFF00CCFF008CFF00C0FF00CCFF00C0FF00C0FF008CFF0059FF0099FF0099FF00
8CFF003FFF004CFF004CFF003FFF0033FF000CFF0000FF1900FF4000FF7300FFB300F3FF0059FF\
E600FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFB300FFC000F3FF00FFC000FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900
FFE600E6FF0099FF00A6FF00E6FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFF300FFF300F3FF0059FF00A6FF0066FF003FFF00C0FF00D9FF00D9FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF00A6FF00
99FF0080FF0073FF0066FF004CFF0026FF000CFF0000FF2600FF4C00FF9900000000BFFF000CFF\
CC00FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFCC00FFC000FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900
80FF0000FF0C73FF0099FF00E6FF00FFF300FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFF300F3FF00C0FF0000E6FFA6FF00C0FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00B3FF00A6FF00
99FF008CFF0073FF0066FF003FFF0000FF0C00FF800080FF00FFA600FFB30059FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFE600
D9FF00C0FF00FFFF00FFF300D9FF00FFFF00FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFFF00E6FF0059FF0059FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF00
8CFF0080FF0066FF0059FF004CFF0026FF0000FF0000FF330000000040FFC000FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000003F00FF000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFCC00FFE6008CFF00
FFF300FFE600FFD900FFD900FFE600FFF300FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFE600FFE600F3FF00E6FF00F3FF00E6FF00E6FF00F3FF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00CCFF00C0FF00B3FF0099FF00
00FF2659FF0033FF0026FF0026FF0000FF1900FF0C00FF59000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000003F00FF0080FF000CFF00E6FF
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00F3FF00FFFF00
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF00A6FF0099FF00
73FF0000FFCC00FF8C8000FF00FF4000FF2600FFB300FF8C00BFFF000CFF000000000000000000\
000000000000000000000000000000000000000000000000CC00FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000019FF00FFCC00FFB300FFE6
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00E6FF00CCFF00C0FF0080FF008CFF008CFF004CFF00
004CFF00000000FF400CFF0000FF4C00CCFF00000000FFD9000000000000000000000000000000\
0000000000000000000000000000000000000000000000000040FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F300FF00000000000000000000000000E6FF00FF7300FF8C7300FF
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00F3FF00F3FF00D9FF00C0FF0000FFBF00FF594CFF008CFF0000BFFF
4CFF0000000033FF004CFF000CFF0000FF660000000040FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000008CFF00D9FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000CFF00000000000000000000000000000000FF4000FF6600A6FF
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFFF00FFFF00F3FF00F3FF00D9FF00C0FF0080FF00A6FF00B3FF00A6FF00A6FF00
73FF0073FF0073FF0066FF003FFF000CFF0000FF8C00000000A6FF000000000000000000000000\
000000000000000000000000000000000000000000000000004CFF00FFBF00FFCC
0000000000000000003F00FFC000FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000FFFF0000000000000000005900FF00000000000000FF190CFF00000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00
A6FF0099FF008CFF0073FF004CFF000000000000000040FF00FFBF000000000000000000000000\
0000000000000000000000000000000000000000000000000000FF00FF8000FF73
0019FF00F3FF0073FF00CCFF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000BFFF000000\
00FFF300FF8000FFFF00FFA60000005900FF000CFF00F3FF0CFF004CFF0033FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00
B3FF00A6FF008CFF0019FF004CFF0026FF0000FF0C00FF2600FF7300FFE6004CFF000000000000\
000000000000000000000000000000000000000000000000004CFF00FF4000FF4C
CC00FF00FF4C00FF7300FFD90C00FF0000000000000000000073FF000000000000C000FF8000FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000B300FF0000000026FFA600FF0000000000000000000000000000008000FF00FFA6\
00FFA600FF4C00FF5900FF9900FFCC00000000FFBF0000004CFF0066FF0073FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300\
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00D9FF00CCFF00C0FF00C0FF00
B3FF00A6FF008CFF0080FF0066FF004CFF0019FF000066FF00FFE6008CFF8C00FF000000000000\
000000000000000000000000000000000000008CFF00000000FF6600FF4000FF0C
00FF2600FF1900FF8000FFCC00000000000000000000BFFF00FFCC00000000E6FF00E6FFB300FF\
000000000000000000000000000000000000000000000CFF0059FF0000000080FF
00000000000000000000000000A6FF0000000000000000000000000000000000008C00FF00FF73\
00FFD900FF1900FF4C00FFA600FFCC0000000073FF26FF0033FF0080FF008CFF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300\
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00
A6FF0099FF008CFF0080FF0066FF004CFF0019FF0000FF2600FF5900BFFF000000000000000000\
0000007300FFB300FF3300FF00000000000000D9FF00FF730099FF00FF1919FF00
19FF0000FF0000FF33008CFF0000000000000066FF00FFBF00FF7300FF8000FF800000008C00FF\
0000000000000000000000000000000000000000009900FF00F3FF00FFF300CCFF
0000FF00000000FFCC00FF9900F3FF00000000000000000000000000000000000000A6FF000000\
00FF0000FF0000FFA600B3FF00A6FF00FFBF26FF0066FF0073FF008CFF0099FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300\
FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0099FF00
00FF0059FF0073FF004CFF004CFF003FFF0026FF0000FF0000FF4000FFA60099FF000000000000\
0000000066FF00000000FFE68000FF00000000F3FF00FF4C0CFF0000FF0C3FFF00
33FF0000FF0000000000A6FF00FF8000FFA600FF3300FF3300FF2600FF3300FF8000FFB3000000\
00000000000000000000000000000000000000000000000000FFCC00FF8000FFFF
00000000FF8C00FF4000FF7300FFF30073FF000000004CFF0000000000005900FF00000000FF0C\
26FF0019FF00F300FF00FFBF00FF5900FF0C26FF0073FF008CFF0099FF00A6FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00\
FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00
8CFF0073FF000040FF00FF1900FF2619FF0000FF0000FF4000FF4C00FFA60000000000000099FF\
00000000000000FF8C00FFA61900FF00B3FF00FFA600FF3333FF004CFF0059FF00
4CFF0000FF0000A6FF00FF0C0CFF000CFF0026FF0019FF000CFF0000FF5900FF7300D9FF000000\
00000000000000000000000000000000000000000000000000FF9900FF4000FFCC
00000000FF1900FF0C00FF3300BFFF00FF7300FF8000FFE60C00FF00000000000000FFE60CFF00\
4CFF004CFF0000F3FF0C00FF00FFA68000FF00000066FF008CFF00A6FF00A6FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00FFFF00\
F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF00
99FF0080FF00F300FF00FF7300FF4C00FF4C00FF3300FF5900FFD93300FFCC00FF9900FF00FFA6\
D900FF00FF4C00FF190066FF00FFB3B300FF00FF0000FF263FFF0066FF0073FF00
4CFF0026FF0000FF9900FF804CFF003FFF004CFF003FFF0000FF000000006600FF0000004C00FF\
0000000000000000000000000000000000007300FF00000000FFBF00FF0C000000
00FF990CFF0019FF0000FF4C00FF0C00FF3300FF990000009900FF00000000000000FF9900FF19\
66FF0073FF0059FF0000F3FF00D9FF00FF333300FF73FF0066FF00A6FF00B3FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00CCFF00\
B3FF00D9FF00D9FF00D9FF00D9FF00C0FF004CFF00A6FF00A6FF00A6FF0099FF00
8CFF0080FF0066FF0033FF0000FF5900D9FF0080FF00FFCC0000000000007300FF00D9FF00FFB3\
00FF9900E6FF19FF0000FF0000FF4000FF6626FF0059FF0000FF4073FF0080FF00
73FF0066FF0000FFB33FFF0066FF0066FF0059FF004CFF000CFF000073FF00FF2600FF80000000\
0000000040FF0000000000000000006600FF00BFFF7300FF00FF5900FF5933FF00
00FF5933FF0033FF0019FF0000FF0000FF2600FF4C00CCFF00000000FF7300E6FF00FF2659FF00\
80FF008CFF0080FF0066FF0073FF001900FF00BFFF8CFF00A6FF00B3FF00C0FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00D9FF00\
8CFF0000FF80C0FF00CCFF00C0FF00B3FF0099FF0073FF008CFF003FFF008CFF00
73FF004CFF004CFF0000FF1900FF590000001900FF0073FF00FFFF00FF4C00D9FF00000000FF59\
0CFF000CFF003FFF0033FF001900FF19FF004CFF0073FF0080FF008CFF008CFF00
8CFF0066FF0059FF0073FF0080FF0080FF0066FF0033FF000CFF0000FF1919FF000000FF00FF33\
00FFA60073FF00000000000000000000000000FFA600FFA600FF4C19FF004CFF00
4CFF004CFF003FFF0026FF0000FFD900FF4000FF6600000000000000FF0C00000000A6FF80FF00\
99FF00A6FF0099FF0099FF0099FF0080FF004CFF0099FF00B3FF00B3FF00C0FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00\
D9FF00C0FF0033FF008CFF0099FF008CFF0080FF0000FFE600FF730CFF004CFF00
59FF0000FF400CFF0000F3FF00000000FFF300FF9900FFB30CFF0000FF0000FF9900000000F3FF\
0CFF004CFF0066FF004CFF0000FF4C00FFE600FFBF80FF0099FF0099FF00A6FF00
99FF0033FF0066FF008CFF008CFF008CFF0066FF0026FF004CFF004CFF0033FF0019FF0000FF0C\
00FF4000FF8C00FFF30033FF00000000CCFF00FF8000FF1900FF4C0CFF0059FF00
66FF0066FF004CFF000CFF0000A6FF4C00FF00FFA65900FF00FFCC4CFF004CFF004CFF0080FF00\
A6FF00B3FF00B3FF00B3FF00A6FF0099FF000080FF99FF00B3FF00C0FF00C0FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00\
E6FF00CCFF0000FF663FFF004CFF0066FF0000FF9900FF8C00FFB30CFF0000FF66
00FF7300FF8000FF9900FFF300FFFF00FF0C00FF0C3FFF004CFF000CFF0000FF0000FF6600FFF3\
00FF660CFF0080FF0080FF000CFF0000FF1900FF4C00FF8099FF00B3FF00B3FF00
A6FF0033FF008CFF0099FF0099FF0099FF0080FF0073FF0066FF0059FF0033FF0019FF00F300FF\
00FFD900FF990099FF8000FF00000000000000000000FF264CFF004CFF004CFF00
80FF0073FF0000FF190099FF00CCFF00FF8000E6FF00FF8C4CFF000099FF8CFF008CFF0000FF19\
B3FF00C0FF00C0FF00C0FF00B3FF0099FF0000FF2673FF00A6FF00C0FF00CCFF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00F3FF00\
E6FF00CCFF00B3FF0073FF0000FF2600FF4C00FF7300FF4059FF0073FF0033FF00
19FF000CFF0019FF0000A6FF00A6FF4CFF0000FF4C59FF0073FF0033FF004CFF0000FFFF00F3FF\
00FF3380FF0099FF0099FF008CFF0080FF000073FF99FF00B3FF00B3FF00C0FF00
B3FF008CFF00A6FF00A6FF00A6FF0099FF008CFF0080FF0073FF0059FF000CFF000CFF0000E6FF\
00000000D9FF00000000B3FF00000000FFBF00FF6600FF1966FF0080FF008CFF00
8CFF0080FF0059FF0000FF190099FF00FF2619FF003FFF0066FF008CFF00A6FF00B3FF00B3FF00\
C0FF00CCFF00CCFF00CCFF00C0FF0026FF0000FF0C00FF8099FF00C0FF00CCFF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900FFD900FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00\
D9FF00A6FF00A6FF008CFF004CFF0000FFE633FF004CFF0066FF008CFF008CFF00
66FF0080FF0073FF000CFF004CFF008CFF0073FF008CFF0099FF0080FF0066FF0000FF1900FF00\
6600FF73FF00A6FF00B3FF00B3FF00A6FF004CFF00A6FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00A6FF008CFF0080FF0066FF0059FF003FFF0019FF0000FF19\
00FFB300000000E6FF00FF593F00FFC000FF26FF0000FF0C66FF008CFF00A6FF00
A6FF008CFF0059FF000CFF0000FFD900FF7300FF0019FF0000FFA680FF00A6FF00B3FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF0066FF0000FF598CFF00C0FF00D9FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00
FFD900FFD900FFE600E6FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00CCFF00D9FF00D9FF00\
CCFF0099FF0059FF0026FF0000FF5900FF593FFF0080FF008CFF00A6FF00A6FF00
4CFF00A6FF0099FF004CFF0066FF00A6FF00A6FF00A6FF00A6FF008CFF003FFF0019FF0073FF00\
99FF00A6FF00C0FF00C0FF00C0FF00B3FF0000FFFFA6FF00C0FF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00B3FF0099FF0073FF0066FF0026FF0026FF0026FF0000FF1900FFBF\
00FFE600FFCC00FFBF0CFF0000FF2600FFD959FF008CFF0000FF268CFF00B3FF00
B3FF00A6FF0099FF0059FF0000FF1900E6FF00FFD90073FF00A6FF73FF00A6FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00B3FF0000FF66B3FF00CCFF00D9FF00
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00
FFD900FFE600FFFF00C0FF00A6FF00CCFF00CCFF00D9FF00E6FF00D9FF00C0FF0099FF00000CFF\
B3FF00A6FF0059FF0000FF5900000000FF0059FF0099FF00A6FF00B3FF00C0FF00
C0FF00C0FF00C0FF0099FF00A6FF00C0FF00C0FF00C0FF00C0FF00A6FF004CFF000019FF73FF00\
A6FF00C0FF00CCFF00CCFF00CCFF00C0FF0000FF0CA6FF00CCFF00D9FF00D9FF00
D9FF00CCFF00CCFF00C0FF00B3FF0099FF0066FF0000F3FF00FFD9008CFF00FF4C00FF4000BFFF\
1900FF00E6FF33FF004CFF001900FF26FF0080FF00A6FF00A6FF00B3FF00C0FF00
C0FF00B3FF00A6FF000CFF0026FF0000FF9919FF0000FF2600FF3300FFFF99FF00C0FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00D9FF00D9FF00D9FF0099FF00CCFF00D9FF00E6FF00
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900
E6FF00CCFF0000FF4000FF26B3FF0066FF00A6FF00A6FF0000FFB326FF0000FF1900FF4C00FF4C\
8CFF0073FF000CFF0000FF4C00FF0C00FF0000FF198CFF00B3FF00C0FF00CCFF00
CCFF00CCFF00CCFF0000FF7399FF00CCFF00D9FF00D9FF00CCFF003FFF0080FF0026FF0000FF19\
A6FF00CCFF00D9FF00D9FF00D9FF00D9FF00B3FF00C0FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00C0FF00A6FF008CFF0066FF0000FF8000FF8000FF0C0040FF0099FF0040FF\
00FF0000FF4C00FFF380FF0000FF6600FF1966FF00B3FF00C0FF00CCFF00CCFF00
CCFF00C0FF008CFF0099FF00A6FF008CFF0059FF000026FF00FF8099FF0099FF004CFF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00E6FF00E6FF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00
FFE600FFE600FFFF00E6FF00F3FF00B3FF00F3FF00F3FF00E6FF00CCFF008CFF0099FF0059FF00\
0CFF0000FF9900FF0000FF7366FF003FFF008CFF0000FF408CFF00CCFF00D9FF00
D9FF00D9FF00D9FF0099FF0099FF00D9FF00E6FF00E6FF00D9FF00C0FF00C0FF0059FF0066FF00\
B3FF00CCFF00E6FF00E6FF00E6FF00E6FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00CCFF008CFF0000FF0C26FF000CFF0000CCFF0019FF26FF0033FF003FFF004CFF00\
59FF003FFF0099FF00A6FF0099FF0080FF0099FF00C0FF00CCFF00CCFF00D9FF00
D9FF00CCFF0000FF33C0FF00C0FF00A6FF0000FF4000FF2680FF00C0FF00CCFF00D9FF00D9FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00F3FF00F3FF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00
FFD900FFD900FFE600FFF300FFF300FFF300FFF300FFFF00F3FF00CCFF00D9FF00CCFF0099FF00\
66FF000CFF0026FF0000FF5973FF0099FF00A6FF00B3FF00B3FF00CCFF00D9FF00
E6FF00E6FF00E6FF00E6FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00A6FF0099FF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00D9FF00C0FF00A6FF008CFF000CFF0000BFFF00FF193FFF0066FF0073FF0059FF00\
8CFF0073FF00A6FF00B3FF00C0FF00A6FF0019FF00B3FF00CCFF00D9FF00D9FF00
E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00A6FF0000FF7399FF00C0FF00D9FF00D9FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00
FFCC00FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00D9FF00B3FF00\
B3FF008CFF0066FF000C00FF59FF008CFF00B3FF00C0FF00CCFF00D9FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF0099FF00C0FF00\
D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00E6FF00D9FF00CCFF00C0FF008CFF004CFF0000FF4000FFFF00FF0C26FF0080FF0099FF00\
A6FF00B3FF00C0FF00CCFF00CCFF00C0FF0066FF000059FFD9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF0033FF00B3FF00CCFF00D9FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00D9FF00\
C0FF0099FF000CFF004CFF0080FF00A6FF00C0FF00CCFF00D9FF00E6FF00E6FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00D9FF0059FF0000FF0C\
D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00E6FF00D9FF00CCFF00B3FF0080FF0059FF0000FF4000FF5933FF0066FF0080FF0099FF00\
B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00CCFF0059FF00E6FF00E6FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00B3FF000CFF00B3FF00CCFF00D9FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00E6FF00CCFF00\
B3FF0080FF0000FFBF33FF0000FF998CFF008CFF00CCFF00D9FF00E6FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00CCFF000CFF008CFF00\
D9FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFFF00FFFF00FFFF00FFFF00
F3FF00E6FF00D9FF00CCFF0099FF0000FF5900FF3300FF800000FF00FF0C00FF260CFF0080FF00\
B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00D9FF0000FF800CFF0099FF00CCFF00E6FF00E6FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00D9FF00C0FF00C0FF00\
99FF0073FF0000FF2600000000FF6633FF00A6FF00C0FF00D9FF00E6FF00F3FF00
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00E6FF0080FF0099FF00\
E6FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
F3FF00E6FF00C0FF00D900FF26FF008CFF0073FF000CFF000CFF0000FFD90026FF26FF0073FF00\
99FF0099FF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00A6FF0000FF8066FF00CCFF00D9FF00E6FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300E6FF0019FF003FFF00A6FF00\
59FF0000000000FFFF00000000FF0C4CFF0000FF66A6FF00C0FF00D9FF00E6FF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00D9FF00B3FF0000FF33\
CCFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00D9FF0026FF00B3FF00CCFF00CCFF00B3FF0066FF0080FF0000FF7300FF0000FF2600FF40\
8CFF00B3FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00B3FF008CFF0000FF4C00FF59A6FF00CCFF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFFF00FFFF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00D9FF00CCFF00\
B3FF0080FF0000FF730CFF004CFF0099FF00B3FF0080FF000CFF0066FF00D9FF00
FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFF300FFF300FFFF00F3FF0019FF00\
F3FF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFFF0000FFD9CCFF00E6FF00E6FF00D9FF0080FF00B3FF0099FF0080FF004CFF0000F3FF00FFE6\
66FF00C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00C0FF0033FF0000F3FFB3FF00D9FF00F3FF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00E6FF00D9FF00\
C0FF00A6FF0080FF000CFF0066FF0066FF00CCFF00D9FF00D9FF00CCFF00D9FF00
FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFFF00A6FF00\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00A6FF0080FF004CFF0000FF4066FF00\
000000B3FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00E6FF00C0FF0000FF1966FF00A6FF00D9FF00F3FF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFF300FFFF00F3FF00E6FF00D9FF00\
C0FF00A6FF004CFF004CFF0099FF00C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFFF00\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00CCFF008CFF0000FF7300FF4C00FF80B3FF00\
C0FF0073FF0066FF00D9FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00E6FF00C0FF008CFF0059FF0000FF66B3FF00F3FF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00E6FF00D9FF00C0FF00\
00FF6680FF0033FF0000FF0C4CFF00A6FF00CCFF00E6FF00F3FF00FFFF00FFF300
FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFFF00F3FF00D9FF000CFF0000FFBF33FF008CFF00B3FF00CCFF00\
E6FF00D9FF00A6FF00CCFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600
FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00CCFF0026FF00CCFF00E6FF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFE600FFF300F3FF00FFFF00F3FF00E6FF00B3FF00CCFF00B3FF00\
99FF0000FFD966FF0066FF0026FF0099FF00D9FF00E6FF00FFFF00FFF300FFF300
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFF300FFF300FFFF00FFFF00E6FF00D9FF008CFF0033FF0000FF0CCCFF00E6FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF0000FF73F3FF00FFFF00FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFE600FFFF00B3FF0099FF00CCFF00CCFF0073FF0000FF0C80FF00\
59FF0066FF008CFF00B3FF0059FF0073FF00A6FF000CFF00FFFF00FFF300FFF300
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF0099FF0000FF4099FF00A6FF00F3FF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300F3FF008CFF00FFFF00FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFE600FFF300FFFF00E6FF0073FF0033FF0000FF9999FF0000FF19\
8CFF00A6FF00CCFF00D9FF00C0FF00A6FF0000FF66E6FF00FFFF00FFF300FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00A6FF0000FF0CD9FF00F3FF00FFFF00\
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300E6FF00FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFE600FFE600FFFF00F3FF00CCFF0033FF00A6FF00CCFF00CCFF00\
D9FF00B3FF00E6FF00F3FF00E6FF00E6FF00CCFF00D9FF00FFFF00FFF300FFE600
FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF0000FF19D9FF00F3FF00FFFF00FFFF00\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00E6FF008CFF0000E6FFA6FF00D9FF00F3FF00\
F3FF00CCFF00FFFF00FFFF00FFFF00FFFF00E6FF0000FF26E6FF00FFFF00FFE600
FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFE600FFE600FFF300FFF300FFFF00E6FF0000FFCC99FF00E6FF00F3FF00FFFF00FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFE600FFFF00F3FF00D9FF00B3FF0000FF66CCFF00E6FF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF0099FF0059FF00F3FF00FFF300
FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFE600FFE600FFF300FFF300E6FF00CCFF0000FF4C3FFF00D9FF00F3FF00FFFF00FFF300\
FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900FFD900FFE600FFF300FFFF008CFF0000FF4C4CFF008CFF00B3FF00F3FF00FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFF300F3FF0000FF26CCFF00D9FF00
FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFE600FFF300FFFF00F3FF00B3FF003FFF00B3FF00E6FF00FFFF00FFF300FFF300\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFD900FFE600FFE600FFF300F3FF00A6FF00B3FF00CCFF00E6FF004CFF00F3FF00FFF300\
FFE600FFE600FFD900FFD900FFD900FFD900FFE600E6FF00F3FF0059FF00FFF300
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFE600FFF300FFFF00E6FF00C0FF0073FF0000FFBFC0FF00F3FF00FFF300FFF300\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900
FFD900FFE600FFF300FFFF00F3FF00B3FF0059FF00D9FF00FFFF00FFF300FFFF00A6FF00FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600F3FF00FFE600
FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFE600FFFF00E6FF00CCFF0000E6FF0CFF00A6FF00D9FF00F3FF00FFF300FFF300\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFD900
FFE6008CFF00F3FF00CCFF0000FF4CF3FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFE600F3FF00CCFF0080FF0000FF0099FF00CCFF00E6FF00FFFF00FFF300FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFE600FFE600FFE600FFE600
FFF300E6FF0019FF0073FF00E6FF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFE600FFF300F3FF0080FF0099FF0000FFBF8CFF00D9FF00F3FF00FFF300FFE600\
FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFCC00FFD900FFE600A6FF00F3FF00FFFF00
CCFF00CCFF0080FF00E6FF00FFFF00FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFD900FFE600FFF300FFFF00D9FF00B3FF0073FF0000FF2699FF00D9FF00FFFF00FFE600\
FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFFF00C0FF00B3FF00
73FF0000FF1973FF00E6FF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFD900FFD900FFE600FFF300D9FF0099FF0000FF9900FF4099FF00D9FF00D9FF00F3FF00FFE600\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300E6FF0099FF00
C0FF00E6FF00F3FF00F3FF00FFF300FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFD900FFD900FFE600FFFF00E6FF0099FF0080FF0066FF0000FF40F3FF00FFFF00FFF300FFE600\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF0000FF0026FF00
C0FF00F3FF00FFF300FFE600FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFE600C0FF0066FF0066FF004CFF008CFF00C0FF00D9FF00F3FF00FFF300FFE600FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFD900FFD900\
FFD900FFE600FFD900FFD900FFE600FFF300F3FF00FFFF00F3FF00CCFF004CFF00
CCFF00F3FF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFFF00CCFF00FFFF00F3FF003FFF0099FF003FFF00CCFF0080FF00FFF300FFE600FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00F3FF00\
00FF0CCCFF00FFFF00FFF300FFF300FFFF00CCFF00D9FF00CCFF008CFF0073FF00
D9FF00FFFF00FFF300FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFCC00FFD900FFD900FFE600FFF300F3FF00CCFF0099FF004CFF00E6FF00FFF300FFE600FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFD900\
FFF300D9FF0099FF00F3FF0000FF4CE6FF00CCFF0080FF004CFF008CFF00CCFF00
A6FF00E6FF00FFF300FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFCC00FFCC00FFD900FFD900FFE600F3FF0073FF0080FF00B3FF00B3FF00D9FF00FFF300FFD900\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00\
FFD900FFE600FFFF00C0FF0099FF00B3FF004CFF00B3FF00D9FF0066FF00F3FF00
FFFF00CCFF0066FF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFCC00FFCC00FFD900FFE600E6FF0000FF0CC0FF00E6FF00FFF300C0FF00E6FF00FFD900\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFCC00\
FFD900FFD900FFF300FFFF00CCFF00A6FF00C0FF00E6FF00F3FF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFCC00FFCC00FFE600FFFF0080FF00CCFF00FFF300FFE600FFD900FFD900FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFC000FFCC00\
FFD900FFD900FFE600FFFF00F3FF00C0FF00CCFF00F3FF00FFFF00FFF300FFE600
FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFCC00FFCC00FFD900FFFF00D9FF00FFF300FFD900FFD900FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00\
FFD900FFD900FFE600FFFF00D9FF0073FF00C0FF00E6FF00FFFF00FFF300FFE600
FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFCC00FFE60080FF00FFF300FFD900FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFE600FFF3003FFF0019FF000000004CFF004CFF00F3FF00FFE600FFD900
FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFCC00FFE60026FF00FFE600FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900\
FFD900FFE600FFF300F3FF00CCFF008CFF00C0FF00D9FF00FFFF00FFE600FFD900
FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFD900F3FF00FFD900FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFE600FFE600\
FFE600FFF300FFFF00F3FF00E6FF0080FF00E6FF00FFFF00FFF300FFE600FFD900
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900B3FF00F3FF00\
FFFF00F3FF00F3FF00E6FF00CCFF0000FF00D9FF00FFFF00FFF300FFE600FFD900
FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFF300C0FF00\
CCFF00C0FF00CCFF00C0FF003FFF00B3FF0066FF00D9FF00FFFF00FFE600FFD900
FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300
FFB300FFC000FFCC00FFE600FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFFF00E6FF00\
59FF008CFF0000FF4C00FF19CCFF00E6FF0000FFBFB3FF00F3FF00FFF300FFE600
FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFCC00
FFE600FFE600FFE6004CFF00FFFF00E6FF00FFF300FFE600FFF300FFFF00FFFF00D9FF00B3FF00\
C0FF00E6FF00D9FF00CCFF00E6FF00FFFF00FFFF00FFFF00D9FF00B3FF00FFFF00
FFF300FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300
FFCC00FFF300E6FF00FFFF0073FF00F3FF0066FF00E6FF00E6FF0066FF00E6FF00CCFF0059FF00\
8CFF00F3FF00FFFF00FFFF00E6FF00FFE600FFE600FFE600FFF300F3FF0099FF00
D9FF00FFD900FFC000FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFF300
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFB300
FFB300FFCC00FFE600FFD900FFE600FFD900FFE600FFFF00D9FF00D9FF0066FF0066FF00D9FF00\
F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFFF00FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600
FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300FFFF00F3FF008CFF00E6FF00\
FFFF00FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFD900FFE600FFFF00CCFF00F3FF00\
FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFFF00C0FF00CCFF00\
FFFF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFE60000FF004CFF00D9FF00\
F3FF00FFF300FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFF300E6FF0080FF0073FF00\
73FF00FFFF00FFE600FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFFF0099FF0073FF0019FF00\
D9FF00F3FF00F3FF00FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFE600F3FF00D9FF003FFF00\
E6FF00FFE600FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFF300D9FF00CCFF00\
FFF300FFE600FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFD900FFE600FFF300E6FF00E6FF00\
FFF300FFE600FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFB300FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00D9FF00D9FF00\
FFFF00FFE600FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFB300FFCC00F3FF00FFFF00FFF300FFFF00E6FF00F3FF00B3FF00CCFF00C0FF00\
E6FF00D9FF00FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFB300FFC000FFD900FFF30073FF00CCFF00C0FF0073FF00D9FF00FFFF00FFFF00\
F3FF00A6FF00FFE600FFD900FFCC00FFC000FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600
FFA600FFB300FFB300FFC000FFCC00FFD900FFFF00E6FF00FFFF00FFFF00F3FF00FFE600FFE600\
FFE600FFF300D9FF00FFE600FFD900FFC000FFC000FFB300FFB300FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600
FFA600FFB300FFB300FFC000FFCC00FFE60099FF00F3FF00FFE600FFE600FFF300FFD900FFCC00\
FFCC00FFD900D9FF003FFF00FFE600FFD900FFC000FFB300FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFB300FFC000FFCC00FFE600FFF300D9FF00FFF300FFD900FFCC00FFCC00FFC000FFC000\
FFC000FFCC00FFD90000FF0CA6FF00FFFF00FFC000FFB300FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600
FFB300FFB300FFC000FFD900FFFF004CFF00D9FF00FFF300FFCC00FFC000FFC000FFC000FFB300\
FFB300FFC000FFC000FFD900FFD90099FF00FFC000FFB300FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300
FFB300FFC000FFCC00FFF300B3FF00FFE600FFD900E6FF00FFD900FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFE600FFC000FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFB300
FFCC00FFE600A6FF00FFE600FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFC000FFC000
FFD900A6FF00FFE600FFCC00FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFFF00FFFF00
C0FF00B3FF00FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFC000FFE600
FFE600FFD900FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFCC00FFF300
FFD900FFC000FFB300FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFC000FFFF00C0FF00
FFF300FFC000FFB300FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF9900FFA600FFB300FFCC00F3FF00FFCC00
FFC000FFC000FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600FFCC00E6FF00FFB300FFB300
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FFA600FFCC00FFB300FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFC000FFCC00FFCC00FFD900FFE600FFD900FFD900FFE600FFF300F3FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFC000FFD900A6FF00E6FF00B3FF00FFFF00FFF300FFF300FFFF00CCFF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFC000FFCC00FFE600FFFF00E6FF0066FF00F3FF00CCFF00E6FF008CFF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFC000FFC000FFCC00FFD900FFE600F3FF0000FF2699FF00B3FF00A6FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFCC00FFCC00FFD900FFF300C0FF00A6FF0026FF0000FF8C
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFCC00FFD900F3FF00E6FF00D9FF00CCFF00A6FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFFF00F3FF00D9FF00A6FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFFF00E6FF008CFF00A6FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFC000FFCC00FFE600FFF300FFF300FFFF00C0FF0000FF8C80FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFC000FFCC00E6FF0019FF00E6FF00E6FF00CCFF0000FF00C0FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300\
FFC000FFC000FFCC00FFD900FFE600F3FF0059FF00B3FF0026FF00CCFF00F3FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFB300\
FFC000FFC000FFCC00FFD900FFF300F3FF00C0FF0019FF008CFF00CCFF00E6FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000\
FFCC00FFCC00FFD900FFE60026FF00D9FF0099FF0099FF00B3FF003FFF0000FF73
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFCC00\
FFD900F3FF00F3FF00D9FF0073FF00B3FF00F3FF0099FF00F3FF0099FF00C0FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFF300\
C0FF00CCFF00FFFF00FFF300FFF300C0FF00FFE600FFE600FFE600FFF300D9FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFCC00FFF300\
CCFF00F3FF00FFD900FFCC00FFCC00FFE600FFD900FFCC00FFD900FFE60099FF00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFE600B3FF00\
CCFF00FFD900FFCC00FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFF300
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFB300F3FF00FFCC00FFCC00\
FFE600FFC000FFC000FFC000FFB300FFB300FFC000FFC000FFC000FFC000FFCC00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900\
FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900FF5900
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFCC00FFCC00FFD900FFE600FFFF00F3FF008CFF00A6FF00E6FF00FFFF00FFF300\
FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00F3FF00E6FF00D9FF00\
C0FF00A6FF0073FF0000FFBF00FF0C66FF008CFF0099FF008CFF004CFF00C0FF00
CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF0026FF0073FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF0066FF000CFF0033FF003FFF00
26FF003FFF003FFF0019FF0000FF5900FF8C00D9FF00FF9900FFE6000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300F3FF00C0FF008CFF00D9FF004CFF00CCFF00\
FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00\
C0FF00A6FF0073FF0000FF0C0CFF003FFF0099FF00B3FF00B3FF00B3FF00C0FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF0099FF0000FFA699FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF0099FF0059FF0000FFCC66FF0073FF0066FF00
59FF0059FF004CFF0000FF2600FF0C00FF0C00FF4000FF8000FFCC00D9FF0000FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300D9FF008CFF00E6FF00FFFF00FFF300FFFF00\
FFF300FFD900FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00\
73FF003FFF0000FF0000FF5933FF008CFF00A6FF00C0FF00CCFF00CCFF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00B3FF0073FF0073FF00A6FF00C0FF00C0FF00\
CCFF00CCFF00C0FF00C0FF00B3FF008CFF003FFF0080FF008CFF008CFF0080FF00
73FF0066FF0059FF003FFF0026FF000CFF0000FF2600FF5900FFA600BFFF0099FF5900FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000
FFC000FFC000FFCC00FFCC00FFD900FFF300FFFF00B3FF00D9FF00FFFF00FFF300FFE600FFD900\
FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF00\
B3FF0066FF0000FF0C19FF004CFF003FFF008CFF00C0FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00C0FF004CFF0080FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00A6FF00A6FF0099FF0099FF0099FF008CFF00
80FF0073FF0059FF004CFF0033FF0000FF2600FFA600000000FFF30026FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000
FFC000FFCC00FFCC00FFD900FFE600FFFF00C0FF00A6FF00F3FF00FFF300FFE600FFD900FFD900\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00CCFF00C0FF00B3FF00\
73FF0000FF0033FF00A6FF00A6FF0066FF00A6FF00CCFF00D9FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF00A6FF00CCFF00CCFF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00A6FF0099FF008CFF00
80FF0059FF004CFF0019FF0019FF0000FF0000FF3300FF80000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000
FFCC00FFCC00FFD900FFD900FFE600FFFF00D9FF0066FF0059FF00FFF300FFE600FFD900FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00C0FF0033FF00\
00FF26B3FF00A6FF00C0FF00CCFF00C0FF004CFF00CCFF00D9FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00B3FF00A6FF0099FF008CFF00
66FF0026FF0019FF0000FFF33300FF00FF4000FF7300FFA6C000FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000
FFCC00FFF300FFE600FFF300FFFF0080FF0073FF00E6FF00FFFF00FFF300FFD900FFD900FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00D9FF00B3FF0000FF19\
99FF00CCFF00D9FF00E6FF00E6FF00D9FF0066FF0000FF33E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF008CFF00
80FF0066FF004CFF0026FF0000FF190000000073FF00FFFF0040FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFD900
F3FF00A6FF0026FF0019FF003FFF0099FF00D9FF00F3FF00FFF300FFE600FFD900FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00CCFF0000B3FFC0FF00\
00FF99D9FF00E6FF00F3FF00F3FF00E6FF00B3FF0099FF00D9FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00B3FF00A6FF0099FF008CFF00
80FF0066FF004CFF0033FF0000FF333F00FF0000000040FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000
FFCC00FFF300FFE600FFF300FFFF00E6FF008CFF00D9FF00FFF300FFE600FFD900FFCC00FFCC00\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF00C0FF00A6FF00D9FF00E6FF00\
E6FF00F3FF00F3FF00FFFF00F3FF00F3FF00E6FF008CFF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0073FF0073FF0073FF00
59FF0059FF0033FF0000FF3300FF4000FF99008CFF000000000000000000000000000000000000\
0000000000001900FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000
FFC000FFCC00FFD900FFE600FFF300F3FF00A6FF00E6FF00FFFF00FFE600FFD900FFCC00FFCC00\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFE600FFE600FFF300FFF300FFFF00A6FF00D9FF00C0FF0019FF00D9FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF0099FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00D9FF00CCFF00C0FF00B3FF00A6FF0099FF0080FF003FFF003FFF00
00FF0C0CFF000CFF0000FFF300FFD90000000000000000000000001900FF9900FF8000FF000000\
0000000033FF0059FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFC000FFC000FFCC00FFD900FFF300F3FF00B3FF00C0FF00B3FF00F3FF00FFE600FFD900FFCC00\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFE600FFE600FFF300FFFF00FFFF00F3FF00D9FF0073FF0000FF0CCCFF00E6FF00F3FF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
E6FF00E6FF00D9FF00B3FF000CFF000CFF008CFF0019FF0066FF0033FF0000FFE6
0026FF00FFE60000006600FF0000000099FF00FFB3B300FF0000000066FF0080FF0059FF8C00FF\
00000000FFCC000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFC000FFC000FFCC00FFD900F3FF0033FF00F3FF00FFF300FFF300E6FF00D9FF00FFE600FFCC00\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFE600FFF30080FF00E6FF00E6FF00A6FF00C0FF0000FF3399FF00E6FF00F3FF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
E6FF00E6FF00D9FF00CCFF00B3FF00A6FF0080FF0000FF8C00FF0C00FF730059FF
00E6FF19FF003FFF0026FF0000FFA600FF0C4C00FF00FF7300FFFF00000000FFA600FF8000FFA6\
00FF8000FF8000FFB300CCFF2600FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFC000FFCC00FFE600F3FF00CCFF00F3FF00FFE600FFD900FFD900FFF300D9FF00FFCC00\
FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFE600FFF300F3FF00B3FF0099FF0099FF0000FF4C8CFF00CCFF00CCFF00FFFF00FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
E6FF00E6FF00D9FF00CCFF00C0FF00B3FF0099FF0000FF5900FF4C00D9FF00FF73
33FF004CFF0066FF0059FF0026FF003FFF0019FF0000FF330073FF9900FF00FF7300FF3300FF73\
00FF3300FF6600E6FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFC000FFD90073FF0099FF00FFFF00FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600
FFE600FFF300F3FF00D9FF00A6FF0066FF0000FF66D9FF00F3FF00FFFF00FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00\
E6FF00E6FF00D9FF00CCFF00C0FF00B3FF003FFF0019FF00000CFF00FF0C000000
59FF0073FF0080FF0073FF0066FF0066FF004CFF000CFF0000000000FF4000FF400CFF0000FF0C\
00FF0C00FF400099FF0026FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300
FFB300FFC000FFCC00FFE600A6FF00FFFF00FFD900FFCC00FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600
FFF300FFFF00F3FF0073FF0099FF008CFF00CCFF00E6FF00FFFF00FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00\
E6FF00E6FF00D9FF00CCFF0066FF0099FF0066FF0000FF2600FF8C33FF0066FF00
3FFF008CFF0099FF008CFF008CFF0080FF0000FF008C00FF0CFF0033FF0000FF0C33FF0026FF00\
00FF0000FF4000FFCC0000000000000000000019FF0C00FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300
FFB300FFC000FFCC00FFFF00FFF300FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFE600FFF300FFF300FFF300
FFFF0019FF00CCFF0000FF0066FF0033FF00CCFF00F3FF00FFFF00FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00\
E6FF00D9FF00CCFF00C0FF00A6FF0000FF664CFF000CFF004CFF0059FF008CFF00
8CFF0099FF00A6FF0099FF0099FF0080FF0066FF000099FF3FFF0059FF004CFF004CFF0026FF00\
00FF263F00FF0000FF00FF8C00A6FF00BFFF00FFF3F300FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300
FFB300FFC000FFD900F3FF00FFD900FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFCC00FFD900FFFF0066FF0099FF00F3FF00
E6FF00C0FF0000FF0CA6FF0019FF00E6FF00C0FF00D9FF00FFF300FFF300FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00\
D9FF00C0FF00B3FF00A6FF0000FFFF73FF0099FF0099FF008CFF0066FF00A6FF00
B3FF00B3FF00B3FF00A6FF0099FF0080FF0000FF3366FF0073FF0073FF0066FF0059FF0033FF00\
00FF5900CCFF00FF0C00FF1900FFF300FF8000FF8C0080FF0000009900FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300
FFC000FFCC00FFFF00FFFF00FFCC00FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFE600FFF300F3FF00C0FF00
00FF8C33FF008CFF00D9FF00F3FF00FFFF00FFFF00F3FF00FFF300FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF0099FF00\
C0FF0099FF0000BFFF8CFF00C0FF00C0FF00C0FF00C0FF00A6FF0019FF00B3FF00
C0FF00C0FF00C0FF00B3FF0099FF000CFF0059FF008CFF008CFF0080FF0073FF003FFF001900FF\
26FF000CFF0019FF0000FF3300FF1900FF3300FFCC00FF9900000000F3FF000000
C000FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300
FFC000FFF300E6FF00FFD900FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFFF00E6FF00
C0FF0099FF00C0FF008CFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00D9FF00A6FF00\
3FFF0000FF0C73FF00C0FF00CCFF00CCFF00CCFF00CCFF00C0FF0099FF00C0FF00
C0FF00C0FF00C0FF00C0FF00A6FF0080FF0099FF0099FF0099FF008CFF0073FF0000FF4C4CFF00\
4CFF003FFF0033FF0019FF000CFF0000FF2600FF4000FF6600FF8C00FFD900D9FF
0040FF3300FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300
FFB300FFD900FFF300FFE600FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFFF00CCFF00
B3FF00B3FF00E6FF00F3FF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300F3FF0019FF00CCFF0099FF0080FF00\
26FF008CFF00C0FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF0080FF0073FF0066FF00\
59FF004CFF0033FF0026FF0000FF0000FF1900FF4000000000FFE600FFE6000000
0066FF3F00FFCC00FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFB300A6FF00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFF300F3FF00C0FF00
00FF2619FF00D9FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300F3FF00D9FF004CFF0000FF0C8CFF00\
99FF00C0FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0073FF00\
66FF004CFF000CFF0000FF0000FF2600FF8000FF7300FF8000FFCC5900FF0019FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFB300FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFE600FFFF0033FF00C0FF00
D9FF00E6FF00A6FF00FFFF00FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300F3FF00D9FF0000FF5980FF00C0FF00\
D9FF0099FF00E6FF00E6FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0080FF0073FF00\
66FF004CFF0026FF000CFF0000FFCC00FFE600CCFF00000000F3FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFE600B3FF00A6FF00FFFF00
FFF300FFF300F3FF00D9FF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFFF00E6FF003FFF0026FF0073FF00D9FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00B3FF0099FF008CFF0080FF0073FF0059FF00\
59FF004CFF0033FF0019FF0000FF0C00FF4000FFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFCC00FFE600CCFF00FFFF00FFF300FFE600
FFE600FFE600FFE60073FF00FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFE600FFF300F3FF00C0FF00E6FF00F3FF00B3FF00E6FF00\
F3FF00F3FF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF008CFF0000E6FF66FF0059FF0000FF59\
33FF0026FF0019FF0000FF0000FF1900FFB300BFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFC000FFC000FFD900D9FF00FFFF00FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00D9FF00D9FF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF0073FF0000FF190CFF0000FFA6\
00FF6600FF2600FF0000FF7300FF4000FF7300FFD90066FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFC000FFC000FFF300FFF300FFE600FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
E6FF00D9FF00CCFF00C0FF00B3FF00B3FF00A6FF0099FF0080FF0059FF0000FF00A600FF00D9FF\
00FFFF00FFBF00000000FFCC00FF9900FFA60066FF000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000003F00FF9900FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFC000FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
E6FF00D9FF00B3FF00A6FF008CFF0080FF0066FF0073FF0000FF3300FF4C00FFF300FFCC0CFF00\
26FF0000FF400033FF8000FF1900FF00CCFFA600FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000004CFF\
004CFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
E6FF00CCFF00A6FF0000FFA60099FF66FF0080FF008CFF0066FF0059FF0000FF2633FF004CFF00\
4CFF0019FF0000FF3300FFB30000002600FF000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000E6FF\
00BFFF6600FF7300FF8000FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00
E6FF00A6FF00A6FF0080FF00A6FF00A6FF00A6FF00A6FF0099FF0080FF0066FF0073FF0073FF00\
66FF003FFF0019FF0000FF2600FFCC3F00FF008CFF9900FF000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000FFD9\
00FFD900FFCC00A6FF000000000000000000CC00FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00
E6FF00D9FF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF008CFF008CFF008CFF0080FF00\
73FF004CFF0000FF0000FF5900000000000000FFD90066FF7300FF000000000000
000000000000000000000000000000000000000000000000000000000000CC00FF00000000FFBF\
00FF8000FF8C00FFE600000000000000000000A6FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00A6FF0099FF0080FF00\
3FFF0000FF7300FF7300FF0000FF4C00FF9900FF9900FFFF000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000E6FF00FF8C\
00FF5900FFBF008CFF00FFB300FFBF00FFA600E6FF000000000000000000000000
0000003F00FFF300FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00
F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00B3FF00A6FF0099FF008CFF00\
66FF0059FF004CFF0033FF000CFF0000FF2600FF6600FFB30080FF4C00FF000000
00000000000000000000000000000000000000000000000000000000000000000000A6FF00F3FF\
00FF2600FF4C0026FF00FF4000FF4000FFA600D9FF3F00FF000000000000000000
0000000066FF0000000000008C00FF0000000019FF3300FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00
F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF008CFF00\
80FF0066FF0059FF0033FF000CFF0000000000D9FF5900FF0080FFE600FF000000
00000000000000000000000000000000000000000000000000000000B3FF0000000099FF00FF33\
00FF0C00FF0C00FF3300FF0C00FF6600FF730000008C00FF000000000000000000
00E6FF00FFBF00000000000000FFFF00F3FF0026FF000000000000000000000000000000000000\
0000000000000000000C00FF0000FF1900FF0000000080FF7300FF000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF008CFF008CFF00\
80FF0066FF0059FF0019FF000CFF0000FF3300FFB300FFE6000000000000000000
00000000000000000000000000000000000000000000000000000000BFFF00FF8C00E6FF00FF4C\
0CFF0019FF000CFF000CFF0000FF0C00FF408C00FF000000B300FF0000000033FF
0080FF00FF7300000000FF8000FFA6000000004CFF000000000000000000000000000000000000\
00000000000000000000000000D9FF00000000FFCC0000009900FF000000000000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF0099FF0073FF0080FF0080FF0080FF00\
26FF0059FF004CFF0033FF0019FF0000FF000099FF00FFBF00D9FF000000000000
00000000000000000000A6FF00000000CCFF0099FF0000FF00000000FFCC00FF4000FF2600FF33\
26FF0033FF0033FF0019FF0000FF59A600FF0000FF00000000FF99F300FF00FF4C
00FF8C00FF2600FF4000FF5900FFD900FFE6000000000000000000000000000000000000000000\
00000000000000000000000000E6FF00FFA600FF8C00FFBF0066FF00000000FF8C
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00F3FF00
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00A6FF0066FF0000FF4000FF004CFF00\
3FFF0033FF0026FF0026FF0000FF2600FF0C00FF3300FF8C0026FF0026FF000000
0000000000000019FF00FFD900000000FFA60073FF000000D900FF5900FF00FF8019FF0026FF00\
00FF194CFF003FFF0000FFB300F3FF00FF8000FF4000FF3300FF0C00FFD90CFF00
00FF0C00FF0000FF1900FF4000FF7300FFB3000000000000000000000000000000000000000000\
0000000000000000006600FF6600FF00FF8000FF5900000000FFA600FF4C00FFD9
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF0080FF0066FF0000FF26\
00FFB3000CFF00FF190CFF0000FF0C00FFBF00FFD900FF8C0033FF0000004C00FF
0019FF0066FF00F3FF00FFA600FF7300FF730000006600FF00FFB300FF5900FF4C26FF004CFF00\
59FF0059FF004CFF0026FF0000FFD90026FF00FF2633FF0033FF000CFF0033FF00
26FF000CFF0000FF3300FFA600FF9900B3FF00A6FF000000000000000000000000000000000000\
00000000000000000000000000000000FF4C00FF2600FF800073FF00FF2600FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00D9FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0073FF0033FF00\
00FF0000FF2600E6FF00FF2600FF3300FF66008CFF00FFE600A6FF0000000033FF
00FFA600FFA600FF9900FF3300FF1900FF7300FF8000F3FF0026FF0CFF0000FF1919FF0059FF00\
73FF0073FF0059FF0033FF0000FF2600BFFF00FF004CFF004CFF003FFF004CFF00
33FF0000FF0000FFB300FFD9E600FF000000C000FF000000000000000000000000000000000000\
0000000000003300FF00000000000000FF3300FF0000FF0000FF330CFF0019FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFF300FFF300F3FF00CCFF00D9FF00CCFF00D9FF00D9FF00D9FF00
D9FF00CCFF00B3FF0000FFA6A6FF00B3FF00A6FF00A6FF0099FF0099FF0080FF0073FF0059FF00\
33FF0000FF1900B3FF00FF8C00FF8000FFF3000000B300FF0073FF0000FF00FFB3
00E6FF00FF4C0040FF00FF2619FF0000FF0C0099FF00FFFF0066FF33FF0059FF0019FF004CFF00\
80FF0080FF0073FF0066FF0026FF0000FF2626FF0059FF0066FF0066FF0059FF00
3FFF0019FF0000FFE600FF8000FF4000FF800C00FFD900FF0C00FF000000000000000000000000\
0000006600FF008CFF00000000FFF300FF2619FF0026FF0000FF2626FF0033FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFF300FFF300FFFF00D9FF0000FF6600CCFFA6FF00CCFF00CCFF00
CCFF00C0FF00B3FF008CFF0080FF0099FF0080FF008CFF008CFF0080FF003FFF0066FF003FFF00\
0CFF0000FF5900D9FF000000000000000CFF00D9FF00FFA600FFB300000000FFF3
00FF5900FF0C00FF0000FF0C33FF0033FF0000FF4000FF4C26FF004CFF0066FF0073FF0073FF00\
8CFF008CFF008CFF0073FF004CFF0059FF0073FF0073FF0073FF0073FF0066FF00
3FFF0000FF3300FF4000FF0C0CFF0000FF4000FF8C00000000FFD90059FF000000000000000000\
00000000000000FFCC00FFE600FFFF00FF0033FF003FFF003FFF003FFF003FFF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFF300FFF300FFF300FFFF00E6FF00D9FF0099FF0066FF00A6FF00B3FF00
A6FF00B3FF00A6FF008CFF0000FF9966FF0059FF0066FF0073FF0073FF003FFF0033FF0033FF00\
00FF0C00CCFF00000000000000FFBF0C00FF00FF4C00FF1900FF4C0066FF1900FF
00FF6600FF0C33FF0033FF0059FF004CFF0000FF2600CCFF00FF0C4CFF0073FF008CFF0099FF00\
99FF0099FF008CFF0073FF00008CFF73FF0080FF008CFF0080FF0080FF004CFF00
0066FF3FFF003FFF0033FF0026FF0000FF0000FF1900FF4000FFB300FFCC008CFF1900FF000000\
0019FFC000FF00FF8C00FF660026FF00000033FF0059FF0059FF0059FF0059FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00C0FF0080FF003FFF00
80FF0099FF0000FFB366FF0000FF4000FF1900FF3300FF333FFF0033FF0026FF0000B3FF00FF0C\
00FF66008CFF00FFA600FFD900FF2600FF1926FF0019FF0000FFA6A600FF4C00FF
00FFFF00FF2626FF0059FF0073FF0059FF003FFF0000FFB300FF8C0CFF0073FF008CFF0099FF00\
A6FF00A6FF0099FF0073FF0000FF8C80FF008CFF008CFF008CFF0080FF0000FF33
4CFF0059FF0059FF004CFF0033FF0019FF0000FF0C00FF3300FF6600FFA600F3FF008CFF000000\
CC00FF00FFFF00FFE600FF1919FF0033FF0026FF0066FF0073FF0073FF0059FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00CCFF0073FF004CFF00
00000026FF0033FF0000FF3300FF2600FF1900FF1926FF0000FF4000FF8C00BFFF5900FF00FFBF\
0059FF00FF8000FF0000FFBF19FF003FFF004CFF0033FF0000BFFF00FF0000FF4C
0019FF00FF8033FF003FFF0080FF0080FF0066FF004CFF000CFF000033FF59FF008CFF00A6FF00\
B3FF00B3FF00A6FF0080FF002600FF99FF0099FF0099FF0099FF008CFF0080FF00
73FF0066FF0059FF004CFF0026FF000CFF0000FF4C00A6FF00FFA600FFB33300FF4C00FF000000\
0000000000000000001900FF3FFF0059FF0026FF0073FF0080FF0080FF0033FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF0080FF00
00A6FF00FF8000FFCC00F3FF00FF333FFF0033FF0066FF0000FF0C00FF8C00FF59004CFF00FFB3\
00B3FF00FF4C3FFF000099FF004CFF66FF0073FF0000FF4C4CFF0033FF0000FF59
004CFF00FFBF59FF0080FF0099FF0099FF0000FF4C8CFF004CFF003FFF0099FF00A6FF00B3FF00\
B3FF00B3FF00B3FF0099FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF00
80FF0073FF0066FF003FFF0000FF0000FF007300FF00FF8C00CCFF0000000000000000003300FF\
0026FF00D9FF00FF999900FF4CFF0073FF0080FF008CFF008CFF008CFF0073FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00CCFF00C0FF00B3FF008CFF00
00FF1900FF1900FF5926FF0026FF0059FF0080FF008CFF0080FF0026FF004CFF0026FF0059FF00\
00FF6600FF4073FF0080FF000CFF0080FF008CFF0073FF0073FF004CFF0000FF00
00FF8019FF0026FF008CFF00A6FF00B3FF00B3FF00A6FF008CFF0073FF00A6FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF00
80FF0073FF0059FF004CFF0033FF0019FF0000FF0C00FF590040FF00000000000000FFA600F3FF\
00000000FF4C00FF0000000026FF0080FF0099FF0099FF0099FF0099FF0059FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00F3FF00E6FF00E6FF00E6FF00D9FF00B3FF004CFF0099FF0066FF00
59FF0019FF000000004CFF0073FF003FFF008CFF00A6FF0099FF0080FF008CFF0099FF0080FF00\
0066FF66FF0099FF0099FF0033FF0099FF00A6FF0099FF0080FF0000FF594C00FF
00FF0080FF008CFF000040FFB3FF00C0FF00C0FF00B3FF0099FF001900FFA6FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0080FF00
73FF0026FF004CFF003FFF0033FF0000FF0000FF0C00FF660000000066FF00FF5900FF1900FF66\
00FF8C0000FF4CFF0059FF004CFF0073FF0099FF00A6FF00A6FF00A6FF0080FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFD900FFD900FFE600FFFF00CCFF00FFFF00F3FF00D9FF00F3FF00F3FF00\
F3FF00F3FF00E6FF0080FF00CCFF00CCFF00CCFF00B3FF0099FF0000FF1926FF00
00FF1900FF8033FF0066FF008CFF0099FF00A6FF00B3FF00B3FF0099FF00A6FF00B3FF0080FF00\
66FF0073FF00A6FF00B3FF00A6FF00B3FF00B3FF00A6FF0000FFD900B3FF19FF00
73FF0099FF00A6FF00B3FF00C0FF00CCFF00CCFF00C0FF008CFF000099FF59FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF004CFF0066FF00
59FF0033FF000CFF0000FF0C0CFF0000FF0CC000FF00FF8CB300FF00FF7300FF8C26FF000CFF00\
00F3FF0CFF0033FF008CFF008CFF0000FF40A6FF00B3FF00B3FF00B3FF00A6FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFD900FFE600FFF300F3FF0066FF00C0FF00CCFF0059FF00CCFF00D9FF00\
E6FF00D9FF00CCFF00B3FF004CFF0080FF00B3FF00A6FF0099FF0059FF0000FF0C
00000000FF8C00FF3359FF008CFF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
8CFF00A6FF00C0FF00C0FF00CCFF00CCFF00C0FF00B3FF008CFF000CFF0000FF26
66FF008CFF00B3FF00C0FF00CCFF00D9FF00D9FF00CCFF00B3FF0000FF4C99FF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF008CFF0059FF00
0C00FF00FF4C00CCFF00FFFF00FF2600FF4000F3FFCC00FF00000000FFFF3FFF0059FF0019FF00\
00FF334CFF008CFF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00B3FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFCC00FFD900FFFF00D9FF00B3FF00B3FF0000FF8C00FF1900FF4C80FF003FFF000CFF00\
00FF5966FF0099FF0066FF0000FF3333FF008CFF003FFF0080FF004CFF0000FF40
00FF8C00FF5900FF1933FF008CFF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00C0FF00\
73FF0099FF00C0FF00CCFF00D9FF00CCFF00CCFF00B3FF0000FF1959FF000CFF00
00FF198CFF00B3FF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF0099FF00B3FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0099FF0080FF0000FF33
00FF8C00FFA600FF3300FFFF0026FF7300FF0066FF00FF194C00FF3FFF0033FF0080FF0066FF00\
00FFE64C00FF00FF40B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00C0FF00B3FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFCC00FFD900FFE600FFF300F3FF00D9FF00D9FF00E6FF00CCFF00E6FF00E6FF00E6FF00\
D9FF00C0FF0066FF0066FF0080FF004CFF0000FF7300FF2626FF0000FF1900FF00
3FFF0059FF0073FF0080FF000CFF008CFF00B3FF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00\
8CFF0080FF00CCFF00D9FF00D9FF00D9FF00D9FF0000FF33B3FF00A6FF0073FF00
00FF1999FF000CFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00CCFF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF0099FF008CFF0080FF0033FF0026FF00
00FF7300FF730CFF0026FF0000FF1919FF0033FF004CFF003F00FF66FF008CFF0099FF0066FF00\
8CFF0000FF4099FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00CCFF00C0FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFCC00FFCC00FFD900FFD900FFE600FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00E6FF0000FF33C0FF00B3FF0099FF0000FF0C19FF0000FF3300FFE60CFF00
59FF0080FF0099FF0099FF008CFF0000FFA6B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00D9FF00\
CCFF00C0FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF0033FF00
73FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00B3FF0059FF008CFF0080FF0026FF0000CCFF
00FFB300FF4000FF0C4CFF0059FF0066FF003FFF0080FF0080FF0066FF00A6FF00B3FF00B3FF00\
A6FF008CFF008CFF00B3FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFF300FFF300FFF300FFFF00\
FFFF00F3FF00D9FF00D9FF00CCFF008CFF0080FF0066FF0066FF0026FF0000FFBF
59FF0080FF00A6FF00B3FF00B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00A6FF00
A6FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00C0FF00B3FF0099FF0066FF0000FF4C
00FFB300FF2626FF004CFF0066FF0080FF008CFF0099FF0099FF0073FF00B3FF00C0FF00C0FF00\
C0FF00A6FF0000FF66A6FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00D9FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300\
FFFF00FFFF00F3FF00E6FF00D9FF00C0FF00B3FF00A6FF008CFF0059FF0000E6FF
4CFF0066FF00A6FF00C0FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF0066FF00
B3FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF0073FF003FFF00
00FF7300FFE600FF6600FF8073FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00CCFF00CCFF00\
CCFF00C0FF0000FFFF3FFF00CCFF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300\
FFF300FFFF00FFFF00F3FF00E6FF00D9FF00C0FF00A6FF008CFF0000FF8033FF00
73FF0099FF00A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF0059FF00
8CFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF0099FF0080FF0033FF00
00FF8C00FF8C26FF004CFF0073FF0080FF0099FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00CCFF0000FF80D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300\
FFF300FFFF00FFFF00F3FF00E6FF00D9FF00C0FF0019FF0019FF0000FF4C33FF00
66FF0080FF0099FF00B3FF00CCFF00D9FF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00C0FF0033FF00
99FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00A6FF00000CFF3F00FF00FF40
00FF7300FF7300FF8C3FFF004CFF0059FF0033FF00A6FF00B3FF00CCFF00CCFF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600\
FFF300FFFF00F3FF00E6FF00D9FF00CCFF00C0FF00A6FF0073FF0000FF0000FF66
00FF3359FF003FFF00A6FF00CCFF00D9FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00D9FF0099FF00
3FFF00B3FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00B3FF0066FF000000FF3FFF000073FF
00FF2600FF4CF300FF00FF3300FF7359FF0080FF00A6FF00B3FF00C0FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600\
FFF300FFFF00F3FF0080FF0099FF0073FF0099FF0073FF004CFF0000FFBF000000
00FFB300B3FF59FF00A6FF00C0FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00D9FF0059FF00
80FF00CCFF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00E6FF00CCFF0080FF003FFF00B3FF0000FF59A6FF008CFF00
00FF4033FF0000FFD90000FF0073FF33FF0000FF8C66FF0073FF0059FF00D9FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600\
FFF300FFFF00D9FF0099FF008CFF00B3FF00A6FF0066FF000026FF00FFA6000000
00FF994CFF0000FF6600FF7399FF00B3FF00A6FF00D9FF00E6FF00F3FF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF0000FF0CB3FF00
3FFF0099FF00E6FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00E6FF0000FF8080FF00C0FF00CCFF00CCFF00C0FF008CFF00
80FF0080FF003FFF0000FF8000FF1900FF5900FF2633FF00A6FF00C0FF00D9FF00E6FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600\
FFF300FFFF00F3FF00E6FF00D9FF00CCFF00C0FF0080FF0073FF0000FF3300FF0C
0CFF0066FF0099FF00B3FF0099FF0000FF6619FF008CFF00E6FF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00E6FF00
3FFF00E6FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFFF00E6FF00A6FF00B3FF00E6FF00E6FF00D9FF00CCFF0080FF00
B3FF0099FF0073FF0066FF0033FF0000FF8C5900FF19FF00B3FF00CCFF00D9FF00E6FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600\
FFF300FFF300FFFF00F3FF00E6FF00D9FF00CCFF00B3FF0099FF0073FF0000E6FF
26FF0073FF00B3FF00CCFF00CCFF00C0FF00C0FF00C0FF00A6FF00FFFF00FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00
B3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00
C0FF00B3FF008CFF0066FF0019FF0000FF404CFF0019FF0000FF99CCFF00D9FF00E6FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFE600\
FFF300FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00C0FF0099FF0059FF0000FF26
26FF00A6FF00C0FF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
19FF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00
CCFF0080FF0066FF0026FF0000FF0C0033FF8CFF004CFF0080FF00B3FF00CCFF00E6FF00F3FF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300\
FFF300FFFF00FFFF00F3FF00E6FF00CCFF00B3FF00B3FF0099FF0033FF000CFF00
80FF00A6FF00C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00
C0FF0099FF0000BFFF00E6FF3300FF00FF0CB3FF00CCFF00CCFF0066FF0073FF0000FF0CF3FF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFF300\
FFFF00FFFF00F3FF00E6FF00D9FF00CCFF0066FF0080FF0059FF0019FF0000FF40
00FF3380FF008CFF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00B3FF00
73FF0019FF0000FF2673FF00A6FF00C0FF00CCFF00E6FF00E6FF00D9FF00C0FF00B3FF00F3FF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFF300FFF300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00FFFF00\
F3FF00F3FF0059FF00CCFF00CCFF00C0FF00A6FF0066FF0000FF8C73FF0073FF00
59FF000CFF00B3FF00D9FF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00
CCFF0000FF403FFF0019FF0000FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFFF0080FF00A6FF00D9FF00\
E6FF00D9FF00C0FF0000FF0C26FF0099FF0080FF0033FF000CFF0099FF00A6FF00
99FF004CFF0099FF00C0FF00D9FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00F3FF00
D9FF00B3FF0000FF7300FF6680FF00D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFF300F3FF00D9FF00CCFF00\
8CFF00A6FF0033FF0000FF4C66FF0019FF0000FF0C0CFF00A6FF0000FF00CCFF00
C0FF004CFF0019FF0073FF00D9FF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00
E6FF00B3FF0019FF00B3FF00CCFF00C0FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFFF00E6FF00\
C0FF003FFF0000FF003FFF00B3FF0099FF00B3FF0000FF0CC0FF00D9FF00E6FF00
D9FF00C0FF00C0FF0059FF00D9FF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00
E6FF00B3FF0099FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00\
CCFF0059FF0080FF00B3FF00CCFF00D9FF00D9FF00C0FF00CCFF00F3FF00F3FF00
F3FF00F3FF00E6FF00CCFF00D9FF00F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00E6FF00
CCFF0000FF40CCFF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00D9FF00\
00FF004CFF003FFF00C0FF00D9FF00F3FF00F3FF00E6FF0099FF00FFFF00FFFF00
FFFF00FFFF00FFFF00E6FF0059FF00D9FF00F3FF00FFF300FFE600FFE600FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF00
59FF0073FF00D9FF00F3FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFFF00F3FF00E6FF00\
C0FF0000FF3399FF00A6FF00D9FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFFF00F3FF0099FF0000FF0C80FF00FFFF00FFF300FFE600FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00E6FF00CCFF00
8CFF0000FF33CCFF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF30099FF00D9FF00B3FF00\
80FF0019FF0099FF00D9FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFF300FFFF00E6FF0066FF00D9FF00F3FF00FFF300FFE600FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300F3FF0080FF003FFF00
59FF008CFF00D9FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFFF00E6FF0059FF0080FF00\
4CFF00B3FF0059FF00D9FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFFF0059FF0000FF400080FFE6FF00FFE600FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00D9FF0080FF00
00FFA699FF00D9FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFF300F3FF00D9FF0059FF00C0FF00\
D9FF00E6FF00E6FF00A6FF00F3FF00FFF300FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFFF00F3FF00D9FF00D9FF00FFF300FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00CCFF0099FF00
66FF0026FF00A6FF00B3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00FFFF00D9FF0080FF00B3FF00E6FF00\
FFFF00FFFF00FFFF00B3FF00E6FF00FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFF300CCFF00FFE600FFD900FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFE600FFF300FFFF00F3FF00E6FF00B3FF0000FF80
00FFCCA6FF00D9FF00E6FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600F3FF00FFFF00FFFF00A6FF0080FF00D9FF00E6FF00FFFF00E6FF00\
FFF300FFE600FFE600FFF300FFFF00FFE600FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600D9FF00FFE600FFD900FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFE600FFF30066FF0066FF004CFF0066FF0026FF00
99FF00C0FF00E6FF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900
FFD900FFE600FFE600FFF300FFFF0066FF00B3FF008CFF00D9FF00FFFF00FFF300FFF300FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFE600FFE600FFFF00F3FF00D9FF0000FF994CFF00
00FF40C0FF00CCFF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFF300FFFF00
FFF300FFF300FFF300FFFF00F3FF00C0FF0099FF00D9FF00CCFF00FFF300FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFFF00E6FF00C0FF0000FF26
00FF663FFF00CCFF00E6FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600D9FF00
B3FF00F3FF00F3FF0099FF00D9FF00A6FF00A6FF00F3FF00FFFF00FFF300FFE600FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFFF00E6FF00C0FF00A6FF00
66FF004CFF004CFF00CCFF00D9FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFF300
F3FF0099FF00CCFF0099FF0059FF000CFF004CFF00F3FF00FFF300FFE600FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300E6FF00A6FF0073FF0000FF40
3FFF008CFF00C0FF00D9FF0080FF00F3FF00FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300
FFFF00D9FF0066FF0099FF00CCFF00D9FF00E6FF00B3FF00FFF300FFE600FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFD900FFE600FFF300FFFF00F3FF00B3FF0000FF6673FF00
8CFF0066FF00E6FF00F3FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300
F3FF00D9FF0099FF00C0FF00E6FF00F3FF00FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFD900FFE600FFFF00F3FF00C0FF0099FF0000FF80A6FF00
C0FF00D9FF00F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00
D9FF0066FF0000000080FF00D9FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFD900FFFF0059FF00C0FF0000FF2600FF4C0CFF008CFF00
B3FF00D9FF00F3FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000F3FF00FFE600\
FFE600E6FF00FFE600FFD900FFD900FFE600FFE600FFFF00F3FF00FFFF00F3FF00
E6FF00C0FF0099FF00CCFF00F3FF00FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFD900FFF300FFFF00FFFF00FFFF00C0FF00C0FF003FFF00
0CFF00C0FF0080FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFF300\
D9FF0073FF00FFFF00FFF300FFE600FFE600FFF300FFFF00A6FF00D9FF00C0FF00
CCFF00A6FF008CFF00D9FF00F3FF00FFF300FFE600FFE600FFD900FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFD900FFE600FFE600FFF300F3FF00D9FF00C0FF00
8CFF000CFF00CCFF00FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFCC00FFD900\
F3FF00F3FF0066FF00CCFF00FFFF00FFFF00F3FF00F3FF00CCFF0073FF003FFF00
8CFF0000FF4CA6FF003FFF00E6FF00FFFF00FFF300FFE600FFD900FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFE600FFFF00D9FF00A6FF00
80FF0099FF0000FF66E6FF00FFFF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFCC00FFCC00\
FFD900FFF300FFFF00F3FF0066FF00C0FF00CCFF00CCFF004CFF00A6FF00C0FF00
C0FF00CCFF00E6FF00E6FF0073FF00B3FF00F3FF00FFE600FFD900FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600E6FF0080FF0066FF00
66FF00D9FF00F3FF00CCFF00A6FF00FFF300FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00\
FFD900FFD900FFE600FFF3008CFF00CCFF0066FF008CFF00A6FF004CFF00E6FF00
E6FF00C0FF00FFFF00FFFF00FFFF00B3FF003FFF00FFE600FFD900FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFFF00C0FF0033FF00
D9FF00FFFF00FFF300FFF300FFF300CCFF00FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00\
FFCC00FFD900FFE600FFF300FFFF00F3FF00CCFF003FFF00CCFF00E6FF00F3FF00
FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFF300CCFF0059FF00
D9FF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00\
FFCC00FFD900FFE600FFE600FFF300F3FF00D9FF008CFF00D9FF00F3FF00FFFF00
FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFF300CCFF00D9FF00
FFF300FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFD900FFE600FFE600FFFF00F3FF00CCFF0000FF66CCFF00E6FF00FFFF00
FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900B3FF00CCFF00FFF300
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFD900FFE600FFF300E6FF00A6FF00A6FF004CFF0099FF00D9FF00E6FF00
FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFF30000FF4CD9FF00FFE600
FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFC000FFC000FFC000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFD900FFD900FFE600FFF300CCFF00C0FF0073FF004C00FF8CFF0080FF00B3FF00
FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900D9FF00D9FF00FFD900
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900\
FFD900FFE600FFE600FFF300F3FF00E6FF00C0FF003FFF00CCFF00E6FF00FFFF00
FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900CCFF00FFD900FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFD900FFD900FFE600\
FFE600FFE600FFF300FFFF00F3FF00E6FF00CCFF00C0FF00E6FF00FFFF00FFF300
FFE600FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFE600E6FF00FFFF00\
FFF300FFF300FFFF00FFFF00F3FF00E6FF00B3FF008CFF00E6FF00FFFF00FFF300
FFE600FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600F3FF00A6FF00\
F3FF00F3FF0080FF00E6FF00D9FF008CFF0099FF0066FF008CFF00F3FF00FFFF00
FFE600FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFFF00D9FF00\
00FF00C0FF003FFF00B3FF00C0FF0000FF80B3FF00C0FF0080FF00A6FF00F3FF00
FFF300FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00\
B3FF0099FF00B3FF0033FF004CFF00CCFF00D9FF00E6FF00B3FF00CCFF0073FF00
FFFF00FFF300FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FFA600FFB300FFCC00FFD900FFD900FFE600
FFF300C0FF00FFFF00F3FF00FFF300FFE600FFE600FFE600E6FF00FFF300FFFF00B3FF00C0FF00\
59FF00D9FF00E6FF00CCFF00CCFF00D9FF00F3FF00FFFF00FFFF00FFFF00E6FF00
73FF00CCFF00FFFF00FFF300FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FFA600FFB300FFC000FFD900D9FF00C0FF00
B3FF00F3FF0080FF00B3FF0019FF003FFF00FFFF00FFFF00CCFF00E6FF00F3FF00CCFF0000FFD9\
8CFF00E6FF00F3FF00FFFF00F3FF008CFF00FFFF00FFF300FFE600FFE600FFF300
E6FF0080FF00B3FF00D9FF00FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFCC00FFF300
FFE600FFE60099FF00FFF300FFF300FFFF00D9FF00A6FF00A6FF0000FF40C0FF00B3FF00C0FF00\
D9FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFD900FFD900FFE600
FFE600F3FF00FFFF00E6FF00FFE600FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFF300
FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300E6FF00F3FF00A6FF00A6FF0080FF00E6FF00\
F3FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFF300FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFE600FFF300FFFF00E6FF0000FF26E6FF00\
FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300
FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300F3FF00C0FF00E6FF00\
FFFF00FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300F3FF0059FF00E6FF00\
FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300F3FF008CFF00CCFF00\
F3FF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFE600FFF300CCFF0026FF00CCFF00\
E6FF00C0FF00FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFF300F3FF00D9FF0059FF000059FF\
A6FF00D9FF00FFF300FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFFF00CCFF0066FF0033FF0000FF66\
C0FF008CFF0066FF00FFF300FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFE600FFFF00D9FF00CCFF004CFF00\
D9FF00FFFF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300FFFF00D9FF0059FF00\
E6FF00FFF300FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFE600FFFF00E6FF0080FF00\
FFFF00FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00E6FF00E6FF00\
FFFF00FFE600FFD900FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFB300FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFF300F3FF00D9FF00CCFF00\
FFFF00FFF300FFE600FFD900FFCC00FFCC00FFC000FFC000FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300
FFB300FFD900FFE600FFF300FFE600FFE600FFF300F3FF00FFFF00F3FF00C0FF00B3FF0080FF00\
D9FF00FFFF00FFF300FFD900FFCC00FFCC00FFC000FFC000FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300
FFB300FFCC008CFF0099FF00C0FF00D9FF00F3FF0066FF00D9FF00D9FF008CFF00F3FF00E6FF00\
59FF0066FF00FFFF00FFD900FFD900FFCC00FFC000FFC000FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300
FFB300FFC000FFCC00FFE600FFF300B3FF008CFF00D9FF00A6FF0000FF19F3FF00FFF300FFF300\
F3FF00F3FF00C0FF00FFE600FFD900FFCC00FFCC00FFC000FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300
FFB300FFC000FFCC00FFD900FFE600E6FF00E6FF00FFFF00FFFF00F3FF00FFFF00FFE600FFD900\
FFD900FFE600F3FF00A6FF00FFF300FFE600FFCC00FFC000FFC000FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300
FFB300FFC000FFCC00FFD900FFF300A6FF00F3FF00FFE600FFE600FFE600FFFF00FFD900FFCC00\
FFCC00FFD900FFE600C0FF004CFF00FFF300FFD900FFCC00FFC000FFB300FFB300
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300
FFC000FFCC00FFD900FFE600FFF300A6FF00FFFF00FFD900FFD900FFCC00FFCC00FFCC00FFC000\
FFC000FFCC00FFCC00FFE600D9FF00E6FF00FFFF0059FF00FFC000FFB300FFA600
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFB300
FFC000FFCC0099FF00F3FF00E6FF00D9FF00FFE600FFD900FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00C0FF00FFE600C0FF00FFD900FFC000FFB300FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000
FFCC00FFD900FFFF00E6FF00D9FF00F3FF00FFF300FFD900FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFCC00FFCC00FFD900FFE600FFC000FFB300FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFCC00
FFD900FFFF0073FF00FFF300FFD900FFD900C0FF00FFD900FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000F3FF00FFC000FFB300FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFCC00FFE600FFF300
B3FF00FFE600FFD900FFD900FFC000FFC000FFC000FFCC00FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FFA600FFB300FFB300FFC000FFCC00FFFF00F3FF00
FFF300FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FFA600FFB300FFCC00FFD900FFD900FFFF00D9FF00FFE600
FFCC00FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FFA600FFB300FFCC00FFE600C0FF00E6FF00FFFF00F3FF00
FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FFA600FFA600FFC000FFCC00FFF300FFF300FFD900FFCC00
FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FFA600FFB300FFC000FFCC00FFF300FFE600FFCC00FFC000
FFB300FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FFA600FFB300FFD900FFF300F3FF00FFE600FFCC00FFB300
FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FFA600FFB300FFD900F3FF00FFE600FFE600FFFF00FFB300
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FFA600FFB300E6FF00FFF300FFD900FFC000FFB300FFC000FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FFA600FFC000FFE600FFC000FFB300FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF9900FFA600C0FF00FFD900FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF9900FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF5900FF5900FF5900FF5900FF5900FF5900FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF9900FFA600FFA600FFA600FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFCC00FFCC00FFD900FFE600FFF300C0FF00B3FF00F3FF00F3FF00FFFF00F3FF00
66FF00FFFF00FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00\
F3FF0080FF0073FF0000FF0CA6FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0080FF0073FF00
66FF0066FF0059FF003FFF0033FF0019FF0000FF3300FFFF00FF66000000B300FF00A6FF0026FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFCC00FFCC00FFD900FFF300E6FF00CCFF00C0FF00FFF300FFE600FFE600FFF300
C0FF00D9FF00FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00\
D9FF0000FF00C0FF00CCFF0080FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00C0FF00C0FF00B3FF00B3FF0099FF0080FF0080FF0073FF0066FF00
26FF004CFF004CFF003FFF0033FF0019FF0000FF0000FF2600FF590000FF9900FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFCC00FFD900FFF3008CFF00F3FF00FFF300FFE600FFE600FFD900FFD900FFE600
FFE600CCFF00FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300D9FF00\
CCFF00F3FF00F3FF00F3FF00C0FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF004CFF008C00FF59FF004CFF00
0CFF0026FF0000FFF326FF0019FF0000FF0C00FF0C00FF4000BFFF8C00FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFCC00FFE600B3FF00F3FF00FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0080FF0059FF0000B3FF0CFF00
00BFFF00FF6600FF8C00FF0C00FF0000FF4C00FF7300FF4C00FF7300D9FF0059FF9900FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFCC00FFF300D9FF00FFF300FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00\
CCFF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0073FF004CFF0000FF4C0073FF
0059FF00FFB300FFE600FF4C00FF5900FF6600FFD900FF730000FF00D9FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000\
FFD900FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00D9FF00C0FF00\
C0FF00A6FF0099FF0099FF0099FF008CFF003FFF004CFF0000FF0000FFF3008CFF
00FF4000FF0C00FF000000009900FF0066FF0000000040FFD900FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000002600FF0033FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF008CFF00\
99FF0080FF0026FF000CFF0000FFB300FF190C00FF19FF0000FFBF00FF660099FF
26FF0026FF0026FF0000FF0C0080FF00D9FF00000000B3FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000033FF0099FF0099FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00C0FF0080FF00\
0099FF00FFCC3FFF0073FF008CFF008CFF0073FF0073FF003FFF0033FF0033FF00
4CFF004CFF003FFF0000FF591900FF0080FF0000006600FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000D9FF00F3FF0000000059FF000CFF3F00FF000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF0099FF00A6FF0059FF00\
80FF0099FF0080FF00A6FF00A6FF00A6FF0099FF008CFF0026FF0073FF0073FF00
66FF0066FF004CFF0033FF0000FF2600FF2600FF9900B3FF0000000019FF000000D900FF000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000019FF00FFF300FFD9C000FF00FFD90059FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00D9FF00C0FF00\
B3FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF0073FF008CFF0080FF00
80FF0073FF0066FF004CFF0019FF0000FF2600FFF30000000080FF00FFFF00CCFF2600FF000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FFCC00FF9900FFBF00FFA600FFF3CC00FF000000\
0000000000000066FF2600FF000000000000000000000000000000000000000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0099FF008CFF00
80FF0073FF0059FF003FFF0000FF5900FF4C00FFE600FFB300FFBF00FFB30033FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000E6FF6600FF00FF7300FF6600FFA600A6FFF300FF00CCFF\
00FFE600FFFF000000000000000000000000000000000000000000F300FF000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0099FF00
8CFF0066FF0000F3FF33FF000CFF0019FF0000FF4000FF4C00FF4C00FF9900FFBF0019FF3F00FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000008CFF00FF7300FFA600FF4000FF8C008CFF00FF66000000\
00FF8000FFA600FFF30073FF0000000000000000000000000000000059FF000000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00A6FF0099FF00
8CFF0073FF0066FF0059FF004CFF0033FF0019FF0000FF0C00FF4000FF6600FFB300D9FF000000\
D900FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000008CFF00FFBF00FF3300FF2600FF4000FFA600FF4000FF33\
00FF668000FF00A6FF0019FF8C00FF00000000000000000000000000D9FF00A6FF
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00A6FF0099FF00
8CFF0080FF0073FF0066FF0059FF0033FF0019FF0000FF2600B3FF00FFFF00BFFF0000000026FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000004CFF008CFF9900FF00FFA600FF4000FF4000FF0C00FF1900FF2600FF0C00FF26\
00FF9900FF8C00B3FFF300FF0000000000000000008C00FF00CCFF00FFCC00A6FF
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00B3FF00A6FF0099FF0099FF00
8CFF0080FF0073FF0066FF004CFF000040FF00FF194C00FF00FF6600FF800073FF000000000000\
000000000000000000000000000000000000000000000000000000A600FF000000
000000000000008CFF00FFBF00FFB300FF8C00FF4C00FF000CFF0000FF0C00FF0C00FF0000FF0C\
00FF2600FF6600FFBF0000000000000000000000004C00FF0C00FF00FF80004CFF
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF008CFF008CFF00
80FF0073FF0066FF0066FF004CFF003FFF0026FF0000FF0000FF1900FF4C00FFBF0000007300FF\
000000000000000000000000000000D900FF0026FF000000CC00FF0C00FF000000
000000000000004CFF00FFA600FF4C00FFB33300FF0CFF0026FF0026FF0026FF0019FF0000FF0C\
00FF4C00FF6600CCFF00000000D9FF004CFF00A6FF00FFB300FF6600FF4000FF73
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00CCFF00CCFF00C0FF00C0FF0099FF0033FF0033FF004CFF0073FF00
73FF0066FF003FFF004CFF003FFF0033FF0026FF000CFF0000FF0C00FF4000FF8000FFD90080FF\
0000000000000000000000000000005900FF00D9FF000000F300FF00F3FF0033FF
5900FF7300FF00F3FF00FFBF00FF2600FF0000FF000CFF0033FF003FFF0033FF0019FF0000FF19\
00A6FF0019FF00000000000000FF4C0080FF00FF7300FF2600FF3300FF1900FF59
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00A6FF003FFF0059FF0033FF0019FF00
26FF003FFF0000FF4026FF0026FF0026FF0000FF0C00FF1900FF1900FF3300FFF3000000000CFF\
B300FF00000000000000000000000000000000FFCC00B3FF00FF9900E6FF7300FF
00000000000000000000000000FF4C26FF0033FF000000003FFF004CFF003FFF0000FF3300FFCC\
0033FF00FF4C00FF2600FFA60CFF0000F3FF00FF190CFF0000FF190CFF0000FF0C
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF0099FF008CFF0080FF0066FF00
00FF0000FF593300FF00FF7300FF000CFF0000FF0000FF3300FF8000FF6600FF8000FFFF000000\
0000000C00FF0040FF008CFF00000000F3FF00FF8C00FF7300FF6600FFA6008CFF
0040FF00000000FF8000FFA600FF0C33FF004CFF0059FF0059FF0059FF004CFF0033FF0000FF33\
004CFF00FF8000FF0026FF0033FF0000FF0026FF0033FF0026FF0019FF0000FF19
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF00A6FF0099FF0080FF0073FF00
0CFF0000FF6600FF3300FFA600FF7300FF1900FF1900FF3300FF9900FFCC00FFCC00FFF3000000\
4C00FF0000FF00FFE60059FF0073FF00FF7300FF6600FF2600FF8C00FFB3000000
0000000033FF00FF1900FF9900FFA633FF0059FF0066FF0066FF0066FF0059FF0000FFBF00FF0C\
0033FF0059FF00FF263FFF004CFF0033FF003FFF003FFF0033FF0019FF0000FF19
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300
FFFF00F3FF00F3FF00E6FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF0099FF00\
59FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0073FF00
59FF0033FF0019FF0000FF6600FF9900FF4C00FF5900FF6600FFBF00000000A6FF0C00FF000000\
00000000BFFF00FFA600FF6600BFFF00FF5900FF0C00FF0000FF3300FF2600FF59
0080FF00FFE60CFF0033FF003FFF0000FF2659FF0073FF0073FF0073FF0066FF0059FF003FFF00\
00FF0C00FFB300FF264CFF0059FF0059FF0059FF004CFF003FFF000CFF0000FF4C
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFFF00D9FF00B3FF00C0FF00B3FF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00A6FF00\
00FF5999FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0073FF00
59FF003FFF000CFF0000FF99CC00FF00FFBF00E6FF00FFB30059FF0000000099FF00F3FF000000\
0033FF00FF9900FF5900FF3300FF4C00FFA600FF0C19FF0000FF000CFF0000FF26
0026FF00FF1900FF404CFF0066FF004CFF0033FF0080FF0080FF0080FF0080FF0073FF004CFF00\
00CCFF3FFF003FFF0059FF0066FF0066FF0066FF0059FF004CFF0033FF0000FF19
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFFF00F3FF00CCFF0066FF0000FF8C00FF00C0FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00\
8CFF0073FF008CFF008CFF0000FF0C8CFF008CFF008CFF0026FF0059FF0059FF00
4CFF0000FF5900FF190073FF0099FF0000000073FF0019FF00D9FF0059FF00FFA600FF800099FF\
00000000FFF300FF8000FF2600FF000CFF0000FF0033FF0033FF0019FF00000000
00FF2619FF004CFF0066FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF0080FF0059FF00\
3FFF0066FF0073FF0073FF0073FF0073FF0073FF0059FF003FFF0019FF0000FF4C
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFFF00F3FF00D9FF00CCFF0000FF5980FF0080FF00B3FF00B3FF00A6FF00B3FF00B3FF00A6FF00\
73FF0000FFCC66FF0073FF000CFF0073FF0073FF0073FF0059FF0000FFB33FFF00
33FF000CFF000080FF00A6FF00000000000000A6FF00FFCC00FFBF00FF5900FF2600F3FF0073FF\
00000000FFF300FF6600FF1919FF0033FF0026FF004CFF004CFF0026FF0000FFFF
00FF730CFF003FFF0066FF0080FF008CFF008CFF0099FF0099FF0099FF008CFF0080FF0026FF00\
4CFF0073FF0080FF0080FF0080FF0080FF0073FF004CFF00C000FF26FF003FFF00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00
FFFF00F3FF00F3FF00E6FF00CCFF00C0FF00A6FF0000FF1980FF0080FF0099FF008CFF0080FF00\
73FF0000FF1900FF0000FF000026FF26FF004CFF0059FF004CFF0000FF8000FF80
0CFF0000FF3300FFA600CCFF0080FF00A6FF00FF8000FF1900FF590CFF000CFF0000FF1900FF80\
4C00FF9900FF00B3FF00FF5919FF003FFF0059FF0066FF0066FF0000B3FF00FF19
00B3FF00FF4000FF4C4CFF0080FF008CFF0099FF00A6FF00A6FF0099FF0099FF0073FF00008CFF\
59FF0080FF008CFF008CFF008CFF008CFF0073FF0026FF0033FF004CFF0059FF00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00
FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF0059FF000033FF00FF8080FF0080FF000066FF\
3FFF0000FF0000F3FF0066FF00FF4000FF4C0CFF0026FF0026FF0000FF0C00FF99
00FF4000FF66004CFF00FF5900FFB300FF8000FF1926FF0000B3FF3FFF0026FF0000FF7300FF33\
00FF590066FF0000000066FF00FF8C33FF0066FF0073FF0080FF0066FF0026FF00
00000000FF660059FF00FF8066FF0099FF00A6FF00A6FF00A6FF00A6FF0099FF0059FF0000FF4C\
73FF008CFF0099FF0099FF0099FF008CFF0080FF0073FF0066FF0066FF0066FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00
FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF0099FF0080FF0000FF803FFF004CFF000CFF00\
00FFD900FF4000FF3300FF0C33FF003FFF0000FF733300FF00FF7300FFD90066FF
00FFD900FFCC0066FF00FF0C19FF0000FF8C00FF403FFF0059FF0059FF004CFF0000FF9919FF00\
00FF6600FF590000FF00FF4C26FF004CFF0000A6FF8CFF008CFF0080FF0033FF00
66FF004CFF008C00FF73FF0080FF0099FF00A6FF00B3FF00B3FF00B3FF00A6FF0099FF003FFF00\
80FF0099FF00A6FF0099FF0099FF0099FF008CFF0080FF0080FF0073FF0066FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00
F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF00A6FF0073FF0000FF7300B3FF00FF0C0040FF\
00FF8C00FF7333FF0059FF0059FF0066FF0033FF0019FF0000FF7300FF0000FFD9
19FF0000FF4000000000FF264CFF0026FF0000FF2600FFD973FF0073FF003FFF004CFF004CFF00\
26FF0000FFBF004CFF00A6FF19FF0073FF008CFF0099FF0099FF0099FF0080FF00
8CFF003FFF0000FFFF80FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00B3FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0073FF0066FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00
F3FF00F3FF00E6FF00E6FF00CCFF00C0FF00C0FF00A6FF008CFF0059FF0000FF0C00FF7300FF0C\
26FF0000FF0033FF0073FF0080FF008CFF0066FF0073FF0000FFBF59FF0000FF19
59FF0033FF0000FFCC0CFF0073FF0073FF0059FF0073FF008CFF008CFF0066FF0073FF0066FF00\
33FF0000FF2600FFA626FF00004CFF66FF0099FF00A6FF00A6FF00B3FF00A6FF00
A6FF008CFF0000FF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0073FF0066FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00
E6FF00E6FF00E6FF00D9FF00B3FF0059FF00A6FF0099FF0080FF0066FF0033FF0000FF4C00FF00\
4CFF0066FF003FFF0066FF008CFF0099FF0099FF008CFF004CFF008CFF0080FF00
80FF0019FF0026FF0073FF008CFF0099FF0066FF0066FF0099FF0099FF0099FF0080FF0059FF00\
00FF0C00FF4C00FF8066FF0080FF003FFF0080FF00B3FF00B3FF00C0FF00B3FF00
B3FF0099FF0000FF198CFF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF008CFF0080FF0059FF0059FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600E6FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF0000FF40
D9FF00D9FF00D9FF00CCFF00C0FF0080FF0000FFCC73FF0033FF003FFF0000FF0000FFF326FF00\
00FF6680FF0080FF0073FF00A6FF00A6FF00A6FF0099FF004CFF00A6FF00A6FF00
8CFF0000FF1900FFB380FF00A6FF00A6FF0099FF0080FF00A6FF00A6FF0099FF0080FF0059FF00\
00D9FF26FF0066FF0073FF0099FF0099FF008CFF00B3FF00C0FF00C0FF00C0FF00
C0FF00A6FF0000BFFF80FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00B3FF00A6FF0099FF0080FF0080FF0073FF004CFF0026FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300F3FF00C0FF00\
F3FF00F3FF00D9FF00D9FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00B3FF00
B3FF00CCFF00CCFF00C0FF00B3FF00A6FF0080FF0000FF6600FF3300E6FF0066FF0CFF004CFF00\
73FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF00B3FF00B3FF00
A6FF008CFF0019FF0099FF00B3FF00C0FF00C0FF00B3FF00C0FF00B3FF00A6FF0066FF004CFF00\
00FFE633FF0066FF008CFF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00
C0FF00B3FF0059FF004CFF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00B3FF00A6FF008CFF000CFF003FFF000CFF0000FF4000FFCC
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFE600FFF300FFFF00E6FF0019FF00\
B3FF00CCFF00B3FF00A6FF00C0FF00CCFF00D9FF00D9FF00CCFF00CCFF00B3FF00
4CFF00A6FF0080FF00B3FF00A6FF0099FF0080FF0019FF0000FF000099FF0019FF00FF2600FF00\
4CFF008CFF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00A6FF0066FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00C0FF00B3FF0099FF0059FF00\
00FF590CFF0059FF0059FF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00
CCFF00C0FF0059FF0033FF00B3FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00C0FF00C0FF00B3FF00A6FF0099FF0080FF0000FF0000FFB300FFA600B3FF
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFE600FFFF0099FF00E6FF00B3FF00A6FF0066FF00\
73FF0000FF0C66FF0099FF000CFF0059FF0000FF5999FF0073FF00A6FF0080FF00
00FFE63FFF0073FF0099FF004CFF0080FF0066FF004CFF0000FF0000FFFF00FF4000FF6600FF00\
4CFF008CFF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00A6FF004CFF00B3FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00B3FF0080FF0033FF00\
3FFF0000FF3300FF4C80FF00A6FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00B3FF003FFF00C0FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00C0FF00C0FF00B3FF00A6FF008CFF0080FF0033FF0000FF660040FF0059FF
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFE600FFFF00FFFF00F3FF00D9FF0099FF00C0FF00\
D9FF00CCFF00C0FF00D9FF0080FF00D9FF00D9FF0099FF0099FF0000FF3326FF00
59FF004CFF0000FFB30CFF004CFF004CFF004CFF0000FF4C00FF1926FF003FFF0033FF0066FF00\
59FF0073FF008CFF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
CCFF00B3FF0000FFFFB3FF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00B3FF0099FF00A6FF00\
4CFF0000FF0000FF6633FF0059FF00B3FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00D9FF00CCFF0080FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
CCFF00C0FF00B3FF0099FF008CFF004CFF0059FF0033FF0000FF330059FF00FF26
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00B3FF00F3FF00\
F3FF00F3FF00E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00CCFF0066FF00A6FF00
99FF0099FF0000FF0000FF4C00FF4000FF730CFF000073FF0CFF0059FF0073FF0073FF008CFF00\
8CFF0073FF0000FFF373FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00C0FF008CFF00B3FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00CCFF00C0FF00\
A6FF0000FF0019FF00A6FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
CCFF00B3FF0000FF7300FF000CFF0000B3FF00FFD900FF0000FFCC0080FF00FFCC
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600C0FF00FFFF00\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00D9FF00A6FF00CCFF00
C0FF00B3FF008CFF0000FF4C3FFF000073FF0CFF0000FF2600FF4000FF0080FF008CFF0099FF00\
A6FF00A6FF008CFF008CFF00C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00C0FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00\
A6FF0000FF190CFF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00C0FF003FFF00A6FF0099FF0073FF0000FFB33F00FF00FFD900FF400CFF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00E6FF00E6FF00D9FF00
D9FF00C0FF0000FF5999FF0073FF0066FF0059FF00000CFF00FF594CFF0073FF0099FF00A6FF00\
B3FF00C0FF00C0FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00\
CCFF0099FF00A6FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
D9FF00CCFF00C0FF00B3FF00A6FF008CFF0019FF0000FF8C00FF8000BFFF0CFF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00F3FF00F3FF00E6FF00
E6FF00C0FF00B3FF00B3FF00A6FF008CFF0073FF003FFF00004CFF33FF0033FF0080FF00B3FF00\
C0FF00C0FF00CCFF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00\
CCFF0066FF00B3FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
D9FF00D9FF00CCFF00C0FF00B3FF0080FF0066FF0033FF0000FF4000F3FF00FFA6
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00
E6FF00D9FF00CCFF00C0FF00B3FF0099FF0059FF0000FFD90CFF004CFF008CFF00A6FF00B3FF00\
C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00\
A6FF0000FF26A6FF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00D9FF00CCFF00C0FF00A6FF008CFF0073FF0000E6FF00FFE6E600FF00E6FF
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00
E6FF00D9FF00CCFF00C0FF00A6FF008CFF0059FF0000FFB300FF2673FF008CFF0099FF00B3FF00\
C0FF00CCFF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00D9FF00\
C0FF0000FF7399FF00CCFF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00\
E6FF00D9FF00CCFF00A6FF0080FF0033FF0059FF0033FF0000FF2600FF8000FF0C
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00
E6FF00D9FF00CCFF00C0FF0099FF0073FF0000FF8000F3FF33FF004CFF0019FF008CFF008CFF00\
A6FF00CCFF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00D9FF00\
00FF8C00FF5900FF73C0FF00D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00\
D9FF00D9FF00C0FF00B3FF0059FF0000FFB300FF2600FF8000FF591900FF00FFFF
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00
D9FF00CCFF00CCFF00C0FF00A6FF0080FF004CFF0000FFBF00FF4000FF194CFF0026FF0080FF00\
B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00\
CCFF0099FF0000FF0CB3FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00\
D9FF00C0FF00B3FF0080FF0000FF2659FF004CFF0000FF7300FF0C4C00FF00FF26
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00E6FF0059FF00
C0FF00A6FF00A6FF00A6FF0080FF0066FF0000FF33004CFF00000000B3FF00FF2619FF0073FF00\
A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00E6FF00\
CCFF004CFF0080FF00C0FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00D9FF00\
C0FF003FFF0066FF00A6FF00A6FF00A6FF000CFF0080FF0000D9FF00FFCC33FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300E6FF0099FF0000FF66
3FFF008CFF008CFF0080FF004CFF0000FF2600FF1900000000000000CCFF26FF0026FF000CFF00\
73FF00B3FF00B3FF00C0FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00E6FF00\
66FF0000FF2600FF8CA6FF00D9FF00F3FF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00C0FF00\
00FF0026FF00C0FF00CCFF00CCFF00C0FF00B3FF0099FF0000FF3373FF0066FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00E6FF00C0FF00
CCFF00CCFF00C0FF00B3FF0099FF0000D9FF33FF0000FF3300FF9900FF5933FF0080FF003FFF00\
8CFF0000FFBF00FF8C8CFF00B3FF00CCFF00D9FF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00\
E6FF00D9FF0073FF00C0FF004CFF00F3FF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00B3FF00\
00A6FFC0FF00D9FF00D9FF00D9FF00D9FF00C0FF0000FF4CA6FF0099FF0059FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00F3FF00
E6FF00D9FF00CCFF00C0FF003FFF008CFF0059FF004CFF000CFF000CFF0073FF0099FF00B3FF00\
B3FF00B3FF0099FF004CFF0000FF7319FF00D9FF00F3FF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00\
FFFF00E6FF008CFF00D9FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00E6FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00C0FF00B3FF0099FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00
E6FF00E6FF00D9FF00CCFF00B3FF00A6FF008CFF0066FF0000FF0C33FF0026FF008CFF00C0FF00\
CCFF00CCFF00CCFF00CCFF004CFF00CCFF0000FFF3F3FF00FFFF00FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300F3FF0000FF19F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00D9FF00CCFF00B3FF00A6FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00
E6FF00E6FF00D9FF00CCFF00C0FF00A6FF0080FF0033FF0000FF4000FF9999FF00B3FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFFF0026FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00A6FF008CFF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00
E6FF00D9FF00CCFF00C0FF00B3FF00A6FF0073FF0000FF0C4CFF0080FF00A6FF00C0FF00CCFF00\
D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFFF00FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00A6FF004CFF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00
E6FF00D9FF0099FF0080FF0099FF008CFF0073FF0026FF0033FF0066FF0059FF00B3FF00C0FF00\
D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00CCFF00B3FF004CFF0019FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00E6FF00
D9FF00CCFF00C0FF008CFF0000FF0C66FF0000FF7300FF8000FFCC00FFA64CFF0000FF738CFF00\
D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF0066FF00B3FF008CFF0000FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFE600FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF003FFF00C0FF00
CCFF00C0FF00B3FF0099FF0066FF0000FF9926FF0080FF0066FF0066FF0000FFF399FF00C0FF00\
D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00B3FF008CFF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFF30099FF004CFF00CCFF00D9FF00E6FF00E6FF00D9FF00C0FF0073FF00
99FF00A6FF008CFF008CFF004CFF0026FF0066FF00A6FF00A6FF0099FF0000FF268CFF00A6FF00\
CCFF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00CCFF008CFF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFE600FFFF00D9FF00B3FF0099FF00A6FF0000FF00C0FF008CFF0026FF00
00FFBF26FF0066FF0000FF9900FF0C80FF0073FF00B3FF00C0FF00A6FF004CFF0000FF0C26FF00\
00FF0CB3FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF0000FF7300FF19
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFE600FFF300FFFF00F3FF00E6FF008CFF0066FF004CFF0026FF0059FF00
8CFF003FFF000CFF0073FF0019FF00A6FF00C0FF00CCFF00D9FF00CCFF0099FF00A6FF008CFF00\
80FF00D9FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00CCFF0073FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFE600FFF300FFF300FFFF00F3FF00D9FF003FFF0059FF0066FF0080FF00
B3FF00C0FF0073FF00C0FF0099FF00B3FF00D9FF00E6FF00E6FF00E6FF0000FF00D9FF00B3FF00\
66FF00D9FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00F3FF00E6FF00CCFF0019FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFE600FFF300FFF300FFFF00F3FF00D9FF00B3FF0066FF0080FF00B3FF00
CCFF00D9FF00D9FF00D9FF00CCFF00B3FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
CCFF00CCFF00E6FF00FFFF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00E6FF00D9FF0073FF00B3FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFE600FFE600FFF300FFF300FFFF00E6FF0000FF004CFF0019FF0080FF00C0FF00
D9FF00E6FF00F3FF00F3FF00E6FF0059FF00E6FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
D9FF0073FF0000FF4CF3FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00CCFF0099FF0000FF198CFF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFE600FFE600FFF300FFFF00F3FF00E6FF00CCFF00A6FF000CFF008CFF0000FF40
C0FF00F3FF00F3FF00FFFF00FFFF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFFF00\
E6FF0099FF00B3FF00D9FF00B3FF00FFF300FFF300FFE600FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00CCFF008CFF004CFF00C0FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600\
FFE600FFF300FFFF00F3FF00E6FF00D9FF00C0FF00A6FF0000FFD9B3FF00CCFF00
E6FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
F3FF00B3FF008CFF0099FF00E6FF00FFFF00FFF300FFE600FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300FFF300FFFF00D9FF00CCFF00B3FF0000000000FFB3A6FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600\
FFE600FFF300F3FF0073FF00C0FF0080FF0099FF0000FF1900FF0CA6FF00D9FF00
F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFFF00F3FF00A6FF0099FF00CCFF00F3FF00FFFF00FFE600FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300FFF300FFFF00E6FF00C0FF0000FF0C59FF0099FF00CCFF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600\
FFF300FFF300F3FF00D9FF0073FF0059FF0080FF00A6FF00C0FF0080FF00D9FF00
F3FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFFF00CCFF004CFF004CFF0099FF00E6FF00FFE600FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300FFF300FFFF00E6FF00CCFF008CFF0000FF3380FF00A6FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300\
FFF300FFFF00E6FF00CCFF0026FF00B3FF00D9FF00A6FF00E6FF00E6FF0073FF00
E6FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFFF00E6FF00E6FF0099FF00E6FF00FFF300FFE600FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300FFFF00F3FF00E6FF00CCFF00A6FF0073FF0000FF0000FF59
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300\
FFFF00F3FF00C0FF0000FF4059FF00D9FF00F3FF00FFFF00FFFF00FFFF00D9FF00
99FF00FFFF00FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFF300FFF300E6FF00E6FF00FFE600FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600\
FFE600FFF300FFFF00FFFF00F3FF00D9FF0000FF0C0073FF26FF0000FF00B3FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00\
E6FF00CCFF0080FF00D9FF00E6FF00A6FF00FFFF00FFF300FFF300FFF300FFFF00
F3FF00FFF300FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFF3008CFF00FFE600FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600\
FFE600FFF300E6FF00CCFF00D9FF00B3FF0073FF0059FF0073FF0099FF00CCFF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFFF00B3FF00F3FF00E6FF00A6FF00\
33FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFE600F3FF00FFE600FFD900FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFE600FFFF00D9FF008CFF00C0FF0066FF0033FF0073FF0099FF00C0FF00D9FF00
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00D9FF00A6FF0080FF0059FF00\
D9FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFE600FFF300FFFF00F3FF00E6FF00C0FF0059FF0033FF0033FF00B3FF00C0FF00
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFD900D9FF00FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00D9FF0080FF00B3FF00CCFF00\
A6FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFE600FFE600FFF300FFFF00F3FF00C0FF00B3FF0000FF0C00FF6673FF0099FF00
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFF3004CFF00E6FF00FFFF00FFFF00F3FF00E6FF00E6FF00C0FF0000FF408CFF00F3FF00\
FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFE600FFE600FFF300FFFF00F3FF00D9FF00C0FF00A6FF0073FF0000FFE600FF33
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900
FFD900FFF300FFFF00CCFF00D9FF00E6FF00D9FF0000FF0C00FF5973FF0080FF00D9FF00F3FF00\
FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFE600FFE600FFF300FFFF00E6FF00CCFF0080FF0073FF0066FF0000FF8073FF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFE600FFF300F3FF00C0FF0019FF00A6FF003FFF0099FF0066FF00B3FF00B3FF00E6FF00\
FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFE600FFF300FFF300F3FF00C0FF0000FF2626FF0000FF4000FF5973FF00CCFF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFE600FFE600FFF300FFFF00E6FF00A6FF0000FF19A6FF00CCFF00D9FF00E6FF00E6FF00CCFF00\
FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFE600FFF300FFFF00F3FF00CCFF0000FFB366FF0080FF0080FF00A6FF00CCFF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFE600FFE600FFF300F3FF00E6FF00C0FF0033FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFF300\
FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFE600\
FFF300FFFF00F3FF00D9FF00A6FF0080FF0026FF00A6FF00C0FF00CCFF00E6FF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600
FFE600FFF300FFFF00CCFF0000FF0C80FF0073FF00B3FF00D9FF00FFFF00FFF300FFF300FFE600\
FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600\
C0FF0066FF004CFF0000FF333FFF003FFF0066FF00A6FF00C0FF00D9FF00E6FF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300
FFF300FFFF00FFFF00E6FF00CCFF0099FF0080FF00A6FF00CCFF00FFFF00FFF300FFE600FFE600\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900CCFF00\
00FF59D9FF00F3FF00E6FF00CCFF0000FF0C99FF0000FF000CFF00CCFF00D9FF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFE600E6FF00\
FFF300FFF300F3FF00FFE600FFE600FFE600FFE600FFE600FFE600FFFF008CFF00
F3FF00F3FF00F3FF00E6FF00CCFF008CFF00C0FF00D9FF00F3FF00FFFF00FFF300FFE600FFE600\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600\
FFF300FFF300FFF300FFFF00E6FF00C0FF00C0FF0000FF2600FFA6A6FF008CFF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFE600\
99FF00C0FF00CCFF00F3FF00FFF300FFF300FFF300FFF300FFF300FFFF00D9FF00
C0FF00D9FF00C0FF00CCFF00A6FF0066FF00A6FF00D9FF00F3FF00FFFF00FFF300FFE600FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900\
FFD900FFE600FFE600FFF300FFFF00E6FF00D9FF00C0FF0099FF0000FF4C8CFF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900\
99FF00F3FF00C0FF0000FF4CD9FF00FFFF00FFFF00FFFF00FFFF00F3FF00D9FF00
8CFF004CFF0000FF1999FF0033FF0099FF004CFF008CFF00E6FF00FFFF00FFF300FFE600FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFD900FFD900FFE600FFE600FFF300F3FF00CCFF00B3FF008CFF0066FF0000FF19
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900\
FFE600FFE600D9FF00F3FF00E6FF00B3FF00D9FF00A6FF00E6FF00D9FF00A6FF00
8CFF00A6FF00B3FF0099FF00A6FF00D9FF00CCFF00CCFF00A6FF00E6FF00FFFF00FFF300FFE600\
FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFD900FFD900FFE600FFFF00E6FF00B3FF0026FF004CFF0073FF00D9FF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00\
FFD900FFD900FFE600FFF300FFFF00E6FF0059FF0080FF00A6FF00B3FF003FFF00
00FF19C0FF00D9FF00D9FF0000FF99E6FF00F3FF00F3FF00E6FF00B3FF008CFF00FFFF00FFE600\
FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFD900FFE600A6FF00CCFF0000FF5999FF0000B3FF80FF00FFFF00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00\
FFCC00FFD900FFD900FFE600FFF300F3FF00E6FF00CCFF0080FF0033FF00B3FF00
C0FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300F3FF00F3FF00C0FF00FFE600\
FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFD900FFE600FFF300FFFF00CCFF000CFF00CCFF00FFFF00FFF300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00\
FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00CCFF0000FF4CC0FF00
D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFD900FFD900FFE600FFFF0080FF0000FF73C0FF00FFF300FFE600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00D9FF0073FF00CCFF00
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFD900FFE600FFFF0026FF00F3FF00FFF300FFE600FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00D9FF003FFF00CCFF00
E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFD900FFF300C0FF00F3FF00FFF300FFE600FFD900FFD900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFD900FFD900FFE600FFF300FFFF00D9FF00D9FF0099FF004CFF00B3FF00
CCFF00E6FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFD900FFFF0000FF40FFFF00FFE600FFD900FFD900FFCC00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFD900FFD900FFE600FFF300CCFF00B3FF003FFF0066FF0000FF9973FF00
B3FF00C0FF00F3FF00FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFCC00FFCC00FFFF0073FF00C0FF00FFF300FFD900FFD900FFCC00FFCC00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFD900FFD900FFE600FFE600FFF300F3FF00CCFF00B3FF0080FF0000FFA680FF00
66FF00B3FF00CCFF00FFFF00FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFCC00FFD900FFFF004CFF00F3FF00FFD900FFCC00FFCC00FFC000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00CCFF00B3FF0026FF00A6FF00
D9FF00CCFF00FFFF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFCC00FFD900FFFF00FFFF00FFD900FFCC00FFCC00FFC000FFC000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFD900\
FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00C0FF008CFF00D9FF00
F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFCC000CFF00FFD900FFCC00FFCC00FFC000FFC000FFC000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900F3FF00FFF300FFF300\
FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF00B3FF00B3FF00E6FF00
F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFF3008CFF00F3FF00\
FFFF00FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00A6FF0099FF00D9FF00
F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFF300F3FF0080FF00\
E6FF00F3FF00E6FF00CCFF00E6FF00E6FF003FFF00B3FF0080FF004CFF0059FF00
D9FF00F3FF00FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00E6FF00\
0099FFCCFF00CCFF0026FF00B3FF00CCFF00A6FF0000FF33B3FF00C0FF004CFF00
99FF0080FF00F3FF00FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFD900FFE600FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00\
A6FF0080FF0000FF26A6FF0073FF0059FF008CFF00A6FF00D9FF00D9FF00C0FF00
C0FF0000FF26E6FF00FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFCC00FFE6008CFF00FFE600
FFE600FFFF00FFE600FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFF300F3FF00E6FF00\
CCFF004CFF00CCFF00CCFF0073FF00B3FF0099FF00E6FF00F3FF00F3FF00E6FF00
F3FF00F3FF0073FF00CCFF00F3FF00F3FF00FFE600FFD900FFD900FFCC00FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFB300FFE60080FF00FFE600FFF300FFF300FFFF00C0FF00C0FF00
F3FF00A6FF00FFFF00FFF300FFE600FFE600FFF30080FF00FFFF00FFFF00F3FF00B3FF0073FF00\
73FF00CCFF00E6FF00E6FF00E6FF00E6FF0099FF00E6FF00FFFF00FFF300FFF300
FFF300FFF300F3FF008CFF0066FF00E6FF00FFFF00F3FF00FFD900FFCC00FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFB300FFC000FFCC00FFD900F3FF0073FF00D9FF00E6FF00D9FF00
C0FF00D9FF004CFF00A6FF00F3FF00D9FF00F3FF00D9FF00D9FF00E6FF00E6FF00CCFF0059FF00\
59FF00B3FF00F3FF00F3FF00FFFF00FFFF00D9FF0059FF00FFF300FFF300FFE600
FFE600FFE600FFF300E6FF00D9FF0099FF0080FF00F3FF00FFE600FFCC00FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFB300FFC000FFC000FFD900FFFF00FFF300FFE600FFF300
F3FF00FFF300FFFF00FFFF00E6FF00B3FF00B3FF0000FF0C80FF00C0FF00CCFF00B3FF00A6FF00\
8CFF00B3FF00F3FF00FFFF00FFF300FFF300FFF300F3FF00FFE600FFE600FFE600
FFD900FFE600FFE600FFE600FFF300E6FF00FFFF008CFF00FFE600FFCC00FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFB300FFB300FFC000FFC000E6FF00FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFF300F3FF00D9FF00E6FF00CCFF0099FF0066FF00A6FF00D9FF00\
E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE6008CFF00FFD900FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFE600FFFF00FFFF00FFFF00D9FF00E6FF00CCFF00A6FF00E6FF00\
F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFF300FFFF00E6FF0019FF00E6FF00\
FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00F3FF0000FF0CE6FF00\
FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300E6FF0066FF00E6FF00\
FFFF00FFF300FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFE600FFFF00E6FF00A6FF0073FF00\
F3FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300D9FF00CCFF004CFF00CCFF00\
E6FF00F3FF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300F3FF00CCFF0059FF00A6FF00\
D9FF00CCFF00F3FF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFF300FFFF00E6FF00B3FF0019FF0000FFF3\
80FF008CFF00E6FF00FFF300FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFFF00D9FF0059FF0080FF0000FF730040FF\
4CFF00CCFF00CCFF0099FF00FFF300FFD900FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300B3FF00CCFF008CFF0066FF00\
CCFF00F3FF00FFFF00FFF300FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300FFFF00F3FF00D9FF0099FF00\
00FF0CE6FF00FFF300FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300F3FF0066FF00B3FF00\
E6FF00FFFF00FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFE600FFF300FFFF00E6FF0099FF00\
F3FF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00D9FF00\
FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000
FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00CCFF00B3FF00\
F3FF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00
FFCC00FFD900FFD900FFD900FFE600FFF300FFF300FFF300FFFF00F3FF00E6FF00B3FF00B3FF00\
D9FF00FFFF00FFF300FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFC000E6FF00
FFFF00FFFF00FFF300FFE600FFF300F3FF00E6FF00FFFF00F3FF00CCFF003FFF00CCFF00CCFF00\
66FF00E6FF00F3FF00FFFF00FFD900FFCC00FFCC00FFCC00FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00
FFF300E6FF00A6FF00F3FF00F3FF00E6FF00A6FF00CCFF00D9FF0099FF008CFF00F3FF00F3FF00\
A6FF004CFF0099FF00FFFF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00
FFD900FFE600FFF300D9FF00A6FF0080FF00D9FF0000FF0CA6FF00D9FF00FFFF00FFF300FFF300\
A6FF00FFFF00CCFF00E6FF00FFE600FFD900FFD900FFCC00FFC000FFC000FFC000
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000
FFCC00FFD900FFE600FFFF0080FF00F3FF00F3FF00E6FF00E6FF00E6FF00FFF300FFE600FFE600\
FFE600FFE600FFF300CCFF00F3FF00FFF300FFE600FFD900FFCC00FFC000FFC000
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000
FFCC00FFD900FFE600F3FF00C0FF00FFFF00FFF300FFF300FFF30080FF00FFF300FFD900FFD900\
FFD900FFD900FFD900FFF30073FF00F3FF00CCFF00FFE600FFCC00FFCC00FFC000
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00
FFCC00FFD900FFF300B3FF0099FF00FFF300FFE600FFD900FFD900FFE600FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFE600F3FF00E6FF00B3FF00FFF300FFD900FFD900FFC000
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00
FFD900FFE600FFF300CCFF00F3FF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFD900FFFF00B3FF00CCFF00F3FF00F3FF00FFCC00
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFF300
F3FF00F3FF00F3FF0066FF00FFFF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFF300FFF300FFF300B3FF00FFE600FFC000
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFE600
F3FF00CCFF00B3FF00D9FF00D9FF00FFE600FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000F3FF00FFCC00FFD900FFF300FFF300FFC000
FFB300FFB300FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFFF00
8CFF00FFFF00FFFF00FFE600FFFF00F3FF00FFD900FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00E6FF00FFCC00
FFB300FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFD900FFE600FFFF00D9FF00
F3FF00FFE600FFD900FFCC00FFD900FFF300FFCC00FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFD900FFCC00
FFB300FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFB300FFB300FFC000CCFF00FFE600FFFF00E6FF00FFE600FFD900
FFD900FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600\
FFA600FFB300FFB300FFC000FFCC00FFE600D9FF00CCFF00FFFF00FFCC00FFCC00
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600\
FFB300FFC000FFCC00FFCC00FFE600FFF3003FFF00FFE600FFD900FFCC00FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600\
FFC00066FF0080FF00FFF300F3FF00B3FF00CCFF00FFE600FFCC00FFC000FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600\
FFB300FFCC00FFD900FFFF00F3FF00FFF300FFE600F3FF00FFC000FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600\
FFB300FFC000FFCC00FFE600F3FF00FFD900FFCC00FFC000FFC000FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600\
FFB300FFC000FFCC00FFF300FFFF00FFD900FFC000FFC000FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600\
FFB300FFCC00FFE600FFFF00FFF300FFCC00FFC000FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300\
FFC000FFD900B3FF00E6FF00F3FF00FFE600FFC000FFB300FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFA600FFB300\
FFCC00FFFF00FFF300FFCC00FFCC00FFFF00FFCC00FFB300FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFCC00\
D9FF00FFD900FFCC00FFC000FFB300FFB300FFB300FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFC000E6FF00\
FFCC00FFB300FFB300FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFD900FFFF00\
FFB300FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFB300FFC000FFB300\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00D9FF0066FF00\
4CFF0080FF00B3FF00C0FF00CCFF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00
B3FF008CFF0026FF0099FF0099FF0099FF008CFF008CFF0099FF0099FF008CFF0080FF0073FF00\
73FF0066FF004CFF0026FF0019FF0000FF0000FF5900E6FF0040FF0040FF00FFD9
00F3FF000000004CFF00F3FF00FFB300FFB300F3FF0000000099FF00FF9900FF4C00FF2600FF19\
00FF2600FF8C0CFF0026FF0033FF0026FF0000FF0000FF8000000000FF2626FF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00F3FF00E6FF00B3FF00\
99FF0066FF0026FF0099FF00C0FF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00
B3FF0099FF0019FF0073FF0080FF008CFF0073FF0066FF008CFF008CFF0080FF0066FF0000FFBF\
59FF0059FF004CFF0026FF0000FFB300FF4000FF8C1900FF000000000000000000
0033FF00FFE600FFA600FF7300FF5900FFA600F3FF00000000000000F3FF00FF8000FF4000FF00\
19FF0019FF0000FF4C3FFF003FFF0033FF0000FF190073FF00FF2619FF003FFF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF00\
CCFF0066FF00A6FF0000FF0C99FF00B3FF00B3FF0073FF00B3FF00B3FF00B3FF00
A6FF008CFF004CFF0000FF8C66FF0066FF004CFF004CFF0073FF0073FF0073FF0066FF003FFF00\
26FF0033FF0033FF0019FF0000FF330066FF0040FF00000000000000000000FFE6
0C00FF00FFE600FF3300FF4C00FF1900FF5900FF7300BFFF9900FF00FFCC00FF6600FF2600FF00\
26FF0033FF0033FF004CFF0059FF003FFF000CFF0000FFFF00FFCC00FF0000FF33
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00\
D9FF00CCFF00C0FF00B3FF0080FF003FFF008CFF0000FFF399FF00A6FF008CFF00
80FF0080FF003FFF0000FFCC26FF0000FF0C00FF1919FF0033FF0059FF0066FF0059FF0033FF00\
0059FF00FF660CFF0000FF0C0073FF00FFBF00FFD900000000FFF300D9FF00FF73
00FF2600FF660CFF0000FF8C0CFF0000FF1900FF66B300FF000000000CFF00000000FFBF00FF00\
33FF004CFF0059FF0066FF0066FF004CFF0000FF1900FF4CE600FF00FFBF00FF0C
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00\
E6FF00D9FF00CCFF00C0FF00A6FF0019FF0000FF1926FF0000FF668CFF0080FF00
004CFF59FF003FFF0000D9FF00FF7300FFCC00FF9900FFFF00FFD926FF0033FF0033FF0026FF00\
00FF0C00E6FF00FF2600FF4000FF998000FF004CFF00FF6600FF6600F3FF00FFE6
19FF0000FF1933FF0033FF0019FF0000B3FF00FF8C00FF9900FFCC0000000040FF00FFBF00FF19\
00FFB34CFF0066FF0073FF0073FF0066FF0059FF0026FF0000E6FF0066FF6600FF
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00\
E6FF00D9FF00D9FF00CCFF008CFF0080FF003FFF0019FF0033FF0059FF0066FF00
00FF193300FF0CFF0000FF7300FF6600FF4C00FF0C00FF590CFF0000FF2600FF0000FF5900FF26\
00FF8C0073FF00CCFF0066FF3300FF00FF8000FF6600FF0000FF4000FF3319FF00
33FF003FFF004CFF004CFF0019FF0000FFE600FF0C00FF0C00FF6600FF8C0066FF00FF8000FFFF\
19FF004C00FF59FF0080FF0080FF0080FF0073FF0000FF0033FF0000FF0000FF73
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
E6FF00D9FF00D9FF00CCFF00B3FF00A6FF008CFF000CFF0000FF1900FFE633FF00
0CFF0000FF6600FFCC00FFE600FF2633FF0019FF004CFF0026FF0000FF2600FF7300A6FF00B3FF\
00FF730040FF00FF4C008CFF00FFBF00FF730CFF0026FF0000FF267300FF00FF59
3FFF0066FF0066FF0059FF003FFF0019FF0026FF0019FF0000FF0000FF4C00BFFF00FF990CFF00\
4CFF0066FF0066FF008CFF008CFF008CFF0073FF0059FF0073FF0066FF0000FF19
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00\
E6FF00D9FF00CCFF00CCFF00C0FF00A6FF0066FF0000FF9900FF190026FF00FF26
00FFCC00FF590066FF00FF2633FF0059FF0059FF0073FF0066FF0000FF0033FF0000FF0000E6FF\
19FF00E600FF26FF0000FF0000FF8000F3FF00FF194CFF004CFF0026FF0000FFCC
00FF0C73FF0073FF0066FF0000FF9959FF004CFF0033FF0000FF1900FF9900FFFF000CFF00FF40\
59FF0080FF008CFF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0033FF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00\
D9FF00D9FF00CCFF00C0FF00B3FF00A6FF008CFF0073FF000CFF0000FF1900FFFF
00FF2619FF000CFF0000FF593FFF0073FF0080FF0080FF0080FF0059FF0073FF0019FF0033FF00\
59FF0000FF2659FF0019FF0000FF0000FFE633FF0066FF0073FF0066FF0000FF59
73FF0080FF008CFF0080FF0066FF0073FF0066FF0033FF0019FF0000FFA600FFD900FF4CC000FF\
00FF1980FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0080FF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
D9FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF0073FF004CFF000CFF006600FF
00FF3333FF004CFF0059FF000019FF73FF008CFF0099FF0099FF008CFF008CFF0059FF0066FF00\
80FF0059FF0073FF0059FF0000FF9900FF8059FF0080FF008CFF0080FF0000FF19
80FF008CFF0099FF0099FF008CFF0080FF0066FF004CFF0019FF0000000000FF8033FF0059FF00\
66FF0059FF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0080FF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00E6FF00E6FF00D9FF00D9FF00\
CCFF00C0FF0066FF0000B3FF8CFF008CFF0033FF0066FF003FFF0026FF0000FF8C
00FF993FFF0066FF0073FF0066FF0000FF808CFF00A6FF00A6FF00A6FF0099FF000CFF008CFF00\
99FF0099FF008CFF0066FF000019FF4CFF0080FF0099FF0099FF0099FF004CFF00
80FF0099FF00A6FF00A6FF0099FF0080FF0059FF0000FF3300FF662600FF26FF0059FF008CFF00\
8CFF0073FF0073FF00B3FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0066FF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFE600FFF300E6FF00D9FF00FFFF00FFFF00FFFF00F3FF00F3FF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF0000FFA6C0FF00D9FF00D9FF00CCFF00\
CCFF00C0FF00A6FF008CFF0000FF6659FF0033FF0026FF0000FF2600FFCC00FF33
33FF0059FF0073FF008CFF008CFF008CFF00A6FF00A6FF00B3FF00B3FF00A6FF004CFF0099FF00\
A6FF00A6FF0099FF0066FF000CFF0000FFB380FF00A6FF00B3FF00B3FF0099FF00
A6FF00B3FF00B3FF00A6FF0099FF0073FF006600FF00FF8000FF0C4CFF0073FF0080FF0099FF00\
A6FF00A6FF00A6FF00C0FF00C0FF00C0FF00CCFF00C0FF00C0FF00B3FF0080FF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFE600FFE600FFF300F3FF0099FF00E6FF00F3FF00E6FF00CCFF00D9FF00
E6FF00E6FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00B3FF00A6FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00A6FF0099FF0066FF0000FF8000FF2600FF6600FFA600FF5900FF00
3FFF0066FF0080FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00B3FF00\
B3FF00B3FF00B3FF0099FF0000FF4073FF00A6FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00A6FF0080FF0059FF0000FF8000FFCC33FF0073FF008CFF00A6FF00\
B3FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF0099FF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600\
FFE600FFF300FFF300FFFF00E6FF0080FF00C0FF0099FF00CCFF00B3FF00A6FF00
CCFF0080FF00D9FF00E6FF00D9FF00D9FF00D9FF00CCFF00B3FF004CFF00A6FF0099FF00B3FF00\
B3FF00A6FF00A6FF008CFF0066FF000CFF0000FF0C00FF9900000000FFD900FF19
00FFCC4CFF0059FF0099FF00A6FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00A6FF008CFF008CFF00B3FF00C0FF00C0FF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00B3FF0099FF0066FF0000FF0000FF7333FF0059FF0073FF0099FF00\
B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300\
FFFF00FFFF00D9FF00D9FF0059FF0099FF004CFF0000FF0080FF0000FF3359FF00
004CFF00FF8C73FF00C0FF00C0FF008CFF00B3FF0000FF5999FF0000D9FF3FFF0000FF4C99FF00\
99FF0080FF008CFF0080FF0073FF004CFF0019FF0000FF5900FFCC00FF7300FF66
00FF6600FF4C80FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00B3FF0080FF0073FF00B3FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00B3FF008CFF0000FF9900FFD900FFE600FFCC00FF5973FF00A6FF00\
B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF0099FF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900B3FF0066FF00\
73FF00A6FF004CFF0033FF0026FF0099FF00B3FF00C0FF0099FF00A6FF00C0FF00
B3FF00C0FF00C0FF00C0FF0066FF0000FFCC59FF0066FF000CFF0000FF4000FF4000FF3359FF00\
80FF0073FF0059FF0066FF003FFF000CFF0000FFBF00FF4C0CFF000CFF0026FF00
33FF0000FF7366FF008CFF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF0080FF0000FFA6B3FF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00CCFF00C0FF0099FF0066FF008CFF0080FF0000FFCC19FF0000FFFF3FFF008CFF00\
B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300\
FFF300FFFF00F3FF00E6FF0080FF00CCFF00D9FF00E6FF00CCFF00CCFF00E6FF00
E6FF00E6FF00E6FF00D9FF00B3FF00C0FF0080FF0000FF8C3FFF0066FF0066FF0066FF0000FFF3\
3FFF0033FF0019FF003FFF0000FF1900FF8000FF0033FF000CFF0059FF0033FF00
73FF0080FF003FFF000CFF0073FF00A6FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00C0FF0080FF0026FF00B3FF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF0059FF00B3FF00B3FF00A6FF008CFF004CFF0000FF7380FF008CFF00\
00FF33C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900\
FFE600FFE600FFF300FFFF0073FF00F3FF00F3FF00FFFF00F3FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00C0FF0033FF00A6FF008CFF00A6FF0073FF003FFF00\
00FF5900FF730000FF00FF4000FFD900FF730CFF004CFF0066FF0073FF0073FF00
8CFF0099FF008CFF0026FF0000FF1959FF00B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00C0FF000CFF00C0FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF008CFF0000FF7373FF00A6FF00C0FF00\
C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFE600FFF300D9FF00FFFF00FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF008CFF00C0FF00CCFF00C0FF00C0FF00A6FF0073FF00\
00FF404CFF0000FF0C0CFF0000FF1900FF4000FF1926FF0066FF0080FF008CFF00
99FF00A6FF00A6FF00A6FF0073FF0066FF00A6FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF0000FF19D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF008CFF0026FF0066FF00B3FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00F3FF00E6FF00CCFF00D9FF00D9FF00D9FF00CCFF00A6FF0000FFA6\
80FF0073FF0033FF0059FF003FFF0000FF3300FFCC3FFF0066FF0080FF0099FF00
A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF0026FF00A6FF00C0FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF0019FF00A6FF00\
A6FF008CFF0080FF0073FF0000B3FF26FF0000FF8000FFE600FF1959FF0099FF00
A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF0000FFD9B3FF00CCFF00D9FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00\
B3FF00A6FF0099FF008CFF0066FF003FFF0000FFBF3FFF0073FF0080FF0099FF00
B3FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00B3FF0000FFBFB3FF00CCFF00D9FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00D9FF00CCFF00\
C0FF00B3FF00A6FF0066FF004CFF0000FF730CFF004CFF0080FF0099FF00A6FF00
B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF0066FF0026FF00A6FF00CCFF00D9FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00\
C0FF00A6FF0099FF0080FF0033FF0000FF4C33FF0066FF0080FF008CFF00A6FF00
B3FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00CCFF00A6FF0019FF0099FF00CCFF00D9FF00\
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00\
C0FF0080FF003FFF0000FF4000FF6600FF2633FF0059FF0059FF0080FF0099FF00
99FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00C0FF0066FF0000B3FF8CFF00C0FF00D9FF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00D9FF00CCFF00\
C0FF00A6FF008CFF0066FF0026FF0000FFCC0CFF0026FF0033FF0073FF0073FF00
4CFF0099FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00A6FF0059FF0000FF4080FF0099FF00\
E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00CCFF00C0FF00\
B3FF00A6FF0080FF0033FF0019FF0000FFBF00FFB300FF4C0CFF0033FF0000FF8C
80FF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00B3FF0059FF0000FF80C0FF00D9FF00\
E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF003FFF00B3FF008CFF0066FF00A6FF00\
99FF0066FF0073FF004CFF0000FFBF00000000000000CCFF00B3FF0073FF0CFF00
33FF0099FF00B3FF00C0FF00CCFF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00D9FF00B3FF0000FF1980FF00C0FF00D9FF00\
F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFF300FFF300FFFF0080FF008CFF0033FF0000FF1966FF0073FF008CFF00\
3FFF003FFF000CFF0000FF2600FF800000000000000099FF00FF4C33FF0026FF00
3FFF0000FF19A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00C0FF0000FFB333FF003FFF0099FF00D9FF00\
E6FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF00B3FF00C0FF00C0FF00C0FF00B3FF00\
A6FF008CFF004CFF0000FF3300FF6600FF8C0099FF00F3FF00FF8C59FF0073FF00
19FF0073FF0000FF3359FF0000FF40A6FF003FFF00CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00B3FF00D9FF00B3FF0059FF0080FF0026FF00\
D9FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00D9FF00CCFF00CCFF00\
C0FF0099FF0000FF7366FF003FFF0000FF1900FF6600FF993FFF000CFF008CFF00
99FF00A6FF00A6FF0080FF0000FF0000FF2619FF0000FF8000FF33E6FF00F3FF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00F3FF00C0FF0000D9FFCCFF00E6FF00\
F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00\
C0FF0099FF0099FF008CFF004CFF0059FF0026FF0000FF7319FF0080FF0099FF00
B3FF00C0FF00C0FF00C0FF00A6FF00A6FF0059FF0000FF5959FF00D9FF00F3FF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00E6FF0000FF99E6FF00FFFF00\
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00E6FF00D9FF00D9FF00\
CCFF00C0FF00A6FF0099FF0080FF0066FF0019FF0000FF193FFF0000FF3380FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00CCFF00CCFF0080FF00E6FF00FFFF00FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF0099FF00F3FF00FFFF00\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00D9FF00\
CCFF00C0FF00B3FF0099FF0080FF0000FF3300FF5926FF0080FF0099FF00B3FF00
C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300F3FF0000FF80FFFF00FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00\
C0FF00C0FF00A6FF0080FF003FFF0000FF8C3FFF0073FF008CFF00A6FF00C0FF00
CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300E6FF00FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF00\
B3FF00B3FF00A6FF008CFF0033FF0000FFA600FF0073FF008CFF00A6FF00B3FF00
CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600
FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF0080FF00\
4CFF008CFF008CFF003FFF004CFF0000FF0000FF1933FF0000D9FF8CFF00A6FF00
B3FF00CCFF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300
FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00B3FF00\
99FF0059FF003FFF0019FF000CFF000CFF0019FF0000FFFF00D9FF33FF0073FF00
99FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF0080FF00CCFF00CCFF00CCFF00C0FF00B3FF00\
99FF0073FF000073FF00FF6659FF0080FF0073FF0066FF004CFF000CFF0099FF00
C0FF00D9FF00E6FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE60080FF00E6FF00D9FF00
CCFF00E6FF00F3FF00F3FF00E6FF00E6FF00CCFF00A6FF00A6FF00B3FF00A6FF00B3FF0099FF00\
8CFF0066FF003300FF00FF4073FF0099FF0099FF0099FF0073FF0000FF2699FF00
B3FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300F3FF0080FF00
73FF0000FF40CCFF00D9FF00C0FF00CCFF00C0FF00A6FF000CFF0066FF0073FF008CFF004CFF00\
66FF0000FF0033FF0066FF0080FF00A6FF00B3FF00B3FF0073FF0026FF0073FF00
73FF00B3FF00B3FF00C0FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFFF00F3FF00
D9FF00CCFF00B3FF008CFF003FFF00A6FF0099FF0073FF0000FF590CFF003FFF0019FF0000FF66\
0CFF0000FF0C8CFF00A6FF0066FF00B3FF00CCFF00C0FF00A6FF0066FF0000FF73
26FF003FFF00C0FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00
F3FF00F3FF00D9FF0080FF0080FF0066FF0073FF0000FF8C66FF0099FF008CFF0073FF0080FF00\
8CFF0019FF0099FF00C0FF00CCFF00CCFF00D9FF00D9FF00C0FF0080FF00A6FF00
99FF0000FF80C0FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300
FFFF00F3FF00E6FF00CCFF0080FF004CFF0000FFF380FF004CFF00A6FF00C0FF00A6FF00B3FF00\
C0FF008CFF008CFF00CCFF00D9FF00E6FF00E6FF00E6FF00C0FF00C0FF00D9FF00
C0FF0066FF0099FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300
FFFF00F3FF00E6FF00D9FF00C0FF0080FF003FFF0099FF00B3FF00C0FF00CCFF00CCFF00CCFF00\
D9FF00CCFF0080FF00D9FF00E6FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
D9FF00CCFF0019FF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300
FFFF00F3FF00D9FF00C0FF00B3FF0080FF0000FF6699FF00C0FF00CCFF00D9FF00E6FF00E6FF00\
E6FF00D9FF008CFF00CCFF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00E6FF003FFF00C0FF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300
FFFF00F3FF00D9FF0099FF008CFF0000FF2600FF0C99FF00B3FF00CCFF00E6FF00F3FF00F3FF00\
F3FF00F3FF00D9FF00CCFF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00E6FF0000FF0C00FF26CCFF00E6FF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00
FFFF00F3FF00D9FF00CCFF00B3FF0033FF000CFF0099FF0059FF00A6FF00E6FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00F3FF00D9FF0000FFBFA6FF00CCFF0033FF00FFFF00FFF300FFF300FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00
F3FF00E6FF00D9FF00C0FF00A6FF0066FF0019FF00C0FF00CCFF00E6FF00F3FF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00CCFF00A6FF0073FF0073FF00D9FF00F3FF00FFF300FFF300FFE600FFE600FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300D9FF00A6FF00
D9FF00C0FF00B3FF00A6FF0066FF0000FF8073FF00C0FF00D9FF00F3FF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFFF00F3FF00E6FF0000FF1966FF00D9FF00F3FF00FFFF00FFF300FFE600FFE600FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00F3FF00D9FF00
00FF0C66FF0000FF7300FF0066FF0099FF0000FF33A6FF00D9FF00F3FF00FFFF00FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFFF00F3FF00C0FF0026FF00A6FF00CCFF00D9FF00E6FF00FFE600FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF00
A6FF0073FF00B3FF00B3FF00A6FF00CCFF0073FF0080FF00D9FF00F3FF00FFFF00FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFF300F3FF0080FF00B3FF00A6FF0080FF00E6FF00FFFF00FFE600FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00CCFF00
8CFF0000FF19CCFF00D9FF008CFF00E6FF00E6FF00D9FF0099FF00E6FF00FFFF00FFF300FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFF300E6FF00F3FF00F3FF00CCFF00A6FF00F3FF00FFF300FFE600FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00E6FF00B3FF0000FF19
3FFF00B3FF00E6FF00F3FF00FFFF00FFFF00FFFF00F3FF00A6FF008CFF00E6FF00FFF300FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFF300FFF300FFF300E6FF008CFF00F3FF00FFE600FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00E6FF00CCFF0059FF00C0FF00
D9FF0099FF00E6FF00FFFF00FFF300FFF300FFF300FFFF00E6FF0099FF00FFFF00FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFF300E6FF00FFFF00FFE600FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600\
FFF300FFFF00FFFF00FFFF00F3FF0066FF00CCFF0000FF73CCFF00E6FF00E6FF00
F3FF00F3FF00F3FF00FFF300FFF300FFF300FFE600FFE600FFF300FFF300FFFF00FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFE600F3FF0073FF00FFE600FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFFF0080FF00E6FF00E6FF00D9FF00A6FF0099FF0066FF00F3FF00FFFF00FFFF00
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE60033FF00FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300\
FFFF00E6FF004CFF00B3FF0019FF0066FF00C0FF00F3FF00FFFF00FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900F3FF00FFF300FFF300FFF300FFE600FFE600FFF300FFF300FFFF00\
FFFF00E6FF00C0FF0000FFA6B3FF00C0FF00A6FF00F3FF00FFF300FFF300FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFD900FFE6008CFF00CCFF00F3FF00FFFF00FFF300FFFF00F3FF00F3FF00\
E6FF00CCFF0000FFFF80FF00C0FF00E6FF00F3FF00FFFF00FFF300FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFD900FFD900FFE600CCFF00CCFF008CFF00E6FF00F3FF00F3FF00D9FF00C0FF00\
CCFF00C0FF008CFF00A6FF00CCFF00F3FF00FFFF00FFF300FFF300FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFE600FFF300F3FF00D9FF00A6FF00CCFF00D9FF00CCFF0059FF00\
00FFF38CFF0000FF198CFF00D9FF00F3FF00FFFF00FFF300FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFE600FFF300FFFF00F3FF00CCFF0073FF0099FF0080FF0073FF00\
A6FF008CFF00C0FF00B3FF00A6FF00E6FF00FFFF00FFF300FFE600FFE600FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFE600FFF300FFF300FFFF00E6FF00C0FF0000FF0080FF0099FF00\
CCFF00D9FF00D9FF00E6FF00E6FF00C0FF00F3FF00FFE600FFE600FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFF300FFF300F3FF00E6FF00CCFF00A6FF0066FF00CCFF00\
D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFE600FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFF300FFFF00E6FF00CCFF00C0FF0099FF00A6FF00CCFF00\
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFF300FFF300FFF300FFFF00D9FF0099FF0059FF0000FF663FFF0026FF00\
59FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF00B3FF0000FF99A6FF00B3FF00\
D9FF00F3FF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFCC00F3FF00FFFF00\
FFE600FFE600FFFF00FFFF00FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300F3FF00C0FF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF00B3FF0080FF00C0FF00D9FF00\
F3FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFF300\
4CFF00F3FF00E6FF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFF300
FFF300F3FF00C0FF00CCFF00E6FF00CCFF00D9FF00CCFF00C0FF00A6FF0066FF00C0FF00D9FF00\
F3FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900\
FFFF00A6FF00B3FF004CFF00CCFF00E6FF00FFFF00FFF300FFF300FFF300FFFF00
FFFF00F3FF00D9FF004CFF00B3FF00A6FF00B3FF00B3FF000CFF004CFF0000FFA68CFF00CCFF00\
E6FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900\
F3FF00FFFF00FFFF00CCFF0073FF0080FF00D9FF00F3FF00FFFF00E6FF00F3FF00
F3FF00E6FF00D9FF00A6FF0026FF0066FF0033FF004CFF0073FF0066FF00B3FF003FFF004CFF00\
D9FF00F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFE600FFF300FFFF00FFFF00F3FF00D9FF00C0FF00D9FF00C0FF00D9FF00
D9FF00B3FF0099FF008CFF00A6FF00B3FF00A6FF00A6FF008CFF00CCFF00D9FF00B3FF00D9FF00\
4CFF00CCFF00D9FF00FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00CCFF0019FF0033FF0073FF00
C0FF00B3FF003FFF004CFF00B3FF00CCFF00D9FF00D9FF003FFF00E6FF00F3FF00F3FF00F3FF00\
E6FF00A6FF00B3FF00B3FF00FFFF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00C0FF00D9FF00CCFF003FFF00
4CFF0059FF00A6FF00A6FF008CFF00D9FF00E6FF00E6FF00E6FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00F3FF00B3FF00CCFF00F3FF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00D9FF00C0FF00
A6FF003FFF00C0FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFD900FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF00
73FF0000FF99C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00
CCFF0033FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00
C0FF0059FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00E6FF00A6FF00
99FF0073FF00C0FF00D9FF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFE600FFE600FFFF00F3FF00C0FF00C0FF00B3FF00
73FF0073FF00A6FF0099FF00D9FF00E6FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFE600FFF300F3FF0073FF0026FF0073FF0080FF00
00FF6600FFCC00FF0C26FF0033FF00B3FF00F3FF00FFF300FFE600FFE600FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFE600FFE600FFF300FFFF00D9FF00CCFF00B3FF0080FF00
00FFCC19FF0099FF004CFF0099FF00CCFF00D9FF00FFFF00FFE600FFE600FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00E6FF00CCFF00C0FF00
99FF0033FF00B3FF00D9FF00CCFF00F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF00
99FF00B3FF00D9FF00E6FF00F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF00
80FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600E6FF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF0099FF00
66FF00C0FF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600E6FF008CFF00E6FF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF00
4CFF00B3FF00D9FF00E6FF00FFFF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF30099FF0080FF00\
E6FF00F3FF00F3FF00E6FF00B3FF00E6FF00E6FF00D9FF00A6FF00B3FF00A6FF00
0CFF0033FF008CFF00D9FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFFF00E6FF00\
00FF6699FF00D9FF00CCFF008CFF00CCFF00D9FF00CCFF0099FF003FFF0099FF00
B3FF00A6FF003FFF00C0FF00CCFF00CCFF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFCC00FFE600FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00\
C0FF000CFF00B3FF008CFF0000FF0026FF00B3FF00B3FF0059FF004CFF00A6FF00
CCFF00C0FF0080FF000CFF0073FF00D9FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFC000FFCC00FFCC00CCFF00FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00\
D9FF00A6FF008CFF004CFF00B3FF0059FF003FFF000CFF00A6FF00CCFF00CCFF00
E6FF00E6FF00A6FF00D9FF00CCFF0080FF00E6FF00FFFF00FFF300FFF300FFE600FFD900FFD900\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000\
FFC000FFCC00FFCC00FFCC00FFD900FFF300FFFF00FFE600FFE600FFF300FFF300
FFE600FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFF300FFF300FFFF00F3FF00E6FF00\
CCFF0099FF00C0FF00CCFF00D9FF00C0FF00C0FF00A6FF00A6FF00D9FF00F3FF00
F3FF00F3FF00D9FF00F3FF00F3FF00E6FF0000FF8026FF00F3FF00E6FF00FFF300FFE600FFE600\
FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFD900FFE600\
FFF300FFD900FFF300FFE600FFF300FFFF00A6FF00C0FF00FFFF00F3FF00F3FF00
FFF300FFF300FFE600FFE600FFE600FFF300B3FF00FFFF00FFFF00FFFF00F3FF0066FF0099FF00\
A6FF0099FF00CCFF00E6FF00E6FF00E6FF00E6FF00D9FF0073FF00E6FF00F3FF00
FFFF00FFF300FFF300FFF300FFF300FFFF00E6FF0066FF004CFF00CCFF00FFFF00FFF300F3FF00\
FFE600FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFF300\
FFE600E6FF0000FF33D9FF00B3FF0099FF00E6FF00A6FF00C0FF0080FF00A6FF00
C0FF00E6FF00FFFF00FFFF00FFFF00FFFF00CCFF00E6FF00F3FF00F3FF00E6FF00C0FF0073FF00\
00FF19A6FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00CCFF00D9FF00FFFF00
FFF300FFF300FFE600FFE600FFF300FFF300FFFF00CCFF00D9FF00A6FF00CCFF00D9FF00F3FF00\
FFE600FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000\
FFCC00FFD900FFE600F3FF00F3FF00FFFF00FFF300FFFF00CCFF00FFFF00F3FF00
F3FF00E6FF0059FF00CCFF00D9FF00CCFF00C0FF00B3FF00C0FF00D9FF00D9FF00C0FF0080FF00\
26FF0099FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF0080FF00FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFFF0080FF00C0FF00CCFF00E6FF00\
FFE600FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300\
FFC000FFC000FFCC00FFF300FFF300FFE600FFE600FFE600A6FF00FFE600FFE600
FFF300FFF300FFFF00E6FF004CFF00A6FF00B3FF00B3FF00A6FF0099FF00C0FF0059FF00C0FF00\
D9FF00E6FF00E6FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFE600FFE600FFF30066FF00FFF300FFFF00E6FF00\
FFFF00FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300\
FFB300FFC000FFC000FFFF00FFD900FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFFF0059FF00E6FF00E6FF00D9FF0080FF0073FF0066FF00B3FF00D9FF00\
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFF300FFE600FFD900FFE600\
E6FF00FFF300FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFE600FFF300F3FF00FFFF00FFFF00E6FF00D9FF00D9FF0033FF00B3FF00D9FF00\
F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFCC00FFCC00FFCC00\
FFD900FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFE600FFE600FFF300FFF300FFFF00FFFF00E6FF00C0FF0059FF00C0FF00\
F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00E6FF0059FF00E6FF00\
F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00E6FF008CFF00E6FF00\
F3FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00C0FF0099FF00D9FF00\
F3FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00D9FF0099FF0099FF00\
E6FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600FFFF00E6FF00CCFF0080FF00CCFF00\
E6FF00F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFF300F3FF00CCFF008CFF0099FF00CCFF00\
D9FF00E6FF00E6FF00F3FF00FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00E6FF00C0FF003FFF0000FF4C\
C0FF00CCFF0026FF00FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300FFFF00D9FF00D9FF0059FF0000FF4C000000\
00F3FF33FF00A6FF00E6FF00FFFF00FFE600FFD900FFD900FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFCC00FFCC00FFD900FFE600F3FF00CCFF00A6FF00A6FF0073FF0000CCFF000000\
73FF00C0FF00A6FF00C0FF00CCFF00FFFF00FFD900FFD900FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFFF00E6FF0099FF00B3FF004CFF0026FF00\
A6FF00D9FF00E6FF00FFFF00FFFF00FFF300FFD900FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFF30099FF00E6FF00D9FF00CCFF00A6FF00\
B3FF00E6FF00FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFE600FFF300FFFF00E6FF00CCFF0099FF00\
B3FF00A6FF00F3FF00FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFFF00F3FF0099FF00A6FF00\
E6FF00FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00D9FF0026FF00\
CCFF00FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00D9FF00C0FF00\
F3FF00FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00F3FF00C0FF00CCFF00\
F3FF00FFF300FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00FFFF00E6FF00C0FF00A6FF00\
E6FF00FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00E6FF00D9FF003FFF00A6FF00\
CCFF00C0FF00FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFC000FFD900E6FF00FFF300F3FF00FFF300
FFE600FFE600FFF300FFFF003FFF00F3FF00FFFF00F3FF00E6FF0033FF0099FF00CCFF00C0FF00\
73FF00D9FF00F3FF00F3FF00C0FF00FFE600FFD900FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFD900E6FF00D9FF00B3FF00
F3FF00FFFF00FFFF00F3FF00A6FF00D9FF00E6FF00E6FF00CCFF0073FF00CCFF00E6FF00E6FF00\
B3FF00B3FF0080FF0099FF00FFFF00FFE600FFD900FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFF300
D9FF0099FF00CCFF00C0FF0073FF00A6FF00B3FF00C0FF0099FF00D9FF00F3FF00FFFF00FFFF00\
E6FF00E6FF00E6FF008CFF00E6FF00FFE600FFD900FFD900FFCC00FFCC00FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600
FFFF00E6FF00A6FF00C0FF00D9FF00D9FF00B3FF00C0FF00C0FF00F3FF00FFF300FFF300FFF300\
F3FF00FFFF00FFFF00F3FF00A6FF00FFF300FFE600FFD900FFD900FFCC00FFCC00
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600
FFF300FFFF0099FF00E6FF00F3FF00FFFF00F3FF00F3FF0099FF00FFFF00FFF300FFE600FFE600\
FFE600FFE600FFE600FFF300E6FF00D9FF00E6FF00FFE600FFE600FFD900FFCC00
FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600
FFF300F3FF00B3FF00F3FF00FFF300FFF300FFF300FFF300E6FF00F3FF00FFE600FFD900FFD900\
FFD900FFD900FFD900FFE600FFF300D9FF00E6FF00FFFF00D9FF00FFE600FFD900
FFCC00FFC000FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600
FFFF00CCFF00A6FF00FFFF00FFF300FFE600FFE600FFE600FFE600D9FF00FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFE600E6FF00CCFF00B3FF00F3FF00FFE600FFD900
FFD900FFCC00FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFD900FFE600
FFFF00C0FF00CCFF00E6FF00FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFF300B3FF00E6FF00FFFF00FFF300
FFF300D9FF00FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFE600FFF300
FFFF00B3FF00F3FF00FFF300FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFE600F3FF00CCFF0019FF0080FF00
F3FF00FFD900FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFFF00C0FF00F3FF00F3FF00
E6FF0099FF00FFFF00FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFD90026FF00FFF300FFF300E6FF00
F3FF00FFD900FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFE600F3FF0099FF0080FF00
C0FF0099FF00B3FF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFE600FFD900FFD900E6FF00
CCFF00FFD900FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFF300D9FF00F3FF00FFFF00
FFFF00FFF300F3FF00FFFF00FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00
FFF300FFD900FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFC000FFCC00FFD900FFD900FFF300B3FF004CFF00FFF300FFE600
FFD900FFD900FFE60099FF00E6FF00FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFD900CCFF00FFCC00FFB300FFB300FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFB300\
FFC000FFCC00FFCC00FFD900FFF300E6FF00C0FF00FFFF00FFF300E6FF00FFD900
FFCC00FFCC00FFCC00FFD900D9FF00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFCC00FFCC00FFB300FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFB300FFC000\
FFCC0066FF00FFF300FFFF00C0FF00FFFF00FFE600FFD900FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFB300FFC000FFC000\
FFCC00FFE600B3FF00CCFF00E6FF00FFD900FFCC00FFCC00FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFCC00\
FFD900FFF30073FF00FFF300FFE600FFCC00FFCC00FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFD900F3FF00FFD900FFD900FFE600\
FFFF00F3FF00F3FF00FFE600FFD900FFCC00FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFCC00FFF300CCFF00F3FF00F3FF00\
D9FF00CCFF00C0FF00FFF300FFCC00FFC000FFC000FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFCC00FFD900FFF30073FF00\
FFF300FFE600FFE600FFF300FFCC00FFC000FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00FFE600C0FF00\
FFE600FFD900FFCC00FFCC00FFC000FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFC000FFCC00FFE60073FF00\
FFE600FFCC00FFCC00FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFCC00FFD900FFF300F3FF00\
FFD900FFCC00FFC000FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFCC00FFF300FFF300FFFF00E6FF00\
FFE600FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFCC00FFF300D9FF00D9FF00E6FF00\
F3FF00FFD900FFC000FFB300FFB300FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFC000FFD900FFFF00FFE600FFD900FFCC00\
FFD900F3FF00FFC000FFB300FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FFA600FFB300FFC000FFD900D9FF00FFE600F3FF00FFC000FFC000\
FFC000FFC000FFC000FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FFA600FFA600C0FF00FFE600FFFF00FFCC00FFC000FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FFA600FFB300FFC000A6FF00FFCC00FFC000FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FFA600FFB300FFE600FFE600FFC000FFB300FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FFA600FFCC00FFC000FFB300FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600\
FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF6600FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00
CCFF00C0FF00B3FF00A6FF0099FF008CFF0073FF0000A6FF00FF0C00FF4026FF0073FF0080FF00\
99FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00
CCFF00C0FF00C0FF00A6FF0099FF0080FF003FFF0000FF1900FF333FFF0059FF0080FF008CFF00\
99FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00
CCFF00C0FF00B3FF0099FF008CFF0080FF004CFF0000FF2600FF4019FF0066FF0073FF008CFF00\
99FF00A6FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00
CCFF00C0FF00A6FF0000FFB30CFF0000FF4019FF0000FF8000FF003FFF0059FF0066FF004CFF00\
8CFF0099FF00A6FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00
CCFF00C0FF00B3FF0099FF008CFF0059FF0000FF0C00FF3300FF2626FF0033FF0026FF0059FF00\
80FF008CFF0080FF0000CCFFA6FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00
CCFF00C0FF00B3FF00A6FF008CFF0066FF003FFF0000FF1900FF4000FF3300FFD90CFF004CFF00\
59FF0026FF0059FF0099FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00D9FF00CCFF00C0FF00C0FF00
C0FF00B3FF0099FF0099FF0080FF0019FF0000FF5900FF3300FFE600000000FFCC00FF1926FF00\
00FF4026FF0080FF0099FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFFF00FFFF00F3FF00D9FF0066FF00B3FF00A6FF0099FF0000FF73
99FF0099FF0073FF0066FF0066FF004CFF0000FF73D900FF0000000000002600FF004CFF00FF99\
00FFE600FFA619FF0099FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFFF00F3FF00CCFF0080FF0066FF003FFF0000FFA666FF0026FF00
80FF000CFF0000FF7319FF0019FF0019FF0000FF199900FF0000000000000099FF00FFCC19FF00\
26FF000CFF0033FF0059FF008CFF00A6FF00B3FF00C0FF00C0FF00CCFF00D9FF00
D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFF300FFF300FFFF00F3FF00D9FF00C0FF008CFF00B3FF0059FF00B3FF00B3FF00
B3FF00A6FF008CFF0059FF0000FF2600FF8000FF4000FF5900FFE60000000073FF00F3FF19FF00\
59FF0059FF0000FF3319FF0000CCFF8CFF0099FF0099FF00B3FF00B3FF00C0FF00
CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF00D9FF00CCFF00CCFF00CCFF00
C0FF00C0FF00A6FF008CFF000CFF0000FF003FFF000CFF0000F3FF00FF8000BFFF0CFF0000FF26\
66FF0080FF0080FF008CFF0099FF0073FF0019FF0000FF0080FF0033FF00A6FF00
C0FF00C0FF00CCFF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00
CCFF00C0FF00B3FF0073FF0073FF0073FF0059FF0026FF0000FF4C0CFF000059FF33FF0066FF00\
80FF0099FF00A6FF00B3FF00B3FF00B3FF0026FF0073FF0000FF2600FF1973FF00
4CFF0080FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00
CCFF00CCFF00B3FF0099FF0099FF008CFF003FFF0066FF004CFF0026FF0000FFFF00FF8C59FF00\
8CFF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF0059FF00
4CFF000CFF00B3FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00
D9FF00CCFF00C0FF00B3FF00A6FF0099FF008CFF0073FF004CFF0000FF0000B3FF3FFF003FFF00\
66FF0099FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF008CFF00
C0FF00C0FF00B3FF0066FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00
D9FF00CCFF00C0FF00C0FF00B3FF0099FF008CFF004CFF0033FF0000FF1900FF0C73FF008CFF00\
8CFF0099FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
E6FF00E6FF00E6FF00E6FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00
D9FF00CCFF00C0FF00B3FF00A6FF0080FF0066FF004CFF0000FF7333FF0066FF0080FF0099FF00\
A6FF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00
CCFF00C0FF00C0FF00B3FF00A6FF008CFF0073FF0000FF7300FF264CFF0073FF008CFF0099FF00\
B3FF00C0FF00CCFF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00
C0FF00A6FF00B3FF00A6FF0099FF008CFF0073FF0000FF1900FFD926FF0066FF0080FF008CFF00\
A6FF00C0FF00CCFF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00
8CFF0000FF8073FF0099FF008CFF004CFF0066FF0033FF0000FF730CFF004CFF0059FF0066FF00\
99FF00B3FF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00
B3FF0080FF004CFF0066FF0073FF004CFF0000FF6600FF5900FF1900FF6600FF3300FF1959FF00\
66FF0073FF0000FF59C0FF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00E6FF0080FF00C0FF00D9FF00D9FF00CCFF00CCFF00C0FF00
B3FF00A6FF008CFF0033FF0000FF190CFF0000FF0059FF0066FF0059FF0019FF0033FF000099FF\
3FFF0099FF00B3FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00C0FF0033FF00C0FF00CCFF00C0FF00C0FF00C0FF00
B3FF00A6FF008CFF0059FF0000FF6600FF8000FF9973FF008CFF0073FF0073FF0066FF000CFF00\
4CFF0099FF00C0FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFE600FFFF004CFF00D9FF00D9FF00C0FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00CCFF00A6FF0099FF00B3FF0059FF00A6FF00A6FF00
99FF0099FF0080FF003FFF0000FF1900A6FF73FF008CFF0099FF0099FF0099FF0080FF0000FF26\
59FF0099FF00B3FF00C0FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFE600FFF300FFFF00CCFF0073FF0080FF0073FF00C0FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00C0FF0099FF0000FF1966FF000CFF0080FF008CFF00
4CFF0073FF003FFF0019FF003FFF0000FF4C73FF0099FF00B3FF00B3FF00B3FF0099FF000CFF00\
4CFF0080FF0080FF00A6FF00C0FF00C0FF00CCFF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFE600FFE600FFF300E6FF00E6FF00CCFF00C0FF00A6FF00A6FF00\
B3FF0099FF00B3FF00B3FF0000FF408CFF0033FF0000FF1933FF0000FF4C19FF00
3FFF0000FF0000FF404CFF0080FF0099FF0066FF008CFF00C0FF00C0FF00C0FF004CFF0080FF00\
19FF003FFF0000FF2659FF0066FF00B3FF00D9FF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFFF00FFFF00F3FF00E6FF00D9FF00C0FF00\
00FF2600FF1959FF0099FF0080FF0000FF7326FF0073FF0080FF004CFF0019FF00
33FF004CFF004CFF0000FF2680FF00B3FF00B3FF0033FF00CCFF00CCFF00CCFF00C0FF008CFF00\
66FF0080FF0080FF0000FF40A6FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF00\
B3FF0099FF0000FF733FFF0033FF0033FF0066FF0099FF00A6FF0099FF0059FF00
8CFF0080FF008CFF0000FF0CA6FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF008CFF00\
B3FF00B3FF00B3FF0000FF0C99FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00F3FF00E6FF00\
CCFF0080FF008CFF004CFF000CFF0080FF0073FF008CFF00C0FF00C0FF00A6FF00
A6FF00C0FF00A6FF008CFF0099FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF0026FF00\
D9FF00D9FF00CCFF0073FF0033FF00C0FF00E6FF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00\
D9FF00C0FF00A6FF004CFF0066FF0099FF00B3FF00C0FF00CCFF00CCFF00CCFF00
CCFF00D9FF00CCFF00C0FF00A6FF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00D9FF00CCFF00A6FF00C0FF00E6FF00F3FF00F3FF00FFFF00FFFF00
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00D9FF00\
CCFF00B3FF00A6FF0059FF0026FF0099FF00C0FF00CCFF00D9FF00D9FF00D9FF00
E6FF00E6FF00D9FF00CCFF000CFF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00E6FF00CCFF0099FF00CCFF00E6FF00F3FF00FFFF00FFFF00
FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF0080FF00\
73FF0033FF0080FF0000FF4C73FF00A6FF00C0FF00CCFF00D9FF00E6FF00E6FF00
F3FF00F3FF00E6FF00D9FF0000FF2699FF00E6FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00E6FF00D9FF0000FF99A6FF003FFF00E6FF00F3FF00FFFF00
FFF300FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF00\
B3FF00A6FF0066FF0000FFB300FF008CFF00A6FF00C0FF00D9FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00CCFF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00F3FF00CCFF00B3FF0019FF00C0FF00D9FF00E6FF00F3FF00
FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00\
CCFF00B3FF0080FF0033FF008CFF0099FF0080FF0059FF00D9FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00E6FF00C0FF0026FF0099FF00C0FF00C0FF00C0FF00
FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00F3FF00E6FF00D9FF00D9FF00\
C0FF00B3FF0080FF0000FF7399FF00C0FF00CCFF00D9FF00E6FF00F3FF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00F3FF00B3FF0000FF8C33FF0000FFB3C0FF00E6FF00
FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFF300FFFF00CCFF00D9FF00E6FF00D9FF00C0FF00C0FF00\
A6FF0080FF0066FF0059FF00A6FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFFF00F3FF00E6FF00D9FF00B3FF0019FF00B3FF00E6FF00
F3FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFF300FFF300FFFF00D9FF00A6FF00B3FF00B3FF004CFF0066FF00\
8CFF000CFF0019FF004CFF0080FF00C0FF00D9FF00F3FF00F3FF00FFFF00FFFF00
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFFF00FFFF00E6FF008CFF0066FF00B3FF00C0FF00
E6FF00F3FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF0099FF003FFF003FFF004CFF00\
00FF0080FF0059FF00A6FF0000FF0C26FF00D9FF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00CCFF0000FF3380FF000CFF00
B3FF00C0FF0073FF00F3FF00FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00D9FF00A6FF0000FF80A6FF00B3FF00\
B3FF0099FF00CCFF00CCFF00C0FF008CFF00D9FF00E6FF00FFFF00FFFF00FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300F3FF0073FF00CCFF0099FF008CFF00
8CFF00E6FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00E6FF00CCFF0099FF0033FF00A6FF00D9FF00\
D9FF00A6FF00E6FF00E6FF00E6FF00CCFF0080FF00D9FF00F3FF00FFFF00FFF300
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFF300D9FF00E6FF00F3FF00E6FF0099FF00
A6FF00F3FF00FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFFF00F3FF00CCFF00B3FF00A6FF0073FF0099FF00CCFF00E6FF00\
F3FF00F3FF00F3FF00FFFF00F3FF00E6FF00B3FF00B3FF00E6FF00FFFF00FFF300
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFF300F3FF00C0FF00
73FF00D9FF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF0073FF0099FF00A6FF0080FF00D9FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00D9FF0000FF19D9FF00FFFF00FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFFF00
C0FF00FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300
FFFF00F3FF00F3FF00F3FF00E6FF00CCFF0000FF2600FF40D9FF00E6FF00D9FF00A6FF00F3FF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00B3FF00FFF300FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300
C0FF000CFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFF300E6FF00FFFF00FFFF00FFFF00
F3FF00E6FF00C0FF00C0FF003FFF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00F3FF00FFFF00\
FFF300FFF300FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFF300FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
99FF003FFF00FFF300FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFF300D9FF0099FF00E6FF00F3FF00
E6FF00D9FF008CFF0099FF0066FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFE600C0FF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFF300FFF300F3FF00CCFF00C0FF00CCFF00
80FF00B3FF0000FF66B3FF00E6FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00A6FF0066FF00
66FF0073FF008CFF00C0FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFF300D9FF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF00B3FF0000FFE6
B3FF00CCFF00D9FF00CCFF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600E6FF00C0FF0099FF00F3FF00\
FFFF00FFF300FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00A6FF0000FF404CFF00
A6FF00D9FF00F3FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600F3FF00D9FF0080FF0099FF00\
F3FF00F3FF00F3FF00F3FF00D9FF00B3FF00D9FF00CCFF00C0FF008CFF0099FF00
B3FF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00D9FF0099FF00\
B3FF00E6FF00D9FF00E6FF00CCFF0000FF00A6FF00A6FF0000FF4C59FF008CFF00
CCFF00E6FF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFF300FFFF00F3FF00\
B3FF0099FF008CFF00C0FF0000FF1973FF0000FF0C00FF2600FF008CFF0033FF00
B3FF00E6FF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00\
C0FF00B3FF004CFF0080FF0066FF0019FF00B3FF00B3FF0080FF00CCFF00CCFF00
C0FF008CFF00D9FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00FFFF00\
E6FF00D9FF00A6FF0073FF008CFF00A6FF00C0FF00D9FF00D9FF00E6FF00F3FF00
E6FF00CCFF0080FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00\
E6FF00D9FF00C0FF0080FF0099FF00C0FF00D9FF00E6FF00E6FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00\
D9FF00CCFF00C0FF008CFF00B3FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00
FFF300FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF0073FF00\
73FF0099FF008CFF003FFF0099FF00C0FF00D9FF00E6FF00F3FF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00F3FF00D9FF00\
B3FF008CFF0000FF1900F3FF00FF9900FF2680FF00E6FF00FFFF00FFFF00FFF300
FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00\
CCFF00C0FF0099FF0073FF00A6FF00C0FF00C0FF00E6FF00FFFF00FFF300FFF300
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00A6FF00FFFF00\
FFE600FFE600FFE600FFFF00FFFF00FFE600FFE600FFE600FFD900FFD900FFE600
FFE600FFE600FFE600FFF300FFFF000CFF00B3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
CCFF00C0FF0073FF00A6FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFF300FFF300
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFE600FFFF00\
A6FF00CCFF00FFFF00E6FF00F3FF00FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFFF00D9FF0026FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
CCFF00B3FF0059FF004CFF00CCFF00D9FF00F3FF00F3FF00FFFF00FFF300FFF300
FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFE600\
F3FF004CFF008CFF00B3FF00C0FF00F3FF00E6FF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00E6FF00CCFF00C0FF00CCFF00CCFF00B3FF00CCFF00C0FF00\
8CFF0099FF003FFF003FFF0073FF00D9FF00E6FF00F3FF00FFFF00FFF300FFF300
FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900\
FFF300D9FF00E6FF00D9FF00A6FF0099FF003FFF00E6FF00FFFF00FFFF00FFF300
FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00CCFF0073FF00A6FF0099FF0073FF0099FF00A6FF00\
80FF0019FF008CFF0080FF008CFF00C0FF00CCFF00F3FF00FFFF00FFF300FFF300
FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFD900\
FFE600F3FF00FFFF00FFFF00D9FF00D9FF00C0FF0000FF00D9FF00F3FF00F3FF00
F3FF00D9FF00F3FF00F3FF00E6FF00D9FF00CCFF0099FF0000FF190CFF0080FF0059FF0066FF00\
73FF0080FF00B3FF00B3FF003FFF0080FF00C0FF00E6FF00F3FF00FFFF00FFF300
FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFE600FFE600FFF300E6FF00FFFF00F3FF00E6FF00C0FF00CCFF00D9FF00
D9FF003FFF00D9FF00E6FF00D9FF008CFF00A6FF008CFF008CFF00A6FF00B3FF0019FF0099FF00\
8CFF00C0FF00D9FF00D9FF00A6FF00D9FF00B3FF00C0FF00E6FF00F3FF00FFFF00
FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00C0FF0099FF00
8CFF0059FF0059FF00CCFF00C0FF0080FF0000FF8C59FF00B3FF00C0FF00CCFF00CCFF00CCFF00\
19FF00D9FF00E6FF00F3FF00F3FF00F3FF00E6FF0000FF0059FF00CCFF00E6FF00
F3FF00FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00E6FF008CFF00
3FFF00A6FF0080FF0099FF00A6FF0080FF0073FF0059FF00A6FF00CCFF00D9FF00E6FF00E6FF00\
B3FF00B3FF00F3FF00FFFF00FFFF00FFFF00FFFF00CCFF00CCFF004CFF0099FF00
E6FF00FFF300FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00A6FF00E6FF00
D9FF00C0FF003FFF0000FF4C33FF008CFF00B3FF00B3FF00B3FF00D9FF00E6FF00F3FF00F3FF00\
F3FF00E6FF00FFFF00FFFF00FFF300FFF300FFF300FFFF00F3FF00D9FF00F3FF00
D9FF00F3FF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00
E6FF0080FF00C0FF00A6FF0066FF0066FF00CCFF00D9FF00D9FF00E6FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00
F3FF00E6FF00D9FF00B3FF0059FF00A6FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00
F3FF00F3FF00E6FF00CCFF008CFF00A6FF00CCFF00E6FF00E6FF00F3FF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00
F3FF00F3FF00E6FF00CCFF0099FF00C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00
F3FF00E6FF00D9FF00C0FF0026FF00B3FF00D9FF00E6FF00E6FF00F3FF00FFFF00FFFF00FFF300\
FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00
E6FF00D9FF0080FF0099FF003FFF00B3FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300\
FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00D9FF00
C0FF00C0FF00B3FF0080FF0073FF0000FF4CA6FF00A6FF00D9FF00E6FF00F3FF00FFFF00FFF300\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF30059FF00C0FF00B3FF00
3FFF0059FF008CFF000CFF0000FFF300FFB300FFCCA6FF00C0FF00A6FF00E6FF00FFFF00FFF300\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFFF00D9FF0099FF00
B3FF0080FF0000FF0000FF0000000033FF0080FF0066FF0059FF0099FF003FFF00E6FF00FFF300\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00F3FF00D9FF00
CCFF008CFF0099FF0000FF4000FFCC80FF00B3FF00A6FF0066FF00D9FF00F3FF00F3FF00FFF300\
FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00
E6FF00CCFF00C0FF0099FF0000FF3326FF00C0FF00D9FF00D9FF00F3FF00FFFF00FFF300FFF300\
FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00
E6FF00D9FF00CCFF0099FF008CFF00C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00
E6FF00D9FF00CCFF00A6FF00B3FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600\
FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFFF00FFF300FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00
E6FF00D9FF00CCFF0059FF00C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600\
FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFF300C0FF00E6FF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
E6FF00D9FF00B3FF0033FF00A6FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600\
FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFF300C0FF00A6FF00D9FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
D9FF00CCFF00B3FF004CFF00A6FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFF300FFF300FFE600\
FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF0080FF00A6FF00\
D9FF00F3FF00F3FF00F3FF00E6FF0099FF00E6FF00E6FF00E6FF00E6FF0080FF00
B3FF00C0FF00A6FF003FFF0080FF00A6FF004CFF00D9FF00F3FF00F3FF00FFFF00FFF300FFE600\
FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00\
8CFF00D9FF00D9FF00E6FF00D9FF00A6FF00CCFF00D9FF00D9FF00D9FF0099FF00
4CFF0066FF0080FF00A6FF0026FF0066FF00A6FF00CCFF00D9FF00C0FF00F3FF00FFF300FFF300\
FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00\
B3FF0066FF00B3FF00CCFF00C0FF0099FF00A6FF008CFF00CCFF00C0FF00B3FF00
00FF8C3FFF00A6FF00C0FF00C0FF008CFF0073FF0099FF00B3FF00CCFF00F3FF00FFFF00FFF300\
FFE600FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00\
FFD900FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00\
D9FF00B3FF0080FF0099FF0033FF0073FF004CFF0026FF00A6FF00A6FF0073FF00
26FF0033FF00B3FF00D9FF00D9FF00C0FF003FFF0019FF00A6FF00B3FF00E6FF00FFFF00FFF300\
FFF300FFE600FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00\
FFE60033FF00FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFFF00FFFF00F3FF00\
E6FF00C0FF0073FF0099FF0073FF00B3FF00B3FF0026FF0019FF0066FF008CFF00
C0FF00CCFF00D9FF00E6FF00E6FF00D9FF00B3FF00D9FF00CCFF00B3FF00C0FF00F3FF00FFFF00\
FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900\
FFE600F3FF00FFFF00FFE600FFE600FFE600FFFF00FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00F3FF00E6FF00\
D9FF00C0FF0059FF00C0FF00CCFF00CCFF00CCFF0099FF00C0FF00B3FF0080FF00
CCFF00E6FF00F3FF00F3FF00F3FF00F3FF00D9FF00F3FF00F3FF00E6FF00B3FF00C0FF0066FF00\
F3FF00F3FF00FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFB300FFC000FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFF300E6FF00CCFF00F3FF00FFFF00FFF300E6FF00FFFF00FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFFF00F3FF00FFFF00FFF300FFFF00FFFF00F3FF00CCFF00C0FF00\
C0FF0033FF00B3FF00CCFF00D9FF00E6FF00E6FF00C0FF00D9FF00D9FF00A6FF00
CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00E6FF00C0FF0099FF00\
C0FF00C0FF00F3FF00FFF300FFF300FFF300FFE600FFD900FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFB300FFC000FFE60099FF00B3FF00C0FF00D9FF00F3FF00FFFF00FFFF00\
F3FF00D9FF00B3FF0066FF00E6FF00CCFF00C0FF00CCFF00F3FF00D9FF00FFF300
FFF300FFF300FFF300FFF300F3FF00B3FF00F3FF00FFFF00FFFF00F3FF00E6FF0080FF0080FF00\
73FF000CFF00B3FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00E6FF00CCFF00
C0FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00F3FF0080FF00\
99FF0000FF59E6FF00F3FF00F3FF0099FF00FFE600FFD900FFCC00FFCC00FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFB300FFB300FFC000FFD900FFD900FFD900FFFF00E6FF0099FF00C0FF00\
CCFF008CFF00F3FF00CCFF004CFF00CCFF00CCFF00A6FF0080FF0000FF00D9FF00
FFFF00F3FF00F3FF00F3FF00E6FF003FFF00D9FF00E6FF00F3FF00E6FF00D9FF00C0FF0080FF00\
00FFB373FF00A6FF00D9FF00F3FF00F3FF00F3FF00FFFF00FFFF00F3FF00E6FF00
73FF00A6FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFF300FFFF00F3FF00\
E6FF0026FF00B3FF008CFF0099FF00F3FF00FFE600FFD900FFCC00FFCC00FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFFF00CCFF00\
FFFF00FFF300FFF300FFFF00CCFF00F3FF00FFFF00F3FF00F3FF00E6FF00E6FF00
66FF00C0FF00CCFF00D9FF00CCFF008CFF00A6FF00B3FF00D9FF00D9FF00CCFF00B3FF0066FF00\
99FF00A6FF0033FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFFF00E6FF00CCFF00B3FF00CCFF00D9FF00FFFF00FFD900FFCC00FFCC00FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFF300F3FF00\
FFE600FFE600FFE600FFE600C0FF00FFF300FFE600FFF300FFF300FFF300FFFF00
D9FF00D9FF0066FF0026FF0066FF00C0FF00A6FF0099FF00C0FF00C0FF00B3FF004CFF00B3FF00\
CCFF00D9FF00D9FF00D9FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFF300E6FF00F3FF00FFF300F3FF00E6FF00F3FF00FFE600FFD900FFCC00FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFE600FFF300\
FFD900FFD900FFD900FFD900FFE600FFE600FFD900FFE600FFE600FFE600FFE600
FFF300FFFF00CCFF00D9FF00D9FF00E6FF00CCFF0073FF0066FF0066FF003FFF00A6FF00D9FF00\
E6FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFFF00FFF300FFE600FFE600FFE600B3FF00D9FF00FFD900FFCC00FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFF30080FF00F3FF00F3FF00F3FF00D9FF00B3FF00CCFF00B3FF0080FF0073FF00D9FF00\
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFCC00FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFE600FFE600FFFF00FFF300FFF300FFFF00D9FF00E6FF00E6FF00CCFF0066FF00B3FF00D9FF00\
F3FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00D9FF00C0FF0033FF00C0FF00\
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00D9FF0000FF26E6FF00\
F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF0099FF00E6FF00\
F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00F3FF00CCFF0000FFCCD9FF00\
F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00B3FF008CFF00CCFF00\
E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00CCFF008CFF0000FF19\
CCFF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFFF00F3FF00E6FF00A6FF0073FF00C0FF00\
E6FF00F3FF00FFFF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300F3FF00A6FF008CFF0080FF00A6FF00CCFF00\
D9FF00E6FF00F3FF00F3FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00E6FF00CCFF00A6FF008CFF00B3FF00\
C0FF00D9FF00D9FF00A6FF00F3FF00FFF300FFE600FFE600FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFE600FFF300FFF300F3FF00E6FF00CCFF008CFF0059FF004CFF00\
99FF00C0FF00A6FF00CCFF00F3FF00FFF300FFE600FFE600FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFD900FFD900FFF300FFFF00F3FF0026FF00D9FF00C0FF004CFF000026FF000000\
0CFF0000FF2680FF008CFF00D9FF00FFFF00FFF300FFE600FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFD900FFD900FFFF00D9FF00B3FF0099FF00A6FF00A6FF003FFF00000000000000\
4CFF00A6FF00C0FF0099FF00B3FF00CCFF00E6FF00FFF300FFD900FFD900FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFE600FFF300FFFF00E6FF008CFF00A6FF008CFF004CFF0000FF19\
73FF00A6FF00D9FF00D9FF00F3FF00F3FF00E6FF00FFF300FFD900FFD900FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFE600FFE600FFF300E6FF00C0FF00D9FF00C0FF0099FF008CFF00\
99FF00CCFF00E6FF00F3FF00FFFF00FFF300FFE600FFE600FFD900FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300E6FF00F3FF00E6FF00D9FF00CCFF00B3FF00\
80FF00C0FF00E6FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00E6FF00CCFF0099FF00\
B3FF00CCFF00A6FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFF300FFFF00D9FF004CFF0099FF00\
CCFF00F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00CCFF0066FF00\
CCFF00F3FF00FFF300FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF0099FF00\
E6FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF00CCFF00\
F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00E6FF00B3FF00CCFF00\
F3FF00FFFF00FFF300FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00E6FF00C0FF0033FF00\
E6FF00F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00E6FF00D9FF00A6FF00B3FF00\
CCFF00D9FF00E6FF00FFF300FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFCC00FFD900FFD900FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFF300E6FF00FFFF00FFFF00FFFF00FFFF00F3FF00CCFF00B3FF0073FF0099FF0080FF00\
3FFF00A6FF00E6FF00FFFF00FFF300FFF300FFE600FFD900FFD900FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFCC00FFF300CCFF00E6FF00C0FF0059FF00FFF300FFF300FFF300
FFF300FFFF00C0FF00E6FF00F3FF00F3FF00F3FF00E6FF008CFF0066FF00C0FF00D9FF00D9FF00\
B3FF00A6FF00D9FF00E6FF00E6FF00CCFF00FFE600FFD900FFD900FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFCC00FFD900A6FF00FFFF00A6FF0099FF00E6FF00FFFF00E6FF00
F3FF00F3FF00CCFF00B3FF00A6FF00E6FF00E6FF00CCFF000CFF008CFF00E6FF00F3FF00E6FF00\
99FF0080FF0099FF0026FF000CFF00F3FF00FFF300FFE600FFD900FFD900FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFC000FFCC00FFD900FFE600FFF300FFFF00D9FF00C0FF004CFF00
D9FF0080FF008CFF0099FF0073FF00C0FF00C0FF0059FF00C0FF00E6FF00F3FF00FFFF00FFFF00\
F3FF0059FF00E6FF00D9FF0033FF00E6FF00FFF300FFE600FFD900FFD900FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFE600FFFF00E6FF008CFF00
A6FF0099FF00CCFF00D9FF00B3FF00A6FF00A6FF00B3FF00E6FF00FFFF00FFF300FFF300FFF300\
FFFF00CCFF00FFFF00FFFF00D9FF0066FF00FFFF00FFF300FFE600FFD900FFD900
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFCC00FFD900FFD900FFE600FFF300FFFF00E6FF00
80FF00E6FF00F3FF00F3FF00CCFF00E6FF00D9FF0080FF00F3FF00FFF300FFF300FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300F3FF00D9FF00FFFF00FFF300FFE600FFD900
FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300FFFF00E6FF00
CCFF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00CCFF00F3FF00FFF300FFE600FFE600FFD900\
FFD900FFD900FFD900FFE600FFE600FFFF008CFF00CCFF00F3FF00FFF300FFE600
FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300FFFF00C0FF00
CCFF00F3FF00FFF300FFF300FFF300FFF300FFF300F3FF00D9FF00FFF300FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFFF0073FF00E6FF00F3FF00F3FF00
FFFF00FFD900FFD900FFCC00FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300D9FF0059FF00
CCFF00FFFF00FFF300FFE600FFE600FFE600FFE600FFF300F3FF00FFE600FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFF30099FF00A6FF00A6FF00B3FF00
FFF300FFE600FFD900FFD900FFCC00FFCC00FFC000FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300E6FF0000FF00
19FF00FFFF00FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFF300FFF300FFFF00CCFF00CCFF00
FFFF00FFF300FFE600FFE600FFF300FFD900FFC000FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00D9FF00C0FF00
F3FF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600E6FF0066FF00
E6FF00D9FF00FFFF00F3FF00D9FF00FFD900FFC000FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFCC00FFE600FFF300FFF300FFF300FFF300FFFF00D9FF00D9FF00
FFFF00FFE600FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFFF00D9FF00
D9FF00E6FF00CCFF00F3FF00FFE600FFCC00FFC000FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFCC00FFCC00FFF300B3FF00F3FF00E6FF00F3FF00E6FF00B3FF00E6FF00
FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFD900C0FF00FFF300
FFE600FFF30099FF00F3FF00FFD900FFCC00FFC000FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFCC00FFD900FFE600FFFF00B3FF0073FF00A6FF00A6FF00D9FF00C0FF00
E6FF00FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFF300FFD900
FFD900FFE600E6FF00D9FF00FFF300FFCC00FFC000FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFCC00FFCC00FFD900FFE600FFFF00A6FF00F3FF00E6FF00E6FF00FFFF00F3FF00
D9FF00FFF300FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFD900FFF300FFE600FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00\
FFCC00FFD900FFF300F3FF00E6FF00D9FF00FFF300FFF300FFF300FFE600FFE600
E6FF00A6FF00FFE600FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFCC00FFD900C0FF00FFD900FFC000FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900\
FFD900FFE600FFFF00B3FF00CCFF00E6FF00FFE600FFD900FFD900FFD900FFD900
FFE600E6FF00E6FF00FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFCC00FFF300FFF300FFC000FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFCC00FFD900FFD900D9FF00\
F3FF003FFF00E6FF00F3FF00FFF300F3FF00FFE600FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900F3FF00FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000C0FF00FFC000FFB300FFA600FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFFF00FFFF00FFE600FFF300D9FF00\
E6FF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFFF00CCFF0099FF00C0FF00\
FFF300FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFF30073FF00FFFF00FFFF00\
FFF300FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFE600FFFF008CFF00FFF300FFE600\
FFD900FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFC000FFE600FFE600FFE600FFD900FFD900FFE60033FF00F3FF00E6FF00F3FF00FFE600FFD900\
FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFB300FFCC00FFF300E6FF00B3FF00F3FF00F3FF008CFF0073FF00D9FF008CFF00FFF300FFD900\
FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFB300FFC000FFCC00FFD900FFE600F3FF0080FF00F3FF00FFFF00FFF300FFF300A6FF00FFD900\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFB300FFB300FFC000FFCC00FFD900FFE600B3FF00FFF300FFE600FFD900FFD900FFD900FFCC00\
FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFB300FFB300FFC000FFCC00FFD900FFE600D9FF00FFF300FFD900FFCC00FFCC00FFC000FFC000\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFB300FFB300FFC000FFCC00FFD900FFF30000CCFFFFF300FFD900FFCC00FFC000FFC000FFC000\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFB300FFC000FFC000FFCC00FFD900FFF300D9FF00FFE600FFD900FFCC00FFC000FFC000FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300
FFB300FFC000FFD900FFD900FFE600FFFF00D9FF00FFE600FFD900FFCC00FFC000FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300
FFB300FFCC00FFF300E6FF00C0FF00C0FF00C0FF00D9FF00FFD900FFCC00FFC000FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300
FFC000FFCC00FFE600E6FF00FFFF00E6FF00FFE600FFFF00F3FF00FFD900FFC000FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300
FFC000FFD900FFFF00E6FF00FFD900FFCC00FFCC00FFCC0099FF00CCFF00FFC000FFB300FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFB300FFB300FFC000
FFD900FFFF00FFFF00FFF300FFD900FFC000FFC000FFC000FFC000FFCC00FFC000FFB300FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFB300FFCC00FFE600
F3FF00FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFC000FFE600F3FF00
CCFF00FFC000FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFC000FFE600FFE600
FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFB300FFCC00FFF300FFF300
FFC000FFB300FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FFA600FFC000FFCC00FFB300FFB300
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFB300FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFE600FFF300FFFF00F3FF00F3FF00E6FF0073FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF0033FF00B3FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF0099FF0059FF0000FF5900FF4C0073FF33FF003FFF00
80FF0099FF008CFF0000FF4C8CFF0073FF004CFF000CFF0080FF00A6FF00C0FF00CCFF00D9FF00\
D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFE600FFF300E6FF00C0FF0099FF00A6FF0000FF0CC0FF00C0FF00D9FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0073FF0080FF00A6FF0099FF008CFF00\
A6FF00A6FF000CFF008CFF0080FF0073FF000026FF00FF1919FF0033FF0080FF00
99FF00A6FF00A6FF00A6FF0099FF0080FF0000FF004CFF0080FF0099FF00A6FF00B3FF00CCFF00\
CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFE600FFE600FFF300F3FF00CCFF0080FF00A6FF0026FF0000FF19B3FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF008CFF0000FF4066FF0066FF0066FF00\
80FF008CFF0066FF0059FF0066FF0000FF1900FF0C33FF0073FF0059FF0080FF00
A6FF00B3FF00B3FF00B3FF00A6FF008CFF0019FF0026FF0000FF2680FF0073FF0099FF00B3FF00\
C0FF0099FF00C0FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFE600FFE600FFF300FFFF00D9FF00D9FF00D9FF0099FF00B3FF0099FF00
A6FF00B3FF00C0FF0000FF80C0FF00C0FF0073FF008CFF0080FF000CFF0000FFCC00FF0C00FFA6\
59FF0066FF0059FF0000FFB300FF4000FF664CFF0073FF0099FF008CFF0019FF00
99FF00C0FF00C0FF00C0FF00B3FF004CFF0080FF003FFF0000FF0C4CFF0000FF5973FF0019FF00\
8CFF00B3FF00D9FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00F3FF00E6FF00D9FF00D9FF00
B3FF0033FF000CFF0033FF003FFF00A6FF008CFF0000FF004CFF0026FF0066FF0066FF0066FF00\
00FF9900FF1900FF4000FF994CFF0019FF0033FF008CFF00A6FF00B3FF008CFF00
66FF00C0FF00CCFF00CCFF00CCFF00C0FF00A6FF0000FF0C66FF0000FF8059FF0000FF598CFF00\
C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00E6FF00
CCFF008CFF0066FF0066FF0059FF0000FF6673FF0000FF3300FF6666FF008CFF0099FF008CFF00\
73FF0059FF0000FF003FFF0080FF0066FF0000FF2699FF00B3FF00C0FF00CCFF00
C0FF00D9FF00D9FF00D9FF00D9FF00CCFF00B3FF0066FF00A6FF0019FF0099FF0066FF0066FF00\
C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00
D9FF00C0FF00B3FF0099FF0000FF3300FF2600FF0C19FF0066FF0059FF0099FF00A6FF00B3FF00\
A6FF008CFF008CFF00A6FF00A6FF0080FF0026FF008CFF00C0FF00CCFF00D9FF00
D9FF00E6FF00E6FF00E6FF00D9FF00CCFF0080FF00B3FF00CCFF00C0FF00B3FF0066FF0073FF00\
B3FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00
E6FF00D9FF00CCFF0080FF008CFF0066FF0000FFBF73FF008CFF0080FF0080FF00B3FF00C0FF00\
C0FF00A6FF00A6FF00C0FF00C0FF008CFF008CFF0099FF00C0FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF004CFF00CCFF00D9FF00D9FF00C0FF0099FF0080FF00\
8CFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00
E6FF00D9FF00CCFF00B3FF0099FF0059FF0033FF0080FF00A6FF00B3FF00B3FF00C0FF00CCFF00\
CCFF00CCFF00C0FF00CCFF00CCFF00CCFF00B3FF0099FF00CCFF00D9FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00E6FF00E6FF00E6FF00D9FF00CCFF0080FF00\
0CFF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00
E6FF00D9FF00CCFF00B3FF0099FF0066FF0026FF0080FF00A6FF00C0FF00C0FF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00C0FF0000FF66C0FF00D9FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF00\
00FF59C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00
D9FF00B3FF00A6FF00A6FF008CFF0059FF0000FF668CFF00B3FF00C0FF00CCFF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00CCFF0099FF00B3FF00D9FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00\
99FF0059FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00
A6FF0080FF0059FF0000FF4C26FF0000FF000CFF0080FF00A6FF00C0FF00CCFF00D9FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00A6FF0000FF33D9FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00\
B3FF004CFF008CFF008CFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00
D9FF00C0FF00B3FF0099FF0000FF8000FF3326FF004CFF008CFF0099FF00C0FF00D9FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00C0FF00F3FF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00\
CCFF0099FF000CFF00B3FF00D9FF00E6FF00E6FF00F3FF00FFFF00FFF300FFF300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00
D9FF00CCFF00C0FF00A6FF0080FF0000FF1900FFBF99FF008CFF0059FF0000FF40CCFF00E6FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
D9FF0033FF004CFF00A6FF0080FF00CCFF00C0FF00C0FF00FFFF00FFF300FFF300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00
D9FF00CCFF00C0FF00A6FF0080FF0000FF008CFF00B3FF00C0FF00C0FF00CCFF00D9FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00\
D9FF00B3FF000CFF0019FF0033FF0000FF0CC0FF00E6FF00FFFF00FFFF00FFF300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00
CCFF00C0FF00A6FF0099FF000CFF0033FF0099FF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00\
B3FF00C0FF00C0FF0099FF0019FF0099FF00CCFF00E6FF00F3FF00FFFF00FFF300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFF300FFF300F3FF0066FF00B3FF00D9FF00D9FF00CCFF00A6FF00
C0FF00B3FF0026FF0073FF0000FF4019FF0080FF00A6FF00CCFF00D9FF00E6FF00F3FF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00\
F3FF00E6FF00D9FF00C0FF0000FF2699FF00CCFF00E6FF00F3FF00FFFF00FFFF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFF300FFF300FFFF00F3FF00D9FF00B3FF0099FF0000FF19B3FF0000FF33
00FF268CFF0073FF0000FFFF73FF003FFF0000FF40A6FF00CCFF00D9FF00F3FF00F3FF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFFF00F3FF00E6FF0000FF7300FF2680FF00C0FF00B3FF00D9FF00F3FF00F3FF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFF300FFF300FFFF00FFFF00E6FF00D9FF0000FF5933FF0066FF0000FF00
4CFF0000FF0C00FF0C8CFF008CFF00A6FF0026FF0033FF0080FF00D9FF00F3FF00F3FF00FFFF00\
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFFF00F3FF00CCFF008CFF0019FF008CFF003FFF00C0FF00CCFF0066FF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFFF00F3FF00F3FF00D9FF00C0FF008CFF0033FF0080FF00
A6FF0099FF0026FF00B3FF00CCFF00CCFF008CFF00A6FF0080FF00D9FF00E6FF00F3FF00FFFF00\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFFF00F3FF00CCFF0066FF00A6FF0099FF0066FF0073FF00CCFF00E6FF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF0000FF1966FF0080FF00B3FF00
CCFF00CCFF00C0FF00C0FF00D9FF00E6FF00D9FF00D9FF0080FF00CCFF00E6FF00F3FF00FFFF00\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFF300FFFF00CCFF00C0FF00E6FF00CCFF00CCFF00A6FF0000FF19D9FF00FFFF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFFF00F3FF00E6FF00D9FF00CCFF00A6FF0033FF0073FF0000FF00
D9FF00E6FF00D9FF00C0FF00E6FF00F3FF00F3FF00E6FF00CCFF008CFF0080FF00F3FF00FFFF00\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFF3000CFF00F3FF00FFFF00F3FF00E6FF0099FF00A6FF00E6FF00FFFF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFFF00FFFF00E6FF00C0FF00A6FF008CFF0019FF0026FF00B3FF00CCFF00
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00F3FF00D9FF00B3FF00A6FF00D9FF00F3FF00\
FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFF300FFF300FFF300FFF300FFFF00E6FF00CCFF008CFF00CCFF00FFFF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00\
FFFF00FFFF00F3FF00E6FF00C0FF0059FF008CFF0066FF00A6FF0080FF00D9FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00CCFF0099FF0059FF00F3FF00\
FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFF300FFFF00F3FF00CCFF00E6FF00FFF300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00\
F3FF00E6FF00E6FF00C0FF0073FF0073FF00CCFF00CCFF00D9FF00B3FF00CCFF00
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00F3FF00B3FF00FFFF00\
FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300E6FF00D9FF00FFF300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00C0FF00E6FF00\
D9FF00C0FF0099FF008CFF00C0FF00C0FF00D9FF00F3FF00F3FF00E6FF0033FF00
F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300F3FF00F3FF00\
FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300F3FF00A6FF00F3FF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFF300D9FF00F3FF00F3FF00FFFF00FFFF00F3FF00E6FF00C0FF00A6FF00\
A6FF004CFF00C0FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFFF00D9FF00FFFF00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFF300FFF300E6FF008CFF00CCFF00E6FF00E6FF00E6FF00D9FF00B3FF0000FF4C\
A6FF0099FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFF300FFFF00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFF300FFFF00F3FF00D9FF0073FF00CCFF00CCFF0033FF00B3FF0099FF0073FF00\
C0FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFFF00F3FF00E6FF00C0FF004CFF0099FF0059FF003FFF0000FF2673FF00\
CCFF00E6FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFE600FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF0099FF0000FF8C73FF00B3FF0099FF00CCFF00\
59FF00E6FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFE600E6FF00F3FF00FFFF008CFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00F3FF00CCFF00B3FF00A6FF0059FF00B3FF00CCFF00D9FF00E6FF00\
E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFE600FFFF00B3FF0019FF00A6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00E6FF00F3FF00E6FF00E6FF00CCFF0073FF0000FF0C59FF008CFF00CCFF00E6FF00F3FF00\
FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFE600FFF300B3FF00A6FF0019FF00C0FF00E6FF00F3FF00FFFF00FFFF00F3FF00
E6FF0080FF00D9FF00D9FF00D9FF00CCFF00B3FF0033FF0099FF00B3FF00CCFF00F3FF00F3FF00\
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFE600FFF300FFFF00F3FF00A6FF00B3FF0073FF00E6FF00E6FF00E6FF00E6FF00
D9FF00C0FF00A6FF00B3FF00B3FF00B3FF0099FF000CFF00A6FF00CCFF00E6FF00F3FF00FFFF00\
FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFE600FFE600FFF300FFFF00F3FF00E6FF00CCFF00B3FF00CCFF00B3FF00D9FF00
CCFF00B3FF0000FF0C59FF004CFF008CFF0000FF8C66FF0080FF00B3FF00E6FF00F3FF00FFFF00\
FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF008CFF0000FF3380FF00B3FF00
99FF0073FF0000FF8080FF0080FF0059FF0099FF00B3FF008CFF003FFF00CCFF00E6FF00F3FF00\
FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00C0FF00B3FF0026FF0000FF0C
66FF003FFF0080FF00B3FF00C0FF00B3FF00B3FF00D9FF00D9FF00CCFF0059FF00C0FF00A6FF00\
FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00D9FF00C0FF0099FF0066FF00
66FF00A6FF0099FF00C0FF00CCFF00D9FF00A6FF00E6FF00E6FF00E6FF00D9FF00C0FF008CFF00\
FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00C0FF0059FF00
80FF00B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFF300FFF300FFF300FFFF00F3FF00E6FF00D9FF00CCFF00C0FF008CFF00
8CFF00C0FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFF300FFF300FFFF00FFFF00E6FF00D9FF00CCFF00C0FF00B3FF0080FF00
A6FF00C0FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFFF00F3FF00B3FF008CFF0059FF0026FF0080FF0026FF00
8CFF00B3FF00C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFFF00FFFF00F3FF00D9FF00B3FF0073FF0080FF0000FF40000000
00FF0C59FF0080FF0073FF00D9FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00C0FF00A6FF008CFF0000FF00
8CFF0073FF00A6FF00C0FF00CCFF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFE600\
FFD900FFD900FFD900FFE600FFE600FFF300FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF30099FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF008CFF0099FF00
B3FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900E6FF00A6FF00\
FFF300FFF300FFF300FFF300FFFF00CCFF00FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFFF00D9FF0099FF00D9FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF003FFF00A6FF00
C0FF00D9FF00E6FF00E6FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFE600FFF300\
8CFF00E6FF00F3FF00FFFF00E6FF00D9FF00FFFF00FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00A6FF008CFF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00A6FF0066FF0073FF00
C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFD900FFE600\
F3FF00D9FF00B3FF003FFF00C0FF00A6FF0099FF00F3FF00E6FF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF00B3FF00C0FF00\
CCFF00CCFF0099FF00CCFF00CCFF00CCFF0073FF00A6FF0099FF0000FF1980FF00
A6FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900\
FFE600FFFF0000FF99CCFF00C0FF00B3FF00B3FF00C0FF004CFF00F3FF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00D9FF00A6FF004CFF00\
B3FF00B3FF0080FF00A6FF00B3FF00B3FF008CFF00008CFF0CFF0080FF004CFF00
73FF00C0FF00CCFF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900\
FFE600E6FF00E6FF00F3FF00F3FF00D9FF0059FF0080FF0019FF00CCFF00CCFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00FFFF00F3FF00F3FF00E6FF00D9FF00C0FF0073FF00\
73FF0019FF003FFF0033FF008CFF0099FF0080FF0000FF6673FF00A6FF00A6FF00
26FF0066FF0019FF00D9FF00F3FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFD900FFFF00FFF300FFF300FFFF00F3FF00CCFF00E6FF00CCFF00A6FF00A6FF00
E6FF00F3FF00F3FF00F3FF0033FF00E6FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF0099FF00\
26FF0073FF008CFF008CFF000CFF0000FF8C59FF00A6FF0099FF00C0FF00C0FF00
99FF00A6FF0066FF00B3FF00E6FF00F3FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFD900FFE600FFE600FFF300FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00
80FF00C0FF00D9FF00D9FF00B3FF00CCFF00D9FF00D9FF00D9FF003FFF0099FF00A6FF0080FF00\
8CFF00B3FF00B3FF00B3FF0073FF00A6FF003FFF00B3FF00CCFF00D9FF00D9FF00
B3FF00D9FF00D9FF00B3FF00B3FF00D9FF00D9FF00F3FF00FFFF00FFF300FFE600FFE600FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00
73FF0099FF00A6FF0080FF0059FF00A6FF00C0FF00CCFF00CCFF00A6FF0000FFCC26FF000CFF00\
A6FF00C0FF00CCFF00CCFF00CCFF00CCFF00A6FF00C0FF00D9FF00E6FF00E6FF00
F3FF00F3FF00E6FF00D9FF00B3FF0080FF0066FF00D9FF00E6FF00CCFF00FFF300FFE600FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFF300FFFF00
F3FF00CCFF0059FF0066FF0099FF0059FF00A6FF00B3FF00B3FF00A6FF0000FF5933FF0033FF00\
A6FF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF0099FF00D9FF00F3FF00F3FF00
FFFF00FFFF00F3FF00F3FF00CCFF00CCFF0000FFF399FF0026FF00F3FF00FFF300FFE600FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00
F3FF0080FF00CCFF00CCFF00C0FF0080FF0073FF000CFF008CFF0026FF0099FF0099FF008CFF00\
0CFF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00CCFF00E6FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00CCFF00CCFF00CCFF0019FF00FFFF00FFE600FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300
FFFF00F3FF00E6FF00E6FF00CCFF008CFF0099FF004CFF0026FF008CFF00B3FF00C0FF00C0FF00\
CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFFF00E6FF00FFFF00FFFF00F3FF0080FF00FFF300FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300
FFF300FFFF00F3FF00F3FF00D9FF00C0FF00C0FF00A6FF0073FF0066FF00C0FF00CCFF00D9FF00\
D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300
FFF300FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00A6FF0019FF008CFF00C0FF00D9FF00D9FF00\
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300
FFF300FFF300FFFF00F3FF00F3FF00E6FF00D9FF00C0FF0099FF0066FF00B3FF00D9FF00E6FF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300
FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00A6FF0059FF00CCFF00D9FF00E6FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300
FFF300FFF300FFFF00F3FF00F3FF00E6FF00D9FF00CCFF0026FF00B3FF00CCFF00D9FF00E6FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300
FFF300FFFF00FFFF00F3FF00E6FF00E6FF00CCFF00C0FF0059FF00A6FF00CCFF00D9FF00E6FF00\
E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300
FFF300FFFF00F3FF00E6FF00E6FF00CCFF0080FF0099FF000CFF0099FF00C0FF00CCFF00D9FF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300
FFFF00F3FF00D9FF00CCFF00CCFF00C0FF00A6FF0033FF0073FF0099FF00B3FF00B3FF00B3FF00\
D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300F3FF00
E6FF00E6FF00CCFF003FFF0099FF00A6FF0033FF0059FF0033FF0000FF998CFF0000FF33B3FF00\
CCFF00CCFF0066FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300F3FF00
D9FF0066FF008CFF0059FF0066FF0073FF0073FF0000FF6600000000FF193FFF003FFF0099FF00\
A6FF00A6FF00C0FF00E6FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00
F3FF00CCFF00B3FF00B3FF0099FF0059FF0059FF0000FF0CA600FF00FF0C80FF0080FF0059FF00\
00FF198CFF0059FF00B3FF00D9FF00FFF300FFF300FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00
FFFF00D9FF00D9FF00CCFF00B3FF008CFF0099FF0026FF003FFF0066FF008CFF00B3FF00A6FF00\
19FF00CCFF00E6FF00E6FF00F3FF00FFF300FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300
FFFF00F3FF00E6FF00D9FF00B3FF00C0FF00B3FF0099FF0066FF0066FF00B3FF00CCFF00CCFF00\
CCFF00D9FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF008CFF003FFF00A6FF0080FF00D9FF00E6FF00\
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00
FFFF00FFFF00F3FF00E6FF00E6FF00D9FF00C0FF0099FF0073FF00C0FF00D9FF00E6FF00F3FF00\
F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00
FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00A6FF00B3FF00CCFF00D9FF00E6FF00F3FF00\
F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0000FF59C0FF00D9FF00E6FF00E6FF00F3FF00\
FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFF30000FF26FFFF00F3FF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00E6FF00D9FF00CCFF0000FF2666FF00B3FF00CCFF00D9FF00E6FF00F3FF00\
FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600F3FF00B3FF008CFF00F3FF00\
FFFF00FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00B3FF0073FF0080FF00C0FF00D9FF00E6FF00F3FF00\
F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600D9FF00E6FF00A6FF00C0FF00\
E6FF00FFFF00FFFF00FFFF00FFFF00FFFF00E6FF00E6FF00F3FF00F3FF00F3FF00
E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0099FF000CFF0099FF00C0FF00CCFF00CCFF00E6FF00\
F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00B3FF00C0FF00\
B3FF00E6FF00F3FF00F3FF00F3FF00F3FF00A6FF0073FF00E6FF00E6FF00E6FF00
E6FF00D9FF0080FF00B3FF00B3FF00B3FF0080FF0000FF1973FF0080FF0099FF00B3FF00E6FF00\
F3FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00E6FF00\
B3FF00CCFF00D9FF00E6FF00E6FF00E6FF00CCFF008CFF00CCFF00D9FF00D9FF00
D9FF00CCFF0073FF003FFF0080FF0000FF008CFF0099FF004CFF0073FF0080FF00C0FF00D9FF00\
D9FF00E6FF00D9FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00\
CCFF008CFF00A6FF00C0FF00D9FF00CCFF00C0FF0026FF00B3FF00B3FF00CCFF00
CCFF00C0FF00A6FF0066FF0000FF4C73FF00B3FF00C0FF00B3FF00A6FF0066FF00A6FF00B3FF00\
C0FF0099FF00E6FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00\
C0FF00B3FF0080FF00A6FF00B3FF008CFF00A6FF0033FF0066FF008CFF00B3FF00
C0FF00B3FF0099FF0019FF0000FF198CFF00C0FF00CCFF00CCFF0080FF0080FF0059FF0026FF00\
26FF00A6FF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFFF00FFE600FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00\
E6FF00CCFF0066FF0026FF008CFF0000FF333FFF0099FF008CFF0019FF0099FF00
73FF0099FF0000FF26A6FF00A6FF0000FF0CCCFF00D9FF00D9FF00D9FF00B3FF00A6FF00B3FF00\
C0FF0073FF00B3FF00E6FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFFF00D9FF00FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00\
E6FF00D9FF00B3FF0059FF0099FF0099FF008CFF00C0FF00B3FF008CFF0073FF00
3FFF0066FF0099FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00B3FF00CCFF00E6FF00\
D9FF00C0FF0000FF4CD9FF00F3FF00F3FF00FFFF00FFF300FFF300FFE600FFE600
FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFF30080FF00FFF300FFE600FFE600\
FFE600FFE600FFFF00FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00\
E6FF00CCFF00B3FF003FFF00B3FF00C0FF00CCFF00CCFF00CCFF00A6FF00B3FF00
B3FF0080FF0099FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00D9FF00E6FF00F3FF00\
F3FF00F3FF00D9FF0080FF00CCFF00A6FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFF300B3FF00CCFF00FFFF00FFFF00\
FFF300FFF300D9FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFFF00FFF300FFF300FFF300FFF300FFFF00FFFF00E6FF00E6FF00D9FF00\
CCFF00B3FF0073FF00B3FF00CCFF00D9FF00D9FF00D9FF00D9FF00C0FF00CCFF00
CCFF00B3FF000CFF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00CCFF0026FF00A6FF00D9FF00E6FF0000FF00F3FF00FFF300
FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFC0004CFF00FFE600FFFF00
FFFF00FFE600FFE600FFE60080FF00FFF300FFF300FFF300FFFF00CCFF00C0FF00CCFF00E6FF00\
FFFF00F3FF00C0FF00F3FF00FFFF00FFFF00FFF300FFE600FFE600FFE600FFE600
FFF300FFF300FFFF0080FF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00D9FF0080FF00B3FF00\
99FF0099FF0073FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00B3FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00F3FF00D9FF0000FF4C99FF0099FF00C0FF00F3FF00FFFF00
FFFF00FFFF00E6FF00FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFC000FFCC00FFE600FFFF00
8CFF00FFFF00A6FF00E6FF000CFF00E6FF00F3FF00C0FF00D9FF0066FF00CCFF00C0FF00C0FF00\
CCFF00A6FF0099FF00A6FF00D9FF00D9FF00F3FF00FFFF00FFF300FFF300FFF300
FFF300FFFF00F3FF00C0FF00D9FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF0099FF000CFF00\
33FF003FFF008CFF00C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00B3FF0066FF00E6FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00F3FF00A6FF00C0FF00C0FF0099FF00D9FF00D9FF00
E6FF00D9FF00E6FF00FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00
FFCC00FFD900FFF300E6FF00F3FF0000FF0C8CFF00D9FF00D9FF00D9FF00F3FF00D9FF00B3FF00\
C0FF00CCFF00D9FF00C0FF0080FF00A6FF00B3FF00E6FF00F3FF00F3FF00D9FF00
F3FF00F3FF00E6FF00C0FF00C0FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00B3FF0080FF00\
00FF4026FF0073FF00A6FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00F3FF00E6FF0099FF0080FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300F3FF00F3FF00F3FF00CCFF0000FF80B3FF0066FF00
80FF00C0FF00FFFF00FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000
FFC000FFCC00FFD900FFE600FFF300F3FF00B3FF00FFFF00FFFF00FFF300FFF300FFFF00E6FF00\
D9FF00F3FF00FFFF00F3FF00D9FF00F3FF00E6FF00D9FF00A6FF00CCFF00A6FF00
D9FF00D9FF00CCFF00B3FF0099FF00B3FF00C0FF00D9FF00D9FF00D9FF00CCFF00B3FF0059FF00\
33FF0066FF00A6FF0059FF00D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00C0FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF004CFF00CCFF0073FF00
D9FF0059FF00F3FF00FFF300FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFC000FFC000FFCC00FFCC00FFD900FFF300E6FF00FFF300FFE600FFE600FFE600FFF300E6FF00\
F3FF00FFF300FFF300FFF300FFFF00FFF300FFFF00FFFF00E6FF00C0FF0099FF00
B3FF008CFF004CFF0099FF00A6FF0073FF00A6FF00CCFF00CCFF00CCFF00C0FF008CFF008CFF00\
C0FF00B3FF00CCFF00CCFF00CCFF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFFF00A6FF00F3FF00FFFF00
F3FF00B3FF00A6FF00FFFF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFC000FFC000FFCC00FFD900F3FF00F3FF00FFE600FFD900FFD900FFD900FFE600FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFFF00F3FF00D9FF00
8CFF00C0FF00B3FF00CCFF00CCFF008CFF0073FF0099FF008CFF00B3FF0080FF00A6FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300A6FF00FFF300FFF300
FFF300FFF300FFFF00C0FF00FFF300FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFC000FFC000FFCC00FFF300FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300F3FF00
99FF00E6FF00E6FF00E6FF00E6FF00CCFF004CFF00A6FF004CFF0073FF0073FF00C0FF00D9FF00\
E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFF300FFE600FFE600
FFE600FFE600FFE600FFFF00C0FF00FFE600FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300F3FF00
D9FF00F3FF00FFFF00F3FF00F3FF00C0FF00C0FF00CCFF00C0FF00B3FF0059FF003FFF00D9FF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFFF00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFFF00
FFFF00FFF300FFF300FFFF00F3FF00B3FF00E6FF00E6FF00D9FF00B3FF0066FF00C0FF00D9FF00\
E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600
FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00A6FF0099FF008CFF0080FF00\
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF00C0FF0099FF00D9FF00\
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF0099FF00D9FF00\
F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00CCFF0066FF00D9FF00\
F3FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00C0FF0080FF00D9FF00\
F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00B3FF0066FF00A6FF00D9FF00\
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF00C0FF0000FF26C0FF00\
C0FF00E6FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF00C0FF0073FF0099FF00\
CCFF00E6FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00E6FF00CCFF0080FF008CFF00C0FF00\
D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFF300F3FF008CFF0080FF004CFF0059FF00A6FF00CCFF00\
D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00D9FF00B3FF0080FF00A6FF00C0FF00\
CCFF00D9FF00E6FF00E6FF00D9FF00CCFF00FFFF00FFF300FFE600FFE600FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFF300FFF300FFFF00F3FF00D9FF00C0FF0099FF0073FF008CFF00\
0CFF00C0FF00CCFF00C0FF008CFF00E6FF00FFFF00FFF300FFE600FFE600FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFD900FFE600FFF300FFF300FFFF00F3FF00E6FF00D9FF00B3FF0080FF0033FF0000FF00\
66FF0000FF19B3FF0073FF00CCFF00E6FF00FFFF00FFF300FFE600FFE600FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFD900FFF300F3FF00F3FF00E6FF00B3FF00D9FF00CCFF0080FF0026FF00000000000000\
0CFF0059FF0080FF0080FF0073FF00D9FF00B3FF00FFFF00FFF300FFE600FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFE600FFFF00D9FF00CCFF0099FF0080FF00B3FF00B3FF008CFF000099FF000000000000\
0CFF008CFF00B3FF00C0FF0066FF0000FFCC99FF00E6FF00F3FF00FFF300FFE600
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFD900FFE600FFF300FFFF00E6FF00CCFF008CFF0073FF0080FF0066FF0019FF0000FFB3\
19FF0000FF33C0FF00D9FF00D9FF00CCFF00E6FF00D9FF00D9FF00D9FF00FFE600
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00A6FF00C0FF00C0FF0099FF0000FF2666FF00\
3FFF00B3FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFF300FFF300FFE600FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFF300FFFF00C0FF00CCFF00D9FF00D9FF00C0FF00B3FF00A6FF00\
59FF00C0FF00D9FF00E6FF00FFFF00FFFF00FFF300FFE600FFE600FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFF300F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF00\
4CFF0099FF00CCFF00E6FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00F3FF00D9FF00CCFF00A6FF00\
66FF00B3FF00C0FF0073FF00F3FF00FFF300FFE600FFE600FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00FFFF00F3FF00D9FF00B3FF0073FF00\
B3FF00D9FF00F3FF00F3FF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00CCFF00C0FF0059FF00\
CCFF00E6FF00FFFF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00CCFF0099FF00\
59FF00E6FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00CCFF0000FF26\
D9FF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00E6FF00D9FF00B3FF00\
E6FF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00E6FF00B3FF00C0FF00\
E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF00A6FF00B3FF00\
D9FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00B3FF008CFF00\
D9FF00E6FF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00E6FF00CCFF0099FF00A6FF00\
CCFF00D9FF00CCFF00F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFCC00FFD900FFD900\
FFD900D9FF00FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300E6FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00CCFF00CCFF00B3FF0073FF0099FF008CFF00\
19FF00A6FF00C0FF00F3FF00FFFF00FFFF00FFF300FFE600FFE600FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFD900B3FF00FFFF00\
FFFF00C0FF00FFFF00FFFF00FFF300FFE600FFE600FFE600FFF300FFFF00E6FF00
B3FF00F3FF00FFFF00FFFF00F3FF00F3FF00E6FF0099FF0099FF008CFF00C0FF00CCFF00CCFF00\
C0FF0073FF00B3FF00E6FF00F3FF00F3FF00F3FF00A6FF00FFE600FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFFF00\
B3FF00D9FF00C0FF0066FF00F3FF00FFF300FFF300FFFF00FFFF00FFFF00E6FF00
A6FF00D9FF00E6FF00F3FF00F3FF00E6FF00CCFF003FFF0000FF4026FF00D9FF00E6FF00E6FF00\
CCFF003FFF00B3FF00CCFF00C0FF00D9FF0099FF00FFFF00FFE600FFE600FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFF300\
FFF300FFFF00E6FF00CCFF0099FF00E6FF00F3FF00CCFF00F3FF00F3FF00D9FF00
A6FF00B3FF0099FF00D9FF00D9FF00D9FF00B3FF000CFF0073FF00CCFF00F3FF00F3FF00F3FF00\
E6FF00CCFF0073FF000CFF0099FF0080FF00D9FF00FFFF00FFF300FFE600FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900\
FFD900FFE600FFF300FFF300F3FF00A6FF008CFF00A6FF00D9FF00CCFF00B3FF00
99FF00A6FF004CFF00C0FF00B3FF00B3FF008CFF00CCFF00E6FF00E6FF00FFFF00FFFF00FFFF00\
F3FF00D9FF00CCFF00E6FF00E6FF00A6FF00C0FF00E6FF00FFF300FFE600FFE600
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00\
FFD900FFD900FFE600FFE600FFF300B3FF00D9FF0073FF00B3FF0080FF0059FF00
CCFF00CCFF00B3FF008CFF0080FF008CFF00C0FF00E6FF00F3FF00FFFF00FFF300FFF300FFF300\
FFFF00CCFF00E6FF00FFFF00FFFF0073FF00CCFF00CCFF00FFFF00FFF300FFE600
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00\
FFCC00FFD900FFD900FFE600FFF300FFFF00F3FF00D9FF0059FF00CCFF00D9FF00
E6FF00E6FF00D9FF00CCFF00D9FF00A6FF00B3FF00F3FF00FFFF00FFF300FFF300FFE600FFE600\
FFF300FFFF00FFF300FFF300FFF300FFFF00F3FF00C0FF00F3FF00FFFF00FFF300
FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00\
FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00A6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF008CFF00F3FF00FFFF00FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300CCFF008CFF00F3FF00E6FF00
FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00CCFF00B3FF00F3FF00FFFF00
FFFF00FFFF00FFF300FFF300FFFF00FFFF00CCFF00E6FF00FFF300FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFFF00CCFF008CFF00E6FF00
FFFF00FFF300FFF300FFFF00FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFD900FFD900FFE600FFE600FFF300F3FF00C0FF00CCFF00F3FF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300F3FF00C0FF00FFFF00FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFF300FFFF003FFF00D9FF00
E6FF00F3FF00E6FF00D9FF00FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFD900FFD900FFE600FFF300F3FF00D9FF0080FF00C0FF00F3FF00FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFF300F3FF00FFF300FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300CCFF00C0FF00
80FF00A6FF00D9FF00FFFF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFD900FFD900FFE600FFF300F3FF00A6FF00000000A6FF00F3FF00FFF300
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFE600FFE600FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFF300F3FF00FFFF00
F3FF00C0FF0080FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFC000FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFD900FFD900FFE600FFE600FFF300F3FF00C0FF0080FF00D9FF00D9FF00FFF300
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300
F3FF0033FF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300F3FF00F3FF00FFCC00FFC000FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFD900\
FFD900FFE600FFE600FFF300FFF300F3FF00CCFF00CCFF00F3FF00FFF300FFE600
FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFE600
FFF300E6FF0019FF00CCFF0066FF00A6FF00E6FF00B3FF00FFFF00FFD900FFCC00FFC000FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFFF00FFF300\
FFF300FFF300FFF300FFFF00FFFF00F3FF00C0FF00E6FF00FFFF00FFF300FFE600
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900
FFE600E6FF00E6FF00F3FF00E6FF00E6FF003FFF00FFFF00FFE600FFCC00FFC000FFC000FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFE600D9FF00\
D9FF00F3FF00E6FF00F3FF00F3FF00D9FF0073FF00E6FF00FFFF00FFE600FFE600
FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFD900
FFF300D9FF00FFF300FFE600FFF300FFFF0080FF00F3FF00FFE600FFCC00FFC000FFC000FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300\
E6FF0073FF00B3FF00B3FF00C0FF0080FF00B3FF00D9FF00FFFF00FFF300FFE600
FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFE600F3FF00FFD900FFD900FFE600FFFF00CCFF008CFF008CFF00FFCC00FFC000FFC000FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300\
F3FF0099FF00D9FF00C0FF00C0FF00F3FF00E6FF00CCFF00E6FF00FFF300FFE600
FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFD900FFCC00FFCC00FFCC00FFD900FFE600FFF3008CFF00FFF300FFCC00FFC000FFC000FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300FFFF00\
99FF00D9FF00F3FF00FFFF0099FF00FFF300FFF300FFFF00A6FF00FFFF00FFE600
FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFF300FFF300FFD900FFC000FFC000FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFFF00F3FF00F3FF00\
A6FF00F3FF00FFF300FFF300FFF300FFE600FFE600FFE600F3FF0099FF00FFFF00
FFE600FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFE600C0FF00FFE600FFCC00FFC000FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600FFFF0080FF0066FF00\
59FF00FFFF00FFE600FFD900FFD900FFD900FFD900FFD900FFE600D9FF00B3FF00
FFFF00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFFF00A6FF00FFCC00FFC000FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFF300FFF300FFFF00F3FF00A6FF00E6FF00FFFF00\
FFFF00D9FF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFF300
FFF300FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFF300FFCC00FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000
FFC000FFF300FFE600FFD900FFD900FFE600F3FF0099FF00D9FF00FFFF00FFF300FFF300FFE600\
FFD900FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFCC00FFCC00FFCC00
FFF300FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000
FFCC00FFE6008CFF00FFFF00FFFF00F3FF00C0FF00F3FF00FFFF00FFE600FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFCC00FFD900FFF300C0FF00C0FF0099FF0000FF0CFFFF00FFE600FFD900FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00
FFCC00FFD900FFF300F3FF00D9FF00FFFF00FFFF004CFF00FFD900FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900
FFD900FFE600FFF300C0FF00F3FF00FFF300FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFB300FFC000FFCC00FFD900FFCC00FFCC00FFCC00FFD900FFF300
FFF300FFF300FFFF0066FF00FFFF00FFE600FFD900FFD900FFCC00FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFB300FFE600E6FF00F3FF00FFF300FFE600FFE600FFE600FFF300
3FFF0080FF00E6FF00CCFF00FFFF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFB300FFC000CCFF00FFF300F3FF00CCFF00F3FF00E6FF00F3FF00
99FF00B3FF00CCFF00B3FF00E6FF00FFF300FFD900FFCC00FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFB300FFC000FFCC00FFCC00FFD900FFE600E6FF003FFF00C0FF00
F3FF00FFFF00FFFF00FFF300F3FF00C0FF00FFE600FFCC00FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFB300FFB300FFC000FFCC00FFCC00FFD900FFE600FFFF00E6FF00
FFF300FFE600FFE600FFD900FFD900FFD900FFE600FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFFF00CCFF00
FFF300FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFFF00E6FF00
FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFE600D9FF00CCFF00
FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFB300FFB300FFC000FFCC00FFCC00FFD900FFE600F3FF00FFFF00
FFE600FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFE600FFF300E6FF00FFFF00
FFE600FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFB300FFB300FFC000FFFF00F3FF00FFF300FFFF00FFFF00D9FF00F3FF00
FFE600FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFB300FFB300FFC000FFD900FFF300A6FF00B3FF00B3FF00F3FF00C0FF00
E6FF00FFE600FFCC00FFC000FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFB300FFB300FFC000FFC000FFD900FFE600CCFF00FFFF00F3FF00FFE600FFE600
FFFF00E6FF00FFE600FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFB300FFB300FFC000FFCC00FFF300FFFF00F3FF00FFE600FFD900FFCC00FFCC00
FFD900FFFF00E6FF00FFD900FFC000FFB300FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300\
FFB300FFC000FFCC00FFD900F3FF00CCFF00C0FF00FFD900FFCC00FFC000FFC000
FFC000FFCC00FFCC00FFFF00FFB300FFB300FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300\
FFC000FFD900FFFF00F3FF00FFE600FFD900FFD900FFCC00FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFE600\
FFD900FFFF00FFFF00FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFCC00\
FFF300FFFF00FFFF00FFCC00FFC000FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFCC00\
FFF300FFE600FFCC00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFC000FFE600\
D9FF00FFFF00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300FFF300FFD900\
FFC000FFC000FFB300FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFC000A6FF00FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300\
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00F3FF00B3FF00C0FF00C0FF00B3FF0099FF0066FF0080FF00\
B3FF00C0FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00D9FF0080FF0000FF8CCCFF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00F3FF00E6FF00D9FF0099FF0080FF004CFF0059FF004CFF0059FF00\
C0FF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00E6FF00D9FF003FFF0099FF00CCFF00C0FF00FFFF00FFF300FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF0080FF003FFF0099FF0033FF00B3FF008CFF00\
C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00E6FF00A6FF0099FF0099FF00F3FF00FFF300FFF300FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00F3FF00F3FF00E6FF00E6FF00CCFF0099FF0066FF0099FF00CCFF00CCFF00D9FF00CCFF00\
19FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00F3FF00F3FF00D9FF0073FF00F3FF00FFF300FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00
E6FF00E6FF0033FF00D9FF00CCFF0033FF0080FF00B3FF00A6FF00D9FF00E6FF00E6FF00E6FF00\
C0FF0066FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00D9FF00E6FF00FFF300FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFF300E6FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF0000FF66
CCFF00CCFF00B3FF0000FF19B3FF00CCFF00D9FF00E6FF00D9FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00D9FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFFF008CFF00FFF300FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300\
FFF300F3FF00A6FF00B3FF00F3FF00F3FF00F3FF00F3FF00F3FF00D9FF00C0FF00
4CFF0000FF264CFF00B3FF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300F3FF00B3FF0099FF00D9FF00E6FF00E6FF00D9FF00D9FF00CCFF0099FF00
4CFF0099FF00B3FF003FFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFFF00F3FF00E6FF00C0FF00B3FF00CCFF00D9FF00B3FF00C0FF00B3FF0099FF00
59FF0059FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFFF00F3FF00F3FF00D9FF0099FF0073FF00B3FF0099FF004CFF0073FF004CFF00
73FF00C0FF00D9FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00\
FFFF00F3FF00F3FF00D9FF00C0FF0080FF0059FF0000FF008CFF008CFF0099FF00
8CFF00B3FF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600D9FF00F3FF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00F3FF00E6FF00D9FF00C0FF00A6FF000CFF0099FF00B3FF00C0FF00CCFF00
CCFF00C0FF0066FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300D9FF00E6FF00F3FF00
E6FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00D9FF00C0FF00B3FF0099FF0033FF00A6FF00C0FF00D9FF00D9FF00
E6FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300F3FF008CFF0073FF00
59FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00E6FF00F3FF00F3FF00\
E6FF00E6FF00D9FF00A6FF0066FF000CFF003FFF0099FF00C0FF00D9FF00E6FF00
F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFFF00A6FF0099FF00
59FF00C0FF00CCFF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF0099FF00CCFF00E6FF00\
E6FF00D9FF00CCFF00C0FF00A6FF0059FF0080FF0073FF0099FF00D9FF00F3FF00
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFFF00F3FF00E6FF00
CCFF0080FF0033FF00D9FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00CCFF0080FF00CCFF00\
CCFF00CCFF00C0FF00B3FF0099FF004CFF00A6FF00C0FF00CCFF00E6FF00F3FF00
FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00
CCFF00D9FF0080FF0099FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF0066FF0099FF00\
A6FF00A6FF00B3FF0059FF0080FF003FFF0099FF00C0FF00D9FF00E6FF00F3FF00
FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00
F3FF00F3FF00E6FF00C0FF0099FF00C0FF00B3FF00CCFF00CCFF00C0FF00B3FF008CFF004CFF00\
4CFF0033FF0080FF0066FF004CFF0059FF004CFF00A6FF00CCFF00E6FF00F3FF00
FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300
FFFF00F3FF00F3FF00D9FF0019FF0066FF0033FF0099FF00B3FF0099FF0033FF0073FF0073FF00\
19FF0080FF0000FF0C66FF008CFF00B3FF0000FFF33FFF00C0FF00D9FF00E6FF00
F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300
FFFF00FFFF00F3FF00E6FF0073FF00A6FF008CFF0066FF008CFF008CFF0019FF003FFF0099FF00\
B3FF00B3FF00A6FF004CFF00C0FF00CCFF00CCFF00CCFF0000FF66B3FF00D9FF00
E6FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300
FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00A6FF0059FF003FFF0000FF0C80FF004CFF0080FF00\
C0FF00CCFF00CCFF008CFF00CCFF00D9FF00E6FF00E6FF00CCFF00A6FF0066FF00
CCFF00FFFF00FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300
FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00B3FF00A6FF0073FF004CFF00A6FF00B3FF00B3FF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00D9FF00D9FF00
D9FF00E6FF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300
FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF0000FF3366FF00A6FF00C0FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFFF00FFFF00F3FF00E6FF00E6FF00D9FF00CCFF00B3FF008CFF0066FF00B3FF00CCFF00D9FF00\
D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF00B3FF008CFF0099FF00B3FF00CCFF00D9FF00\
D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00
FFFF00E6FF00D9FF00C0FF00B3FF0099FF00A6FF000CFF0033FF0099FF00B3FF00C0FF00CCFF00\
D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00
F3FF00E6FF00A6FF0000FF400CFF0059FF000CFF0019FF0026FF0066FF0099FF00A6FF00C0FF00\
CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
F3FF00E6FF00CCFF00C0FF008CFF008CFF0066FF0019FF0000BFFF33FF0066FF0026FF008CFF00\
3FFF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
F3FF00E6FF00E6FF00CCFF00C0FF00B3FF008CFF0073FF0000FF008CFF0073FF0099FF003FFF00\
C0FF00C0FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFF300F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF0073FF008CFF00B3FF00B3FF00C0FF00CCFF00\
D9FF00E6FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC0066FF00F3FF0066FF00\
FFE600FFE600FFE600FFE600FFE600FFF300D9FF00FFFF00FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300F3FF00A6FF00D9FF00F3FF00F3FF00FFFF00FFFF00F3FF00F3FF00F3FF00
E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF003FFF00A6FF00C0FF00CCFF00D9FF00E6FF00\
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFD900CCFF00C0FF00\
E6FF00FFF300FFFF00FFF300FFF300FFFF00B3FF00F3FF00FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFFF00F3FF00B3FF0000FF19D9FF00E6FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00D9FF00CCFF00CCFF00B3FF0000FF2666FF00A6FF00C0FF00CCFF00D9FF00E6FF00\
F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFD900FFE600FFF300\
F3FF0099FF00C0FF00F3FF00F3FF00F3FF00C0FF00E6FF00FFFF00FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFFF00F3FF00D9FF00A6FF00A6FF00D9FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00C0FF00B3FF008CFF0000FF008CFF00C0FF00CCFF00D9FF00E6FF00\
F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600\
FFF300D9FF00B3FF00CCFF00A6FF00CCFF004CFF00CCFF00C0FF00F3FF00F3FF00
CCFF00FFF300FFF300FFF300FFF300FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00F3FF00E6FF00CCFF008CFF00CCFF00CCFF00D9FF00CCFF0033FF00CCFF00
CCFF00CCFF00C0FF0099FF00A6FF00A6FF0080FF000066FF8CFF00A6FF00B3FF00D9FF00E6FF00\
F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900\
FFE600FFF300E6FF0073FF00B3FF0000FF0CB3FF0066FF00C0FF00D9FF00D9FF00
D9FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00F3FF00E6FF00D9FF00B3FF008CFF008CFF00C0FF00C0FF0099FF00B3FF00
C0FF00C0FF00B3FF0080FF0059FF0080FF000CFF0059FF0000FF4C19FF00B3FF00CCFF00D9FF00\
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900\
FFE600FFF300F3FF00C0FF00E6FF00CCFF00D9FF00A6FF008CFF0066FF0080FF00
C0FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00E6FF00D9FF00B3FF008CFF0073FF0099FF008CFF004CFF0080FF00
66FF00A6FF00A6FF008CFF0019FF0026FF008CFF0099FF008CFF0000FF0099FF00B3FF0000FF19\
D9FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900\
FFD900FFF30080FF00F3FF00FFFF00FFFF00F3FF00D9FF008CFF00B3FF00B3FF00
73FF00B3FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFFF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00D9FF00D9FF00C0FF0080FF000099FF66FF0000FF334CFF0033FF00
3FFF0080FF0080FF0000FF1966FF000CFF0099FF00B3FF00A6FF0066FF0000FF5919FF0099FF00\
D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFD900FFF300FFF300FFF300FFF300FFF300FFFF00C0FF00D9FF00E6FF00D9FF00
8CFF00B3FF008CFF00D9FF00E6FF00F3FF00F3FF00E6FF00B3FF00C0FF00E6FF00E6FF00E6FF00\
E6FF00CCFF00CCFF00CCFF00C0FF0099FF0000FF2680FF0059FF0099FF0099FF00
3FFF003FFF003FFF0066FF00A6FF00A6FF00B3FF00CCFF00C0FF00A6FF00B3FF00B3FF004CFF00\
C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFD900FFD900FFE600FFE600FFE600FFF300FFF300F3FF00FFFF00FFFF00F3FF00
E6FF00E6FF00CCFF008CFF00CCFF0026FF00D9FF00D9FF00C0FF00C0FF00D9FF00E6FF00D9FF00\
D9FF00B3FF0080FF00A6FF00A6FF008CFF0073FF00A6FF00B3FF00B3FF00B3FF00
8CFF0099FF008CFF0066FF00B3FF00CCFF00CCFF00D9FF00D9FF00C0FF00CCFF00D9FF00CCFF00\
66FF00C0FF00CCFF00E6FF00D9FF00F3FF00FFFF00FFF300FFF300FFE600FFE600
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00
FFFF00F3FF00E6FF00CCFF0059FF0073FF00C0FF00B3FF0099FF0099FF00C0FF00CCFF00CCFF00\
CCFF00B3FF0066FF0059FF003FFF004CFF0099FF00B3FF00C0FF00C0FF00C0FF00
A6FF00C0FF00B3FF0059FF00B3FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
CCFF0033FF00A6FF00B3FF00C0FF00E6FF00F3FF00F3FF00FFF300FFE600FFE600
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFFF00F3FF00E6FF00CCFF0073FF0066FF0033FF0000FF9919FF0073FF00C0FF00C0FF00\
C0FF00B3FF008CFF0033FF0000FF9966FF0099FF00C0FF00CCFF00CCFF00D9FF00
D9FF00D9FF00CCFF00B3FF00A6FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00CCFF0099FF0099FF00A6FF00C0FF00CCFF00C0FF00FFFF00FFE600FFE600
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFFF00F3FF00D9FF0099FF00B3FF0019FF00A6FF008CFF0059FF00A6FF00A6FF00\
B3FF0099FF0073FF0066FF0026FF004CFF008CFF00B3FF00CCFF00D9FF00D9FF00
E6FF00E6FF00D9FF00CCFF0033FF00B3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00E6FF00D9FF00C0FF0073FF003FFF0080FF00CCFF00FFFF00FFF300FFE600
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFF300FFF300FFFF00F3FF00CCFF00C0FF00D9FF00CCFF00C0FF0099FF0019FF0066FF0066FF00\
8CFF003FFF008CFF00A6FF00A6FF0099FF0000FF00B3FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00E6FF0099FF00D9FF00D9FF0073FF00E6FF00FFF300FFE600
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFF300FFF300FFF300FFFF00E6FF00E6FF00E6FF00E6FF00CCFF00B3FF0066FF008CFF004CFF00\
19FF0066FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00D9FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF0000FF59F3FF00FFFF00F3FF00A6FF0099FF00FFE600
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF0073FF00C0FF00B3FF0099FF00\
73FF0059FF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFF300
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF00B3FF00\
4CFF0080FF00B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF0019FF00\
80FF003FFF00A6FF00C0FF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF00\
A6FF0033FF00A6FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00\
B3FF0000FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00\
B3FF0099FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00D9FF00C0FF00\
80FF008CFF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00B3FF00\
66FF0080FF0099FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFF300FFF300FFF300FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00B3FF008CFF008CFF00\
00FF8C8CFF00B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFF300FFF300FFFF00FFFF00F3FF0033FF00CCFF00D9FF00CCFF00C0FF0099FF0026FF00\
66FF008CFF00A6FF00B3FF00B3FF004CFF00D9FF00E6FF00E6FF00F3FF00FFFF00
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFF300FFFF00F3FF00F3FF00E6FF00CCFF00A6FF00B3FF00B3FF00B3FF008CFF0066FF00\
33FF0059FF008CFF0099FF0080FF00B3FF00CCFF00D9FF00D9FF00D9FF00F3FF00
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFF300FFF300C0FF0099FF00CCFF00C0FF00B3FF003FFF0066FF008CFF0099FF003FFF000CFF00\
00FF6600FF0066FF0066FF004CFF00B3FF00C0FF00C0FF00B3FF00CCFF00F3FF00
FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFF300FFF300FFFF00E6FF00B3FF0000FF0033FF008CFF008CFF003FFF0073FF004CFF0000FFBF\
00000000FF730CFF004CFF0000FF598CFF00A6FF0019FF003FFF00A6FF00D9FF00
F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFF300FFF300FFFF00F3FF00D9FF0073FF00C0FF00C0FF00A6FF0080FF004CFF0059FF00004CFF\
00D9FF00FF403FFF008CFF0073FF0033FF004CFF0080FF00B3FF0059FF0033FF00
CCFF00F3FF00FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFF300FFF300FFFF00FFFF00E6FF00D9FF00D9FF00CCFF00C0FF0066FF008CFF0080FF0033FF00\
33FF0000FF0C73FF00A6FF00A6FF0099FF0026FF00B3FF00D9FF00D9FF00E6FF00
E6FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFF300FFF300FFFF00FFFF00F3FF00E6FF00E6FF00D9FF00C0FF00A6FF00B3FF00A6FF008CFF00\
66FF0066FF0099FF00B3FF00C0FF00CCFF00C0FF008CFF00E6FF00F3FF00FFFF00
FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF0099FF00\
59FF0073FF0059FF00B3FF00CCFF00D9FF00D9FF00D9FF00F3FF00FFFF00FFFF00
FFF300FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00A6FF0033FF00\
73FF00A6FF00C0FF00C0FF00D9FF00E6FF00E6FF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF0099FF00\
3FFF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF0099FF00\
A6FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00B3FF0019FF00\
B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFF300CCFF00FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF00A6FF0019FF00\
B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600F3FF00D9FF00F3FF00D9FF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00C0FF0099FF0000FF00\
A6FF00C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFFF00B3FF004CFF0033FF00E6FF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF0066FF00\
80FF00B3FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600F3FF00D9FF00CCFF0099FF00CCFF00\
00FF26F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00B3FF0066FF004CFF00\
99FF00B3FF00CCFF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF0059FF008CFF00\
B3FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00CCFF00CCFF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF008CFF0019FF00\
80FF0059FF00B3FF00A6FF00B3FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00E6FF00D9FF00\
A6FF00CCFF00E6FF00E6FF00F3FF00F3FF00E6FF00E6FF00CCFF0099FF00D9FF00
D9FF00E6FF00E6FF00D9FF00D9FF00CCFF0033FF0080FF00A6FF0099FF008CFF0019FF0080FF00\
33FF0000BFFF73FF0099FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00
FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00\
D9FF008CFF00CCFF00CCFF00CCFF00E6FF00E6FF00D9FF00CCFF0000FF73C0FF00
CCFF00D9FF00D9FF00D9FF00CCFF00C0FF0099FF0066FF0059FF0019FF0080FF00A6FF00A6FF00\
8CFF008CFF0026FF0080FF00C0FF00CCFF00D9FF00D9FF00C0FF00D9FF00FFFF00
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00\
D9FF008CFF008CFF008CFF00C0FF00CCFF00CCFF00CCFF00C0FF0000FF00A6FF00
C0FF00C0FF00CCFF00CCFF00CCFF00C0FF008CFF004CFF000059FF00FF00A6FF00B3FF00C0FF00\
C0FF00B3FF004CFF008CFF00A6FF00A6FF00B3FF00B3FF00A6FF00E6FF00FFFF00
FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFCC00FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00\
D9FF00B3FF0073FF003FFF008CFF00C0FF00B3FF00A6FF00A6FF0033FF0073FF00
80FF00A6FF00C0FF00C0FF00C0FF00B3FF008CFF0000FF2633FF0080FF00A6FF00C0FF00CCFF00\
CCFF00C0FF0080FF0033FF003FFF0059FF0000FF660CFF00C0FF00E6FF00F3FF00
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00
FFCC00FFF300FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00\
E6FF00D9FF00C0FF0073FF0066FF0099FF0073FF0000FF0033FF0080FF003FFF00
4CFF0080FF00A6FF0080FF00A6FF0080FF003FFF003FFF0099FF0080FF00A6FF00CCFF00D9FF00\
D9FF00CCFF00C0FF0073FF00A6FF008CFF00B3FF008CFF00A6FF00CCFF00F3FF00
FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFD900F3FF00F3FF00FFF300FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00\
E6FF00D9FF00CCFF00A6FF0073FF0026FF0066FF0033FF008CFF00A6FF00A6FF00
80FF0019FF0073FF000CFF0073FF0000FF00A6FF00C0FF00C0FF00CCFF0099FF00D9FF00E6FF00\
E6FF00E6FF00D9FF008CFF00CCFF00D9FF00CCFF00B3FF0066FF0099FF00E6FF00
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFF30080FF00FFFF00FFE600FFD900FFD900FFD900FFD900FFD900FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00\
E6FF00D9FF00CCFF00B3FF0000FF0099FF00B3FF00A6FF00A6FF00C0FF00C0FF00
A6FF0066FF008CFF003FFF008CFF0000FFB399FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00\
F3FF00E6FF00D9FF0000FF00D9FF00E6FF00E6FF0099FF00D9FF00B3FF00CCFF00
E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFE600FFF300E6FF00F3FF00FFF300FFE600FFE600FFE600FFE600FFE600F3FF00FFF300FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00\
E6FF00D9FF00CCFF00B3FF004CFF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00
C0FF003FFF00B3FF00C0FF00A6FF0000FF4CA6FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF0099FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF0000FF00
B3FF00D9FF00CCFF00F3FF00F3FF00F3FF00F3FF00FFF300FFF300FFE600FFE600FFE600FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600
FFE600FFF300E6FF00D9FF00FFFF00FFFF00FFF300FFF300FFF300FFFF00CCFF00FFFF00FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00E6FF00D9FF00\
CCFF00CCFF00A6FF0066FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00
CCFF0059FF00CCFF00CCFF00C0FF00A6FF0059FF00CCFF00E6FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00D9FF00
4CFF004CFF00CCFF00E6FF00E6FF00D9FF00A6FF00FFFF00FFF300FFF300FFE600FFE600FFE600\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFC000FFCC00FFCC00\
FFD900FFFF00FFE600FFE600FFD900FFD900FFE60059FF00FFE600FFE600FFE600
FFF300FFFF00E6FF0033FF00D9FF00D9FF00E6FF00FFFF00FFFF00F3FF00CCFF00F3FF00FFFF00\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
F3FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00C0FF00C0FF00C0FF00\
99FF00B3FF008CFF0080FF00B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00D9FF00E6FF00E6FF00D9FF00CCFF0073FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00CCFF00
D9FF0099FF00A6FF00A6FF00C0FF0080FF00E6FF00F3FF00FFFF00FFF300FFF300FFF300FFF300\
FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFC000FFE600FFFF00\
73FF008CFF008CFF0066FF00FFFF00D9FF00FFFF00D9FF00FFFF00FFF300FFFF00
F3FF00F3FF00D9FF003FFF0066FF0073FF00CCFF00E6FF00D9FF00E6FF00A6FF00CCFF00E6FF00\
F3FF0099FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
E6FF0073FF00E6FF00F3FF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF0033FF008CFF00\
0CFF0073FF003FFF0066FF00A6FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF0099FF00C0FF00E6FF00F3FF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
F3FF00CCFF0073FF0033FF0099FF0059FF00CCFF00E6FF00F3FF00F3FF00F3FF00C0FF00F3FF00\
FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00\
FFE600FFE600FFF300FFE600FFFF00C0FF0073FF0059FF0099FF00E6FF00D9FF00
B3FF0059FF0073FF00D9FF00D9FF00C0FF00A6FF00C0FF0000FF00A6FF00B3FF008CFF00C0FF00\
CCFF0080FF00E6FF00FFFF00FFFF00FFF300FFFF00FFFF00FFFF00FFFF00F3FF00
E6FF00C0FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00CCFF00A6FF0080FF00\
3FFF0000FF8066FF0099FF00C0FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00C0FF004CFF00D9FF00F3FF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFFF00B3FF00D9FF00D9FF00CCFF0066FF00C0FF00D9FF0099FF00D9FF00A6FF00D9FF00FFFF00\
FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000\
FFCC00FFCC00FFCC00FFD900FFD900FFFF00F3FF00F3FF0066FF00A6FF00B3FF00
D9FF00D9FF00B3FF00F3FF00F3FF00D9FF00CCFF008CFF00D9FF00C0FF00E6FF00CCFF0080FF00\
A6FF00B3FF0019FF00D9FF00F3FF00F3FF00F3FF00D9FF00F3FF00F3FF00F3FF00
E6FF0099FF00B3FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00B3FF0080FF00\
3FFF0000FF263FFF0059FF0099FF0099FF00E6FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00D9FF00B3FF0080FF00F3FF00FFFF00FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFFF00E6FF00F3FF00F3FF00CCFF00A6FF0059FF00B3FF000CFF008CFF008CFF00E6FF00FFF300\
FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300FFFF00CCFF00D9FF00
FFFF00FFFF00FFFF00FFF300FFF300FFFF00E6FF00A6FF00F3FF00F3FF00FFFF00F3FF0066FF00\
E6FF00E6FF00D9FF00D9FF0099FF00CCFF00CCFF00C0FF00E6FF00E6FF00D9FF00
CCFF00A6FF008CFF00C0FF0080FF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00A6FF000CFF00\
80FF008CFF0066FF008CFF003FFF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF0066FF00FFFF00FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFFF00F3FF00D9FF0066FF00CCFF0019FF00D9FF00B3FF00CCFF00FFFF00\
FFF300FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFF300F3FF00F3FF00
FFF300FFF300FFE600FFE600FFF300FFF300F3FF00CCFF00FFFF00FFF300FFF300FFFF00B3FF00\
FFFF00FFFF00FFFF00F3FF00E6FF008CFF003FFF0066FF00C0FF00C0FF0080FF00
A6FF004CFF008CFF000CFF008CFF00C0FF00CCFF00CCFF00CCFF00CCFF00C0FF0066FF0026FF00\
B3FF00B3FF0073FF00CCFF00C0FF00B3FF00E6FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00E6FF00FFFF00FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFFF00E6FF00CCFF00F3FF00F3FF00F3FF00CCFF0073FF0033FF00\
FFF300FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600B3FF00FFFF00
FFE600FFE600FFE600FFE600FFE600FFE600FFFF00A6FF00FFF300FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFFF00CCFF00E6FF008CFF0026FF0080FF0099FF00
00FF40C0FF00C0FF00A6FF0059FF00B3FF00B3FF00A6FF00C0FF00B3FF008CFF0099FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFF300D9FF00E6FF00FFFF00FFF300FFFF0066FF00F3FF00C0FF00\
FFFF00FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFE60000FF0CFFF300
FFE600FFD900FFD900FFD900FFD900FFD900FFE600FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF0073FF00C0FF00D9FF00
99FF00D9FF00D9FF0099FF0080FF0080FF0019FF003FFF0099FF0080FF003FFF00B3FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600F3FF00F3FF00FFF300FFE600FFE600FFF300FFF300FFFF00\
99FF00F3FF00FFF300FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFFF00FFD900
FFD900FFD900FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFF300FFFF00F3FF0066FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF0073FF0099FF00A6FF0000FF4C8CFF0066FF0099FF00C0FF00CCFF00\
D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFF300FFE600FFE600FFD900FFD900FFD900FFE600FFE600\
FFFF00B3FF00F3FF00FFD900FFCC00FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFF300D9FF00CCFF00F3FF00F3FF00
F3FF00F3FF00F3FF00D9FF0066FF00CCFF00CCFF00C0FF00B3FF008CFF004CFF0066FF00D9FF00\
E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFFF00FFE600FFCC00FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFF300E6FF00F3FF00FFFF00FFFF00
FFFF00FFFF00F3FF00D9FF00C0FF00D9FF00D9FF00D9FF00C0FF0059FF008CFF00C0FF00D9FF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00C0FF003FFF004CFF00B3FF00CCFF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00C0FF0099FF0000FF4C99FF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF0073FF00A6FF00D9FF00\
E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00D9FF00C0FF00B3FF00D9FF00\
E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00F3FF00D9FF008CFF00C0FF00D9FF00\
E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF0066FF00B3FF00D9FF00\
E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00E6FF00D9FF0099FF0099FF00CCFF00\
E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00C0FF0073FF0000FF19B3FF00CCFF00\
E6FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00CCFF0099FF0066FF00C0FF00\
CCFF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00CCFF00B3FF0073FF0000FFE6\
80FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFF300FFFF00F3FF00F3FF00D9FF0066FF008CFF000CFF00B3FF00\
CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFE600FFE600FFF300FFF300F3FF00D9FF00D9FF00CCFF00B3FF0033FF00A6FF00C0FF00\
D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFE600FFE600FFF300FFFF00D9FF00A6FF0059FF0099FF0080FF0080FF00B3FF00C0FF00\
CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFF300FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFE600FFE600FFF300FFFF00F3FF00E6FF00D9FF00B3FF0099FF004CFF00A6FF00C0FF00\
CCFF00CCFF00D9FF00E6FF00E6FF00E6FF008CFF00E6FF00FFF300FFF300FFE600
FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFE600FFE600FFE600FFF300FFFF00F3FF00E6FF00D9FF00CCFF00B3FF004CFF0080FF0099FF00\
A6FF008CFF00CCFF00D9FF00D9FF00C0FF00C0FF00F3FF00FFF300FFF300FFE600
FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00D9FF00CCFF0099FF0019FF0066FF0066FF00\
4CFF00A6FF00C0FF00C0FF00A6FF00B3FF00D9FF00F3FF00FFFF00FFF300FFE600
FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600
FFE600FFF300FFF300FFFF00F3FF00E6FF00E6FF00D9FF0000FF008CFF0059FF0000FF6600FFCC\
00FF6673FF0099FF00A6FF004CFF00B3FF00D9FF00F3FF00FFFF00FFF300FFF300
FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600
FFF300F3FF00F3FF00E6FF00CCFF00CCFF00CCFF00CCFF0099FF0033FF0000FF59000000000000\
00FF8C4CFF004CFF008CFF0099FF000CFF00B3FF00D9FF00E6FF00FFFF00FFF300
FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFF300
C0FF00CCFF00C0FF0026FF0080FF0059FF00B3FF00B3FF0099FF0059FF00004CFF000000000000\
00FF4C3FFF0099FF00B3FF00C0FF00A6FF0073FF0073FF00B3FF00E6FF00F3FF00
FFFF00FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600
FFF300FFFF00FFFF00D9FF00CCFF0099FF0000FFBF59FF0000FF260CFF0026FF0000FF40000000\
00FFA600FF6680FF00C0FF00CCFF00CCFF0073FF00D9FF00D9FF00C0FF0080FF00
8CFF00FFFF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFE600FFF300FFF300FFFF00F3FF00D9FF008CFF0099FF00B3FF008CFF0080FF000CFF0026FF00\
00FF4C80FF008CFF00CCFF00D9FF00E6FF00E6FF00F3FF00FFFF00FFFF00FFFF00
FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFE600FFE600FFF300FFFF00F3FF00D9FF0080FF00CCFF00CCFF00C0FF003FFF0019FF008CFF00\
3FFF004CFF00C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFF300FFF300FFF300
FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFE600FFE600FFE600FFF300F3FF0080FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF00\
66FF00A6FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600
FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFE600FFE600FFF300FFFF00E6FF00F3FF00F3FF00E6FF00D9FF00D9FF00CCFF00B3FF00\
8CFF0080FF00A6FF00CCFF00E6FF00F3FF00FFFF00FFF300FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF00\
3FFF0099FF00A6FF0033FF00B3FF00F3FF00FFF300FFF300FFE600FFE600FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00C0FF0073FF00\
26FF00C0FF00D9FF00E6FF00D9FF00F3FF00FFF300FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00E6FF00A6FF0073FF0080FF00\
B3FF00CCFF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00E6FF00CCFF00C0FF0000FF26\
C0FF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF00A6FF00\
59FF008CFF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF0000FF3373FF00\
CCFF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF0000FF19\
CCFF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF00C0FF00\
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00D9FF00A6FF0073FF00\
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00C0FF008CFF00B3FF00\
D9FF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00B3FF004CFF00\
C0FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00E6FF00CCFF0073FF0099FF00\
CCFF00D9FF00E6FF00F3FF00F3FF00FFF300FFF300FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00D9FF00C0FF0073FF008CFF00\
B3FF00CCFF00CCFF0099FF00E6FF00FFFF00FFF300FFF300FFE600FFE600FFE600
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFC000FFCC00FFD900FFD900FFD900FFD900FFF300FFFF00FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300D9FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00D9FF00CCFF00CCFF0026FF0099FF008CFF00A6FF00A6FF00\
19FF0073FF0059FF00CCFF00E6FF00FFFF00FFFF00FFF300FFF300FFF300FFE600
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFC000FFCC00F3FF00CCFF00FFF300FFF300FFFF00E6FF00FFFF00FFF300FFF300\
FFE600FFE600FFE600FFE600FFF300FFF300FFFF00D9FF008CFF00F3FF00F3FF00
FFFF00FFFF00FFFF00F3FF00F3FF00D9FF0073FF0099FF000CFF00A6FF00CCFF00CCFF00CCFF00\
C0FF00A6FF0080FF00CCFF00E6FF00F3FF00F3FF00F3FF00F3FF00D9FF00FFE600
FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFC000FFCC00FFD900FFE600E6FF00CCFF00B3FF0080FF00D9FF00CCFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00E6FF00A6FF00D9FF00E6FF00
F3FF00F3FF00F3FF00F3FF00E6FF00B3FF008CFF0000FF8C73FF00C0FF00D9FF00E6FF00D9FF00\
D9FF00B3FF008CFF00C0FF00D9FF00D9FF00E6FF00E6FF0059FF00F3FF00FFF300
FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFCC00FFD900FFF300E6FF00F3FF00E6FF00C0FF00C0FF00C0FF00\
F3FF00FFFF00FFFF00F3FF00FFFF00FFFF00F3FF00E6FF0000FF9973FF00D9FF00
8CFF00E6FF00E6FF00E6FF00D9FF00C0FF0066FF0066FF00B3FF00D9FF00E6FF00F3FF00E6FF00\
D9FF0066FF0080FF00A6FF00B3FF0073FF00B3FF008CFF00E6FF00FFFF00FFF300
FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFCC00FFCC00FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00\
A6FF00C0FF00E6FF00A6FF00E6FF00E6FF00E6FF00D9FF00B3FF008CFF00A6FF00
B3FF00CCFF00D9FF00D9FF00CCFF0000FF008CFF00C0FF00A6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00A6FF0099FF00B3FF00B3FF00C0FF003FFF00B3FF00FFFF00FFF300
FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFD900FFE600FFE600FFF300FFF300FFFF00\
E6FF0019FF0080FF0099FF00CCFF00D9FF00B3FF0099FF0099FF00B3FF00A6FF00
8CFF00C0FF008CFF00C0FF0066FF00C0FF00D9FF00E6FF00E6FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00F3FF00C0FF00D9FF00E6FF00E6FF00D9FF0080FF00C0FF00D9FF00FFFF00
FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300\
F3FF00D9FF00D9FF008CFF00A6FF00B3FF003FFF0073FF00CCFF00CCFF00B3FF00
8CFF0059FF004CFF0099FF0099FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300\
FFFF00F3FF0000FF0CF3FF00FFFF00FFFF00F3FF00C0FF00C0FF0099FF00FFFF00
FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300\
FFF300FFFF00E6FF00CCFF00A6FF00B3FF00CCFF00CCFF00E6FF00E6FF00D9FF00
B3FF00CCFF00CCFF00C0FF008CFF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFFF0099FF00FFFF00FFF300FFF300FFFF00F3FF00E6FF008CFF00F3FF00
FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600\
FFF300FFFF00F3FF00E6FF00B3FF00C0FF00E6FF00E6FF00F3FF00F3FF00F3FF00
B3FF00E6FF00E6FF00CCFF00C0FF00C0FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFE600FFE600FFF300FFF300FFFF00E6FF00CCFF00
E6FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600\
FFF300FFF300FFFF00E6FF0026FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00
F3FF00FFFF00FFFF00F3FF00E6FF00CCFF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300F3FF0099FF00
CCFF00E6FF00CCFF00FFF300FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600\
FFF300FFF300F3FF00D9FF0059FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFFF00F3FF0066FF00D9FF00FFFF00FFF300FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFFF00C0FF00
B3FF0073FF00E6FF00FFFF00FFF300FFF300FFFF00CCFF00FFE600FFD900FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600\
FFF300FFFF00F3FF00C0FF00B3FF00E6FF00F3FF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00D9FF00CCFF00FFFF00FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFF300FFFF00
E6FF008CFF00D9FF00E6FF00F3FF00F3FF00A6FF00FFFF00FFE600FFD900FFD900FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600\
FFF300F3FF00E6FF00C0FF0073FF00B3FF00FFFF00FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFF300CCFF00D9FF00FFFF00FFE600FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFF300
F3FF0099FF00A6FF008CFF00C0FF00A6FF00E6FF00FFF300FFE600FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600\
FFFF00B3FF0026FF0073FF00B3FF00E6FF00FFFF00FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFFF00FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600
E6FF00E6FF00E6FF00D9FF00CCFF00B3FF00F3FF00FFFF00FFF300FFE600FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300\
FFFF00F3FF00B3FF0026FF0080FF00D9FF00FFFF00FFF300FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFE600
E6FF00FFF300FFFF00F3FF00CCFF0073FF00E6FF00FFFF00FFF300FFF300FFE600FFE600FFE600\
FFE600FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300\
FFFF00E6FF00B3FF0099FF00D9FF00E6FF00F3FF00FFF300FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFE600FFE600FFF300FFFF0080FF00B3FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300\
F3FF00D9FF00FFD900FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300\
FFFF00F3FF00C0FF00C0FF00F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFE600FFF300F3FF00CCFF00B3FF00D9FF00C0FF0066FF00E6FF00E6FF0099FF00\
F3FF00FFE600FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFCC00FFCC00FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00\
FFFF00E6FF00A6FF00D9FF00F3FF00FFF300FFE600FFE600FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900FFD900FFE600FFFF004CFF00E6FF00A6FF00CCFF00E6FF00C0FF00B3FF00FFFF00\
FFE600FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFCC00FFCC00FFD900FFFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF0073FF00E6FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFD900FFE600F3FF00F3FF00FFFF00FFF300FFFF00FFFF00E6FF004CFF00E6FF00\
FFE600FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFCC00FFCC00FFD900FFE600F3FF00B3FF00E6FF00F3FF00CCFF00E6FF00E6FF00\
D9FF00CCFF0099FF00E6FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFD900FFF30080FF00FFF300FFE600FFE600FFE600FFF300D9FF00C0FF00FFFF00\
FFE600FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFD900FFE600FFF300F3FF00C0FF00C0FF0080FF008CFF00CCFF00\
33FF00C0FF00B3FF00CCFF00E6FF00FFF300FFE600FFE600FFD900FFD900FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFE600E6FF00FFE600FFD900FFD900FFD900FFF3008CFF00B3FF00A6FF00\
A6FF00FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00D9FF00C0FF00D9FF00A6FF0000FF66\
D9FF00E6FF00D9FF00C0FF00B3FF00FFFF00FFE600FFE600FFD900FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFCC00FFD900FFD900FFCC00FFCC00FFCC00FFD900FFE600FFF300FFF3004CFF00\
FFF300FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFE600FFE600FFF300F3FF00A6FF00D9FF00F3FF00F3FF00C0FF00\
F3FF00FFFF00FFFF00FFFF00D9FF00F3FF00FFF300FFE600FFD900FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFFF00\
FFF300FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFD900FFE600FFF300FFF300FFFF00E6FF00A6FF00F3FF00FFFF00FFF300FFFF00\
FFFF00FFE600FFE600FFF300FFFF0099FF00F3FF00FFF300FFD900FFD900FFCC00
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFF300\
E6FF00FFE600FFCC00FFC000FFC000FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600F3FF00D9FF00D9FF00CCFF00E6FF00FFFF00FFF300FFE600FFE600\
FFE600FFD900FFD900FFE600FFF300F3FF00A6FF00FFFF00FFF300FFD900FFCC00
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFD900\
A6FF00FFFF00FFE600FFC000FFC000FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900
FFD900FFE600FFE600FFF300F3FF00B3FF0099FF00CCFF0099FF00FFF300FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFF300D9FF00CCFF00FFFF00FFD900FFCC00
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFD900\
FFFF00F3FF00FFE600FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFE600
FFF300FFFF00FFFF00D9FF008CFF00F3FF00FFFF00FFFF00C0FF00FFFF00FFE600FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFFF00FFFF00FFCC00FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFCC00FFE600FFE600FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFCC00FFD900FFD900FFD900FFD900FFE600FFF300CCFF00
D9FF0099FF00E6FF00F3FF00FFFF00FFFF00FFE600FFE600FFF3004CFF00FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900E6FF00FFCC00FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFCC00F3FF00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFCC00FFD900D9FF00FFF300FFE600FFE600FFF300FFFF00CCFF00
D9FF00CCFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFCC00FFD900FFF300D9FF00F3FF00FFFF00CCFF00E6FF00CCFF00
FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFCC00FFCC00FFD900FFE600FFFF00CCFF00B3FF00C0FF00B3FF0073FF00
FFFF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFD900FFE600FFF300F3FF00D9FF00F3FF00FFFF00F3FF00
D9FF00FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFD900FFD900FFE600FFF300E6FF00E6FF00FFFF00FFF300FFE600
FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFE600FFE600FFF300FFFF0080FF008CFF00FFF300FFE600FFD900
FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFB300FFC000FFCC00FFCC00FFD900FFFF00FFD900FFD900FFD900FFD900\
FFD900FFFF00F3FF00FFFF00FFFF00F3FF00B3FF00FFFF00FFE600FFE600FFD900
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFB300FFC000FFD900A6FF00FFFF0066FF00FFFF00FFF300FFE600FFE600\
FFF300FFFF00A6FF00D9FF00E6FF00D9FF00D9FF00FFFF00FFE600FFD900FFD900
FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFB300FFB300FFC000FFD900FFF300FFFF00F3FF00CCFF00F3FF00F3FF00\
F3FF00F3FF008CFF00CCFF0073FF00D9FF0066FF00E6FF00FFF300FFE600FFD900
FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFCC00FFD900FFE600FFF300E6FF00CCFF00\
C0FF008CFF00E6FF00F3FF00E6FF00FFFF00FFFF00E6FF0099FF00FFFF00FFD900
FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFCC00FFD900FFD900FFF300FFFF00\
D9FF00E6FF00FFFF00FFF300FFF300FFE600FFE600FFE600C0FF00F3FF00FFD900
FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300\
E6FF00E6FF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFD900FFE600\
F3FF00B3FF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600\
F3FF00F3FF00FFF300FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFF300\
B3FF0073FF00FFF300FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFD900FFF300\
D9FF00F3FF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300\
66FF00FFFF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFD900FFE600FFE600FFFF00\
C0FF00FFFF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFF300FFF300FFE600FFFF00FFFF00F3FF00\
A6FF00F3FF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFC000FFCC00FFE600F3FF008CFF00C0FF00E6FF0000FF00\
E6FF00C0FF00F3FF00FFE600FFD900FFCC00FFC000FFC000FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFF300CCFF00E6FF00D9FF00F3FF00\
FFF300FFFF00E6FF00FFFF00FFE600FFCC00FFC000FFC000FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFE600FFF300D9FF00FFF300FFF300FFFF00\
FFD900FFD900FFE600E6FF00FFFF00FFE600FFCC00FFC000FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFB300FFB300FFC000FFC000FFCC00FFE600FFFF00F3FF00FFFF00FFE600FFD900FFCC00\
FFCC00FFCC00FFCC00FFE600FFFF0080FF00FFCC00FFC000FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFB300FFB300FFC000FFC000FFCC00FFD900FFF300D9FF00E6FF00F3FF00FFD900FFCC00FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFB300FFC000FFC000FFE600FFE6008CFF00E6FF00FFFF00FFD900FFF300FFD900FFC000FFC000\
FFC000FFC000FFB300FFC000FFC000FFC000FFC000FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFB300
FFC000FFCC00FFD900FFF300E6FF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300
FFE60080FF00FFFF00D9FF00FFF300FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300
FFCC00FFE60000FF33FFF300FFE600FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300
FFCC00FFE600F3FF00FFD900FFCC00FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFC000
FFE60066FF00D9FF00FFD900FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFCC00
E6FF00FFE600FFD900E6FF00FFC000FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFA600FFCC00CCFF00
FFCC00FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FFA600FFB300D9FF00E6FF00
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7300FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00D9FF00CCFF00C0FF00A6FF0073FF003FFF0099FF00B3FF00C0FF00
C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00F3FF00F3FF00E6FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00D9FF00CCFF00C0FF00B3FF0080FF0000FFF38CFF00B3FF00C0FF00
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00\
E6FF00E6FF00D9FF00CCFF00C0FF00B3FF008CFF003FFF0099FF00C0FF00CCFF00
CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00\
E6FF00D9FF00CCFF00CCFF00C0FF00B3FF0099FF0073FF00A6FF00C0FF00CCFF00
D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00\
C0FF00C0FF00C0FF00B3FF00B3FF0099FF0059FF008CFF00A6FF00C0FF00CCFF00
CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00A6FF008CFF00\
99FF008CFF0099FF0073FF008CFF0066FF0019FF0080FF0099FF00B3FF00C0FF00
CCFF00D9FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00D9FF00A6FF00\
3FFF0066FF0000FF4C3FFF003FFF0000FF0000FF594CFF0066FF0099FF008CFF00
B3FF00C0FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00\
C0FF0099FF0099FF008CFF0000FFBF19FF000099FF3FFF0000FF404CFF0000FF0C
8CFF0073FF00C0FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00\
CCFF00C0FF00B3FF00A6FF008CFF0066FF0000FF0C73FF0033FF003FFF0099FF00
73FF00A6FF00B3FF008CFF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00\
D9FF00CCFF00C0FF00B3FF0099FF0059FF0080FF0073FF00A6FF00A6FF00C0FF00
C0FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFD900FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFE600FFE600FFE600F3FF00FFF300FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFFF00D9FF00E6FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00\
D9FF00CCFF00C0FF00B3FF0099FF0026FF0099FF00B3FF00C0FF00CCFF00CCFF00
D9FF00E6FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFD900FFF300C0FF00A6FF00\
FFFF00FFE600FFE600FFE600FFE600FFE600FFF300FFFF00A6FF00D9FF00FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00E6FF0073FF00C0FF00
D9FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00CCFF00C0FF00B3FF008CFF0059FF00A6FF00C0FF00CCFF00CCFF00D9FF00
E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFE6008CFF00E6FF00\
26FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFFF00C0FF00E6FF00FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00C0FF00B3FF0000FF99
CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
CCFF00CCFF00C0FF0099FF0000FF0066FF00A6FF00C0FF00CCFF00D9FF00D9FF00
E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300\
FFFF0059FF00D9FF00C0FF00F3FF00FFFF00F3FF00F3FF0099FF00E6FF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF0080FF00
33FF00CCFF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00C0FF00B3FF00A6FF0080FF00008CFF80FF00B3FF00CCFF00CCFF00D9FF00
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600\
FFF300F3FF00C0FF0073FF00CCFF00D9FF00CCFF00D9FF0080FF00CCFF00E6FF00
F3FF00FFFF00FFFF00F3FF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF00
99FF00C0FF00D9FF00D9FF00D9FF00D9FF00CCFF00B3FF00CCFF00D9FF00CCFF00CCFF00C0FF00\
B3FF00B3FF00A6FF0099FF003FFF0059FF008CFF00A6FF00C0FF00CCFF00D9FF00
E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900\
FFE600FFFF00F3FF00B3FF008CFF0099FF0073FF00A6FF004CFF0099FF00A6FF00
E6FF00F3FF00E6FF00B3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00
C0FF0080FF00C0FF00B3FF00CCFF00CCFF00C0FF004CFF00C0FF00CCFF00CCFF00C0FF00B3FF00\
3FFF008CFF0099FF008CFF004CFF0033FF0026FF008CFF0000FF26C0FF00D9FF00
D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900\
FFE600FFE600FFFF00E6FF0000FF00C0FF00B3FF00A6FF00C0FF00A6FF008CFF00
CCFF00CCFF00C0FF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00
C0FF0000FF0073FF00A6FF00B3FF00B3FF00A6FF0019FF00A6FF00B3FF00C0FF00B3FF00A6FF00\
73FF0000FF2659FF003FFF0059FF0073FF003FFF000CFF0099FF00C0FF00CCFF00
CCFF00D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900\
FFD900FFE600FFF300E6FF00CCFF00E6FF00E6FF00E6FF00D9FF00A6FF0000FF33
80FF0080FF0033FF00C0FF00E6FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00
C0FF00A6FF0073FF0080FF0099FF0066FF008CFF0000FF0080FF0059FF00A6FF00A6FF0099FF00\
8CFF0000FF0000FF1980FF0099FF0099FF008CFF0026FF0080FF0099FF00B3FF00
8CFF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900\
FFD900FFE600FFFF00A6FF00F3FF00FFFF00FFFF00F3FF00F3FF00D9FF0080FF00
C0FF0000FF0CB3FF0000FF0CB3FF008CFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00
CCFF00A6FF004CFF000CFF0073FF000CFF0019FF0059FF003FFF003FFF008CFF0073FF0080FF00\
4CFF0059FF0000FF733FFF00A6FF00B3FF00A6FF0066FF0019FF003FFF003FFF00
99FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFD900FFE6000CFF00F3FF00FFF300FFF300FFF300FFFF00FFFF00E6FF00B3FF00
D9FF00D9FF00D9FF0059FF0073FF0019FF00CCFF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
CCFF00CCFF00E6FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00
C0FF00B3FF008CFF0019FF0066FF003FFF0000FF338CFF0080FF0000FF0C4CFF0000FF7333FF00\
59FF0099FF0099FF0073FF00B3FF00C0FF00C0FF00B3FF003FFF0099FF0099FF00
66FF0066FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00E6FF00D9FF00
F3FF00F3FF00E6FF00B3FF00D9FF0033FF0000FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00\
CCFF0099FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00A6FF00B3FF00C0FF00
B3FF00A6FF0080FF004CFF0099FF0099FF0080FF00A6FF00A6FF0080FF0073FF0000FF6666FF00\
3FFF00A6FF00C0FF00C0FF00CCFF00CCFF00CCFF00C0FF008CFF00CCFF00C0FF00
B3FF0066FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF003FFF00B3FF008CFF00CCFF00D9FF00CCFF00\
C0FF00A6FF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF003FFF0019FF0099FF00
99FF008CFF003FFF008CFF00A6FF00B3FF00B3FF00C0FF00B3FF0099FF00A6FF00A6FF0080FF00\
00FFB3A6FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00D9FF00D9FF00
D9FF00C0FF0033FF00A6FF00CCFF00D9FF00B3FF00E6FF00F3FF00FFFF00FFFF00FFF300FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00C0FF008CFF0000FF33B3FF00B3FF00B3FF00\
A6FF0066FF00B3FF00B3FF00CCFF00CCFF00CCFF00C0FF00A6FF0000FF593FFF00
4CFF003FFF0080FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00\
8CFF00B3FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF0073FF008CFF00A6FF00A6FF00A6FF00D9FF00E6FF00F3FF00E6FF00F3FF00FFF300\
FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00D9FF00CCFF0000FF3373FF003FFF0059FF00\
59FF003FFF0080FF0099FF00C0FF00C0FF00C0FF00C0FF00A6FF008CFF004CFF00
0000003FFF0080FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00CCFF00CCFF00\
A6FF00A6FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00D9FF00C0FF008CFF008CFF000CFF00CCFF003FFF00CCFF0099FF00FFFF00FFF300\
FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF00C0FF0073FF00A6FF0019FF00\
99FF004CFF0019FF0066FF00B3FF00B3FF00B3FF00B3FF00A6FF0080FF003FFF00
4CFF003FFF0019FF0099FF00B3FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
C0FF0066FF00C0FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00A6FF00CCFF00C0FF0000FF5999FF004CFF0033FF00D9FF00F3FF00FFF300\
FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF0073FF00C0FF00C0FF00B3FF00\
C0FF00A6FF003FFF0059FF008CFF0066FF0099FF0099FF0073FF0073FF008CFF00
8CFF008CFF0026FF0000FF8C73FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00C0FF00C0FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00C0FF00A6FF000CFF00B3FF00A6FF00C0FF00FFFF00\
FFF300FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00CCFF00C0FF00D9FF00D9FF00D9FF00\
CCFF00C0FF008CFF000CFF0000FF0C00FF0C80FF004CFF004CFF0099FF00A6FF00
B3FF00B3FF0080FF00A6FF00A6FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00E6FF00\
E6FF00E6FF0066FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00C0FF00D9FF00E6FF00D9FF00CCFF008CFF00F3FF00\
FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00C0FF0080FF0099FF0080FF004CFF0019FF0033FF0080FF00A6FF00B3FF00
C0FF00C0FF00C0FF00CCFF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00D9FF00F3FF00FFFF00FFFF00FFFF00E6FF0080FF00\
F3FF00FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00\
D9FF0099FF00B3FF00B3FF00A6FF0099FF0080FF0000FF0080FF00A6FF00C0FF00
CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFF300FFF300FFF300FFF300FFF300FFFF00\
F3FF00FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00\
E6FF00CCFF00CCFF00CCFF00C0FF00B3FF0073FF0000FF4C8CFF00B3FF00C0FF00
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00\
E6FF00E6FF00D9FF00D9FF00CCFF00A6FF004CFF004CFF008CFF00B3FF00C0FF00
CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00E6FF00D9FF00CCFF00A6FF0099FF0000FF1973FF0099FF00C0FF00
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF0080FF0066FF00A6FF00C0FF00
D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF008CFF0080FF00C0FF00CCFF00
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF008CFF00A6FF00C0FF00CCFF00
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF0033FF00B3FF00C0FF00CCFF00
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00E6FF00D9FF00CCFF00C0FF0066FF0066FF00A6FF00C0FF00CCFF00
D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00\
E6FF00E6FF00D9FF00CCFF00C0FF00B3FF008CFF0019FF0073FF00A6FF00CCFF00
D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00\
E6FF00D9FF00CCFF0059FF00A6FF0099FF0000FF1933FF0099FF00B3FF00C0FF00
CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00B3FF0080FF0000FFCC33FF0080FF0099FF00B3FF00C0FF00
C0FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00D9FF008CFF00C0FF00\
CCFF00C0FF00C0FF00B3FF0099FF0073FF0026FF0073FF0080FF0099FF00A6FF00
A6FF0059FF00C0FF00D9FF00D9FF00E6FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFF300FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00B3FF008CFF00\
A6FF0099FF00A6FF0099FF0080FF0059FF0000FFF333FF000CFF0080FF0099FF00
73FF0099FF00C0FF00CCFF00CCFF00D9FF00C0FF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFF300FFFF0080FF004CFF00C0FF00B3FF00B3FF00A6FF000CFF00\
4CFF0066FF008CFF008CFF004CFF000CFF0000FF8C00FF990CFF0066FF0066FF00
00FF5999FF00B3FF00C0FF00C0FF00C0FF0033FF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00A6FF0000FF8C80FF0000FFE68CFF00\
80FF0000FF8059FF0073FF004CFF0000FF7300000000000000FF1900FF0000FFB3
00FFFF00FF6699FF00A6FF003FFF008CFF008CFF00CCFF00E6FF00F3FF00FFFF00FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00D9FF00B3FF00A6FF0099FF00B3FF00\
A6FF0080FF0033FF0033FF0026FF0000FF1900D9FF00000000FF004CFF0080FF00
73FF000CFF0066FF0073FF0000FF198CFF0080FF0000FF0CC0FF00E6FF00F3FF00FFFF00FFF300\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00E6FF0080FF00CCFF00CCFF00C0FF00\
B3FF0099FF0000FF1980FF0073FF0019FF0000FF0000FF5926FF000CFF008CFF00
99FF0080FF0073FF0033FF00A6FF00C0FF00CCFF00CCFF00D9FF0059FF0073FF00FFFF00FFF300\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00D9FF00CCFF00\
C0FF0066FF0099FF0099FF008CFF003FFF0059FF0000FF6673FF008CFF00A6FF00
B3FF00A6FF00B3FF00A6FF00B3FF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFF300FFF300\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00\
C0FF0033FF00B3FF00B3FF00A6FF008CFF0080FF000CFF0073FF0099FF00B3FF00
C0FF00CCFF00CCFF00CCFF0033FF00D9FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00\
D9FF00CCFF00CCFF00C0FF00B3FF0099FF0073FF0000FF1900FF0C80FF00B3FF00
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00\
D9FF00D9FF00CCFF00C0FF00A6FF0080FF0026FF0066FF00A6FF00A6FF0080FF00
D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00\
E6FF00D9FF00D9FF00CCFF00B3FF008CFF0000FF26A6FF00C0FF00CCFF00CCFF00
D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00\
E6FF00D9FF00D9FF00CCFF00C0FF0099FF0000FF264CFF00C0FF00D9FF00D9FF00
E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00\
E6FF00D9FF00D9FF00CCFF00C0FF0099FF008CFF00C0FF00CCFF00D9FF00E6FF00
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00\
E6FF00D9FF00D9FF00CCFF00B3FF0066FF00A6FF00C0FF00CCFF00D9FF00E6FF00
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFF300FFFF00FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00D9FF00CCFF00C0FF00A6FF004CFF0080FF00C0FF00CCFF00D9FF00E6FF00
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300D9FF00F3FF00FFFF00FFFF00F3FF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00D9FF00CCFF0073FF0066FF0066FF00A6FF00C0FF00CCFF00D9FF00E6FF00
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFFF0080FF00CCFF00E6FF00A6FF00F3FF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00CCFF00B3FF0099FF0000FF998CFF008CFF00C0FF00D9FF00D9FF00
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFFF00D9FF0000FF33A6FF008CFF00E6FF00\
F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00CCFF00CCFF00B3FF0099FF0073FF0066FF00A6FF00C0FF00CCFF00D9FF00
E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFFF00B3FF00D9FF00C0FF0080FF00CCFF00\
CCFF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
CCFF00CCFF00C0FF00B3FF003FFF0000FF2680FF00A6FF00C0FF00CCFF00CCFF00
D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00E6FF0080FF0000FF00\
8CFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00
B3FF00E6FF00E6FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00A6FF008CFF0000FF1980FF0099FF00A6FF00C0FF00C0FF00
59FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00E6FF00D9FF00CCFF00\
33FF0080FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00
26FF00C0FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00B3FF00A6FF0099FF00\
B3FF00B3FF00A6FF0099FF0000FFD900FFA63FFF003FFF0073FF0099FF0073FF00
B3FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00\
CCFF0000FF73D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
A6FF008CFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00A6FF004CFF003FFF00\
8CFF0080FF0080FF004CFF0033FF008CFF0080FF0019FF004CFF0000FF598CFF00
C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00FFFF00FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00F3FF00\
D9FF00B3FF00A6FF00CCFF00CCFF00A6FF00D9FF00E6FF00D9FF00D9FF00CCFF00
B3FF00A6FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF008CFF0059FF00\
3FFF000CFF0073FF0099FF00A6FF00A6FF00A6FF008CFF008CFF003FFF0066FF00
B3FF00CCFF00CCFF00D9FF00D9FF00CCFF0000FF33F3FF00FFFF00FFFF00FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00\
E6FF00CCFF0000FF0C99FF00A6FF00B3FF00CCFF00D9FF00CCFF00CCFF00C0FF00
8CFF0073FF00B3FF00C0FF00A6FF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF0080FF004CFF00\
00FFD900FF1980FF00A6FF00B3FF00C0FF00C0FF00B3FF00A6FF0019FF0080FF00
A6FF00B3FF00A6FF00C0FF00C0FF0080FF00CCFF00F3FF00FFFF00FFFF00FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00\
E6FF00A6FF0099FF0033FF004CFF0099FF00C0FF00C0FF00B3FF00B3FF00B3FF00
99FF004CFF0099FF0099FF0080FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF008CFF0033FF00\
26FF0000FF0C99FF00B3FF00C0FF00CCFF00CCFF00C0FF00A6FF0000FF8026FF00
8CFF0099FF0059FF008CFF004CFF00B3FF00D9FF00F3FF00F3FF00FFFF00FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFD900FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00\
E6FF00D9FF00CCFF00B3FF0080FF0080FF00A6FF00B3FF0080FF0026FF008CFF00
73FF0059FF0000FFBF3FFF008CFF00A6FF00B3FF00B3FF00B3FF00A6FF0099FF0000FF2659FF00\
66FF0033FF0080FF00B3FF00CCFF00CCFF00D9FF00CCFF0080FF00B3FF008CFF00
4CFF0080FF003FFF0099FF004CFF008CFF00CCFF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFE600F3FF00FFE600FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00\
F3FF00E6FF00D9FF00C0FF0000FF9900FF3380FF008CFF003FFF0000FFBF00FF80
8CFF0099FF008CFF0073FF0059FF0099FF0099FF0080FF0099FF008CFF000CFF0099FF00A6FF00\
A6FF0099FF004CFF00C0FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF0099FF00
99FF00C0FF0033FF00C0FF0099FF0080FF00B3FF004CFF00E6FF00F3FF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFD900FFF30059FF00E6FF00FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00D9FF00CCFF00B3FF008CFF0000FF1980FF004CFF0059FF0066FF00
A6FF00B3FF00A6FF0080FF003FFF0066FF0059FF0000FF8C59FF0000FF3373FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF008CFF00
C0FF00CCFF00D9FF00CCFF00C0FF0099FF008CFF00C0FF00E6FF00F3FF00F3FF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFD900FFD900FFE600F3FF00C0FF00FFF300FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00\
E6FF00E6FF00D9FF00CCFF00B3FF0073FF0066FF00A6FF00B3FF00A6FF0073FF00
B3FF00C0FF00C0FF00A6FF008CFF0019FF008CFF0026FF008CFF0000FF6680FF00B3FF00CCFF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00E6FF00E6FF00D9FF004CFF00
CCFF00E6FF00E6FF00E6FF00CCFF00CCFF00B3FF0000FF4CD9FF00E6FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFE600FFFF008CFF00FFFF00FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600D9FF00FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00\
E6FF00E6FF00D9FF00CCFF00B3FF0080FF0080FF00B3FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00C0FF00A6FF0099FF00B3FF00B3FF00A6FF004CFF008CFF00B3FF00CCFF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00C0FF00
D9FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF008CFF003FFF00D9FF00D9FF00E6FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFE600FFF300FFFF00D9FF00F3FF00FFFF00FFF300FFF300FFE600
FFE600FFE600FFF300FFFF00CCFF00FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00\
D9FF00D9FF00CCFF00C0FF00A6FF0073FF00B3FF00C0FF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00CCFF0099FF00B3FF00C0FF00CCFF00B3FF003FFF0000FF3380FF00CCFF00\
D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00F3FF00E6FF00
F3FF00F3FF00FFFF00FFFF00F3FF00F3FF00F3FF00D9FF00C0FF008CFF00B3FF0080FF00D9FF00\
E6FF00F3FF00F3FF00B3FF00F3FF00FFF300FFF300FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000
FFC000FFCC00FFCC00FFE600FFD900FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFF300FFFF0026FF00C0FF00F3FF00FFFF00E6FF00FFFF00
FFF300FFF300FFFF00F3FF0019FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFFF00E6FF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00D9FF00D9FF00\
C0FF00CCFF00C0FF0059FF004CFF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00C0FF00CCFF00D9FF00D9FF00CCFF00C0FF0080FF00B3FF00D9FF00\
E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00CCFF00A6FF0099FF0080FF00CCFF00\
D9FF00D9FF00D9FF0059FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00
FFD900FFD900FFE60066FF00FFE600FFE600FFD900FFD900FFD900FFE600E6FF00FFF300FFE600\
FFE600FFF300FFF300FFFF00F3FF00D9FF008CFF00D9FF00D9FF004CFF00F3FF00
FFFF00FFFF00FFFF00E6FF00B3FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300F3FF0099FF00D9FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00A6FF00B3FF00C0FF00\
66FF00B3FF00A6FF0080FF000CFF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF00B3FF00D9FF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF00D9FF00C0FF0066FF00B3FF00\
99FF00B3FF0080FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFFF00
FFFF00FFF300FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFCC00E6FF00
FFFF00CCFF00D9FF00A6FF00CCFF00B3FF00FFFF00FFF300FFF300FFF300E6FF00F3FF00FFF300\
FFF300FFFF00F3FF00F3FF00E6FF00CCFF004CFF0080FF00A6FF00B3FF00E6FF00
F3FF00E6FF00E6FF00D9FF0019FF00D9FF00CCFF00F3FF00F3FF00D9FF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00C0FF00CCFF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00C0FF0073FF008CFF00\
66FF0080FF0033FF0059FF0000FF263FFF00C0FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF0000FF4CCCFF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF0099FF008CFF00\
66FF0099FF0066FF00C0FF00E6FF00F3FF00F3FF00F3FF00FFFF00F3FF00D9FF00
D9FF00FFF300FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000
FFCC00FFE600E6FF00FFF300C0FF00FFF300F3FF00A6FF0066FF0059FF00CCFF00CCFF00E6FF00\
F3FF00D9FF00C0FF008CFF00CCFF003FFF00CCFF00CCFF00C0FF0073FF00CCFF00
CCFF0066FF00A6FF00B3FF008CFF008CFF00CCFF00E6FF00D9FF00CCFF00F3FF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00CCFF00A6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00A6FF0099FF0026FF00\
19FF0019FF0000FF7366FF008CFF00B3FF00CCFF00D9FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00CCFF0099FF0080FF00\
D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00E6FF00A6FF00CCFF00\
C0FF00C0FF008CFF00A6FF00D9FF00D9FF00D9FF00D9FF00E6FF00D9FF00B3FF00
FFFF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000
FFC000FFCC00FFD900FFD900FFD900FFD900FFE600FFF300D9FF00D9FF00D9FF00B3FF00C0FF00\
D9FF00B3FF00C0FF0059FF00A6FF00CCFF00E6FF00E6FF00D9FF0080FF0000FF4C
00FF0CB3FF0099FF00B3FF00CCFF00C0FF0080FF0073FF0099FF0099FF00D9FF00E6FF00FFFF00\
FFFF00FFFF00FFFF00F3FF00FFFF00FFFF00FFFF00F3FF00E6FF00D9FF0099FF00
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00B3FF008CFF00\
00FF2600FFB300FF4066FF008CFF00A6FF00C0FF00D9FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00C0FF008CFF00\
C0FF00E6FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00D9FF00D9FF00E6FF00\
E6FF00D9FF008CFF0099FF00B3FF00CCFF00B3FF0099FF00B3FF0000FF8CF3FF00
FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFE600B3FF00FFFF00FFFF00CCFF00CCFF00\
26FF00CCFF00E6FF00F3FF00D9FF00F3FF00FFFF00FFFF00F3FF00D9FF00C0FF00
A6FF00D9FF00E6FF00E6FF00E6FF00D9FF0000FF0CCCFF00CCFF00B3FF008CFF00A6FF00E6FF00\
E6FF00F3FF00E6FF008CFF00E6FF00F3FF00F3FF00E6FF00D9FF00C0FF0000A6FF
A6FF00CCFF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF0099FF0073FF00\
3FFF004CFF004CFF0026FF0000FF4C80FF0066FF00CCFF00E6FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF004CFF00CCFF00\
26FF00E6FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300F3FF00FFFF00FFFF00\
F3FF00D9FF00CCFF0099FF000CFF0073FF003FFF00B3FF00A6FF003FFF00D9FF00
FFFF00FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600FFFF00F3FF00\
73FF00E6FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFFF00F3FF00D9FF00
CCFF00F3FF00F3FF00FFFF00FFFF00F3FF00A6FF00E6FF00F3FF00E6FF00E6FF00D9FF008CFF00\
A6FF00CCFF00CCFF00A6FF00D9FF00E6FF00D9FF00CCFF00CCFF00C0FF0059FF00
A6FF00B3FF0099FF00C0FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00A6FF003FFF00\
80FF0073FF0080FF0073FF0099FF008CFF00A6FF00D9FF00E6FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00\
A6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFFF00F3FF00E6FF0000FF0CA6FF00CCFF0066FF00D9FF00CCFF0073FF00D9FF00
F3FF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFFF00\
C0FF00F3FF00FFF300FFF300FFF300FFE600FFE600FFF300FFF300FFFF00B3FF00
D9FF00FFFF00FFFF00FFF300FFF300FFFF00C0FF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00\
C0FF0059FF003FFF0019FF00B3FF00CCFF00B3FF0099FF00A6FF0099FF0073FF00
66FF0073FF0073FF00C0FF00CCFF00CCFF00D9FF00CCFF00CCFF00CCFF00B3FF0073FF0019FF00\
A6FF00B3FF00B3FF0080FF00C0FF00C0FF0099FF00D9FF00E6FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
E6FF00F3FF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFFF00F3FF00C0FF00D9FF00F3FF00F3FF00F3FF00E6FF0099FF008CFF00
33FF00FFFF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFFF00\
3FFF00FFFF00FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFF300B3FF00
D9FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
D9FF00CCFF00D9FF00A6FF004CFF00A6FF0073FF0000FF6600FF3399FF00B3FF00
B3FF0099FF0019FF00A6FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF0099FF0073FF00A6FF00\
B3FF00CCFF00CCFF00B3FF00D9FF00D9FF00D9FF0080FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300F3FF008CFF00F3FF00FFFF00FFFF00FFFF00F3FF00CCFF00E6FF00
59FF00F3FF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900F3FF00\
CCFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFE600FFE600FFFF00
FFFF00FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFFF00F3FF00E6FF00C0FF00B3FF0066FF00C0FF00C0FF003FFF00C0FF00CCFF00
CCFF00A6FF0000FF4C8CFF00A6FF0080FF0099FF00B3FF00B3FF008CFF0080FF00B3FF00C0FF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFF300E6FF0059FF00FFFF00FFF300FFF300FFF300FFF300FFFF00FFFF00
F3FF000CFF00FFFF00FFF300FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFFF00\
D9FF00FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFFF00FFFF00E6FF00CCFF0080FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00B3FF00A6FF0019FF004CFF0000FF0026FF0026FF0080FF000CFF0033FF00C0FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFF300E6FF00FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFF30033FF0000FFBFE6FF00FFF300FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900CCFF00\
FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFF300FFF300FFFF00F3FF00C0FF00D9FF00E6FF00F3FF00F3FF00F3FF00E6FF00
E6FF00CCFF00A6FF008CFF00B3FF008CFF0059FF008CFF0080FF0059FF00A6FF00C0FF00CCFF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFE600
FFE600FFF300C0FF00D9FF00F3FF00FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFF300FFF300E6FF0080FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00D9FF0066FF00C0FF00CCFF00C0FF00B3FF00B3FF0099FF004CFF0080FF00A6FF00CCFF00\
D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600F3FF00FFE600FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300F3FF00CCFF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00C0FF00B3FF00D9FF00D9FF00D9FF00CCFF00C0FF0099FF0000FF2699FF00C0FF00D9FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFFF00FFFF00FFF300FFF300FFF300FFF300FFFF00FFFF00
F3FF0099FF00D9FF00E6FF00E6FF00E6FF00D9FF00CCFF00A6FF0059FF00A6FF00C0FF00CCFF00\
D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF0099FF0099FF0099FF0026FF00B3FF00C0FF00\
D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00CCFF00B3FF008CFF0073FF00B3FF00\
D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00C0FF0059FF00A6FF00CCFF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00E6FF00CCFF00A6FF0099FF00D9FF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00A6FF00C0FF00D9FF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00CCFF0059FF00C0FF00D9FF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00B3FF0026FF00B3FF00D9FF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00F3FF00D9FF00C0FF0080FF0099FF00CCFF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00E6FF00C0FF00A6FF0000FF0CB3FF00CCFF00\
D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00E6FF00C0FF00B3FF0026FF0099FF00CCFF00\
D9FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00C0FF0033FF0080FF00B3FF00\
C0FF0080FF00A6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00C0FF00A6FF0066FF003FFF00\
99FF00B3FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF0080FF00A6FF0066FF003FFF00A6FF00\
CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFF300FFF300FFFF00F3FF00E6FF00E6FF00D9FF00C0FF0099FF0073FF0099FF00B3FF00\
CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFF300FFFF00C0FF00CCFF00C0FF00C0FF00C0FF00A6FF0000FF800CFF00B3FF00C0FF00\
CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFF300FFFF00F3FF00C0FF0099FF00B3FF0026FF003FFF0000FF0C99FF00B3FF00C0FF00\
CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFF300
FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFF300FFFF00FFFF00F3FF00E6FF00D9FF00C0FF00A6FF008CFF008CFF00A6FF00B3FF00\
C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00D9FF004CFF00E6FF00FFFF00
FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600
FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00C0FF0099FF004CFF008CFF00A6FF00\
A6FF00A6FF00C0FF00CCFF00D9FF00D9FF00CCFF00A6FF00B3FF00F3FF00FFFF00
FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600
FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00C0FF008CFF000CFF0080FF0080FF00\
33FF0059FF00B3FF00C0FF00CCFF00C0FF00A6FF00B3FF00D9FF00F3FF00FFFF00
FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300
FFF300FFFF00FFFF00F3FF00E6FF00E6FF00D9FF00C0FF00A6FF0080FF003FFF0033FF0033FF00\
33FF0080FF008CFF00B3FF00B3FF0099FF0000FF40C0FF00E6FF00F3FF00FFFF00
FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00
FFFF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00B3FF0026FF0066FF000CFF0000FFFF0000FF\
00A6FF19FF0000FF3380FF008CFF004CFF0080FF00B3FF00C0FF00E6FF00F3FF00
FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300CCFF00F3FF00
F3FF00E6FF00D9FF00B3FF00CCFF00CCFF00C0FF0080FF004CFF0000FF004C00FF000000000000\
00E6FF26FF0066FF0059FF0099FF0099FF0019FF0000FF8CC0FF00CCFF003FFF00
F3FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFFF00A6FF0073FF00A6FF00
00FF338CFF0099FF004CFF0099FF00C0FF00B3FF00A6FF0080FF000CFF00000000000000000000\
00FFE60CFF0073FF0099FF00B3FF00B3FF00B3FF0073FF008CFF003FFF0080FF00
D9FF00F3FF00F3FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFFF00F3FF00
F3FF00CCFF00C0FF00B3FF0073FF0099FF0099FF0073FF0059FF0000FF0C00FF5900FFE6000000\
2600FF00FF3366FF0073FF00C0FF00CCFF00CCFF00C0FF0019FF00CCFF008CFF00
C0FF00A6FF00C0FF00D9FF00FFFF00FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300
FFFF00E6FF00E6FF00B3FF00B3FF0073FF0080FF008CFF0080FF0073FF003FFF000CFF0000FF59\
0059FF19FF0059FF0099FF00C0FF00D9FF00D9FF00D9FF003FFF00E6FF00F3FF00
F3FF00E6FF0080FF00F3FF00FFFF00FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300
FFF300FFFF00F3FF00E6FF00C0FF0059FF00B3FF00C0FF00A6FF0099FF0066FF003FFF004CFF00\
3FFF0066FF0099FF00B3FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00FFFF00
FFFF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600
FFF300FFFF00FFFF00E6FF00A6FF00B3FF00CCFF00CCFF00CCFF00A6FF0080FF0066FF008CFF00\
66FF0073FF00A6FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600
FFF300FFF300FFFF00C0FF0066FF00D9FF00D9FF00D9FF00D9FF00C0FF00C0FF00B3FF00A6FF00\
80FF0073FF00B3FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300
FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFF300F3FF00CCFF00D9FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00\
99FF0073FF00A6FF00C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFF300FFF300FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00D9FF00CCFF00B3FF00\
99FF0000FF660CFF0000FF00C0FF00CCFF00E6FF00FFFF00FFF300FFF300FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF00B3FF00\
80FF0059FF00B3FF00C0FF00B3FF003FFF0099FF00F3FF00FFF300FFF300FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00B3FF0000FF99\
0CFF008CFF00CCFF00D9FF00E6FF00E6FF00F3FF00FFFF00FFF300FFF300FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF00A6FF0066FF0059FF00\
A6FF00C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFF300FFF300FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF00C0FF00B3FF000CFF00\
B3FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00CCFF0073FF00\
99FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00D9FF00CCFF00A6FF00\
8CFF0073FF004CFF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF0080FF0026FF00\
C0FF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00CCFF0073FF00\
8CFF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00CCFF008CFF00\
D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00D9FF0066FF00B3FF00\
D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00C0FF0033FF00A6FF00\
D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00D9FF00C0FF0080FF00A6FF00\
CCFF00D9FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00A6FF0000FF00\
99FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF0073FF0073FF0073FF00\
C0FF00D9FF00E6FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00D9FF00C0FF0080FF0099FF00\
C0FF00CCFF00D9FF00D9FF00D9FF0073FF00FFFF00FFFF00FFF300FFF300FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFF30099FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF0000FF733FFF00\
99FF0019FF00C0FF00C0FF0066FF00D9FF00F3FF00FFFF00FFF300FFF300FFF300
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFD900FFD900FFD900
FFE600FFE600D9FF00FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300E6FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00E6FF004CFF00CCFF00CCFF008CFF0099FF000CFF00A6FF00B3FF00B3FF00\
33FF0073FF008CFF0059FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFCC00F3FF0080FF00FFF300FFF300
FFF300FFFF00B3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFFF00D9FF008CFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00E6FF00CCFF0073FF00A6FF004CFF0099FF00B3FF00CCFF00CCFF00CCFF00\
C0FF00B3FF0099FF0099FF00CCFF00E6FF00E6FF00F3FF00F3FF00FFFF00F3FF00
F3FF00E6FF00FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFE600E6FF0066FF00
E6FF00D9FF000CFF00C0FF00F3FF00CCFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00E6FF00C0FF00CCFF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00D9FF00C0FF003FFF0059FF0073FF00B3FF00CCFF00D9FF00D9FF00D9FF00\
D9FF00C0FF008CFF0066FF00C0FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00
B3FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFE600F3FF00
C0FF004CFF00D9FF0073FF008CFF0080FF00E6FF00FFFF00FFFF00FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00E6FF00CCFF00B3FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00CCFF0099FF003FFF0000FF198CFF0073FF00D9FF00E6FF00E6FF00E6FF00\
D9FF00CCFF0073FF0080FF00B3FF00CCFF00CCFF0099FF00D9FF00C0FF0099FF00
E6FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900D9FF00
FFFF00FFFF00FFFF0080FF00E6FF00CCFF0073FF00D9FF00F3FF00F3FF00F3FF00A6FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00CCFF0073FF00C0FF00CCFF008CFF00D9FF00E6FF00
E6FF00D9FF00D9FF00C0FF00A6FF0080FF0059FF00A6FF00D9FF00E6FF00F3FF00F3FF00F3FF00\
E6FF0026FF00C0FF00A6FF0066FF008CFF0080FF0073FF0059FF0066FF00CCFF00
F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600
FFE600FFE600FFF300F3FF00FFFF00F3FF00E6FF00CCFF00CCFF00D9FF00D9FF0059FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00C0FF0073FF0066FF0099FF00A6FF00CCFF00D9FF00
D9FF00CCFF00CCFF00A6FF000CFF00B3FF00C0FF000CFF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00D9FF0000FF19A6FF00CCFF00B3FF00C0FF00C0FF0080FF0099FF00
F3FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900
FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00C0FF00A6FF0099FF008CFF00C0FF00\
D9FF00D9FF00A6FF00A6FF003FFF00A6FF00A6FF0099FF0066FF00B3FF00C0FF00
C0FF00C0FF008CFF0099FF00CCFF00D9FF00E6FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00E6FF00B3FF00CCFF00E6FF00E6FF00E6FF00D9FF0000FF4CB3FF00
D9FF00E6FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00CCFF00CCFF00C0FF008CFF00B3FF00\
C0FF00C0FF0000FF733FFF00A6FF00CCFF00CCFF00A6FF004CFF008CFF0073FF00
4CFF0066FF0073FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300\
FFFF00FFFF00E6FF0026FF00E6FF00F3FF00F3FF00F3FF00E6FF0099FF0099FF00
00FF0CE6FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300F3FF00F3FF00D9FF004CFF0073FF00\
8CFF0066FF00A6FF0099FF00CCFF00D9FF00D9FF00CCFF00B3FF0099FF00C0FF00
C0FF00B3FF000CFF00C0FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFFF00F3FF0080FF00F3FF00FFFF00FFFF00FFFF00F3FF00D9FF00E6FF00
80FF0059FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00FFFF00F3FF00D9FF00C0FF00\
59FF00C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00C0FF00C0FF00D9FF00
D9FF00C0FF0073FF00C0FF00E6FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600\
FFF300FFF300FFFF00D9FF00FFFF00FFF300FFF300FFF300FFF300FFFF00FFFF00
E6FF0099FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00CCFF00\
66FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00CCFF00CCFF00E6FF00
E6FF00A6FF00CCFF0026FF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFE600FFE600FFE600FFE600FFF300FFF300FFFF00
F3FF00CCFF00C0FF00D9FF00FFFF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00F3FF00E6FF00C0FF00\
C0FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00F3FF00F3FF00FFFF00
F3FF00F3FF00E6FF008CFF00E6FF00FFFF00FFFF00FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFFF00E6FF0080FF00CCFF00E6FF00D9FF00F3FF00FFF300FFF300FFE600FFE600FFE600FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00F3FF00E6FF0099FF00\
CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00C0FF00D9FF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFF300F3FF0080FF0059FF0099FF00C0FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00E6FF003FFF008CFF00\
CCFF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00CCFF0033FF00E6FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFF300F3FF00F3FF00E6FF00B3FF003FFF00E6FF00F3FF00FFFF00FFFF00FFFF00B3FF00FFFF00\
FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00E6FF00CCFF0026FF00\
CCFF00E6FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFF300FFF300FFF300F3FF0000FF19CCFF00F3FF00FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFF300FFFF00E6FF00A6FF00C0FF00D9FF00E6FF00E6FF00F3FF00D9FF00C0FF00FFFF00\
FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00D9FF00B3FF0080FF00\
B3FF00D9FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFFF00F3FF0080FF00FFFF00FFE600FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFE600FFE600FFF300FFFF0099FF008CFF00A6FF0066FF00A6FF00C0FF00C0FF00F3FF00FFF300\
FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300CCFF003FFF00B3FF008CFF00A6FF00\
CCFF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300F3FF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFE600FFF300F3FF00CCFF00E6FF00D9FF00D9FF00CCFF0080FF00D9FF00F3FF00FFF300\
FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00E6FF0066FF0000FF6619FF00\
C0FF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFE600C0FF00F3FF00FFFF00FFFF00F3FF00D9FF00A6FF000CFF00F3FF00FFFF00\
FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00E6FF00C0FF0073FF00B3FF00\
C0FF00C0FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFE600FFF300FFF300FFF300FFF300F3FF00D9FF008CFF00D9FF00F3FF00FFFF00\
FFFF00FFF300FFF300FFE600FFE600FFE600FFF300D9FF00FFFF00FFE600FFCC00
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF0080FF0059FF00B3FF00D9FF00\
E6FF00F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300F3FF00CCFF0066FF00B3FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00A6FF00CCFF00FFE600FFCC00FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00C0FF00B3FF00E6FF00\
FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300F3FF00D9FF008CFF00C0FF00D9FF00\
CCFF00B3FF0099FF00E6FF00D9FF00A6FF00D9FF00FFF300FFD900FFCC00FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF004CFF00CCFF00E6FF00\
FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFFF00C0FF00B3FF00D9FF00A6FF00\
C0FF00D9FF00CCFF0073FF0059FF00F3FF00FFF300FFD900FFCC00FFCC00FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFF300F3FF00E6FF00
FFFF00FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00D9FF0080FF00E6FF00F3FF00\
FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFFF0059FF00E6FF00FFFF00FFFF00\
F3FF00F3FF00F3FF00C0FF0026FF00FFFF00FFE600FFD900FFCC00FFCC00FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600B3FF00C0FF00
A6FF00F3FF00FFFF00F3FF00D9FF00F3FF00F3FF00F3FF00E6FF00CCFF00B3FF00E6FF00FFFF00\
FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFF300D9FF00F3FF00FFF300FFF300FFF300\
FFF300FFF300FFFF00CCFF008CFF00F3FF00FFE600FFD900FFCC00FFCC00FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFF300FFFF00
D9FF00C0FF00D9FF00D9FF0026FF00D9FF00E6FF00CCFF00C0FF0099FF00A6FF00CCFF00F3FF00\
FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFFF00C0FF00FFF300FFE600FFE600FFE600\
FFE600FFF300FFFF00CCFF00CCFF00F3FF00FFF300FFD900FFCC00FFCC00FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFE600FFF300
F3FF00CCFF0099FF0073FF008CFF00A6FF00C0FF003FFF00A6FF00CCFF00A6FF00C0FF00E6FF00\
F3FF00FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFE600E6FF00FFE600FFD900FFD900FFD900\
FFD900FFE600F3FF00D9FF00CCFF0026FF0099FF00FFF300FFCC00FFCC00FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300
FFFF00E6FF0000FF00CCFF00CCFF0099FF0073FF00CCFF00E6FF00E6FF00CCFF00B3FF0059FF00\
F3FF00FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFF300FFD900FFD900FFCC00FFCC00FFCC00\
FFD900FFD900F3FF00FFF300FFFF00A6FF00F3FF00FFE600FFCC00FFCC00FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFF300
F3FF00CCFF00C0FF00E6FF00E6FF00E6FF00CCFF00E6FF00F3FF00FFFF00E6FF00F3FF00CCFF00\
E6FF00FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFE600F3FF00E6FF00FFE600FFCC00FFCC00FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFF300FFFF00
E6FF0073FF00D9FF00F3FF00FFFF00FFFF00E6FF00D9FF00FFF300FFF300FFF300FFF300FFFF00\
80FF00D9FF00FFFF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFD900FFD900FFF300CCFF00FFE600FFD900FFCC00FFC000
FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600F3FF00FFFF00FFFF00F3FF00
CCFF00C0FF00E6FF00FFFF00FFF300FFF300FFF300FFFF00FFE600FFE600FFE600FFE600FFF300\
E6FF00B3FF00C0FF00FFF300FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFD900FFE6008CFF00E6FF00FFE600FFCC00FFC000
FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300F3FF00A6FF00CCFF00D9FF00
B3FF00E6FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFE600FFE600\
FFFF00E6FF00CCFF00F3FF00FFF300FFE600FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFD900FFFF00E6FF00FFF300FFE600FFCC00
FFC000FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFE600FFE600FFF300F3FF00C0FF00C0FF0099FF00
B3FF00CCFF00FFFF00FFF300FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFFF00D9FF008CFF00D9FF00FFE600FFCC00FFCC00FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFCC00FFCC008CFF00FFFF0080FF00FFE600FFCC00
FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900\
FFE600FFE600FFE600FFF300FFF300FFFF00D9FF00CCFF00CCFF00F3FF00CCFF00
F3FF00C0FF00F3FF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900F3FF00FFF300FFFF00CCFF00FFD900FFCC00FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFFF00FFE600FFC000
FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600\
A6FF00FFFF00FFFF00D9FF00D9FF00C0FF0066FF00D9FF00D9FF00FFF300FFF300
FFF300FFFF008CFF00FFF300FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFE600E6FF00FFE600FFCC00FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFF300FFC000
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFD900FFE600FFD900FFD900FFD900FFD900FFE600FFE600\
FFFF0099FF0073FF004CFF00E6FF00FFFF00FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFF300FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFCC00FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFF300FFC000
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFCC00FFD900E6FF00E6FF00FFF300FFE600FFE600FFF300FFF300\
F3FF0059FF00D9FF00CCFF00FFFF00FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFCC00FFD900FFF300CCFF00B3FF00FFFF00FFFF00B3FF00E6FF00\
D9FF00C0FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFF300F3FF0080FF00D9FF00A6FF0059FF00\
99FF00E6FF00FFFF00FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFE600FFFF00E6FF00A6FF00D9FF00D9FF00\
E6FF003FFF00F3FF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600FFFF00E6FF00CCFF00F3FF00FFFF00\
FFFF00FFFF00F3FF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFFF00D9FF00D9FF00FFFF00FFF300\
FFE600FFE600FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFF300F3FF0080FF0073FF00FFF300FFE600\
FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFC000FFCC00FFCC00FFCC00FFE600FFD900FFCC00FFCC00FFCC00
FFD900FFD900FFE60073FF00FFFF00FFF300FFF300FFFF00D9FF00CCFF00FFFF00FFF300FFE600\
FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFC000FFF300F3FF00FFE600FFE600D9FF00FFE600FFE600FFD900FFD900
FFD900FFE600FFE600F3FF00C0FF00F3FF00F3FF00F3FF00D9FF00D9FF00FFFF00FFF300FFE600\
FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFB300FFB300FFC000FFD900F3FF00C0FF00CCFF00E6FF00A6FF00FFF300FFE600
FFF300FFF300FFF300F3FF00C0FF00B3FF00C0FF00CCFF0099FF0099FF00F3FF00FFF300FFE600\
FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFC000FFCC00FFF300FFF300FFF300E6FF00E6FF00B3FF00F3FF00
F3FF00E6FF00F3FF00D9FF008CFF00D9FF00B3FF00CCFF00D9FF00B3FF00CCFF00FFFF00FFF300\
FFD900FFD900FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFCC00FFD900FFD900FFE600FFE600FFF300CCFF00
B3FF008CFF00CCFF00C0FF00E6FF00F3FF00F3FF00D9FF00FFFF00FFFF00E6FF00CCFF00FFFF00\
FFF300FFD900FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFFF00
FFFF00D9FF0066FF00E6FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFF300FFFF00E6FF00\
E6FF00FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600
FFF300F3FF0073FF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFD900FFE600FFE600\
FFE600FFD900FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600
FFE600FFFF003FFF00F3FF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900
FFE600FFFF00CCFF00D9FF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900
FFE600FFFF00C0FF00FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900
FFF300E6FF00B3FF00F3FF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900
FFF3004CFF008CFF00E6FF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600
FFF300F3FF00E6FF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600
FFF3004CFF00E6FF00FFF300FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600
FFF300E6FF00E6FF00FFF300FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFD900FFE600FFE600FFE600FFE600FFF300FFF300
FFFF00E6FF00E6FF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFD900D9FF00CCFF00FFFF00FFFF00E6FF00F3FF00
E6FF008CFF00B3FF00F3FF00FFF300FFE600FFD900FFCC00FFCC00FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFC000FFC000FFCC00FFE600FFFF00B3FF00CCFF0099FF00CCFF00
CCFF00F3FF00D9FF00CCFF00F3FF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFC000FFCC00FFCC00FFD900FFF300F3FF00E6FF00F3FF00D9FF00
F3FF00FFF300FFF300FFF300D9FF00D9FF00FFF300FFD900FFCC00FFC000FFC000FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFC000FFC000FFCC00FFD900FFE600FFF300CCFF00FFFF00FFF300FFF300
CCFF00FFE600FFD900FFD900FFF300D9FF00CCFF00FFF300FFE600FFCC00FFC000FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFC000FFC000FFCC00FFCC00FFE600FFF300FFFF00D9FF00FFF300FFE600FFD900
FFD900FFD900FFCC00FFCC00FFD900FFE60066FF00CCFF00FFFF00FFCC00FFC000FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000\
FFC000FFC000FFCC00FFD900FFFF00CCFF00D9FF00E6FF00FFE600FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFE60073FF00FFCC00FFC000FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000\
FFCC00FFCC00FFD900FFF300F3FF00F3FF00FFFF00F3FF00FFF300FFD900FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFD900FFD900FFC000FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00\
FFF300FFE600D9FF00B3FF00FFFF00FFF300FFD900FFD900FFFF00FFCC00FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFC000FFCC00FFD900\
FFF300CCFF00F3FF00FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB30080FF00FFFF00FFE600C0FF00\
F3FF00FFFF00FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFCC00FFE600D9FF00D9FF00\
E6FF00B3FF00FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFB300FFC000FFD900FFF300FFFF00\
FFE600FFD900FFCC00FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFCC00FFD900FFF300FFF300\
FFD900FFCC00FFC000FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFB300FFC000FFD900FFFF00E6FF00FFF300\
FFD900FFC000FFC000FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFB300FFCC00FFE600F3FF00FFF300FFF300\
D9FF00FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFCC00E6FF00FFE600FFD900FFCC00FFC000\
FFC000FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FFA600FFA600FFB300FFD900FFE600FFC000FFC000FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FFA600FFC000FFD900FFCC00FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FFA600FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00FF7F00\
FF7F00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF0099FF00\
73FF0066FF00B3FF00CCFF00CCFF00C0FF00C0FF0000FF26A6FF00C0FF00CCFF00
D9FF00D9FF00D9FF00CCFF00CCFF00B3FF008CFF0026FF0080FF0073FF0080FF0000FF338CFF00\
A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00B3FF0073FF00B3FF00B3FF00
4CFF0080FF008CFF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00C0FF0000FF9926FF00B3FF00CCFF00C0FF00A6FF00
E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF0059FF00\
B3FF008CFF0080FF00B3FF008CFF0099FF00A6FF0019FF0099FF00B3FF0080FF00
C0FF00CCFF00CCFF00CCFF00C0FF00B3FF0000FF1959FF0000FF0C26FF0000FF0C00FF198CFF00\
A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00C0FF00CCFF00CCFF00
C0FF00A6FF008CFF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00CCFF00C0FF0080FF0080FF0000FF0066FF00C0FF00
D9FF00E6FF00E6FF00E6FF00A6FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00\
CCFF0073FF0026FF0073FF000CFF003FFF0066FF0033FF0000FF7373FF0099FF00
B3FF00C0FF00C0FF00C0FF00C0FF00B3FF0099FF0073FF0033FF0000000000FFBF66FF008CFF00\
A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00C0FF0026FF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00B3FF008CFF0080FF004CFF0099FF00
C0FF00B3FF00CCFF00B3FF00D9FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00\
D9FF00CCFF0080FF008CFF0099FF0033FF0099FF0099FF0066FF0000FF6673FF00
A6FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF0059FF0033FF003FFF000CFF0000FFE600FF59\
99FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF0099FF0099FF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF0000FF0CCCFF00CCFF0099FF0066FF00
99FF0073FF0080FF00A6FF00E6FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
E6FF00C0FF0066FF00B3FF00C0FF0000FF00B3FF00B3FF0099FF0019FF0080FF00
99FF008CFF0099FF00A6FF00A6FF008CFF0073FF004CFF0080FF0080FF0073FF0073FF004CFF00\
80FF00A6FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF0059FF0080FF00C0FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0099FF00
99FF000CFF00B3FF0000FF19CCFF00F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00\
D9FF0000FF0CC0FF00CCFF00CCFF00CCFF00CCFF00C0FF0000FF0073FF004CFF00
73FF0019FF0073FF008CFF008CFF003FFF0033FF0099FF00A6FF00A6FF00A6FF0099FF0000FF80\
66FF00A6FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00CCFF00CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00A6FF00
CCFF00D9FF00D9FF0073FF0080FF00D9FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00F3FF00\
B3FF00B3FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00B3FF0073FF0026FF00
73FF0000FF263FFF0066FF0033FF0000FF4080FF00A6FF00B3FF00B3FF00B3FF00B3FF0099FF00\
B3FF0000FF33CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00CCFF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00E6FF0059FF00
E6FF00F3FF00F3FF00CCFF00D9FF0080FF00E6FF00FFFF00FFF300FFE600FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00B3FF0000FFA699FF00
99FF0000FF3373FF0059FF0000FFE673FF0099FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF004CFF00
F3FF00FFFF00FFFF00FFFF00FFFF00F3FF0073FF0099FF00FFF300FFE600FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF000CFF00B3FF00B3FF00
B3FF0099FF0099FF0080FF0000FF0073FF0099FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00FFE600FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00C0FF00C0FF00CCFF00CCFF00
C0FF00B3FF00A6FF0080FF003FFF0066FF0000FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFF300FFE600FFE600FFE600FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00
CCFF00C0FF00A6FF0080FF0033FF008CFF00A6FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00
CCFF00C0FF0080FF000CFF0026FF0033FF00A6FF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00
D9FF00C0FF00A6FF00A6FF0000FFB34CFF0080FF008CFF00C0FF00CCFF00D9FF00D9FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00
D9FF00CCFF00C0FF00B3FF008CFF0000FF0099FF00B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
D9FF00CCFF00CCFF00B3FF0073FF004CFF00A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
D9FF00CCFF00CCFF00B3FF008CFF004CFF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
D9FF00CCFF00CCFF00B3FF008CFF0099FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00
D9FF00CCFF00C0FF00A6FF0019FF0099FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00
D9FF00CCFF00A6FF0066FF0059FF0099FF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00
CCFF00C0FF00B3FF008CFF0000FFBF8CFF0099FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00
B3FF00B3FF0000FF4073FF0000FF4C73FF0099FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00\
FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF0080FF00
00FF6699FF0080FF0000FF6666FF008CFF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00\
FFFF00F3FF00F3FF00CCFF00CCFF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF00
99FF003FFF0000FF264CFF0080FF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00D9FF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00\
F3FF00F3FF00E6FF00CCFF0059FF00C0FF00CCFF00CCFF00C0FF00C0FF00B3FF00
A6FF008CFF0059FF004CFF0073FF0080FF008CFF00A6FF00B3FF00B3FF008CFF00A6FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00F3FF00\
F3FF00E6FF00E6FF00CCFF00B3FF0099FF00B3FF00A6FF00B3FF00B3FF00A6FF00
99FF0080FF0066FF000CFF0059FF004CFF0066FF0099FF0099FF008CFF004CFF00B3FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00E6FF00C0FF00D9FF00\
D9FF00CCFF00CCFF00C0FF00A6FF003FFF008CFF0073FF0099FF00A6FF0099FF00
00FF4C33FF0033FF0000FF0C0CFF0000FF0059FF0080FF0080FF0019FF008CFF00B3FF00C0FF00\
CCFF00CCFF00CCFF00C0FF0026FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00CCFF00B3FF00\
99FF0000FF00B3FF003FFF008CFF0000FF400CFF0026FF000CFF008CFF0080FF00
66FF0000FF4000FF6600CCFF0099FF00FF5900FF4066FF004CFF0033FF0080FF0099FF00B3FF00\
B3FF00A6FF00B3FF0080FF00C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00\
99FF0099FF0059FF0000FF4C0CFF008CFF008CFF0073FF0033FF0059FF0073FF00
59FF0000FF6600BFFF00000000000000FF5919FF003FFF003FFF0000FFA633FF0080FF0099FF00\
A6FF0066FF0080FF0000FF2699FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00F3FF00\
D9FF00C0FF0019FF00A6FF0066FF00A6FF00A6FF0059FF0066FF0000FF0000FF33
00FF0000FF5900FF8C0059FF00000000FF4033FF0066FF0080FF0073FF0033FF0066FF000CFF00\
80FF0026FF0059FF0099FF0000FF2666FF00C0FF00D9FF00E6FF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00\
E6FF00C0FF00B3FF00C0FF00C0FF00C0FF00C0FF00A6FF0080FF0019FF0073FF00
73FF004CFF000CFF0000FF8C00CCFF00FF0C00FF5966FF008CFF008CFF0073FF000CFF0000FF73\
26FF0099FF0099FF00C0FF00B3FF00C0FF00C0FF0066FF0026FF00F3FF00FFFF00
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00\
E6FF00B3FF00CCFF00D9FF00CCFF00CCFF00C0FF00B3FF0080FF0066FF008CFF00
8CFF000CFF0000FF3333FF0000FF003FFF004CFF0033FF0099FF00A6FF0099FF0080FF0099FF00\
33FF00A6FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00\
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF0073FF0066FF00A6FF00A6FF00
99FF003FFF0073FF0066FF000CFF0073FF008CFF0099FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
A6FF00A6FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00\
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF0099FF00B3FF00B3FF00B3FF00
A6FF0099FF008CFF0073FF003FFF0059FF008CFF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00\
CCFF0059FF00C0FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00CCFF00C0FF00C0FF00
B3FF00A6FF008CFF0073FF0000FF8C3FFF0000FFF399FF00B3FF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF0099FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00
B3FF00A6FF0080FF0000FF4C19FF0099FF00A6FF0073FF0099FF00CCFF00D9FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00
B3FF0000FF0C3FFF0066FF008CFF00A6FF00C0FF00C0FF00C0FF00D9FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00
C0FF00A6FF008CFF0033FF0099FF00B3FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00
C0FF00B3FF0073FF0000FF1999FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00
C0FF00B3FF003FFF0073FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00
C0FF00A6FF003FFF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFE600FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00
B3FF0080FF0073FF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFE600F3FF00D9FF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00
B3FF0073FF0059FF00A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFE600FFF300D9FF00E6FF00F3FF00FFFF00FFFF00F3FF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF0059FF00
26FF0000FF1980FF00A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFE600FFF300FFFF0066FF0080FF00E6FF00E6FF0099FF00F3FF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00B3FF00
A6FF0066FF0019FF008CFF0099FF00A6FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFE600FFF300FFFF00E6FF0066FF0066FF00C0FF00B3FF00E6FF00\
F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00
A6FF008CFF0059FF000CFF0099FF00B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFE600FFF300FFFF00D9FF00A6FF0080FF008CFF008CFF00CCFF00\
E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00
99FF0080FF0026FF0059FF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFE600FFE600FFF300FFFF00CCFF00E6FF00D9FF00CCFF0000FF66B3FF00\
CCFF00B3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00E6FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00
8CFF0059FF0059FF008CFF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00E6FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00F3FF00F3FF00D9FF0019FF0066FF00\
26FF00CCFF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00D9FF0099FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00
99FF0066FF003FFF0080FF0099FF0099FF00B3FF00B3FF00B3FF0066FF00CCFF00E6FF00E6FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF0073FF00CCFF00CCFF00\
80FF00A6FF00CCFF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00CCFF0073FF0066FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00CCFF0026FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
4CFF0026FF000CFF0066FF0033FF0019FF0099FF0099FF0080FF00A6FF00CCFF00D9FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00\
C0FF008CFF00B3FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00E6FF00
E6FF00E6FF00CCFF008CFF0099FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00CCFF00C0FF0099FF0080FF0080FF008CFF0099FF0080FF008CFF0080FF00
33FF0073FF0080FF0066FF0000FF330CFF0073FF0019FF0099FF00C0FF00CCFF00D9FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00\
D9FF00CCFF000CFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00D9FF00CCFF00B3FF0059FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00C0FF008CFF003FFF003FFF000CFF0080FF003FFF000CFF0080FF00
99FF0099FF00A6FF008CFF003FFF0080FF0073FF003FFF0099FF00B3FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00F3FF00FFFF00FFFF00FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00\
E6FF00D9FF0066FF0033FF00C0FF00CCFF00A6FF00C0FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00B3FF0073FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00CCFF00\
CCFF00CCFF00C0FF00A6FF008CFF0066FF000CFF004CFF0026FF0080FF0099FF00
A6FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF004CFF0073FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF0099FF00CCFF00F3FF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
E6FF00D9FF00C0FF0000FF0C8CFF00A6FF0033FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00A6FF0000FF4C3FFF00B3FF00C0FF00A6FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00C0FF00B3FF00A6FF0073FF004CFF0000FF8000FF2600FFCC73FF00A6FF00
B3FF00C0FF00C0FF00C0FF00B3FF00A6FF004CFF0026FF0080FF00A6FF00B3FF00B3FF0080FF00\
C0FF00C0FF00A6FF0099FF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00\
F3FF00D9FF0099FF008CFF003FFF004CFF0073FF00A6FF00C0FF00C0FF00C0FF00
B3FF00C0FF00B3FF0099FF0026FF0080FF0099FF0099FF0059FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00A6FF0080FF003FFF0019FF0000FF1973FF0099FF00B3FF00
C0FF00C0FF00CCFF00CCFF00C0FF00B3FF0099FF0026FF000CFF008CFF0099FF008CFF0019FF00\
99FF003FFF008CFF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFD900FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
F3FF00D9FF00CCFF00C0FF00B3FF0099FF0033FF0099FF00B3FF00B3FF00A6FF00
59FF0080FF0099FF008CFF003FFF004CFF0033FF0066FF008CFF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF0099FF0066FF000CFF0066FF000CFF0073FF0099FF00B3FF00
C0FF00CCFF00CCFF00CCFF00CCFF00C0FF0080FF0099FF0073FF0000FF0059FF0000FF4033FF00\
80FF004CFF008CFF00C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFD90099FF00FFE600FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00D9FF00CCFF00C0FF0099FF0000FF7380FF0099FF00A6FF008CFF00
59FF0026FF003FFF0059FF0080FF0073FF0059FF004CFF0059FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF008CFF0066FF0066FF003FFF0099FF0080FF0073FF003FFF00B3FF00
CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF0080FF0066FF00A6FF0080FF0080FF00\
A6FF0099FF0000FF59B3FF00CCFF00D9FF00F3FF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFD900FFE600A6FF00FFFF00FFE600FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00E6FF00D9FF00C0FF0073FF008CFF0000FF5980FF0080FF0059FF00
3FFF0000FF194CFF008CFF0099FF0099FF0099FF0073FF004CFF0080FF008CFF0073FF0059FF00\
8CFF008CFF0000FF008CFF00A6FF00B3FF00B3FF00A6FF00B3FF0099FF00C0FF00
D9FF00D9FF00D9FF00E6FF00D9FF00D9FF00CCFF00C0FF0099FF0066FF00C0FF00C0FF00C0FF00\
C0FF00A6FF0000FF268CFF00A6FF00B3FF00E6FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFD900FFF30000FF19CCFF00A6FF00FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00E6FF00D9FF00CCFF00B3FF00A6FF0080FF0026FF0080FF008CFF00
80FF0000FF4C73FF00A6FF00B3FF00B3FF00A6FF0073FF0059FF003FFF0066FF0019FF0000FF00\
19FF0033FF0059FF0099FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF0073FF00C0FF00CCFF00D9FF00D9FF00\
D9FF00C0FF0073FF004CFF0066FF00C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFFF00C0FF00E6FF00FFF300FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00E6FF00E6FF00D9FF00CCFF00C0FF0099FF0059FF0059FF0099FF00A6FF00
A6FF0099FF0073FF00B3FF00C0FF00C0FF00B3FF00A6FF008CFF0033FF0080FF0073FF0059FF00\
80FF0066FF0000FF0099FF00B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00F3FF00E6FF00E6FF00E6FF00CCFF004CFF00C0FF00D9FF00E6FF00E6FF00\
E6FF00CCFF00C0FF00CCFF0080FF0059FF00CCFF00E6FF00E6FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFFF00D9FF0080FF00FFFF00FFF300FFE600FFE600\
FFE600FFD900FFD900FFD900FFE600FFE600FFE600FFFF00FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF0000FF008CFF00B3FF00B3FF00
C0FF00C0FF00B3FF00C0FF00CCFF00CCFF00C0FF00C0FF00A6FF0000FF00A6FF00A6FF00A6FF00\
A6FF008CFF0000FF1999FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00A6FF00B3FF00E6FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00D9FF00C0FF0099FF00CCFF00D9FF00E6FF00E6FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFE600FFE600FFF300F3FF0059FF00FFFF00FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300A6FF00FFF300FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00D9FF00CCFF00CCFF00C0FF00A6FF0059FF0099FF00B3FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00A6FF008CFF00B3FF00C0FF00C0FF00\
B3FF008CFF004CFF008CFF00B3FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF0080FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00CCFF0066FF0033FF00C0FF00CCFF00B3FF00
D9FF00F3FF00F3FF00F3FF00F3FF00F3FF00CCFF00FFFF00FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFF300FFF300F3FF0073FF00E6FF00FFFF00FFF300FFF300\
FFF300FFF300FFE600FFE600FFF300FFF300F3FF0080FF00E6FF00FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00CCFF00CCFF00C0FF00A6FF0000FF00A6FF00B3FF00C0FF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF0026FF0099FF00C0FF00CCFF00CCFF00\
C0FF0000FF198CFF0033FF0099FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00CCFF0019FF008CFF0099FF00A6FF00
D9FF00E6FF00E6FF00E6FF00E6FF00C0FF00D9FF00FFFF00FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900\
FFE600FFD900FFD900FFD900FFCC00FFD900FFD900FFD900FFD900FFE600FFD900
FFD900FFE600FFE600FFE600FFE600FFF300FFFF00D9FF00A6FF00B3FF00E6FF00F3FF00F3FF00\
CCFF00FFFF00FFF300FFF300FFF300FFFF00F3FF0073FF00F3FF00FFFF00FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFFF00CCFF00F3FF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00C0FF00D9FF00D9FF00D9FF00\
59FF00C0FF00C0FF00C0FF004CFF0059FF004CFF00B3FF00C0FF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00D9FF00D9FF00D9FF00\
CCFF00C0FF00B3FF0059FF00B3FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00D9FF0099FF008CFF008CFF0066FF00
C0FF00D9FF00D9FF00D9FF00CCFF0033FF00E6FF00F3FF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFCC00FFD900FFD900FFD900FFE600\
CCFF00FFE600FFE600FFE600FFD900FFD900FFD900FFE600FFF300E6FF00FFF300
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00C0FF008CFF00D9FF00E6FF00D9FF00\
CCFF00F3FF00FFFF00FFFF00FFFF00F3FF00E6FF0073FF00E6FF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFFF00D9FF00D9FF00E6FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00CCFF00A6FF00C0FF00C0FF00\
99FF00A6FF00B3FF00A6FF008CFF0000FF1999FF00B3FF00C0FF00CCFF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00CCFF00A6FF00B3FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00F3FF00C0FF00D9FF00CCFF00A6FF0080FF00
B3FF00B3FF008CFF00C0FF0066FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFFF00FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFC000C0FF00CCFF00C0FF00FFFF00FFFF00F3FF00\
80FF00D9FF00E6FF00FFFF00FFF300FFE600FFF300FFF300FFFF0099FF00FFFF00
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00C0FF0073FF0073FF00C0FF0099FF00\
CCFF00E6FF00F3FF00F3FF00F3FF00E6FF00D9FF0033FF00D9FF00E6FF00F3FF00
FFFF00FFFF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFFF00F3FF00CCFF0059FF00D9FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF0099FF008CFF00A6FF00\
8CFF0073FF008CFF0066FF0073FF0000FF008CFF00B3FF00CCFF00CCFF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF0059FF008CFF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00C0FF008CFF00
0CFF0080FF0073FF004CFF0080FF00C0FF00D9FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00E6FF0026FF00FFFF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000FFD900FFD900CCFF00CCFF00E6FF00\
F3FF00CCFF00E6FF00CCFF00E6FF00F3FF00E6FF00FFFF00F3FF0000FF19E6FF00
FFFF00FFFF00FFFF00E6FF00E6FF00E6FF00E6FF00D9FF00A6FF00B3FF00C0FF0073FF008CFF00\
8CFF00D9FF00E6FF00D9FF00CCFF00D9FF00CCFF0000FF59B3FF00B3FF00E6FF00
F3FF00E6FF0099FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00F3FF00E6FF0073FF00B3FF00E6FF00F3FF00F3FF00
F3FF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF008CFF0059FF003FFF00\
66FF004CFF0059FF0033FF0026FF0066FF0099FF00B3FF00CCFF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00D9FF00C0FF0073FF00B3FF00CCFF00E6FF00F3FF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00D9FF0073FF00
C0FF0080FF00B3FF00A6FF0073FF0000FF0CCCFF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
E6FF0066FF0080FF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFF300FFF300\
FFE600FFF300FFF300FFF300FFFF00CCFF0080FF00C0FF00C0FF0066FF00A6FF00
D9FF00F3FF00E6FF00C0FF00B3FF003FFF00C0FF0099FF00C0FF00D9FF00D9FF00D9FF00C0FF00\
80FF00C0FF00CCFF00A6FF008CFF00A6FF0019FF00B3FF0000FF0059FF00CCFF00
CCFF00CCFF0099FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00C0FF000CFF00D9FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF0099FF0073FF00\
66FF0019FF0000FF7300FF1966FF008CFF00A6FF00B3FF00CCFF00D9FF00D9FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00CCFF00A6FF0080FF00CCFF00E6FF00F3FF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00C0FF00CCFF00
D9FF00D9FF00CCFF00C0FF0059FF00A6FF00CCFF00D9FF00D9FF00B3FF00CCFF00D9FF00CCFF00\
00FFFFE6FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFF300E6FF00D9FF00D9FF00E6FF0080FF00
C0FF00CCFF00CCFF0019FF00CCFF0080FF00C0FF0080FF00D9FF00F3FF00F3FF00E6FF00CCFF00\
99FF004CFF0066FF00B3FF00B3FF00A6FF00C0FF00D9FF00CCFF0059FF0099FF00
19FF0080FF0066FF00B3FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00FFFF00\
FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00C0FF00A6FF00CCFF00D9FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF0099FF00\
73FF0000FF808000FF00FF0C66FF0080FF008CFF00B3FF00C0FF00CCFF00D9FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00E6FF00D9FF00C0FF0059FF00A6FF00CCFF00E6FF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00F3FF0099FF00E6FF00
F3FF00E6FF00E6FF00CCFF0033FF008CFF008CFF00C0FF00C0FF00A6FF0066FF00B3FF0066FF00\
80FF00F3FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFE600D9FF00FFFF00FFFF00FFFF00CCFF00
C0FF003FFF0073FF00D9FF00E6FF00E6FF00E6FF0099FF00F3FF00FFFF00FFFF00F3FF00B3FF00\
D9FF00C0FF0080FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00CCFF0073FF00
C0FF00C0FF00C0FF0000FF0C80FF00C0FF00E6FF00F3FF00F3FF00F3FF00E6FF00A6FF00E6FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00A6FF0033FF0073FF00CCFF00D9FF00
CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF0080FF00\
26FF0000FF0033FF003FFF0000FF400CFF000CFF008CFF0000FF0CCCFF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00E6FF008CFF00C0FF0080FF00CCFF00F3FF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00FFFF00
FFFF00F3FF00F3FF0066FF00C0FF0059FF0019FF003FFF008CFF0000FF66B3FF0099FF0073FF00\
C0FF00E6FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFF300FFE600FFE600FFF300F3FF00
F3FF00CCFF00A6FF00E6FF00F3FF00FFFF00FFFF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00CCFF0073FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00B3FF00
E6FF00E6FF00E6FF00C0FF00D9FF00CCFF008CFF00CCFF00C0FF00D9FF00CCFF0080FF00D9FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF0019FF00A6FF00C0FF00C0FF00
73FF00CCFF00D9FF00D9FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF008CFF0033FF00\
66FF0066FF0080FF0066FF0073FF008CFF0080FF0026FF00B3FF00D9FF00E6FF00
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00E6FF00E6FF00C0FF00D9FF00F3FF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00E6FF00C0FF0000FF0CC0FF00B3FF0080FF00CCFF00CCFF00B3FF00\
80FF00D9FF00F3FF00FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300
FFFF00D9FF00A6FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
F3FF00D9FF00CCFF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00A6FF00
F3FF00FFFF00F3FF00F3FF00F3FF00F3FF00D9FF00A6FF0080FF008CFF00A6FF0080FF00B3FF00\
D9FF00D9FF00CCFF00B3FF00C0FF00C0FF00A6FF004CFF0073FF008CFF0099FF00
99FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF0019FF00\
8CFF0099FF00A6FF0099FF008CFF00B3FF00B3FF003FFF008CFF00D9FF00E6FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00CCFF00FFFF00FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFFF00FFFF00E6FF00CCFF008CFF00D9FF00E6FF00C0FF00E6FF00E6FF0099FF00\
8CFF00C0FF00D9FF0099FF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600
FFF300E6FF00E6FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFFF00D9FF00B3FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFFF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF0099FF00B3FF0099FF0099FF008CFF00\
C0FF00C0FF00A6FF0073FF0080FF0080FF0080FF0099FF008CFF003FFF0026FF00
99FF00B3FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00A6FF0059FF0066FF00\
8CFF00B3FF00C0FF00B3FF000CFF00C0FF00CCFF00CCFF00A6FF00C0FF00E6FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00CCFF00FFFF00FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFFF00F3FF00B3FF00D9FF00F3FF00F3FF00F3FF00F3FF00F3FF00D9FF00\
8CFF0099FF0080FF00F3FF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600
FFF300A6FF00F3FF00FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300D9FF00CCFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF008CFF00D9FF00D9FF00B3FF0066FF00\
80FF0099FF0000FF2680FF0059FF008CFF00B3FF00C0FF00B3FF00A6FF0080FF00
73FF00A6FF00C0FF00C0FF00B3FF00C0FF00C0FF00C0FF00B3FF00A6FF0073FF008CFF00B3FF00\
B3FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00E6FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFFF00F3FF0059FF00E6FF00FFFF00FFFF00FFFF00FFFF00FFFF00A6FF00\
E6FF00E6FF0000FF33B3FF00FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600
FFFF0080FF00A6FF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFF300F3FF00F3FF00FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00F3FF00F3FF00E6FF0099FF00C0FF00\
8CFF0099FF00C0FF00B3FF00A6FF008CFF00CCFF00CCFF00CCFF00B3FF0080FF00
66FF0099FF00A6FF0099FF000CFF00A6FF00B3FF00B3FF00A6FF003FFF0073FF00B3FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFF30099FF008CFF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00F3FF00B3FF00F3FF00FFFF00FFE600FFE600FFD900FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900
FFFF0099FF00FFFF00FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00\
8CFF00B3FF00CCFF00D9FF00CCFF00CCFF00D9FF00D9FF00CCFF00B3FF0099FF00
59FF0066FF0080FF0026FF0026FF0073FF0099FF0099FF004CFF0000FF1999FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFF300FFFF0000FF26FFFF00FFF300FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300F3FF0099FF00D9FF00FFFF00FFFF00FFD900FFD900FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900
FFF300E6FF00FFFF00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00D9FF00\
8CFF00CCFF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00
8CFF004CFF0099FF008CFF0033FF004CFF004CFF0019FF003FFF008CFF00A6FF00C0FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFF300FFFF00FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300E6FF0073FF0026FF00FFFF00FFE600FFD900FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFD900
CCFF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00CCFF00\
B3FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00
8CFF0099FF00B3FF00B3FF0026FF008CFF0099FF008CFF003FFF0059FF00A6FF00C0FF00CCFF00\
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFFF00F3FF00CCFF00CCFF00FFE600FFD900FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300F3FF0073FF00\
CCFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00B3FF00
99FF00C0FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0073FF0059FF0080FF00A6FF00CCFF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFFF00E6FF00FFD900FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFFF0066FF00\
C0FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00D9FF0019FF00
C0FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF0000FF5959FF00A6FF00C0FF00CCFF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00A6FF00
D9FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF0026FF008CFF00B3FF00C0FF00CCFF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00C0FF0099FF0033FF0066FF0080FF00C0FF00CCFF00\
D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00E6FF00D9FF008CFF00A6FF00A6FF0059FF0073FF00A6FF00A6FF00\
C0FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF00A6FF0073FF008CFF00B3FF00\
CCFF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00A6FF0059FF00B3FF00CCFF00\
D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00B3FF0066FF0099FF00D9FF00\
E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00C0FF0073FF00C0FF00D9FF00\
E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00C0FF0080FF00CCFF00D9FF00\
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00B3FF0059FF00C0FF00D9FF00\
E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00C0FF0073FF008CFF00C0FF00D9FF00\
E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00B3FF003FFF0080FF00A6FF00\
D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00C0FF0073FF0066FF00B3FF00CCFF00\
D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFFF00FFFF00F3FF00CCFF0099FF0099FF0059FF0099FF00B3FF00CCFF00\
D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF00CCFF00C0FF00A6FF0059FF0073FF00C0FF00\
CCFF00D9FF00E6FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00A6FF0019FF008CFF00B3FF00\
C0FF00C0FF00C0FF00D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF0099FF0033FF0073FF00\
73FF0080FF00C0FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00C0FF00B3FF0099FF0000FF1999FF00\
B3FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300
FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00C0FF0000FF3380FF0019FF0000FF26A6FF00\
C0FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300
FFF300FFFF00F3FF00E6FF00E6FF00D9FF00D9FF00C0FF00A6FF0059FF008CFF00A6FF00B3FF00\
CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300
FFFF00D9FF00D9FF00B3FF0099FF00CCFF00C0FF00B3FF0099FF0000FFE68CFF00B3FF00C0FF00\
CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300
FFFF00E6FF0099FF00A6FF0099FF0033FF008CFF003FFF0073FF0073FF00A6FF00B3FF00C0FF00\
CCFF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300
FFFF00F3FF00E6FF00D9FF00CCFF00C0FF008CFF008CFF0080FF0059FF0099FF00B3FF00C0FF00\
C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00C0FF00
D9FF00E6FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300
FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00C0FF00B3FF00A6FF0066FF0099FF00A6FF00B3FF00\
C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00D9FF00CCFF0000FF00
CCFF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300
FFFF00FFFF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF004CFF0066FF008CFF00A6FF00\
3FFF00A6FF008CFF00C0FF00CCFF00D9FF00D9FF00D9FF00CCFF00A6FF00A6FF00
D9FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00
FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF0073FF004CFF0080FF0080FF00\
00FF194CFF008CFF00B3FF00C0FF00CCFF00CCFF00C0FF00A6FF00A6FF00D9FF00
E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00
FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF00B3FF008CFF004CFF003FFF003FFF004CFF00\
00FF2666FF008CFF00A6FF00B3FF00C0FF00B3FF00A6FF0026FF00C0FF00D9FF00
E6FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00FFFF00
F3FF00E6FF00E6FF00E6FF00D9FF00CCFF0033FF008CFF008CFF0066FF0000B3FF00FF2600FF66\
00FF2600FF0073FF0059FF0099FF00A6FF00A6FF0066FF0066FF00C0FF00D9FF00
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFE600FFE600FFF300FFFF00FFFF00FFFF00F3FF00F3FF00
99FF00D9FF00D9FF00D9FF00D9FF00CCFF00B3FF0033FF0066FF0000FF9900FF59000000000000\
00000000FF8026FF000CFF0059FF0000FF263FFF004CFF0073FF00A6FF0073FF00
D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFE600FFE600FFF300FFFF00CCFF00E6FF00E6FF00E6FF00D9FF00
C0FF00B3FF00CCFF00CCFF00CCFF00C0FF008CFF0019FF0026FF0000FF80000000000000000000\
00000000FF403FFF0066FF0073FF008CFF0099FF0099FF0059FF0059FF00A6FF00
C0FF00CCFF003FFF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFE600FFF30000FF598CFF00A6FF008CFF008CFF00B3FF00C0FF00
A6FF0073FF0073FF00C0FF00C0FF00B3FF00A6FF0080FF0000FFE600FFB3000000000000000000\
0000FF00FF3300FF4073FF0099FF00A6FF00B3FF00B3FF00B3FF0080FF0080FF00
8CFF0066FF0099FF00D9FF00F3FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFE600FFE600FFF300F3FF00F3FF00F3FF00E6FF00CCFF0066FF00
99FF0099FF0080FF0099FF00A6FF00A6FF0000FF8073FF004CFF0000FFE600D9FF000000000000\
00000000FF6626FF0073FF008CFF00B3FF00C0FF00C0FF00C0FF00A6FF0080FF00
A6FF00C0FF0059FF0066FF00C0FF0080FF00D9FF00F3FF00FFF300FFE600FFE600FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFE600FFE600FFF300FFFF00FFFF00F3FF00E6FF00CCFF00
D9FF00B3FF008CFF0000FF0080FF0059FF000CFF0033FF004CFF003FFF0000FFBF00FF593F00FF\
00000000FF8C19FF0000FF268CFF00C0FF00CCFF00CCFF00CCFF00CCFF00B3FF00
CCFF00D9FF00E6FF00E6FF00C0FF0080FF00B3FF00C0FF00CCFF00FFF300FFE600FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00
E6FF00CCFF00C0FF0099FF0073FF00A6FF00A6FF008CFF0080FF0073FF004CFF000CFF0000FF00\
00FF4C00FF4066FF0066FF0073FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00
CCFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00
F3FF00E6FF00CCFF008CFF00A6FF00C0FF00C0FF00B3FF00A6FF0080FF004CFF004CFF0059FF00\
00FF2600FF0C80FF00A6FF00B3FF00C0FF00D9FF00E6FF00E6FF00E6FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00
F3FF00E6FF00C0FF0099FF00C0FF00CCFF00CCFF00CCFF00B3FF003FFF0080FF0073FF008CFF00\
73FF0000FF0C80FF00A6FF00C0FF00D9FF00D9FF00E6FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00
F3FF00C0FF0019FF00CCFF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF00B3FF00A6FF00A6FF00\
73FF0000FF2699FF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFFF00
F3FF00A6FF00CCFF00D9FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00C0FF00B3FF00\
A6FF0073FF0099FF00B3FF00CCFF00D9FF00D9FF00E6FF00F3FF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300
E6FF00E6FF00E6FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00\
A6FF0066FF0073FF0080FF00B3FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF00\
A6FF0080FF0073FF0033FF0066FF00B3FF00C0FF00D9FF00E6FF00F3FF00FFFF00
FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300
FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF00\
99FF0000FF1999FF00A6FF00C0FF00B3FF0080FF008CFF00C0FF00F3FF00FFFF00
FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00A6FF008CFF00\
80FF0059FF00B3FF00CCFF00D9FF00D9FF00D9FF00C0FF00E6FF00E6FF00FFF300
FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00C0FF00A6FF003FFF00\
80FF0099FF0026FF00CCFF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300
FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF0073FF0000FF0C66FF0066FF00\
A6FF00C0FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00D9FF00CCFF00C0FF00B3FF004CFF00\
8CFF00C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00D9FF00C0FF008CFF00\
3FFF00C0FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF00\
66FF000CFF008CFF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00B3FF0080FF00\
59FF00C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00C0FF0080FF00\
B3FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF0073FF00\
A6FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF0059FF00\
CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00A6FF00A6FF00\
D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00CCFF0099FF0099FF00\
CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00C0FF00A6FF0000FF0CB3FF00\
CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00B3FF0059FF0000FF40\
C0FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00C0FF00A6FF0000FF26\
3FFF0099FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00B3FF008CFF0019FF00\
B3FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00B3FF0073FF008CFF00\
B3FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00FFFF00FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00A6FF0080FF008CFF00\
B3FF00C0FF00CCFF00D9FF00D9FF00CCFF0073FF00E6FF00FFFF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300F3FF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00CCFF00C0FF00B3FF0080FF000CFF0073FF00\
80FF0080FF00A6FF00C0FF00C0FF008CFF00C0FF00E6FF00F3FF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFE600FFFF00FFFF00FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300F3FF00D9FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00E6FF0066FF00CCFF00CCFF00CCFF0033FF00A6FF0000FF3380FF00A6FF00B3FF00B3FF00\
80FF0000FF8C33FF0099FF0019FF00C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00CCFF00FFFF00FFF300\
FFE600FFE600FFF300FFF300F3FF00CCFF00FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00B3FF004CFF00\
A6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00E6FF00CCFF0000FF0073FF00B3FF0080FF0073FF008CFF00C0FF00CCFF00CCFF00C0FF00\
A6FF00B3FF00A6FF0080FF0099FF00C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFE600FFFF00D9FF00\
B3FF00D9FF00FFFF00FFFF00E6FF00C0FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFF300FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00E6FF00C0FF00\
A6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00D9FF00CCFF0099FF0019FF008CFF003FFF00A6FF00C0FF00CCFF00D9FF00D9FF00D9FF00\
CCFF00CCFF00B3FF0099FF0033FF0080FF00D9FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00E6FF0066FF00E6FF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600\
A6FF00C0FF00D9FF0019FF008CFF0080FF00B3FF00E6FF00D9FF00E6FF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00D9FF00\
80FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00CCFF00B3FF008CFF0000FF7326FF0073FF00B3FF00CCFF00D9FF00D9FF00E6FF00D9FF00\
D9FF00CCFF00C0FF0073FF008CFF00B3FF00CCFF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00C0FF0080FF00F3FF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900\
FFF300F3FF00B3FF00D9FF00E6FF00D9FF0000FF0C73FF008CFF00B3FF00E6FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00\
73FF00C0FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00CCFF00A6FF0026FF000CFF0059FF0099FF0099FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00C0FF0000FF8C66FF0099FF00C0FF00C0FF00C0FF0066FF00CCFF00
CCFF00A6FF00C0FF00E6FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900\
FFE600E6FF00F3FF00FFFF00FFFF00F3FF0033FF00D9FF00D9FF0000FF0C3FFF00
E6FF00F3FF00F3FF00F3FF00F3FF00D9FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00\
A6FF004CFF00C0FF00CCFF0099FF00CCFF00D9FF00E6FF00E6FF00E6FF00D9FF00
D9FF00C0FF00A6FF0026FF008CFF0059FF00B3FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
E6FF00D9FF008CFF00C0FF00A6FF0019FF008CFF0080FF0080FF004CFF0066FF00
99FF0073FF00D9FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900\
FFD900FFFF00FFF300FFF300FFF300FFFF00CCFF00F3FF00F3FF00D9FF00CCFF00
33FF00D9FF00D9FF00E6FF00D9FF008CFF00E6FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00\
A6FF0066FF00A6FF00B3FF0066FF00C0FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF0080FF0080FF008CFF00B3FF00B3FF00B3FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00D9FF00B3FF0000FF26B3FF00A6FF003FFF008CFF00C0FF00
A6FF000CFF00CCFF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00
D9FF0073FF00B3FF00CCFF00C0FF00A6FF00D9FF00E6FF00E6FF00D9FF00C0FF00CCFF00B3FF00\
8CFF008CFF0000FF0066FF0080FF00B3FF00CCFF00CCFF00CCFF00CCFF00C0FF00
B3FF003FFF00A6FF008CFF00CCFF00D9FF00C0FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00E6FF00C0FF0080FF00CCFF00D9FF00CCFF00D9FF00D9FF00
C0FF0080FF00C0FF00E6FF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00
F3FF00D9FF0059FF0066FF0073FF003FFF0099FF00CCFF00D9FF00CCFF0080FF008CFF0066FF00\
A6FF00C0FF00B3FF00A6FF0019FF00A6FF00B3FF00B3FF00A6FF00B3FF00A6FF00
73FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00E6FF00A6FF00CCFF00E6FF00E6FF00E6FF00E6FF00E6FF00
CCFF0059FF00B3FF00CCFF00CCFF00F3FF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300
FFFF00D9FF00CCFF00CCFF00C0FF0073FF00A6FF00C0FF00C0FF00A6FF0059FF004CFF008CFF00\
C0FF00CCFF00CCFF00B3FF0080FF003FFF008CFF000CFF0000FF3359FF0026FF00
A6FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFFF00FFFF00FFFF00E6FF008CFF00D9FF00F3FF00F3FF00F3FF00F3FF00F3FF00
CCFF0099FF008CFF008CFF00CCFF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300
FFFF00F3FF00E6FF00E6FF00D9FF0059FF0073FF008CFF0080FF0080FF00A6FF00A6FF00CCFF00\
D9FF00D9FF00D9FF00CCFF00C0FF004CFF00A6FF00B3FF00B3FF00B3FF008CFF00
80FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00E6FF0033FF00E6FF00FFFF00FFFF00FFFF00FFFF00F3FF00
C0FF00E6FF00D9FF00A6FF00B3FF00E6FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300
FFF300FFFF00FFFF00F3FF00E6FF00CCFF00C0FF008CFF00A6FF00C0FF00CCFF00D9FF00D9FF00\
E6FF00E6FF00E6FF00D9FF00CCFF0033FF00CCFF00CCFF00CCFF00CCFF0080FF00
99FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF0059FF00FFFF00FFFF00FFF300FFF300FFF300FFFF00
FFFF00FFFF00F3FF00E6FF00A6FF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFF300FFF300FFFF00FFFF00F3FF00E6FF00C0FF0066FF00B3FF00D9FF00D9FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00E6FF00D9FF0073FF00D9FF00E6FF00E6FF00D9FF008CFF00
3FFF004CFF00CCFF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00F3FF00D9FF00A6FF00E6FF00F3FF00FFFF00FFF300FFF300FFF300FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF0080FF00CCFF00D9FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF0066FF00E6FF00F3FF00F3FF00E6FF00D9FF00
C0FF00A6FF00E6FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFFF00E6FF004CFF0099FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600
FFF300FFF300FFF300FFFF00F3FF00E6FF00C0FF00A6FF00D9FF00E6FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00FFFF00FFFF00FFFF00F3FF00F3FF00
D9FF0099FF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFFF00F3FF00D9FF008CFF00CCFF00E6FF00E6FF00A6FF00FFFF00FFF300\
FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFF300FFF300FFFF00F3FF00D9FF00A6FF00B3FF00D9FF00E6FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
E6FF0099FF00CCFF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFF300FFFF00D9FF0080FF0080FF00A6FF0066FF00D9FF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600
FFF300FFF300FFFF00FFFF00E6FF00C0FF0000FF0CA6FF00D9FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
F3FF0080FF0099FF0073FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFF300FFFF00C0FF00E6FF00D9FF00B3FF00A6FF00D9FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00E6FF00CCFF00FFE600FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600
FFF300FFF300FFFF00F3FF00E6FF00C0FF0066FF00C0FF00D9FF00F3FF00F3FF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00E6FF0026FF00D9FF00F3FF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00E6FF00A6FF00B3FF00D9FF00E6FF00F3FF00\
F3FF00FFFF00F3FF00E6FF008CFF00FFFF00FFE600FFE600FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFF300FFF300FFFF00F3FF00E6FF00CCFF008CFF00B3FF00CCFF00F3FF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300F3FF003FFF0073FF00C0FF00F3FF00FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00CCFF003FFF00CCFF00D9FF00CCFF00\
D9FF00E6FF00D9FF0099FF00E6FF00FFFF00FFE600FFE600FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFF300FFFF00F3FF00E6FF00CCFF00A6FF0080FF00A6FF00CCFF00F3FF00FFFF00FFFF00FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFFF00FFFF00D9FF00E6FF00FFF300FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFF300F3FF00B3FF0066FF0073FF0099FF0066FF00\
00FF26C0FF0073FF00D9FF00F3FF00FFF300FFF300FFE600FFE600FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300
FFF300CCFF0066FF00C0FF00B3FF008CFF0099FF00C0FF00E6FF00F3FF00FFFF00FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFFF00E6FF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFE600FFE600FFF300F3FF00A6FF00D9FF00E6FF00A6FF00CCFF00\
CCFF0099FF00B3FF00E6FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300
FFF300F3FF00E6FF00C0FF0073FF0000FF8C73FF0099FF00E6FF00F3FF00FFFF00FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600E6FF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFF3008CFF00E6FF00FFFF00F3FF00F3FF00E6FF00\
D9FF00B3FF0099FF00C0FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300
FFF300FFFF00F3FF00CCFF00A6FF0000FF408CFF0066FF00CCFF00F3FF00FFFF00FFF300FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFFF00F3FF00FFFF00FFF300FFF300FFFF00F3FF00\
D9FF0073FF008CFF00D9FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFE600FFD900FFCC00FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300
FFF300FFFF00F3FF00D9FF0080FF0059FF00B3FF00CCFF00C0FF0059FF00FFFF00FFF300FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300F3FF00\
D9FF0080FF00C0FF00D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFFF00C0FF0073FF00F3FF00FFCC00FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300
FFFF00FFFF00D9FF00A6FF0026FF00C0FF00D9FF00E6FF00F3FF00FFFF00FFF300FFF300FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300E6FF00\
D9FF00CCFF0026FF00C0FF00E6FF00F3FF00F3FF00F3FF00CCFF00F3FF00FFFF00
FFFF00FFFF00F3FF003FFF00C0FF00FFF300FFD900FFCC00FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFFF00FFFF00E6FF00D9FF0099FF00C0FF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300\
F3FF00E6FF00C0FF0099FF00CCFF00D9FF00D9FF00C0FF0066FF0080FF00F3FF00
E6FF00CCFF0099FF00A6FF00FFF300FFE600FFD900FFCC00FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00
FFFF00F3FF00E6FF00CCFF0073FF00B3FF0059FF00FFFF00FFFF00FFF300FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300\
FFFF00D9FF0059FF00C0FF00CCFF0080FF0099FF0080FF00CCFF00A6FF00C0FF00
00FF00C0FF00FFFF00FFF300FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00F3FF00E6FF00CCFF004CFF00D9FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600\
FFFF00E6FF0080FF00E6FF00F3FF00E6FF00C0FF00E6FF00E6FF00E6FF00CCFF00
C0FF00E6FF00FFFF00FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFFF00\
D9FF00B3FF00FFFF00FFFF00FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00E6FF00C0FF00C0FF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600\
FFFF004CFF00F3FF00FFFF00FFF300FFFF00FFFF00FFFF00FFFF00F3FF00D9FF00
A6FF00D9FF00FFFF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFF300\
E6FF00C0FF00A6FF00F3FF00FFFF00FFFF00F3FF00C0FF00F3FF00F3FF00F3FF00
E6FF00E6FF00CCFF008CFF00CCFF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFF300\
E6FF00E6FF00FFFF00FFF300FFF300FFE600FFF300FFF300FFF300F3FF00CCFF00
80FF00D9FF00FFFF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600\
FFF300F3FF00D9FF00C0FF00D9FF00E6FF00D9FF0080FF00D9FF00E6FF00E6FF00
CCFF00CCFF00B3FF003FFF00C0FF00D9FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900E6FF00\
8CFF00F3FF00FFF300FFE600FFE600FFE600FFE600FFE600FFF300FFFF00D9FF00
A6FF00E6FF00FFFF00FFF300FFE600FFD900FFCC00FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600\
FFF300FFFF00F3FF0099FF0080FF00C0FF00C0FF0080FF00A6FF00CCFF00CCFF00
A6FF0066FF00B3FF00B3FF0073FF00CCFF00E6FF00F3FF00FFF300FFF300FFE600FFE600FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFF300\
A6FF00FFFF00FFE600FFD900FFD900FFD900FFD900FFE600FFE600FFFF0099FF00
C0FF008CFF00E6FF00F3FF00CCFF00FFD900FFCC00FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600\
FFF300FFF300FFFF00E6FF00C0FF0080FF004CFF00C0FF000CFF008CFF0099FF00
B3FF00A6FF00D9FF00D9FF0099FF00B3FF00CCFF00A6FF00FFFF00FFF300FFE600FFE600FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFD900F3FF00\
FFF300FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600D9FF00F3FF00
FFFF00E6FF0026FF00F3FF00FFE600FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600\
FFF300FFF300FFFF00E6FF00C0FF00C0FF00D9FF00D9FF000CFF00C0FF0099FF00
D9FF00E6FF00F3FF00E6FF008CFF00CCFF00A6FF00D9FF00FFFF00FFF300FFE600FFE600FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600
FFF300F3FF00A6FF00FFFF00FFE600FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600\
FFF300FFFF00F3FF00D9FF004CFF00D9FF00E6FF00F3FF00E6FF00E6FF004CFF00
E6FF00F3FF00FFFF00FFFF00E6FF00F3FF00D9FF008CFF00F3FF00FFF300FFF300FFE600FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFE600FFF300E6FF00F3FF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300\
FFF300FFFF00E6FF008CFF0059FF00E6FF00F3FF00FFFF00FFFF00F3FF00C0FF00
E6FF00FFFF00FFF300FFF300FFF300FFFF00FFFF00CCFF00D9FF00F3FF00FFF300FFE600FFE600\
FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFE600FFFF00F3FF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFF300FFFF00\
FFFF00F3FF00E6FF0066FF00A6FF00F3FF00FFFF00FFF300FFF300FFF300FFFF00
FFFF00FFF300FFE600FFE600FFE600FFF300FFF300F3FF0080FF00E6FF00E6FF00FFF300FFE600\
FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFD900FFF300B3FF00FFFF00FFE600FFD900FFCC00FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600F3FF00CCFF00F3FF00\
F3FF00E6FF00D9FF008CFF00E6FF00FFFF00FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFFF00D9FF00C0FF00D9FF00FFFF00FFF300\
FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFD900FFF300F3FF00CCFF00FFF300FFD900FFCC00FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00D9FF00B3FF00\
B3FF00CCFF00A6FF00D9FF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFFF00B3FF00CCFF00E6FF00FFFF00\
73FF00FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFD900FFFF00C0FF00B3FF00FFFF00FFF300FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00D9FF00C0FF00\
33FF00B3FF00CCFF00A6FF00F3FF00FFF300FFF300FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFF300E6FF00E6FF00D9FF00A6FF00\
FFF300FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFCC00FFD900E6FF00FFF300E6FF00FFFF00FFD900FFC000FFC000FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00A6FF00D9FF0073FF00E6FF00\
E6FF00D9FF00F3FF00E6FF00E6FF00FFFF00FFE600FFE600FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600D9FF00FFF300FFFF00A6FF00\
FFF300FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFCC00FFD900FFD900F3FF00C0FF00FFD900FFC000FFC000FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFFF00FFFF00FFF300FFF300E6FF00F3FF00F3FF00D9FF0080FF0080FF008CFF00F3FF00\
FFFF00FFF300FFF300FFFF00B3FF00F3FF00FFE600FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFFF00\
FFF300FFD900FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFCC00FFCC00FFD90033FF00FFD900FFC000FFC000FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFFF00B3FF00F3FF00E6FF00D9FF00A6FF00D9FF00F3FF00D9FF00FFFF00E6FF00FFFF00\
FFE600FFE600FFE600FFE600FFFF008CFF00FFE600FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFE600\
A6FF00FFD900FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFCC00FFF300FFE600FFC000FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFCC00CCFF00FFE600FFE600FFE600FFD900FFD900FFE600FFE600
FFF300FFFF00E6FF008CFF008CFF008CFF00E6FF00FFFF00FFF300FFF300FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFE600FFE600FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFE600FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFD900FFC000FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFCC00FFCC00FFE600B3FF0000FF0CFFF300FFE600FFE600FFF300FFF300
FFFF00FFFF00E6FF00B3FF00E6FF00E6FF00F3FF00FFF300FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFE600FFFF00C0FF0099FF00FFFF00FFFF00FFFF0026FF00
F3FF00E6FF00A6FF00CCFF00FFFF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFD900FFE600FFF300F3FF0080FF00B3FF00E6FF00B3FF00
99FF00CCFF00B3FF00F3FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF00D9FF0059FF0000FF0CC0FF00
C0FF00C0FF0073FF00E6FF00FFFF00FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300F3FF00CCFF00D9FF00E6FF00
E6FF00F3FF00F3FF0099FF00D9FF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFE600FFF300FFF300F3FF0059FF00E6FF00F3FF00
FFFF00FFFF00FFF300FFFF00F3FF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFE600FFE600FFF300FFFF00E6FF0080FF00F3FF00FFFF00
FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFE600FFE600FFF300FFF300F3FF008CFF008CFF00F3FF00FFF300
FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFE600\
FFF300FFF300FFF300FFF300FFF300FFFF00F3FF0099FF00D9FF00FFFF00FFF300
FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFCC00
FFCC00FFCC00FFD900FFFF00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
73FF00F3FF00FFFF00FFFF00FFFF00F3FF00E6FF008CFF00F3FF00FFFF00FFF300
FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFF300CCFF00
FFE600FFE600FFF3008CFF00FFF300FFE600FFE600FFD900FFD900FFD900FFE600FFE600FFF300\
F3FF0066FF00E6FF00E6FF00F3FF00E6FF00D9FF00C0FF00F3FF00FFFF00FFF300
FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFC000FFCC00FFD900
E6FF00D9FF00CCFF00C0FF00D9FF00E6FF00FFFF00FFF300FFE600FFE600FFF300FFF300FFFF00\
F3FF00CCFF00C0FF004CFF00D9FF00CCFF00B3FF00B3FF00E6FF00FFFF00FFF300
FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00
FFD900CCFF00FFF300FFFF0099FF00E6FF0033FF00F3FF00FFFF00FFFF00E6FF00FFFF00F3FF00\
E6FF00B3FF00C0FF00B3FF008CFF00B3FF00CCFF0099FF00A6FF00F3FF00FFF300
FFE600FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000
FFD900FFE600FFE600FFE600FFF300FFF300FFFF00E6FF0080FF00D9FF008CFF00E6FF00E6FF00\
80FF00CCFF00E6FF00E6FF00CCFF00D9FF00F3FF00D9FF00E6FF00C0FF00F3FF00
FFF300FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300CCFF00D9FF0099FF00B3FF008CFF00\
D9FF00F3FF00F3FF00FFFF00F3FF00E6FF00FFFF00FFF300FFFF00E6FF00B3FF00
E6FF00CCFF00FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000
FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600FFFF00FFFF00E6FF00CCFF00CCFF00\
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFF300F3FF00
F3FF0080FF00FFE600FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00E6FF00CCFF00\
F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600E6FF00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFFF00E6FF00C0FF00\
F3FF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300C0FF00C0FF00\
F3FF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300F3FF0099FF00\
F3FF00FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300F3FF00D9FF00\
FFFF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFFF00B3FF00CCFF00\
FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600FFF300E6FF0099FF00B3FF00\
CCFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFFF0080FF00CCFF00\
FFFF00FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300FFFF003FFF00F3FF00\
FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300D9FF00B3FF00F3FF00\
FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000
FFC000FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300F3FF0080FF00F3FF00\
FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFFF00F3FF008CFF00F3FF00\
FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000
FFD900E6FF00F3FF00FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF0059FF00E6FF00\
FFFF00FFF300FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000
FFCC00FFF300F3FF00A6FF00F3FF00F3FF00D9FF00E6FF00F3FF00D9FF0066FF00CCFF0099FF00\
E6FF00E6FF00FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFCC00FFD900FFE600FFFF00CCFF00C0FF004CFF004CFF00C0FF00CCFF00F3FF00F3FF0026FF00\
D9FF00E6FF00FFF300FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFCC00FFD900FFE600FFF300F3FF00CCFF00E6FF00C0FF00A6FF00E6FF00FFFF00FFF300FFFF00\
FFFF00E6FF00F3FF00FFF300FFE600FFD900FFCC00FFCC00FFC000FFC000FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFCC00
FFCC00FFD900FFE600FFF300F3FF00E6FF00FFFF00FFF300FFFF00D9FF00FFE600FFE600FFE600\
FFE600FFF300B3FF00E6FF00F3FF00FFE600FFD900FFCC00FFC000FFC000FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00
FFD900FFE600FFE600FFFF0099FF00FFFF00FFF300FFE600FFE600FFF300FFD900FFD900FFD900\
FFD900FFE600FFFF00E6FF00E6FF00FFFF00D9FF00FFD900FFC000FFC000FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00\
FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00FF8C00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00A6FF008CFF004CFF004CFF004CFF00\
00FF1973FF008CFF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00D9FF00
B3FF00CCFF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0073FF004CFF0000FF0C\
59FF0080FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00B3FF00A6FF004CFF00
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00
A6FF0099FF00C0FF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF008CFF0073FF004CFF00\
4CFF0073FF0080FF0080FF008CFF00A6FF00A6FF00B3FF00A6FF0066FF00A6FF00
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00
C0FF0066FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF0073FF004CFF00\
26FF0059FF0059FF000CFF0080FF0099FF0099FF0099FF0080FF0000FF00B3FF00
C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFFF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00
C0FF0066FF0059FF0099FF008CFF0099FF00A6FF00A6FF0099FF004CFF0000FF1959FF0000CCFF\
0CFF0026FF0000FF0C00FF0073FF008CFF008CFF0066FF0000FF1999FF00B3FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00A6FF00C0FF00E6FF00F3FF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300F3FF00A6FF0000FF4CA6FF00CCFF00C0FF00B3FF00C0FF00B3FF00
A6FF008CFF0026FF0000FF0C33FF0073FF008CFF0099FF008CFF0059FF0019FF0026FF0000FF19\
00FF5900FF6600FF1933FF0059FF0073FF0073FF0033FF004CFF0099FF00A6FF00
B3FF00C0FF00C0FF00C0FF00C0FF00B3FF0000FFFFCCFF00E6FF00F3FF00F3FF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFFF00F3FF00D9FF00CCFF008CFF0033FF0066FF00A6FF0080FF00
66FF0059FF0066FF0000FF3359FF0000FF1973FF0080FF0080FF0066FF000CFF0000FF7300CCFF\
00000000000000FFFF00FF0026FF004CFF0026FF0000FF0059FF0080FF0066FF00
A6FF00B3FF00A6FF0099FF00A6FF0080FF00A6FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFFF00FFFF00F3FF00E6FF00C0FF00B3FF0000FF0066FF0000FF99
33FF0080FF0099FF008CFF0080FF0000FF403FFF0066FF0066FF0059FF0033FF0000FF8C000000\
00000000000000FFA600FF0C26FF004CFF003FFF004CFF0000FF0000FFA680FF00
99FF0099FF008CFF0000FFA673FF000CFF0080FF00B3FF00CCFF00E6FF00F3FF00F3FF00FFFF00\
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00B3FF004CFF0099FF00
8CFF0099FF00A6FF00A6FF0080FF0066FF0000FF0026FF0000FF0C00FF1900FFA600FF4000FFE6\
3F00FF00000000FFBF00FF003FFF0066FF0073FF0073FF0066FF0000FF3373FF00
73FF0080FF0073FF0026FF0073FF008CFF0073FF008CFF0026FF00CCFF00E6FF00E6FF00F3FF00\
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00B3FF00A6FF00C0FF00
C0FF00C0FF00C0FF00B3FF00A6FF008CFF0066FF000CFF0066FF0066FF0019FF0019FF0000FF33\
00FFD90033FF00FF5900FF403FFF0073FF008CFF008CFF0080FF004CFF0019FF00
00FF7333FF0073FF008CFF0000FF80B3FF00A6FF008CFF00A6FF0080FF00A6FF00C0FF00E6FF00\
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00D9FF0019FF00C0FF00CCFF00
CCFF00CCFF00C0FF00C0FF00B3FF0099FF0059FF0073FF0080FF0080FF0066FF0019FF0000FF59\
00FF0000FF260CFF0033FF0000FF1959FF0099FF0099FF0099FF0080FF0066FF00
66FF0059FF0080FF00B3FF00C0FF00CCFF00CCFF00B3FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
F3FF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00C0FF00B3FF008CFF0080FF008CFF0099FF008CFF0066FF0019FF003FFF00\
3FFF0000FF0C33FF0066FF0066FF0080FF00A6FF00A6FF00A6FF0099FF0099FF00
A6FF0066FF0026FF00B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00CCFF0099FF000CFF0099FF00A6FF00A6FF0099FF0000FFCC26FF0073FF00\
66FF003FFF0066FF0080FF008CFF00A6FF00B3FF00B3FF00C0FF00B3FF00C0FF00
C0FF00B3FF0019FF00B3FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00D9FF00D9FF00CCFF0059FF0073FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF00\
73FF0033FF003FFF0073FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00B3FF0073FF00CCFF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF008CFF00\
73FF003FFF0026FF003FFF0080FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF0080FF00\
66FF0000FF0C73FF0073FF0073FF0073FF00A6FF00CCFF00CCFF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF008CFF0059FF00\
33FF0059FF0080FF00A6FF00A6FF008CFF004CFF00CCFF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00B3FF000CFF0073FF003FFF00\
66FF008CFF00A6FF00B3FF00C0FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0099FF0000FF19\
4CFF0099FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF0073FF00\
3FFF0019FF00B3FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF003FFF00\
8CFF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF0000FF00\
A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0073FF008CFF00\
B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF0080FF0000FF408CFF00\
B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFE600FFFF00E6FF00F3FF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF0059FF0059FF00\
8CFF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFE600FFF300C0FF00B3FF00F3FF00FFFF00FFFF00FFF300FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF0080FF004CFF008CFF00\
A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFE600FFF300FFFF00E6FF00D9FF00E6FF00F3FF00FFFF00F3FF00CCFF00F3FF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0000FF198CFF0066FF004CFF0080FF00\
A6FF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFE600FFE600FFF300F3FF0073FF003FFF00E6FF00E6FF00E6FF0059FF00E6FF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF008CFF0000FF4C66FF00\
8CFF0099FF0033FF00C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFF300FFFF00D9FF0073FF00C0FF00C0FF00C0FF00C0FF00E6FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00A6FF0099FF0073FF0000FF26\
33FF008CFF00A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFF300FFFF00D9FF0026FF008CFF0073FF0019FF00B3FF00CCFF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF008CFF0073FF0000FF00\
80FF00A6FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFF300F3FF0066FF00D9FF00CCFF00B3FF00B3FF0026FF00C0FF00\
D9FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF003FFF0066FF0000FF8C59FF00\
8CFF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFF300FFFF00F3FF00F3FF00E6FF00D9FF00C0FF003FFF0099FF00\
B3FF0000FF33D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00D9FF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF0080FF0000FF4066FF00\
8CFF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00C0FF00C0FF00D9FF00E6FF00
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00C0FF004CFF0066FF00\
66FF00A6FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00CCFF0099FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF0080FF0033FF0066FF00\
80FF008CFF008CFF00A6FF00B3FF00B3FF00B3FF0099FF0099FF00CCFF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00E6FF0080FF00CCFF00CCFF00\
A6FF0080FF00B3FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF0080FF0000FF338CFF00CCFF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF0059FF00
B3FF00B3FF0099FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF003FFF0026FF0000FF4C00FF00\
66FF0059FF0026FF008CFF00A6FF0099FF008CFF0073FF00B3FF00CCFF00D9FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00E6FF00D9FF00\
8CFF00A6FF0000FF66CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF0099FF008CFF00CCFF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF008CFF00
66FF0099FF0066FF0099FF00A6FF00A6FF00A6FF0099FF008CFF0066FF004CFF0000FFD973FF00\
3FFF000CFF0000FF0066FF0080FF0059FF008CFF00B3FF00C0FF00CCFF00D9FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00\
D9FF00CCFF00A6FF00B3FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00A6FF0000FF40C0FF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF008CFF00
26FF003FFF0000FF0C80FF008CFF0073FF0073FF0019FF003FFF0073FF0073FF0099FF008CFF00\
80FF0019FF003FFF0059FF0000FF5959FF0099FF00B3FF00C0FF00CCFF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00\
E6FF00D9FF00C0FF004CFF00B3FF00C0FF00D9FF00D9FF00CCFF00CCFF00D9FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00B3FF000CFF00B3FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00B3FF00A6FF00
8CFF0073FF000CFF0033FF0066FF0000FF663FFF0033FF008CFF0099FF00A6FF00A6FF00A6FF00\
99FF004CFF008CFF008CFF0066FF0000FF668CFF00A6FF00C0FF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00C0FF0066FF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00\
E6FF00E6FF00CCFF008CFF0000FF26B3FF00C0FF00C0FF008CFF00B3FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF0000FF26A6FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00A6FF00
99FF0080FF003FFF0019FF003FFF0000FF0C66FF008CFF00A6FF00A6FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF0099FF0080FF0026FF0073FF00A6FF00B3FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00C0FF0099FF00B3FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00D9FF00B3FF0019FF0099FF0099FF00A6FF0066FF00B3FF00CCFF00
CCFF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF008CFF0000FF0080FF00A6FF00C0FF00C0FF00\
B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF00
8CFF0073FF003FFF0000FF660066FF00FF3366FF008CFF00A6FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00A6FF003FFF003FFF0080FF0099FF00B3FF00B3FF00B3FF00
66FF00C0FF00C0FF00C0FF00A6FF0080FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00D9FF00B3FF004CFF004CFF004CFF0066FF0080FF00B3FF00C0FF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF0099FF0066FF003FFF0099FF00A6FF00A6FF00\
4CFF00B3FF00C0FF00C0FF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF00
8CFF0059FF0000FF5900FFB300FF1959FF0080FF0099FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00A6FF0080FF0000FF5966FF003FFF0099FF00A6FF0099FF00
26FF0099FF00A6FF008CFF0099FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00B3FF00A6FF00B3FF00A6FF008CFF0080FF0059FF004CFF00B3FF00
C0FF00C0FF00B3FF0073FF00A6FF00B3FF00A6FF0099FF004CFF0066FF0073FF008CFF008CFF00\
73FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00
8CFF0033FF0026FF004CFF0000FFB366FF008CFF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00A6FF0066FF0080FF0000FF4C59FF0073FF0080FF0059FF00
00FF3300FF0066FF003FFF00A6FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00D9FF00CCFF00CCFF00C0FF00B3FF008CFF0000FF338CFF00A6FF00
B3FF00B3FF0099FF0000FF193FFF008CFF008CFF0080FF0019FF004CFF0000FF263FFF000CFF00\
80FF0099FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF00
4CFF0000FF0C66FF0073FF003FFF004CFF0000FFF399FF00B3FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF004CFF00A6FF00A6FF008CFF0026FF004CFF0080FF003FFF00
66FF008CFF008CFF0000FF4C8CFF004CFF00D9FF00E6FF00E6FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFD900FFF300F3FF00FFE600FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF008CFF0033FF0073FF008CFF00
99FF0099FF0080FF0059FF000CFF0059FF0000FF0073FF0080FF0080FF0033FF0066FF0033FF00\
3FFF008CFF00A6FF00A6FF0099FF0099FF00A6FF00A6FF0099FF008CFF0026FF00
66FF008CFF0073FF0099FF008CFF0080FF0073FF008CFF00C0FF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0080FF0059FF0099FF00A6FF000CFF00
33FF00B3FF00A6FF008CFF0026FF00B3FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFD900FFD900FFF300CCFF00FFF300FFE600FFE600FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00E6FF00D9FF00D9FF00CCFF0080FF0080FF0080FF0000FF9973FF00
80FF0080FF0059FF0033FF0000D9FF00FF334CFF008CFF0099FF0099FF0099FF008CFF0066FF00\
3FFF0080FF008CFF008CFF0066FF0066FF008CFF008CFF0080FF0000FF1980FF00
99FF00A6FF00B3FF00B3FF00A6FF00A6FF00A6FF0073FF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00A6FF0033FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF003FFF003FFF0099FF00A6FF008CFF00D9FF00E6FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFD900FFE600FFFF0080FF00F3FF00D9FF00FFF300FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF0099FF0073FF000CFF00
00FF0C73FF0073FF0073FF003FFF004CFF008CFF00A6FF00A6FF00A6FF00A6FF0099FF0073FF00\
00FF0000FF2673FF0073FF003FFF0000FF8019FF0073FF003FFF003FFF0073FF00
A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00B3FF00CCFF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00A6FF00A6FF00C0FF00CCFF00CCFF00
D9FF00CCFF00CCFF00B3FF0059FF0033FF0066FF00A6FF00CCFF00E6FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFE600FFFF00E6FF0026FF00E6FF00FFF300FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF00A6FF0080FF0026FF00
80FF0099FF0099FF0099FF004CFF0066FF003FFF00B3FF00B3FF00B3FF00B3FF00A6FF0066FF00\
80FF0059FF000CFF0066FF003FFF0000FF0066FF0059FF0026FF0073FF0099FF00
B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00CCFF004CFF00B3FF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00A6FF00B3FF00C0FF00A6FF0073FF0099FF00D9FF00E6FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFE600FFF300F3FF0099FF00E6FF00FFFF00FFF300FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00CCFF00C0FF0059FF0000FF8C66FF00
8CFF00A6FF00B3FF00B3FF00B3FF0099FF00A6FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF00\
99FF004CFF0066FF008CFF0073FF0000FF808CFF008CFF0026FF0059FF0080FF00
B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00CCFF0059FF00B3FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF0073FF00D9FF00D9FF00B3FF00B3FF0099FF00CCFF00D9FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFE600FFF300F3FF00D9FF008CFF00F3FF00FFF300FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFFF00FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF0066FF0073FF00
A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
A6FF0000FF5973FF00A6FF00A6FF00A6FF00A6FF0099FF0073FF0000FF0099FF00
B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00B3FF00A6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF0099FF0059FF00C0FF00CCFF00E6FF00\
E6FF00E6FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFE600FFE600FFF300FFFF00E6FF0080FF00F3FF00FFFF00FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300CCFF00FFFF00FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF0033FF008CFF00
A6FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
B3FF0026FF00A6FF00B3FF00C0FF00C0FF00B3FF00A6FF0073FF0066FF008CFF00
B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00C0FF00D9FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00C0FF0000FF003FFF00C0FF00CCFF00\
CCFF00A6FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFF300FFFF00F3FF0026FF00E6FF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFF300FFF300E6FF008CFF00F3FF00FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00A6FF0073FF0099FF00B3FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
B3FF004CFF00B3FF00C0FF00CCFF00CCFF00C0FF00A6FF0059FF0073FF0026FF00
80FF003FFF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00C0FF0000FFB3A6FF0066FF00\
B3FF008CFF00D9FF00E6FF00E6FF00F3FF00F3FF00E6FF00D9FF0073FF00F3FF00
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300FFF300FFFF00E6FF0000FF00CCFF00E6FF00F3FF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFFF00F3FF0099FF00E6FF00FFFF00\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFFF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00C0FF0099FF00A6FF0080FF0080FF00A6FF00B3FF00
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
C0FF003FFF00C0FF00CCFF00CCFF00CCFF00CCFF0099FF00B3FF00A6FF0059FF00
99FF00C0FF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00CCFF0073FF0073FF0059FF00\
19FF00A6FF00CCFF00D9FF00E6FF00E6FF00E6FF00D9FF0000FF1959FF00E6FF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFD900CCFF00FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFFF00E6FF00C0FF0080FF00CCFF00E6FF00F3FF00
F3FF0059FF00F3FF00FFFF00FFF300FFF300FFF300FFFF00FFFF00E6FF00B3FF00D9FF00FFFF00\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
F3FF0033FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00CCFF0026FF00D9FF00D9FF00CCFF00\
C0FF00A6FF00C0FF00C0FF00B3FF0099FF0026FF0059FF0080FF00B3FF00C0FF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
CCFF00C0FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF0099FF00
99FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00C0FF00B3FF00C0FF00B3FF00\
8CFF0080FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF0073FF00CCFF00E6FF00
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFE600E6FF00FFF300FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFE600FFE600F3FF00FFFF00FFF300FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFFF00F3FF00E6FF00CCFF0059FF00C0FF00D9FF00E6FF00
D9FF0059FF00E6FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF0073FF00E6FF00F3FF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00\
F3FF00A6FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00B3FF00B3FF00C0FF00C0FF00\
B3FF0000FF19A6FF00B3FF00A6FF0099FF004CFF0000FF0C99FF00B3FF00C0FF00
CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00B3FF00
A6FF00C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00D9FF00D9FF00D9FF00C0FF00\
73FF0080FF00A6FF00B3FF008CFF0099FF00B3FF0080FF00B3FF00D9FF00E6FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFE600\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC00066FF00\
F3FF00E6FF00FFF300FFFF00FFFF00FFFF00D9FF00CCFF00F3FF00D9FF00FFFF00
FFF300FFE600FFE600FFE600FFF300FFF300F3FF00CCFF00FFFF00FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00CCFF0026FF00A6FF0073FF00C0FF00
B3FF00C0FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF0066FF00B3FF00E6FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00E6FF00FFFF00FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
E6FF00C0FF008CFF00CCFF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00C0FF0073FF0099FF00A6FF00\
A6FF0033FF008CFF0099FF0066FF0080FF0066FF0066FF008CFF00A6FF00C0FF00
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00A6FF00
59FF00A6FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00\
B3FF0080FF0066FF008CFF000CFF0059FF0059FF0073FF00B3FF00D9FF00E6FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00CCFF003FFF00F3FF00FFE600\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFCC00\
FFE600FFE600FFF300D9FF0099FF00C0FF008CFF00D9FF008CFF00C0FF00A6FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00E6FF00CCFF00F3FF00FFFF00FFFF00FFFF00FFFF00\
E6FF00E6FF00F3FF00F3FF00E6FF00D9FF00C0FF0080FF00B3FF0073FF0080FF00
19FF00A6FF0099FF00E6FF00E6FF00E6FF00CCFF00E6FF00D9FF00CCFF0033FF00B3FF00CCFF00\
8CFF00E6FF00F3FF00F3FF00E6FF00C0FF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00\
E6FF00CCFF004CFF00C0FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00C0FF0080FF0066FF0059FF00\
80FF0026FF0066FF0073FF003FFF0019FF0000FF2673FF008CFF00A6FF00C0FF00
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00C0FF00
00FF80A6FF00C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00\
CCFF0000FF33A6FF0099FF008CFF00A6FF0099FF0000FF6699FF0019FF00D9FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00CCFF0099FF00E6FF00FFF300FFE600\
FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFC000FFC000\
FFCC00FFCC00FFD900FFE600FFFF00F3FF00FFF300FFF300D9FF00FFFF00FFFF00
F3FF0033FF00C0FF00CCFF00E6FF00E6FF00D9FF0099FF00D9FF00E6FF00F3FF00F3FF00F3FF00\
B3FF00CCFF00D9FF00CCFF00D9FF0080FF0099FF00CCFF00CCFF00C0FF00C0FF00
B3FF0059FF00C0FF00CCFF00D9FF00C0FF00A6FF00B3FF00C0FF00B3FF0059FF0059FF00A6FF00\
B3FF00D9FF00E6FF00E6FF00CCFF00C0FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
E6FF00D9FF00B3FF00A6FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF0080FF0099FF0080FF0033FF00\
3FFF000CFF0033FF000CFF0000FF334CFF0073FF008CFF00A6FF00B3FF00C0FF00
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00A6FF00
99FF0000FF0C66FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00\
C0FF00A6FF00CCFF00CCFF00C0FF00C0FF00B3FF008CFF0073FF00C0FF00D9FF00
D9FF00E6FF00D9FF0073FF00E6FF00E6FF00E6FF00D9FF0066FF00D9FF00F3FF00FFF300FFE600\
FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFCC00FFD900FFFF00FFF300FFE600FFE600FFE600FFE600FFE600
FFF30073FF00E6FF008CFF008CFF0080FF0026FF00B3FF0000FF00D9FF00E6FF00E6FF00D9FF00\
B3FF004CFF0080FF004CFF00A6FF0033FF00C0FF00D9FF00E6FF00E6FF00D9FF00
CCFF0080FF0099FF00B3FF00C0FF0080FF0073FF0000FF4080FF0099FF00C0FF00B3FF0099FF00\
80FF00C0FF00C0FF00CCFF00A6FF00C0FF00D9FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
E6FF00D9FF00C0FF0099FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00C0FF00B3FF00A6FF008CFF00\
80FF0059FF0000FF0C00000000FF2626FF0080FF0099FF00A6FF00B3FF00C0FF00
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00
C0FF004CFF00A6FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00D9FF00\
73FF00D9FF00E6FF00E6FF00D9FF00D9FF00C0FF0066FF008CFF00B3FF00CCFF00
CCFF00CCFF00C0FF0073FF00CCFF00D9FF00C0FF0066FF00D9FF00F3FF00FFFF00FFF300FFE600\
FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFF300E6FF00CCFF00E6FF00E6FF00D9FF0073FF00B3FF00C0FF00CCFF00C0FF00\
73FF00CCFF00C0FF00A6FF00C0FF00A6FF00D9FF00E6FF00F3FF00F3FF00E6FF00
CCFF008CFF00A6FF004CFF004CFF00B3FF00C0FF00B3FF0080FF00C0FF00D9FF00CCFF00B3FF00\
66FF0099FF0033FF0073FF008CFF004CFF00C0FF00CCFF00C0FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
E6FF00D9FF00C0FF008CFF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF0099FF00\
80FF004CFF0000FF0C00CCFF00FF5959FF0073FF0080FF008CFF00A6FF00B3FF00
C0FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
CCFF0059FF0073FF00B3FF00C0FF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00E6FF00\
80FF00E6FF00F3FF00F3FF00E6FF00D9FF00CCFF000CFF003FFF0080FF00B3FF00
C0FF00C0FF00B3FF0073FF0066FF00B3FF0000FF0099FF00E6FF00F3FF00FFF300FFF300FFE600\
FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFE600D9FF00F3FF00FFFF00FFFF00F3FF00C0FF00C0FF0066FF0099FF00A6FF00\
D9FF00E6FF00E6FF00E6FF00D9FF00C0FF00F3FF00F3FF00FFFF00F3FF00F3FF00
C0FF00D9FF00CCFF00A6FF0066FF00CCFF00D9FF00D9FF0099FF00E6FF00E6FF00E6FF00CCFF00\
C0FF0073FF00C0FF00A6FF00CCFF0099FF003FFF0059FF0059FF00CCFF00E6FF00
F3FF00F3FF00F3FF00F3FF00D9FF00C0FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00CCFF008CFF0019FF0099FF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00B3FF00A6FF008CFF00\
59FF004CFF0019FF0026FF003FFF0000FF0C00FF0C00FF4000FF268CFF008CFF00
8CFF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00
73FF00C0FF00A6FF004CFF00CCFF00E6FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00D9FF00\
F3FF00FFFF00FFFF00F3FF00F3FF00E6FF0000FF8CC0FF0099FF0080FF0080FF00
8CFF0099FF0073FF0080FF00A6FF0080FF004CFF00B3FF00D9FF00F3FF00FFFF00FFF300FFE600\
FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFE600F3FF00FFF300FFF300FFF300FFFF00D9FF00E6FF00CCFF008CFF00C0FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00D9FF00A6FF00A6FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
CCFF00B3FF00D9FF00E6FF00E6FF00CCFF00C0FF00CCFF00A6FF0000FF33CCFF00
D9FF00CCFF00E6FF00D9FF00CCFF0073FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00CCFF00B3FF0080FF008CFF00C0FF00CCFF00C0FF0099FF00C0FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00A6FF0059FF0019FF00\
26FF003FFF0019FF0073FF0066FF000CFF0080FF003FFF0066FF0033FF00A6FF00
C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
D9FF00E6FF00D9FF0080FF00C0FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00CCFF0099FF003FFF00
B3FF0000FF0C73FF00B3FF00CCFF00C0FF004CFF004CFF0080FF00E6FF00FFFF00FFF300FFE600\
FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300FFFF00FFFF00D9FF0000FF00D9FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFFF00
FFFF00F3FF00E6FF00CCFF00CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
D9FF0099FF00E6FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF0099FF00
80FF00A6FF00CCFF00CCFF00B3FF0099FF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00C0FF00A6FF0059FF008CFF00A6FF00B3FF00B3FF0033FF00C0FF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0099FF0066FF00\
66FF008CFF004CFF0099FF008CFF0000FF0099FF00A6FF00A6FF0000FF8099FF00
CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00E6FF00D9FF00D9FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00A6FF0066FF00B3FF00
CCFF00D9FF00B3FF00CCFF00D9FF00D9FF00C0FF0033FF00C0FF00E6FF00F3FF00FFFF00FFF300\
FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFF300FFF300F3FF00B3FF00B3FF00\
F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00F3FF00B3FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
E6FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00C0FF00
C0FF0019FF0099FF0059FF0080FF004CFF003FFF00CCFF00CCFF00CCFF00B3FF008CFF00A6FF00\
B3FF00B3FF0099FF0000FF004CFF0019FF008CFF0080FF0099FF00C0FF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00A6FF008CFF0059FF00\
80FF00A6FF00A6FF00B3FF00A6FF0000FF19A6FF00C0FF00C0FF0073FF0066FF00
C0FF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00E6FF003FFF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF0000FF3399FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00B3FF004CFF00A6FF0073FF00C0FF00B3FF00FFF300\
FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300F3FF008CFF00F3FF00\
FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFFF00F3FF00B3FF008CFF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
E6FF00B3FF00B3FF00A6FF00B3FF0099FF0073FF00B3FF00C0FF00C0FF0099FF0059FF0000FF0C\
80FF0033FF008CFF0099FF0099FF003FFF0073FF0033FF008CFF00A6FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF003FFF0066FF00\
4CFF00B3FF00C0FF00C0FF00C0FF0080FF00B3FF00CCFF00CCFF00CCFF00C0FF00
66FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00D9FF00C0FF00E6FF00
F3FF00F3FF00FFFF00FFFF00F3FF00F3FF00D9FF004CFF00B3FF00B3FF0000FF19E6FF00FFFF00\
FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300E6FF0000FF0CFFFF00\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300B3FF00B3FF00D9FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
E6FF0080FF00D9FF00D9FF00CCFF00B3FF0000FF0059FF00A6FF0099FF0000FF5973FF0026FF00\
3FFF008CFF00B3FF00B3FF00B3FF00A6FF0099FF0073FF0059FF00A6FF00B3FF00
C0FF00C0FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF0099FF0073FF0080FF00A6FF00\
B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
CCFF00A6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00B3FF00CCFF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00D9FF00D9FF00E6FF00D9FF0019FF00A6FF00FFFF00\
FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFF300D9FF00CCFF00FFFF00\
FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFF300FFFF00CCFF00F3FF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
F3FF00E6FF00E6FF00E6FF00D9FF0019FF00B3FF0066FF0000FF0C99FF00B3FF00A6FF0099FF00\
59FF00A6FF00C0FF00CCFF00C0FF00C0FF00A6FF0073FF0073FF0099FF00A6FF00
B3FF00A6FF0059FF00A6FF00B3FF00B3FF00B3FF00A6FF0059FF0033FF0099FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300E6FF0080FF00D9FF00F3FF00
FFFF00FFF300FFF300FFF300FFF300FFFF00E6FF00F3FF00FFFF00F3FF00E6FF008CFF00F3FF00\
FFFF00FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600C0FF003FFF00E6FF00FFF300\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFF3008CFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00A6FF0059FF00B3FF00CCFF00CCFF00C0FF00\
73FF00CCFF00CCFF00CCFF00CCFF00C0FF00A6FF0033FF0059FF0066FF0099FF00
99FF0080FF0000FF4073FF0099FF00A6FF00A6FF0099FF0066FF0080FF00A6FF00C0FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFFF00CCFF0059FF00FFFF00
FFF300FFF300FFF300FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00E6FF0066FF00\
E6FF00FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFF300CCFF00E6FF00FFF300\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00B3FF0080FF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00B3FF00A6FF008CFF004CFF0000FF4C
00FF4026FF0000FF8C33FF0080FF008CFF008CFF0059FF0000FF9966FF00A6FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300D9FF00FFFF00FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300F3FF00C0FF00\
4CFF00E6FF00F3FF00E6FF00FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFF300B3FF00FFFF00FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00B3FF00C0FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF008CFF0000FF198CFF00
99FF008CFF004CFF004CFF0000FF7366FF000CFF0019FF0080FF0099FF00B3FF00C0FF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF30080FF00FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFFF00\
C0FF0080FF0066FF00FFFF00FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900F3FF00FFF300FFE600FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFFF00F3FF00CCFF0073FF00D9FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00C0FF0099FF0073FF00B3FF00
B3FF00B3FF008CFF0066FF0099FF0099FF008CFF0059FF0000FF0099FF00B3FF00C0FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300\
99FF00F3FF00B3FF0073FF00FFF300FFD900FFD900FFCC00FFCC00FFC000FFC000
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFFF00F3FF00C0FF0099FF00D9FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0066FF00B3FF00C0FF00
C0FF00C0FF004CFF00B3FF00B3FF00A6FF0099FF003FFF0033FF008CFF00A6FF00C0FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFF300FFF300FFF300F3FF00E6FF00FFE600FFD900FFCC00FFCC00FFC000FFC000
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFFF00F3FF00CCFF00C0FF00E6FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00A6FF00A6FF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF008CFF0033FF0066FF008CFF00B3FF00CCFF00\
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFF300FFE600FFCC00FFCC00FFCC00FFC000FFC000
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFF300FFF300F3FF0080FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00CCFF0000FF00C0FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF008CFF0059FF0059FF0099FF00B3FF00C0FF00CCFF00\
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFF300F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00CCFF00C0FF00D9FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF0059FF0080FF00A6FF00B3FF00C0FF00CCFF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00CCFF00C0FF0099FF0000FF7359FF0080FF00A6FF00C0FF00CCFF00\
D9FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00D9FF00CCFF000CFF0099FF00A6FF0080FF0000FF4C99FF00B3FF00C0FF00\
C0FF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00E6FF00E6FF008CFF0080FF00C0FF00C0FF0099FF0080FF004CFF0033FF003FFF00\
A6FF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00CCFF00B3FF0099FF000CFF00A6FF00C0FF00\
CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00B3FF0073FF0080FF00B3FF00CCFF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00D9FF00C0FF00A6FF0066FF00A6FF00CCFF00\
D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF0099FF0080FF00C0FF00D9FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00B3FF0099FF00CCFF00D9FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF008CFF00A6FF00CCFF00D9FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00C0FF008CFF0000FF00CCFF00D9FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00CCFF0073FF0026FF00A6FF00C0FF00CCFF00\
D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00CCFF00C0FF0059FF008CFF00A6FF00B3FF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF0080FF0066FF00A6FF00C0FF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00C0FF00A6FF0059FF0099FF00C0FF00CCFF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00E6FF00B3FF0073FF008CFF0019FF0073FF00A6FF00C0FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00C0FF00C0FF00A6FF0000FF0C73FF008CFF00C0FF00\
CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF0073FF0000FF0C99FF00B3FF00\
C0FF00CCFF00CCFF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF0099FF003FFF008CFF00A6FF00\
A6FF00A6FF008CFF0080FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF008CFF0000FF0033FF00\
59FF0099FF00B3FF00CCFF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00
FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00CCFF00C0FF00B3FF0099FF0080FF0000FF4099FF00\
B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00
FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00B3FF0066FF0099FF0059FF003FFF004CFF00A6FF00\
C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00
F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00C0FF00A6FF0066FF0066FF0080FF0099FF0099FF00\
C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00F3FF00
E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00A6FF0019FF0073FF0099FF00B3FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00D9FF00B3FF00
B3FF0099FF008CFF00C0FF00C0FF0099FF00A6FF0099FF003FFF0066FF00A6FF00B3FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF00
B3FF00A6FF00A6FF0080FF0066FF0066FF0000FF0C66FF0059FF008CFF00A6FF00B3FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00
E6FF00D9FF00CCFF00C0FF00A6FF0099FF0080FF0073FF0033FF008CFF00A6FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00E6FF00D9FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00
E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF0080FF0080FF00A6FF00B3FF00B3FF00\
C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
D9FF00CCFF0099FF00A6FF00E6FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00
F3FF00E6FF00E6FF00D9FF00CCFF00CCFF00C0FF00A6FF008CFF004CFF008CFF00A6FF00A6FF00\
B3FF00B3FF00C0FF00B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF000CFF004CFF00CCFF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00
F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF008CFF0033FF0059FF008CFF0099FF00\
80FF0099FF008CFF0000FF0CC0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
B3FF0059FF00C0FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00
F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF008CFF0019FF0066FF0080FF0080FF00\
73FF004CFF0033FF0099FF00B3FF00C0FF00CCFF00CCFF00CCFF00C0FF00A6FF00
66FF00C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF008CFF0059FF0000FF0059FF0059FF0059FF00\
4CFF003FFF0073FF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00A6FF0019FF00
A6FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
E6FF00E6FF00D9FF00D9FF00B3FF00A6FF00A6FF008CFF0073FF004CFF0019FF000CFF0000FF00\
00FF3333FF0059FF0080FF0080FF008CFF00A6FF00B3FF00A6FF003FFF0033FF00
99FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00CCFF00C0FF008CFF0000FF0C80FF003FFF0026FF0000FF660080FF000000\
00FFBF00FFBF33FF0059FF0026FF0073FF0080FF008CFF008CFF0059FF0080FF00
A6FF00C0FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600\
FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00B3FF00C0FF00D9FF00
D9FF00D9FF00CCFF00CCFF00C0FF0099FF0033FF004CFF0026FF0000FF4C0059FF000000000000\
00000000FFF300FF0C00FF003FFF000CFF0000FF6659FF0073FF0080FF0019FF00
59FF008CFF00A6FF00CCFF00D9FF00E6FF00E6FF00FFFF00FFFF00FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300\
FFFF00F3FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00C0FF008CFF00C0FF00
CCFF00CCFF00CCFF00C0FF00B3FF0073FF0066FF003FFF0000FF33000000000000000000000000\
0000000059FF00FF003FFF0066FF0073FF0026FF0099FF00A6FF00A6FF0080FF00
80FF0026FF00A6FF00C0FF00CCFF00B3FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300CCFF00\
CCFF00C0FF0099FF0000FF5900FF00C0FF0059FF00C0FF00B3FF0026FF0099FF00
A6FF00C0FF00C0FF00B3FF00B3FF0099FF0080FF003FFF0000FF590019FF000000000000000000\
00000000FFA600FF4019FF0073FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00
A6FF0019FF008CFF0099FF0000FF0C73FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300\
FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300\
F3FF0073FF00E6FF00D9FF00D9FF00B3FF0099FF0073FF0000FF0099FF0059FF00
99FF00A6FF00B3FF00B3FF00A6FF008CFF0080FF0026FF0000FF260000FF000000000000000000\
00000000F3FF00FF4C3FFF0073FF008CFF00A6FF00B3FF00C0FF00C0FF00C0FF00
B3FF008CFF0066FF008CFF0099FF0099FF003FFF00C0FF00D9FF00D9FF00E6FF00D9FF00FFFF00\
FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600\
FFF300FFFF00FFFF00FFFF00F3FF00E6FF00CCFF00B3FF00C0FF00B3FF0080FF00
66FF0073FF0099FF0099FF0080FF0000FF0059FF003FFF0000FF6600FF4C00FF8C00FFCC000000\
00000000CCFF00FF4C00FF4C59FF0059FF0073FF00C0FF00C0FF00CCFF00CCFF00
CCFF00C0FF0099FF00C0FF00CCFF00CCFF00CCFF00CCFF0080FF0059FF00C0FF003FFF00CCFF00\
FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFF300FFF300FFFF00FFFF00F3FF00D9FF00D9FF00D9FF00CCFF0099FF00
99FF0073FF003FFF0059FF0073FF0080FF0066FF0059FF0066FF0000FF590CFF0000FF9900CCFF\
0066FF00E6FF00FF0C4CFF0033FF0080FF00B3FF00C0FF00CCFF00CCFF00D9FF00
D9FF00CCFF00A6FF00C0FF00D9FF00E6FF00E6FF00E6FF00D9FF00D9FF0066FF00D9FF00E6FF00\
B3FF00A6FF00FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00
B3FF0080FF0066FF0099FF00A6FF00A6FF0080FF0080FF0080FF0066FF003FFF0000FF0C19FF00\
00FF1900FFCC19FF0066FF0073FF0059FF00A6FF00CCFF00D9FF00D9FF00D9FF00
E6FF00D9FF00D9FF00C0FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00FFFF00FFFF00\
FFF300FFF300FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00
C0FF0073FF0099FF00B3FF00C0FF00C0FF00B3FF00A6FF008CFF0066FF003FFF004CFF0059FF00\
33FF0033FF004CFF0080FF0099FF00A6FF00B3FF00CCFF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00
C0FF0073FF0099FF00C0FF00CCFF00CCFF00C0FF00B3FF0099FF004CFF0059FF0073FF0080FF00\
73FF0066FF0019FF0033FF00A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00E6FF00C0FF00
33FF00C0FF00CCFF00CCFF00D9FF00CCFF00CCFF00C0FF004CFF0099FF0099FF008CFF0099FF00\
8CFF004CFF0059FF0099FF00B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00CCFF000CFF00
A6FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF00\
99FF0080FF0000FFA6A6FF00B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00C0FF0099FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00\
A6FF0099FF003FFF0099FF00B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00\
B3FF0099FF003FFF0080FF008CFF00B3FF00C0FF00CCFF00D9FF00E6FF00F3FF00
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00C0FF00\
B3FF0099FF0073FF0000FF0C33FF0073FF00A6FF00C0FF00CCFF00D9FF00E6FF00
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00\
A6FF0073FF003FFF008CFF008CFF0099FF00A6FF0080FF00A6FF00C0FF00B3FF00
E6FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00\
A6FF0080FF0059FF00A6FF00B3FF00C0FF00CCFF00C0FF00B3FF0066FF0066FF00
D9FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00CCFF00A6FF0080FF00\
66FF0059FF0080FF00B3FF00CCFF00D9FF00D9FF00D9FF00D9FF008CFF00E6FF00
E6FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF0073FF00\
73FF0073FF0099FF0073FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00D9FF0099FF004CFF0099FF004CFF0026FF00\
99FF00B3FF00C0FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF0066FF0073FF00A6FF00B3FF0099FF0059FF00\
99FF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00CCFF00B3FF0073FF00\
26FF0073FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF0099FF00\
59FF00A6FF00C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF00B3FF00\
8CFF0000FF0099FF00A6FF00D9FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF008CFF00\
66FF00A6FF00C0FF00C0FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00CCFF0080FF0019FF00\
99FF00C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0099FF00\
8CFF00C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF004CFF00\
99FF00C0FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0000FF26\
C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00CCFF00B3FF00A6FF00\
CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00C0FF0073FF00A6FF00\
CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00CCFF00C0FF0080FF0066FF00\
C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00B3FF0080FF008CFF0066FF00A6FF00\
CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00C0FF00B3FF0000FF1980FF00\
C0FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF0099FF0033FF00\
99FF0080FF00B3FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF0059FF00\
8CFF00B3FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF008CFF0073FF003FFF00\
0CFF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00C0FF00A6FF0059FF008CFF00\
B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF0073FF008CFF00\
A6FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00CCFF0099FF00E6FF00F3FF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0000FF000CFF0000FF80\
99FF0099FF00A6FF00B3FF00CCFF00CCFF00C0FF000CFF00A6FF00E6FF00F3FF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFE600F3FF00FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFFF00D9FF00E6FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00D9FF00
D9FF00D9FF00D9FF00D9FF00B3FF00C0FF00C0FF0099FF008CFF0073FF0073FF0099FF0099FF00\
26FF0059FF000CFF0080FF00B3FF00A6FF0059FF00B3FF00D9FF00E6FF00F3FF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFD900FFE600
FFD900FFD900FFD900FFE600FFE600FFE600FFF300A6FF00FFFF00FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFFF00E6FF0000FF26E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00
66FF00C0FF00CCFF00CCFF00B3FF0080FF0080FF0026FF0066FF00B3FF00B3FF00C0FF00B3FF00\
A6FF003FFF0073FF003FFF0080FF0000FF1999FF00CCFF00D9FF00E6FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFF300F3FF00E6FF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFFF00C0FF00F3FF00FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFFF00FFFF0073FF0099FF003FFF00D9FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00
C0FF0080FF0033FF00B3FF0099FF0000FF2680FF0073FF00B3FF00C0FF00CCFF00CCFF00CCFF00\
C0FF00B3FF00B3FF00A6FF008CFF0073FF00B3FF00CCFF00D9FF00E6FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFD900FFF300FFFF00
D9FF00E6FF00F3FF00A6FF00FFFF00FFFF00F3FF00A6FF00E6FF00F3FF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFFF00F3FF00E6FF00CCFF008CFF00CCFF00E6FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00
C0FF008CFF0026FF008CFF0073FF0000FF19A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00\
CCFF00CCFF00C0FF00B3FF0099FF0059FF0080FF00A6FF00D9FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00C0FF00C0FF00FFFF00FFF300FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600
FFF300E6FF0099FF00A6FF00E6FF00CCFF00D9FF0099FF00C0FF008CFF00F3FF00F3FF00B3FF00\
F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00A6FF00C0FF00D9FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00
B3FF0073FF0026FF0059FF000CFF0099FF00B3FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00C0FF0080FF0000FF73A6FF00C0FF00CCFF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00B3FF00A6FF00F3FF00FFF300FFF300FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900
FFE600FFF300F3FF00C0FF008CFF00B3FF008CFF00CCFF00B3FF00A6FF00CCFF00CCFF00A6FF00\
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00C0FF00B3FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00CCFF0073FF00
73FF0073FF0000FF0C00FF4066FF0000FF8CA6FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00CCFF00C0FF008CFF0073FF00A6FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00C0FF0059FF00D9FF00FFFF00FFF300FFF300FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900
FFD900FFE600FFF300E6FF00D9FF00E6FF00F3FF00E6FF00CCFF0080FF0080FF0099FF0059FF00\
CCFF00CCFF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00C0FF008CFF00C0FF00CCFF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00
99FF003FFF0059FF0033FF0080FF00B3FF00C0FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00CCFF00A6FF008CFF008CFF003FFF00A6FF00B3FF00C0FF00B3FF00
A6FF0099FF00C0FF00CCFF00A6FF0080FF00D9FF00F3FF00FFFF00FFF300FFF300FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFD900FFF3004CFF00F3FF00FFFF00FFFF00FFFF00E6FF00B3FF00D9FF00D9FF00C0FF00\
80FF003FFF00D9FF00F3FF00F3FF00F3FF00F3FF00F3FF00CCFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0080FF008CFF00C0FF00CCFF00C0FF00\
A6FF00D9FF00D9FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00B3FF00
8CFF0059FF008CFF004CFF008CFF00C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00D9FF00A6FF00C0FF00B3FF008CFF0073FF008CFF0073FF008CFF00
00FF5966FF0000FF338CFF0066FF00B3FF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900FFF300FFFF00FFF300FFF300FFF300FFF300F3FF00D9FF00F3FF00F3FF00CCFF00\
D9FF00A6FF0066FF00D9FF00E6FF00E6FF00E6FF00E6FF00A6FF00D9FF00E6FF00
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF0073FF008CFF00A6FF00B3FF00A6FF00\
A6FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00B3FF0099FF00
80FF0099FF00B3FF004CFF0026FF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00D9FF00D9FF00C0FF0066FF0080FF00B3FF00A6FF008CFF00
99FF00B3FF00B3FF00A6FF0066FF00C0FF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00D9FF008CFF0099FF00CCFF00D9FF00CCFF0099FF00CCFF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF0000FF4C66FF0000FF0C73FF0019FF00\
A6FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00A6FF004CFF00
99FF008CFF00CCFF00CCFF00CCFF008CFF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00E6FF00D9FF00CCFF008CFF00B3FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF0099FF0033FF00CCFF00E6FF00F3FF00FFFF00FFF300FFF300FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00\
FFFF00FFFF00E6FF00CCFF0080FF00B3FF0099FF00B3FF0000FF66C0FF00CCFF00
D9FF00D9FF00D9FF00CCFF00A6FF00B3FF0066FF0073FF00A6FF00A6FF008CFF0099FF0066FF00\
59FF00B3FF00C0FF00C0FF00B3FF00C0FF00C0FF00B3FF0099FF0073FF00A6FF00
CCFF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00E6FF00CCFF0073FF00CCFF00D9FF00E6FF00E6FF00
E6FF00E6FF00D9FF00CCFF0000FF2699FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFF300FFF300\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFFF00F3FF00E6FF00C0FF00A6FF008CFF00A6FF0080FF0000FF19C0FF00
CCFF00CCFF00CCFF00B3FF0000FF3373FF0073FF00B3FF00C0FF00C0FF00C0FF00B3FF0073FF00\
80FF00A6FF00A6FF0099FF0000FF1999FF00A6FF008CFF0080FF00C0FF00CCFF00
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00E6FF00C0FF00B3FF00D9FF00E6FF00F3FF00F3FF00
F3FF00F3FF00E6FF00D9FF00A6FF0066FF0099FF00C0FF00A6FF00E6FF00FFFF00FFF300FFF300\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFFF00E6FF004CFF00D9FF00CCFF00CCFF0099FF0080FF00A6FF00
C0FF00C0FF00B3FF0073FF0033FF0059FF00A6FF00C0FF00CCFF00CCFF00CCFF00B3FF0080FF00\
73FF0073FF0073FF0000FF6600FF0073FF0080FF003FFF0099FF00C0FF00D9FF00
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00E6FF00C0FF00A6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00D9FF0099FF00C0FF00B3FF008CFF00C0FF00F3FF00FFFF00FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFF300FFF300FFFF00F3FF00E6FF00E6FF00E6FF00D9FF00B3FF008CFF0000FF66
99FF0099FF0059FF0033FF00A6FF008CFF00C0FF00CCFF00D9FF00D9FF00D9FF00CCFF00C0FF00\
A6FF003FFF00A6FF00B3FF0099FF00B3FF00A6FF0080FF008CFF00B3FF00D9FF00
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00E6FF00B3FF00CCFF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00CCFF00D9FF00E6FF00D9FF0099FF00B3FF00D9FF00F3FF00FFFF00FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00D9FF00B3FF00C0FF00A6FF00
73FF008CFF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00D9FF00CCFF00\
B3FF008CFF00C0FF00CCFF00CCFF00CCFF00C0FF0080FF004CFF00C0FF00D9FF00
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00D9FF00D9FF00F3FF00FFFF00FFF300FFF300
FFF300FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00CCFF008CFF00D9FF00F3FF00FFFF00FFFF00\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00B3FF00
4CFF00A6FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
B3FF00B3FF00CCFF00D9FF00D9FF00D9FF00C0FF0059FF0080FF00B3FF00CCFF00
E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300E6FF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00E6FF00F3FF00FFFF00\
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00C0FF00
73FF00B3FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
19FF00C0FF00D9FF00E6FF00E6FF00E6FF00C0FF00B3FF00B3FF004CFF00C0FF00
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF008CFF00CCFF00D9FF00F3FF00\
FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00
4CFF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
D9FF00D9FF00E6FF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF0059FF00CCFF00
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00E6FF0026FF0033FF00A6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF0066FF00
B3FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00B3FF00CCFF00
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00A6FF00B3FF00D9FF00\
E6FF00E6FF00CCFF00D9FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00C0FF0026FF00
B3FF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00B3FF00B3FF00
E6FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00E6FF00C0FF008CFF00A6FF00\
C0FF00C0FF008CFF00E6FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00D9FF00C0FF008CFF00
A6FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00CCFF0099FF00
D9FF00E6FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFFF00D9FF00C0FF00CCFF00B3FF00\
A6FF0080FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFFF00FFFF00E6FF00FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFF300FFF300FFFF00F3FF008CFF0099FF008CFF0099FF00
C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00A6FF00B3FF00
59FF00D9FF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300E6FF00F3FF00E6FF00D9FF00\
C0FF0066FF004CFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
D9FF008CFF00FFFF00FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00E6FF00CCFF00B3FF008CFF00
CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00B3FF00
A6FF00D9FF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00\
B3FF0099FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
B3FF00D9FF00FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00B3FF0019FF00
C0FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00CCFF00
B3FF0000FF26CCFF00B3FF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00E6FF00\
CCFF0066FF00B3FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00D9FF00C0FF00
C0FF00F3FF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300FFFF00FFFF00F3FF00E6FF00D9FF00C0FF00B3FF0073FF00
8CFF008CFF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFFF004CFF00
F3FF00CCFF00C0FF00FFFF00FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00F3FF00\
D9FF0099FF0000FF0CA6FF00B3FF0099FF0099FF00CCFF00CCFF0019FF00CCFF00
F3FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFF300FFF300F3FF00D9FF00D9FF00D9FF00CCFF0099FF0019FF0080FF00
C0FF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFFF00E6FF00CCFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00\
CCFF00A6FF00CCFF0080FF0073FF0026FF00B3FF0080FF0073FF0099FF00D9FF00
F3FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFF300FFF300F3FF00C0FF00B3FF00A6FF00A6FF008CFF0066FF00A6FF00
CCFF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFFF008CFF00FFF300FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFF300FFFF00D9FF00\
B3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00C0FF0066FF00C0FF00D9FF00
F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFF300FFF300FFFF00F3FF00D9FF00B3FF004CFF0026FF0000FF4C8CFF00
4CFF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFFF00FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFFF0099FF00\
E6FF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00CCFF00A6FF0099FF00B3FF00
E6FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFF300FFF300FFFF00F3FF00E6FF00C0FF00A6FF0066FF0000FF008CFF00
8CFF00CCFF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600E6FF00F3FF00\
FFFF00FFF300FFF300FFFF00FFFF00F3FF00E6FF008CFF000CFF00A6FF00CCFF00
E6FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFCC00FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFFF00F3FF00E6FF00D9FF00A6FF0080FF0099FF00C0FF00
C0FF0066FF00A6FF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFFF00F3FF00E6FF00C0FF0066FF00C0FF00D9FF00
E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFF300\
FFF300D9FF00F3FF00FFFF00D9FF00FFCC00FFCC00FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFFF00F3FF00D9FF00C0FF0080FF0080FF00A6FF00CCFF00
E6FF00E6FF00E6FF00F3FF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFF300FFF300F3FF00B3FF0073FF008CFF00B3FF00CCFF00
E6FF00F3FF00F3FF00F3FF00FFFF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFFF00\
E6FF0066FF00D9FF00FFF300FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFFF00FFFF00F3FF00D9FF00C0FF008CFF00B3FF00CCFF00E6FF00
F3FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFF300E6FF00E6FF00E6FF00C0FF0033FF00B3FF00
D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00F3FF00FFFF00FFFF00FFFF00F3FF00D9FF00\
B3FF00A6FF00FFF300FFD900FFD900FFCC00FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF00A6FF00A6FF00CCFF00E6FF00
F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00D9FF00C0FF004CFF00
8CFF00CCFF00D9FF00D9FF00B3FF00B3FF00A6FF00D9FF00E6FF00E6FF0073FF003FFF00B3FF00\
D9FF00FFF300FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00F3FF00E6FF00CCFF008CFF008CFF0033FF00E6FF00
FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFE600FFE600FFF300FFF300F3FF00CCFF0073FF00B3FF00
CCFF0080FF00A6FF00A6FF0066FF00C0FF00C0FF0073FF00C0FF0059FF0000FF26E6FF00FFFF00\
FFF300FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF0000FF0CCCFF00E6FF00F3FF00
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFE600FFE600FFF300F3FF00D9FF00A6FF00D9FF00
E6FF00E6FF00CCFF00C0FF00D9FF00E6FF00E6FF00D9FF00B3FF00A6FF00D9FF00F3FF00FFF300\
FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600
A6FF00FFFF00FFFF00F3FF00FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF0099FF00D9FF00F3FF00FFFF00
FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300F3FF00C0FF00CCFF00F3FF00
FFFF00FFFF00F3FF00E6FF00F3FF00F3FF00F3FF00E6FF00CCFF0066FF00D9FF00F3FF00FFF300\
FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFE600
FFF300A6FF00C0FF00CCFF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00E6FF00D9FF0099FF00CCFF00E6FF00F3FF00FFFF00
FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFE600FFE600FFFF00CCFF00D9FF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00D9FF00B3FF00A6FF00C0FF00FFF300\
FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFE600
FFF300D9FF00E6FF0059FF0059FF00E6FF00F3FF00F3FF00F3FF00F3FF0000FF40E6FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00D9FF00CCFF0073FF00C0FF00E6FF00F3FF00FFFF00
FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFF300F3FF0059FF00F3FF00FFF300FFF300
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00CCFF0033FF00CCFF00F3FF00FFF300\
FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFE600FFF300FFFF00E6FF00CCFF00C0FF00D9FF00E6FF00E6FF00E6FF00B3FF00CCFF00E6FF00\
E6FF00E6FF00D9FF00CCFF00C0FF00B3FF0073FF00C0FF00D9FF00E6FF00F3FF00
FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFD900FFD900C0FF0080FF00D9FF00FFFF00FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300F3FF00CCFF00A6FF00D9FF00F3FF00FFF300\
FFE600FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFE600FFF300FFF300FFFF00F3FF00C0FF0059FF00B3FF00CCFF00CCFF00A6FF00B3FF00CCFF00\
D9FF00CCFF00C0FF0059FF0000FF26B3FF00A6FF004CFF0080FF00E6FF00F3FF00
FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFD900FFF300E6FF00E6FF00FFF300FFE600FFE600
FFD900FFD900FFD900FFE600FFE600FFE600FFF300F3FF00B3FF004CFF00CCFF00CCFF00F3FF00\
FFFF00FFF300FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFE600FFE600FFF300FFFF00F3FF00D9FF00C0FF008CFF00A6FF0066FF0099FF0073FF00B3FF00\
C0FF00B3FF0066FF003FFF00C0FF00CCFF00C0FF004CFF00B3FF00D9FF00E6FF00
E6FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFD900FFE6008CFF00FFFF00FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFF300C0FF00E6FF00E6FF00CCFF00C0FF00A6FF00\
C0FF00FFF300FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600
FFE600FFE600FFF300FFFF00FFFF00E6FF00D9FF0000FFA6B3FF00C0FF00C0FF00A6FF0033FF00\
4CFF0099FF00C0FF00D9FF00E6FF00E6FF00D9FF00B3FF0000FF334CFF008CFF00
E6FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFF300FFF300FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFF300C0FF00FFFF00FFFF00F3FF00D9FF00A6FF00\
FFFF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600
FFE600FFE600FFF300FFFF00FFFF00E6FF00CCFF0099FF00CCFF00D9FF00D9FF00C0FF00C0FF00\
B3FF00A6FF00D9FF00E6FF00F3FF00F3FF00E6FF003FFF00CCFF00CCFF0000FF00
D9FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFE600FFF300FFFF00A6FF00C0FF00\
FFFF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600
FFE600FFF300FFF300FFFF00F3FF00E6FF00B3FF00C0FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00A6FF00E6FF00F3FF00FFFF00FFFF00F3FF00C0FF00F3FF00E6FF00CCFF00
C0FF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFFF00B3FF00\
FFFF00FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600
FFF300FFF300FFFF00FFFF00CCFF00C0FF0073FF00CCFF00E6FF00F3FF00F3FF00F3FF00F3FF00\
E6FF008CFF00E6FF00FFFF00FFFF00FFF300FFF300FFFF00FFFF00FFFF00F3FF00
19FF00E6FF00F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300E6FF00\
FFFF00FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300
FFF300FFF300FFFF00F3FF00E6FF00A6FF0019FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00D9FF00D9FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
33FF0019FF00E6FF00F3FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600B3FF00\
CCFF00FFF300FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00D9FF0073FF00CCFF00D9FF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFF300FFE600FFE600FFE600FFE600FFE600FFF300FFF300
F3FF00A6FF00C0FF00D9FF0099FF00FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFE600F3FF00\
C0FF00F3FF00E6FF00FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300A6FF00CCFF00
E6FF00E6FF00E6FF00E6FF00CCFF0099FF00E6FF00F3FF00FFFF00FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
F3FF00E6FF00D9FF004CFF00E6FF00FFFF00FFF300FFE600FFE600FFD900FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFF300\
E6FF00B3FF00FFFF00FFE600FFD900FFCC00FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300F3FF00CCFF00
80FF00B3FF00CCFF00CCFF00A6FF00CCFF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFF300FFFF00E6FF0066FF00D9FF00F3FF00FFFF00FFFF00FFF300FFD900FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600\
F3FF00C0FF00F3FF00FFFF00FFFF00FFE600FFCC00FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00F3FF00D9FF00
66FF00A6FF0099FF008CFF00B3FF00B3FF00E6FF00FFFF00FFF300FFF300FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFF300FFFF0000FF408CFF0080FF00C0FF00E6FF00FFE600FFD900FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFE600\
B3FF00F3FF00E6FF0099FF00FFF300FFD900FFCC00FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF0033FF00
CCFF00D9FF00C0FF00D9FF00D9FF00C0FF00D9FF00FFFF00FFF300FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600E6FF00F3FF00FFFF00F3FF008CFF00FFFF00FFE600FFD900FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFE600\
FFE600FFE600FFFF00C0FF00FFF300FFCC00FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00E6FF00B3FF00C0FF00B3FF00
E6FF00F3FF00F3FF00F3FF00FFFF00F3FF004CFF00E6FF00FFF300FFE600FFE600FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900CCFF00FFF300FFF300FFFF00D9FF00D9FF00FFE600FFD900FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFD900FFE600F3FF00FFF300FFCC00FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600E6FF00FFFF00\
FFF300FFF300FFFF00D9FF00F3FF00E6FF00D9FF00B3FF00CCFF00CCFF00B3FF00
F3FF00FFFF00FFF300FFF300FFF300FFFF00E6FF00CCFF00F3FF00FFE600FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFE600FFF300F3FF00FFE600FFD900FFCC00FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFE600F3FF00FFD900FFC000FFC000FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFF300E6FF00C0FF00\
F3FF00F3FF00E6FF00B3FF0080FF00D9FF00E6FF00E6FF00F3FF00FFFF00D9FF00
F3FF00FFF300FFE600FFE600FFE600FFE600FFFF00F3FF00F3FF00FFE600FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600A6FF00F3FF00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFCC00FFD900FFFF00FFD900FFC000FFC000FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00CCFF00
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFFF00CCFF00\
C0FF0073FF00C0FF00C0FF00E6FF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFD900FFD900FFE600FFE600FFE600C0FF00FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFF300FFCC00FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFCC00FFCC00FFD900FFC000FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFE600
D9FF00FFFF00E6FF00FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF00\
A6FF00CCFF00C0FF00D9FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFE600
E6FF0080FF00C0FF00FFFF00FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00E6FF00C0FF00\
CCFF00E6FF00F3FF00E6FF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900
FFF300FFFF00CCFF00B3FF00F3FF00FFFF00FFFF00F3FF00A6FF00E6FF00E6FF00D9FF00A6FF00\
E6FF00FFFF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900
FFE600FFF300FFFF00E6FF00C0FF00CCFF00E6FF00E6FF00A6FF00B3FF00CCFF00C0FF00CCFF00\
F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900
FFE600FFE600FFF300FFFF00B3FF0099FF00C0FF0073FF00B3FF00A6FF0026FF00A6FF00C0FF00\
F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900
FFE600FFE600FFF300FFFF00F3FF00CCFF003FFF00CCFF00D9FF00D9FF00C0FF00D9FF00CCFF00\
D9FF00FFFF00FFF300FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFE600FFE600FFF300FFFF00F3FF00D9FF00C0FF00E6FF00F3FF00F3FF00F3FF00FFFF00F3FF00\
C0FF0073FF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFE600FFE600FFF300FFFF00F3FF0099FF00CCFF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300\
FFFF00FFFF00FFF300FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600
FFE600FFE600FFF300FFFF00F3FF00C0FF00CCFF00F3FF00FFFF00FFF300FFF300FFF300FFE600\
FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFF300FFF300F3FF0099FF003FFF00D9FF00FFFF00FFF300FFF300FFE600FFE600FFE600\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFFF00F3FF00CCFF0099FF0080FF00FFFF00FFF300FFF300FFE600FFE600FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFE6008CFF00FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00E6FF00A6FF00D9FF00F3FF00FFFF00FFF300FFE600FFE600FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFF300FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600CCFF000CFF00F3FF00FFFF00FFFF00
FFFF00FFFF00F3FF00E6FF0080FF00D9FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFCC00CCFF00F3FF00FFE600FFE600FFE600FFF300CCFF00FFF300FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFF300FFFF00D9FF00D9FF00F3FF00F3FF00
F3FF00F3FF00E6FF00D9FF0080FF00E6FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFC000FFD900FFE60026FF00B3FF00FFFF00F3FF00A6FF00A6FF00FFFF00C0FF00FFF300FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFFF00E6FF003FFF00CCFF00C0FF00
D9FF00E6FF00D9FF00C0FF0000FF26E6FF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFC000FFCC00FFCC00FFE600E6FF00D9FF00E6FF00E6FF00A6FF00C0FF00B3FF00F3FF00FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00B3FF008CFF008CFF00
A6FF00C0FF000CFF00A6FF008CFF00CCFF00E6FF00FFFF00FFF300FFE600FFE600FFD900FFD900\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900\
FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF0099FF00
73FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0073FF00
80FF00A6FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFE600FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0080FF0000FF00
8CFF00A6FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFE600FFFF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00A6FF008CFF004CFF00
59FF0080FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600
FFE600FFF300C0FF008CFF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF0099FF0059FF0019FF00
80FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600
FFE600FFF300F3FF00A6FF00CCFF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00E6FF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00CCFF00C0FF0059FF004CFF0066FF0033FF0066FF00
8CFF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFF300FFFF00F3FF0099FF00CCFF00D9FF00F3FF00F3FF00F3FF00E6FF0073FF00F3FF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF008CFF0073FF003FFF00
0CFF0099FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFF300FFF300FFFF00C0FF0059FF0066FF00D9FF00E6FF00E6FF00D9FF008CFF00E6FF00\
F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF0073FF0000FF33
4CFF0080FF008CFF008CFF0000FF99C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFF300FFFF00E6FF00C0FF008CFF00C0FF0099FF00CCFF00A6FF00C0FF00E6FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF008CFF0073FF00
0CFF0019FF0066FF008CFF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFF300FFFF00F3FF00CCFF0073FF0059FF0073FF00A6FF0000FF19C0FF00D9FF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF008CFF0073FF00
00FF0C66FF0099FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFF300FFFF00E6FF0099FF00A6FF00C0FF0026FF0099FF0073FF0099FF00B3FF00\
D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF008CFF0080FF0000FF00
00FF1900FF0099FF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFF300F3FF0073FF00CCFF00D9FF00D9FF00CCFF00C0FF00A6FF0000FF0CB3FF00\
CCFF00CCFF0080FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF0066FF0000FF4C26FF00
66FF0080FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFF300FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00B3FF000CFF008CFF00\
A6FF00A6FF00B3FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00C0FF00CCFF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF008CFF0066FF000CFF00
59FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00B3FF008CFF008CFF00\
4CFF0066FF00C0FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00C0FF00B3FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF008CFF0066FF0019FF00
59FF0080FF008CFF0099FF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF0066FF00C0FF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00D9FF0099FF00CCFF00C0FF00\
B3FF0073FF00A6FF00C0FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00A6FF008CFF00\
B3FF00C0FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF008CFF00C0FF00C0FF00C0FF00B3FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0080FF0073FF0059FF0026FF00
3FFF0073FF0080FF0073FF0000FF268CFF00A6FF00A6FF00A6FF0099FF0026FF008CFF00CCFF00\
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00D9FF00D9FF00\
C0FF0059FF0000FF7373FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0080FF00\
80FF00C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF0066FF008CFF00A6FF00A6FF0066FF00\
A6FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF003FFF0019FF004CFF00
19FF0000FF004CFF0019FF0000FF6680FF0099FF008CFF0066FF0066FF0099FF00C0FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00\
CCFF00C0FF00A6FF0073FF00C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF0080FF00\
80FF00B3FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF0099FF004CFF008CFF008CFF0073FF00\
99FF00A6FF0099FF008CFF0099FF008CFF008CFF0033FF000CFF0073FF0080FF00
80FF0073FF0019FF0000FF7300FF264CFF0073FF000CFF0000FF0099FF00B3FF00C0FF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00\
E6FF00D9FF00CCFF00A6FF00B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF00\
3FFF00B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00A6FF0073FF004CFF0000FF333FFF0059FF00\
66FF008CFF0080FF004CFF0066FF000CFF0059FF0000FF0073FF008CFF0099FF00
99FF008CFF003FFF003FFF0059FF0066FF0026FF0026FF0073FF0099FF00B3FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
E6FF00D9FF00D9FF00C0FF0026FF00B3FF00C0FF00CCFF00D9FF00D9FF00CCFF00
4CFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00\
59FF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0099FF008CFF0066FF0059FF000CFF00\
3FFF0073FF003FFF0019FF003FFF0059FF008CFF0099FF0099FF00A6FF00A6FF00
A6FF0099FF0073FF0059FF008CFF0080FF0073FF0000FF2659FF008CFF00A6FF00C0FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00C0FF00B3FF00
D9FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00\
E6FF00E6FF00D9FF00CCFF0026FF0066FF008CFF00C0FF00CCFF00CCFF00B3FF00
80FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00\
3FFF00A6FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF008CFF0066FF000CFF00\
19FF004CFF0033FF0000FF4073FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00
B3FF00A6FF0073FF0099FF0099FF0099FF0080FF0059FF0000FF0C59FF0099FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00CCFF00C0FF0000FF73C0FF00
E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00E6FF00D9FF00CCFF00B3FF0080FF0080FF00B3FF00B3FF00B3FF00A6FF00
4CFF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF0099FF00\
00FF0099FF00A6FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF0080FF0066FF0026FF00\
00FF0C00FF0000FF7359FF0080FF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF0000FF0000FF0C80FF0099FF00B3FF00B3FF00\
C0FF00C0FF00B3FF00C0FF00CCFF00CCFF00CCFF00C0FF0066FF0099FF00B3FF00
E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00E6FF00D9FF00C0FF008CFF0073FF0080FF008CFF0099FF0000FF80
A6FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF0099FF00\
33FF004CFF008CFF00B3FF00B3FF00B3FF00B3FF0099FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0073FF0059FF000CFF000CFF00\
0099FF00FF7326FF0033FF0026FF008CFF00A6FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0080FF004CFF004CFF0080FF0099FF00A6FF00B3FF00\
B3FF00A6FF003FFF00B3FF00C0FF00C0FF00A6FF008CFF0099FF00CCFF00D9FF00
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00E6FF00CCFF00B3FF0066FF0080FF004CFF0033FF004CFF0059FF00
99FF00B3FF00C0FF00C0FF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF0099FF00\
73FF0019FF008CFF00A6FF00A6FF00A6FF0080FF0000FF0CB3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF008CFF0073FF0033FF0000FF19\
00FF8000FF664CFF0073FF008CFF0099FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00A6FF008CFF004CFF0019FF0066FF003FFF0099FF0099FF00\
99FF008CFF004CFF008CFF00A6FF00A6FF0080FF008CFF00C0FF00D9FF00E6FF00
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00E6FF00C0FF008CFF00B3FF00B3FF0080FF008CFF0080FF0000FF19
73FF008CFF00B3FF00C0FF00C0FF00C0FF00B3FF008CFF00A6FF00B3FF00B3FF00A6FF008CFF00\
66FF000CFF0080FF0080FF008CFF008CFF0000FF8099FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF008CFF0073FF0026FF003FFF00\
3FFF0000FF0C4CFF0080FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00A6FF0066FF004CFF0073FF0000FF1900FF0C80FF0080FF00\
80FF004CFF000CFF0000FF0080FF0073FF004CFF0099FF00C0FF00CCFF00D9FF00
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900
FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00E6FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF008CFF0059FF00
66FF0099FF00A6FF00B3FF00B3FF00B3FF0059FF0059FF0080FF0099FF0099FF0099FF0080FF00\
00FF0000FFCC3FFF0000FF0C73FF0059FF0059FF0099FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF004CFF0059FF0000FF3359FF00\
66FF0000FF0000FF2673FF0080FF0099FF00B3FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00A6FF008CFF00A6FF0099FF0080FF004CFF0000FFE659FF00\
26FF0000FF0C33FF0080FF0080FF0073FF0059FF008CFF00B3FF00CCFF00D9FF00
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFF300
F3FF00FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00CCFF00C0FF00B3FF008CFF0033FF00
73FF008CFF00A6FF00A6FF00A6FF00A6FF008CFF004CFF0026FF0073FF0066FF0066FF003FFF00\
59FF0073FF0059FF000CFF003FFF0019FF0059FF0080FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00A6FF00A6FF0099FF0099FF0080FF004CFF0059FF000CFF0080FF00\
8CFF0073FF0000FF0C19FF004CFF004CFF0026FF00C0FF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF008CFF003FFF0073FF0099FF00\
99FF0059FF0073FF0099FF00A6FF0099FF0066FF0026FF008CFF00C0FF00D9FF00
D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFF300
A6FF00FFF300FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF008CFF0000FF00
4CFF0000FF008CFF0099FF0099FF008CFF0033FF0033FF0000FF0C33FF0000FF0C59FF0080FF00\
8CFF008CFF0080FF0066FF0073FF0059FF0000FF0066FF008CFF0099FF0099FF00
99FF0073FF0099FF00A6FF00A6FF0099FF0019FF0066FF0033FF0080FF0099FF008CFF0099FF00\
A6FF0099FF0073FF008CFF0059FF0099FF00C0FF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0059FF0059FF0099FF00B3FF00\
B3FF00A6FF008CFF00B3FF00B3FF00A6FF008CFF0000FF2699FF00B3FF00CCFF00
CCFF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFF300
80FF00C0FF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF0019FF008CFF008CFF00
59FF000CFF0073FF0080FF0080FF0066FF0000FF1933FF0000FF400CFF003FFF0073FF0099FF00\
99FF00A6FF0099FF0099FF008CFF0066FF0000FF0066FF0080FF008CFF008CFF00
80FF0000FFB333FF008CFF008CFF008CFF0066FF0033FF0080FF0099FF00A6FF00B3FF00B3FF00\
B3FF00B3FF0099FF00B3FF00A6FF0099FF00C0FF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF0099FF0033FF0099FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF003FFF0000FF008CFF0000FF4CA6FF00
59FF00CCFF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFFF00
CCFF00D9FF00F3FF00C0FF00FFF300FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF00B3FF00A6FF00
73FF0066FF0000FF4C26FF003FFF0066FF0019FF0073FF004CFF0033FF0073FF008CFF00A6FF00\
A6FF00A6FF00A6FF00A6FF0099FF0080FF000CFF003FFF004CFF0080FF0080FF00
19FF0033FF0026FF004CFF0073FF0066FF0000FF403FFF008CFF00A6FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF0099FF00CCFF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0099FF00A6FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00A6FF000CFF0073FF0033FF0000FF33
A6FF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE60059FF00
D9FF0026FF00B3FF00E6FF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF00
99FF0073FF0000FF4073FF008CFF0099FF0099FF008CFF0033FF0059FF0059FF008CFF00A6FF00\
B3FF00B3FF00B3FF00B3FF0099FF0033FF0073FF0033FF0000FF3333FF0000FF4C
00FF4000FF3300FF193FFF0026FF0000FF3359FF0080FF0099FF00B3FF00B3FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF0026FF00A6FF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00A6FF00A6FF00B3FF00A6FF0073FF00
99FF00C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300
FFFF00D9FF0033FF00E6FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF00
8CFF000CFF0033FF0066FF0099FF00A6FF00A6FF00A6FF0099FF008CFF0066FF00A6FF00B3FF00\
C0FF00C0FF00C0FF00B3FF00A6FF0099FF0099FF0080FF004CFF0066FF0080FF00
73FF0000FF8C66FF0080FF0080FF0066FF0000FF5980FF0099FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00C0FF0080FF0000FF00CCFF00D9FF00\
D9FF00E6FF00E6FF00E6FF00D9FF00D9FF0099FF00C0FF00CCFF00C0FF0019FF00
80FF00A6FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300
FFFF00CCFF0066FF00D9FF00F3FF00FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF0099FF00
80FF000CFF0080FF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF004CFF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF004CFF0000FF8080FF0099FF00
99FF0080FF0080FF0099FF008CFF0080FF004CFF0019FF0000FF66A6FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF008CFF0066FF00B3FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00
C0FF0026FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300
FFFF00E6FF00CCFF00A6FF00F3FF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300F3FF00FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00A6FF00
8CFF003FFF0080FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF0000FF3399FF00A6FF00
B3FF00A6FF00A6FF00A6FF0099FF0080FF000CFF0019FF0099FF00B3FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF0099FF00B3FF00D9FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
CCFF00A6FF0073FF00C0FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300
FFF300F3FF00CCFF008CFF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFFF00D9FF00FFF300
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF00
73FF004CFF0080FF0099FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF0099FF0080FF00A6FF00B3FF00
C0FF00C0FF00B3FF00B3FF00A6FF0080FF0000FF4073FF0099FF00B3FF00C0FF00CCFF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00B3FF00D9FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
D9FF00C0FF0059FF0019FF0066FF00C0FF00CCFF00D9FF00CCFF0059FF00D9FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFF300FFF300
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300
FFF300FFFF00E6FF0000FF33E6FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00D9FF00CCFF00FFFF00
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF00
3FFF004CFF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF008CFF0066FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF008CFF004CFF0000FFF366FF0099FF0099FF00CCFF00D9FF00\
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00D9FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00CCFF00B3FF0099FF0059FF00B3FF00B3FF00C0FF00B3FF00A6FF00D9FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00CCFF0033FF00F3FF00FFFF00FFF300FFF300
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300
FFF300FFFF00E6FF0066FF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00D9FF0099FF0073FF00
FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00B3FF0080FF0033FF00
8CFF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF008CFF0099FF00C0FF00CCFF00
CCFF00CCFF00CCFF00C0FF00B3FF0066FF0099FF0080FF0059FF008CFF00B3FF00CCFF00D9FF00\
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
E6FF00E6FF00CCFF0099FF0000FF198CFF004CFF0099FF0026FF00C0FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF008CFF00CCFF00F3FF00FFFF00FFFF00FFF300
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300
FFFF00F3FF00CCFF0019FF00C0FF00CCFF00E6FF00F3FF00FFFF00FFFF00F3FF00F3FF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00B3FF0099FF00E6FF00
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00E6FF00F3FF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF0066FF008CFF0073FF0059FF00
99FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00A6FF00B3FF00CCFF00CCFF00
D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00B3FF00A6FF0000FF1999FF00C0FF00CCFF00D9FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00E6FF00D9FF00C0FF0066FF008CFF0080FF0080FF0033FF00A6FF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00C0FF0073FF00CCFF00F3FF00FFFF00FFFF00FFFF00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFFF00FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFFF00F3FF00D9FF00C0FF004CFF00B3FF00E6FF00F3FF00F3FF00F3FF00C0FF00D9FF00FFFF00\
FFFF00FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00D9FF0000FF0CE6FF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00E6FF00D9FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00D9FF008CFF00CCFF00D9FF00D9FF00CCFF00\
CCFF004CFF00B3FF00C0FF00C0FF00C0FF00B3FF0099FF004CFF004CFF0080FF00
A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00C0FF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF008CFF0099FF00C0FF00CCFF00D9FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00D9FF0059FF00C0FF00C0FF00B3FF0099FF0033FF00A6FF00C0FF00CCFF00CCFF00\
B3FF00CCFF00CCFF00C0FF00A6FF00B3FF00D9FF00F3FF00F3FF00FFFF00FFFF00
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF3008CFF00FFFF00\
FFF300FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00
FFFF00F3FF00E6FF00C0FF003FFF00B3FF00D9FF00D9FF00E6FF00D9FF00A6FF00D9FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00B3FF00E6FF00
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFFF00F3FF00D9FF003FFF00D9FF00E6FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00C0FF0099FF00C0FF00C0FF00C0FF00\
C0FF0066FF0073FF00B3FF00B3FF00B3FF00A6FF008CFF0000FF0033FF0099FF00
A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00A6FF0099FF00C0FF00CCFF00D9FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00E6FF00D9FF00D9FF00D9FF00CCFF00A6FF0033FF008CFF00B3FF00B3FF00A6FF00\
66FF00B3FF00C0FF0099FF0099FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00
FFFF00C0FF00FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFFF00D9FF00E6FF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
F3FF00F3FF00E6FF00C0FF0080FF00A6FF00B3FF00B3FF00CCFF00C0FF0099FF00D9FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF0099FF00A6FF00D9FF00
E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF000CFF0080FF00B3FF00A6FF00E6FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF003FFF0059FF00A6FF00B3FF00\
B3FF0099FF0073FF0099FF0099FF0059FF008CFF0080FF0059FF0066FF008CFF00
A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00A6FF0073FF00B3FF00CCFF00D9FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00CCFF0099FF008CFF0026FF008CFF0099FF0073FF00\
19FF0080FF008CFF0019FF0099FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00
D9FF00B3FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFFF00D9FF00D9FF00\
FFFF00FFFF00FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00D9FF00C0FF0080FF0073FF0080FF0059FF00B3FF008CFF0099FF00CCFF00E6FF00\
E6FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00C0FF003FFF00C0FF00
D9FF00E6FF00E6FF00F3FF00FFFF00FFFF00F3FF00E6FF00E6FF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF00C0FF0019FF00CCFF00E6FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF0033FF008CFF003FFF00\
99FF0080FF000CFF0080FF008CFF0066FF0066FF0059FF0026FF0000FF004CFF00
33FF00A6FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00B3FF0073FF0099FF00C0FF00CCFF00\
D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00A6FF0059FF0026FF003FFF0033FF00\
73FF0099FF0073FF0066FF0099FF00C0FF00CCFF00E6FF00E6FF00F3FF00F3FF00
D9FF00D9FF00A6FF00C0FF00F3FF00F3FF00CCFF00F3FF00FFFF00FFFF00F3FF00C0FF00C0FF00\
E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00A6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00CCFF00B3FF008CFF00C0FF00C0FF0099FF0026FF008CFF0059FF0099FF00CCFF00\
D9FF00E6FF00D9FF00CCFF00CCFF00D9FF00D9FF00CCFF00A6FF0066FF00B3FF00
C0FF00B3FF00CCFF00E6FF00F3FF00F3FF00E6FF00C0FF00CCFF00F3FF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00A6FF0059FF00B3FF00D9FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0099FF0000FF9900FF0C00FF19\
73FF0066FF000CFF0066FF0066FF0059FF0000FFCC26FF0000FF4C73FF008CFF00
A6FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF0066FF008CFF00B3FF00C0FF00\
D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00A6FF008CFF00B3FF00B3FF0000FFB3\
A6FF00B3FF00A6FF0066FF0073FF0059FF00C0FF00D9FF00E6FF00E6FF00E6FF00
FFFF00FFFF00FFFF00F3FF00C0FF00A6FF0099FF00C0FF00E6FF00CCFF00D9FF00C0FF00A6FF00\
CCFF00B3FF00F3FF00F3FF00F3FF00F3FF0066FF008CFF00CCFF00CCFF00CCFF00
D9FF00CCFF0066FF00B3FF00CCFF00CCFF00CCFF0019FF00C0FF00B3FF008CFF0073FF00C0FF00\
CCFF00D9FF00CCFF0073FF00B3FF0080FF00C0FF00B3FF0080FF008CFF0059FF00
99FF0073FF00CCFF00D9FF00E6FF00E6FF00D9FF0099FF00D9FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00B3FF0019FF00CCFF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00A6FF00A6FF0099FF0080FF0033FF00\
4CFF0026FF0019FF000CFF0000FF0C19FF0033FF0059FF0073FF008CFF00A6FF00
B3FF00C0FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF003FFF00A6FF0066FF003FFF00A6FF00\
D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00CCFF0033FF00C0FF00CCFF00CCFF00A6FF00\
CCFF00C0FF00B3FF008CFF0019FF00A6FF00C0FF00D9FF00D9FF00D9FF00D9FF00
FFE600FFE600FFE600FFF300F3FF00E6FF00D9FF003FFF00B3FF008CFF008CFF0099FF00A6FF00\
59FF00CCFF00E6FF00E6FF00E6FF00E6FF00C0FF004CFF00A6FF008CFF0080FF00
A6FF008CFF0000FF00CCFF00D9FF00E6FF00E6FF00D9FF00D9FF00CCFF008CFF0080FF0099FF00\
C0FF00C0FF00A6FF004CFF000CFF004CFF008CFF0059FF00B3FF00C0FF008CFF00
99FF004CFF00B3FF00CCFF00C0FF00CCFF00C0FF0066FF00CCFF00E6FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00C0FF0080FF00CCFF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF008CFF00\
80FF0066FF004CFF0000FF4C008CFF00FF6600FF0C59FF0080FF008CFF00A6FF00
B3FF00C0FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0099FF0073FF00B3FF00\
CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00B3FF00B3FF00D9FF00D9FF00E6FF00D9FF00\
D9FF00CCFF00B3FF0000FF6673FF00A6FF00C0FF00CCFF00CCFF00D9FF00CCFF00
FFD900FFD900FFE600FFE600FFF300FFF300F3FF00D9FF00B3FF00D9FF00C0FF00D9FF00D9FF00\
8CFF00B3FF00CCFF00D9FF00D9FF00CCFF0099FF00A6FF00C0FF0099FF008CFF00
B3FF008CFF00C0FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00A6FF0099FF003FFF00\
99FF0080FF008CFF00B3FF00B3FF0099FF008CFF00B3FF00CCFF00CCFF00CCFF00
B3FF0000FF0080FF00A6FF0033FF0066FF0099FF0026FF0099FF00CCFF00D9FF00A6FF00E6FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0026FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF0099FF00\
8CFF0073FF000CFF0000FF4000000000FFB30CFF0066FF0080FF008CFF0099FF00
A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00A6FF0073FF0099FF00\
C0FF00CCFF00D9FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00E6FF0080FF00CCFF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00C0FF008CFF004CFF0099FF008CFF00C0FF00C0FF00CCFF00C0FF00
FFD900FFD900FFD900FFD900FFE600FFE600FFF300E6FF00E6FF00F3FF00F3FF00F3FF00E6FF00\
C0FF0059FF0073FF00B3FF00C0FF0066FF00C0FF00CCFF00D9FF00D9FF00D9FF00
CCFF00A6FF0073FF00E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF0000FF0CC0FF00A6FF00\
8CFF008CFF00C0FF00CCFF00CCFF00CCFF00A6FF00CCFF00D9FF00D9FF00D9FF00
C0FF00A6FF0073FF0080FF00A6FF008CFF00A6FF00B3FF0059FF00A6FF00B3FF00A6FF00D9FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF008CFF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00A6FF0073FF00B3FF00\
C0FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF0099FF00\
80FF0066FF004CFF0000FF3300FF3300FF0C0CFF004CFF0066FF0066FF0000FF59
8CFF00A6FF00A6FF0066FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF0073FF00A6FF0059FF00\
8CFF000CFF00CCFF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00E6FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00D9FF00B3FF0080FF0099FF0000FF000CFF00A6FF00B3FF00B3FF00B3FF00
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300A6FF00FFFF00FFF300FFF300FFFF00F3FF00\
A6FF00CCFF00C0FF0073FF0000FF00B3FF00D9FF00E6FF00E6FF00F3FF00F3FF00
E6FF00B3FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00E6FF00D9FF00CCFF00\
80FF0099FF00CCFF00D9FF00E6FF00E6FF00D9FF00E6FF00E6FF00E6FF00E6FF00
D9FF00CCFF0080FF00B3FF00CCFF00CCFF00CCFF00CCFF00B3FF008CFF0000FF0C73FF00B3FF00\
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00E6FF00D9FF0000FF73D9FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00A6FF0026FF0033FF00\
A6FF00CCFF00CCFF00D9FF00CCFF00A6FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00A6FF0099FF0080FF00\
33FF0033FF0026FF003FFF004CFF004CFF003FFF0026FF0059FF0033FF0000FF80
73FF0073FF0059FF0080FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00B3FF00C0FF00CCFF00B3FF00\
59FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00D9FF0099FF00CCFF00C0FF00A6FF0080FF0000FF193FFF0073FF0080FF00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFFF00FFF300FFE600FFF300FFF300FFFF00\
CCFF00E6FF00E6FF00CCFF0080FF00A6FF00E6FF00F3FF00F3FF00F3FF00FFFF00
F3FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00\
B3FF0099FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00D9FF00A6FF00CCFF00D9FF00E6FF00E6FF00D9FF00C0FF00C0FF00CCFF0099FF00B3FF00\
8CFF00CCFF00D9FF00A6FF00D9FF00E6FF00D9FF00CCFF0080FF00CCFF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00B3FF0080FF004CFF00\
B3FF00C0FF00C0FF00C0FF00B3FF008CFF00CCFF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF0099FF0073FF0000FF00\
00FF004CFF0059FF004CFF0080FF0073FF0000FF194CFF0080FF0073FF003FFF00
73FF0033FF00A6FF00C0FF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00E6FF00C0FF00\
73FF0026FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00E6FF00D9FF00CCFF00B3FF0080FF008CFF00B3FF00B3FF0080FF00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300\
FFFF00FFFF00F3FF00C0FF008CFF00CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00\
C0FF00C0FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00E6FF008CFF00D9FF00E6FF00F3FF00F3FF00F3FF00D9FF00E6FF00E6FF00E6FF00D9FF00\
CCFF0080FF008CFF004CFF00C0FF00CCFF00CCFF00C0FF0066FF00C0FF00D9FF00
D9FF00E6FF00E6FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00A6FF0066FF0080FF00\
99FF00A6FF00B3FF00B3FF0099FF00A6FF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00A6FF0099FF0073FF00\
59FF0080FF008CFF000CFF008CFF008CFF0073FF0000FF0C99FF00A6FF00A6FF00
99FF0026FF00A6FF00C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00\
CCFF00CCFF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00F3FF00E6FF00D9FF0000FF4C73FF00B3FF00CCFF00CCFF00A6FF00
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600\
FFF300FFF300FFFF00D9FF0099FF00B3FF00F3FF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00E6FF00\
73FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00E6FF00B3FF00D9FF00F3FF00F3FF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00B3FF00B3FF0080FF00A6FF0099FF0099FF00A6FF0059FF00A6FF0099FF00
CCFF00D9FF00D9FF00CCFF00B3FF00B3FF00C0FF00C0FF00C0FF00B3FF0099FF0059FF0026FF00\
4CFF0073FF0099FF008CFF003FFF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF004CFF00\
3FFF008CFF0099FF00A6FF00A6FF00A6FF008CFF008CFF00A6FF00B3FF00B3FF00
A6FF0080FF0000FFA6C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
D9FF00A6FF00E6FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00F3FF00F3FF00E6FF00C0FF003FFF00C0FF00D9FF00E6FF00E6FF00
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600\
FFE600FFF300FFFF00F3FF0080FF00E6FF00F3FF00FFFF00FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00E6FF00\
80FF00CCFF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF004CFF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00D9FF00A6FF0066FF008CFF0066FF008CFF008CFF0033FF00A6FF00
C0FF00CCFF00CCFF00C0FF0080FF0080FF0080FF0099FF00A6FF008CFF0059FF0080FF008CFF00\
66FF000CFF0066FF003FFF0080FF00A6FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF008CFF0066FF0019FF00\
66FF0099FF00B3FF00B3FF00B3FF00B3FF00A6FF0059FF00B3FF00C0FF00C0FF00
C0FF00C0FF00A6FF00B3FF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00D9FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00F3FF00E6FF00C0FF00B3FF00D9FF00E6FF00F3FF00F3FF00
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFE600FFF300FFFF00E6FF00CCFF00F3FF00FFFF00FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00E6FF00\
33FF00CCFF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00E6FF00CCFF0080FF00C0FF00B3FF00C0FF00B3FF0000FF4C99FF00
B3FF00B3FF00B3FF00A6FF0080FF0033FF0000FF0C73FF0066FF0080FF00A6FF00A6FF00A6FF00\
99FF0000FFA680FF0059FF0073FF0080FF00B3FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF008CFF0000FF1980FF00\
8CFF0000FF40B3FF00C0FF00C0FF00C0FF00B3FF004CFF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF0073FF00B3FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFFF00F3FF00D9FF0066FF00D9FF00E6FF00F3FF00FFFF00FFFF00
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFE600FFF300FFFF00C0FF00B3FF00FFFF00FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFFF00CCFF00\
B3FF00D9FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00F3FF00A6FF00C0FF00D9FF00D9FF00CCFF00C0FF0073FF000CFF00
66FF0099FF0099FF003FFF0073FF0073FF0000FF8C3FFF0080FF0099FF00B3FF00C0FF00B3FF00\
B3FF00A6FF0099FF0080FF0000FFBF8CFF00A6FF00B3FF00C0FF00C0FF00C0FF00
A6FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF00A6FF008CFF0026FF008CFF00A6FF00\
B3FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00C0FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFFF00F3FF00D9FF004CFF00D9FF00F3FF00FFFF00FFFF00FFFF00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFE600FFF300FFFF00A6FF00D9FF00FFFF00FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFFF00\
8CFF00E6FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00F3FF00A6FF00E6FF00E6FF00E6FF00D9FF00B3FF00A6FF00A6FF00
73FF000CFF0073FF00A6FF00B3FF00A6FF008CFF0066FF0080FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00A6FF0066FF004CFF008CFF00A6FF00A6FF00B3FF00B3FF0099FF00
66FF00B3FF00B3FF00C0FF00B3FF00B3FF00A6FF003FFF0026FF0066FF0099FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFFF00F3FF00C0FF00A6FF00E6FF00F3FF00FFFF00FFF300FFF300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900\
FFE600FFF300E6FF008CFF00E6FF00FFFF00FFF300FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFFF00\
99FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF00
A6FF004CFF00A6FF00C0FF00C0FF00C0FF00C0FF0099FF00B3FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00A6FF0073FF000CFF004CFF008CFF0099FF00A6FF0099FF0073FF00
66FF008CFF00A6FF00B3FF00B3FF00A6FF0099FF0080FF004CFF008CFF00A6FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300F3FF00D9FF0066FF00D9FF00FFFF00FFF300FFF300FFF300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900\
FFD900FFF300F3FF0073FF00F3FF00FFF300FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300\
FFFF00FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00CCFF00
00FFBF73FF00B3FF00CCFF00CCFF00D9FF00CCFF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00\
CCFF00C0FF0073FF0099FF008CFF0000FF0C73FF0073FF0080FF0000FF1959FF00
3FFF003FFF008CFF0099FF0099FF0099FF0066FF0066FF0059FF0099FF00B3FF00C0FF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFF300FFFF00E6FF00B3FF00F3FF00FFF300FFF300FFE600FFE600
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFD900FFE600F3FF0080FF00CCFF00FFF300FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00
B3FF0066FF00B3FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00CCFF00C0FF00B3FF00A6FF0080FF0000FF2659FF0073FF0066FF003FFF00
5900FF0CFF0066FF0073FF0080FF0073FF0026FF0059FF0080FF008CFF00B3FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFF300F3FF00F3FF00FFF300FFF300FFE600FFE600FFE600
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFD900FFE600E6FF00F3FF00FFF300FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00
A6FF00C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00CCFF00C0FF00A6FF0059FF0059FF0099FF00A6FF0099FF0026FF00
4CFF0059FF0026FF0073FF0059FF003FFF0033FF0080FF0099FF00A6FF00C0FF00C0FF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFFF00FFF300FFE600FFE600FFE600FFE600FFE600
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFD900FFF300E6FF00FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00B3FF00
59FF00CCFF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00D9FF00CCFF00C0FF00B3FF0059FF0099FF00B3FF00B3FF00B3FF0099FF00
66FF0073FF0099FF0099FF0099FF0080FF0033FF003FFF0099FF00A6FF00B3FF00C0FF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00E6FF00B3FF00
8CFF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00D9FF00D9FF00C0FF00A6FF0000FF73A6FF00C0FF00C0FF00C0FF00B3FF00
8CFF00A6FF00A6FF00A6FF00A6FF008CFF0000FF003FFF008CFF00A6FF00B3FF00C0FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00C0FF008CFF00
C0FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00D9FF0080FF000CFF00B3FF00C0FF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00B3FF00A6FF0099FF0080FF0033FF0059FF0073FF0026FF00A6FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00E6FF0099FF00
C0FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00E6FF00CCFF0080FF0066FF00C0FF00CCFF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00C0FF00C0FF00B3FF0099FF0080FF0026FF0080FF0099FF00A6FF00C0FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00D9FF00C0FF00
E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00CCFF003FFF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00C0FF00A6FF0066FF003FFF004CFF0080FF00A6FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFFF00D9FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00E6FF00CCFF00B3FF00B3FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00CCFF00C0FF00B3FF0099FF0000FF6673FF0099FF00A6FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00C0FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00CCFF00C0FF00B3FF0073FF004CFF0066FF008CFF00A6FF00B3FF00C0FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00D9FF00CCFF00B3FF008CFF004CFF0080FF0073FF004CFF0059FF00A6FF00C0FF00C0FF00\
CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00D9FF00CCFF008CFF0080FF00B3FF00A6FF008CFF0000FF9966FF0099FF00A6FF00B3FF00\
A6FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF004CFF00C0FF00C0FF00C0FF00C0FF00A6FF008CFF0073FF0026FF0059FF003FFF00\
8CFF00C0FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF0080FF0066FF00A6FF00C0FF00\
CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0099FF0019FF008CFF00B3FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF0099FF0080FF0033FF0099FF00C0FF00CCFF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF008CFF0033FF003FFF00CCFF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF0066FF0099FF00C0FF00D9FF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF0080FF00B3FF00CCFF00D9FF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00B3FF000CFF00C0FF00CCFF00D9FF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF0099FF0000FF00B3FF00CCFF00D9FF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF00C0FF0073FF004CFF00A6FF00CCFF00D9FF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00C0FF0080FF0059FF0080FF00B3FF00C0FF00CCFF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF0099FF0000FFB399FF00B3FF00C0FF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF0099FF0066FF0019FF0073FF00B3FF00\
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00E6FF00D9FF00D9FF00CCFF0080FF004CFF003FFF0099FF00B3FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00E6FF00CCFF00C0FF00B3FF0099FF0000FF008CFF00A6FF00C0FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00F3FF00E6FF0099FF0080FF000CFF004CFF004CFF0000FF4C8CFF00A6FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00F3FF00E6FF00D9FF00C0FF00C0FF00B3FF00A6FF008CFF0026FF0019FF00A6FF00C0FF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF00B3FF008CFF0019FF003FFF00A6FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00E6FF00D9FF00D9FF00CCFF00C0FF0066FF0059FF0000FF7399FF00B3FF00\
B3FF00C0FF00C0FF00B3FF00B3FF003FFF00E6FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF0099FF0073FF0080FF008CFF00\
80FF0099FF0080FF004CFF00B3FF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF0080FF0000FF7300FF4C\
80FF0099FF0099FF00B3FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF00A6FF0099FF0059FF0019FF008CFF00\
A6FF00C0FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00E6FF00D9FF00CCFF00A6FF00A6FF00A6FF0080FF0066FF0059FF0073FF0099FF00\
B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00D9FF00CCFF00B3FF008CFF003FFF0033FF0059FF0066FF0073FF0066FF00\
B3FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF0080FF004CFF008CFF0099FF00A6FF00B3FF00\
C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00E6FF00E6FF00CCFF00D9FF00
D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0066FF004CFF008CFF00A6FF00B3FF00C0FF00\
C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFFF00F3FF0080FF00CCFF00C0FF0059FF00B3FF00
A6FF00C0FF00C0FF00B3FF0099FF00A6FF0099FF003FFF004CFF0019FF00A6FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFFF00FFFF00E6FF00CCFF008CFF00A6FF0066FF00
3FFF0066FF0099FF0099FF0026FF0066FF0080FF0033FF0080FF0099FF00A6FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF00CCFF00C0FF00
C0FF00B3FF0099FF004CFF0080FF0000FF0C00FF993FFF008CFF0099FF00A6FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00D9FF00
CCFF00CCFF00B3FF00A6FF00A6FF0059FF0080FF0033FF0026FF0099FF00A6FF00B3FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00CCFF00CCFF00CCFF00A6FF00F3FF00FFFF00FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00
D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF008CFF0066FF0099FF00A6FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00C0FF0066FF00B3FF00E6FF00FFFF00FFFF00FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00
D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF0019FF0080FF0099FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF008CFF0099FF0099FF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00
E6FF00D9FF00D9FF00CCFF00C0FF00C0FF00A6FF0080FF004CFF0059FF0000FF9999FF0099FF00\
99FF0080FF00A6FF00A6FF0073FF00B3FF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00CCFF00CCFF00C0FF00A6FF0099FF00C0FF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00
E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF0099FF0066FF0000FF0C73FF008CFF008CFF00\
80FF000CFF0080FF0059FF008CFF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00A6FF0073FF00B3FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00D9FF00D9FF00CCFF00C0FF00B3FF008CFF0080FF004CFF003FFF0066FF0073FF0080FF00\
73FF0000FF1900FFF34CFF0080FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00A6FF008CFF008CFF00C0FF00CCFF00E6FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00
D9FF00D9FF00CCFF00C0FF00C0FF00A6FF008CFF0066FF0033FF0033FF0059FF004CFF003FFF00\
3FFF0000FF4C59FF0073FF008CFF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00
B3FF00A6FF0000FF33A6FF00C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
D9FF00D9FF00C0FF00B3FF00A6FF00A6FF008CFF0080FF0059FF000CFF0026FF000CFF000CFF00\
00FF0019FF003FFF0066FF0080FF008CFF0019FF00A6FF00B3FF00B3FF00B3FF00
99FF0073FF0000FF0073FF00C0FF00D9FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00CCFF00C0FF008CFF0080FF0080FF0080FF004CFF004CFF0000FF0000FF1900FFD9F300FF\
00FF8000FFF300FFCC3FFF0066FF0066FF0066FF008CFF0099FF0099FF0099FF00
8CFF0000FF0C80FF00A6FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00D9FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00C0FF00A6FF0073FF004CFF0066FF0033FF000CFF0000FF3300FFCC000000000000\
0000000000000080FF00FF0033FF000CFF0000FF0059FF0059FF0066FF0073FF00
00FF0033FF0073FF008CFF00A6FF00A6FF00B3FF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00D9FF0080FF00C0FF00CCFF00D9FF00D9FF00CCFF00
CCFF00CCFF00C0FF00A6FF0080FF0000FF3333FF0026FF0000FF59B300FF000000000000000000\
0000006600FF00FF8C0CFF0026FF004CFF0059FF0026FF0059FF0073FF008CFF00
8CFF008CFF000CFF0019FF0080FF0080FF00C0FF00CCFF00D9FF00D9FF00C0FF00E6FF00F3FF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFFF00F3FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00CCFF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00
CCFF00C0FF00B3FF0099FF0080FF0066FF0033FF0000FF59000000000000000000000000000000\
00000000000000FFA60CFF003FFF0066FF0073FF0080FF0000FF2699FF00A6FF00
A6FF00A6FF0026FF008CFF0059FF0080FF00B3FF00C0FF00C0FF00C0FF00B3FF00E6FF00F3FF00\
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFE600FFF300E6FF00D9FF0073FF0099FF004CFF0066FF0099FF00\
C0FF00CCFF00A6FF00C0FF00C0FF0099FF0080FF0099FF00A6FF00C0FF00C0FF00
C0FF00B3FF00B3FF00A6FF008CFF0073FF003FFF0000FF7300FFE6000000000000000000000000\
000000F300FF00FF7300FF4C0CFF0066FF0080FF008CFF0099FF00A6FF00B3FF00
B3FF00B3FF00B3FF00A6FF0033FF0073FF0099FF0099FF0080FF0066FF00B3FF00D9FF00E6FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFE600FFF300FFFF00F3FF00D9FF00C0FF00D9FF00C0FF00D9FF00\
CCFF0059FF0059FF0099FF004CFF0073FF0066FF000CFF0099FF00B3FF00B3FF00
B3FF00B3FF00A6FF0099FF008CFF0073FF0033FF0000FFA6F300FF000000000000000000000000\
000000A600FF00FFA600FF0033FF0066FF0080FF0099FF00A6FF00B3FF00B3FF00
C0FF00C0FF00C0FF00B3FF0059FF004CFF0059FF0033FF0066FF0099FF0059FF00A6FF00CCFF00\
E6FF00E6FF00E6FF00F3FF00E6FF00FFFF00FFF300FFF300FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300F3FF00E6FF00F3FF00F3FF00F3FF00\
E6FF00D9FF00C0FF0080FF00A6FF00B3FF00A6FF0000FF408CFF0099FF00A6FF00
A6FF00A6FF0099FF0033FF0073FF0066FF004CFF0000FF0000FFBF00FFB30000003300FF000000\
00000000000000000000FF260CFF0066FF0080FF008CFF00A6FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0066FF00B3FF00C0FF00C0FF0059FF00B3FF0066FF00\
C0FF00CCFF00C0FF00D9FF00A6FF00E6FF00FFFF00FFF300FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
F3FF00E6FF00CCFF00C0FF00CCFF00CCFF00B3FF0000FF9959FF0000FF0C80FF00
8CFF008CFF0059FF0026FF0000FF2633FF0000FF660CFF0019FF0000FF2600FF4C00FF8C3300FF\
00000000000000FF8C00FF0C00FF403FFF0000FF0066FF00A6FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF0073FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00\
B3FF0033FF0059FF0073FF00A6FF0073FF00E6FF00F3FF00FFF300FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00\
FFFF00F3FF00CCFF00D9FF00D9FF00D9FF00B3FF00A6FF00A6FF0073FF004CFF00
00FF8C73FF0080FF0073FF0073FF0026FF0066FF0066FF0026FF0000FF400CFF0000FF3300FF99\
00FFCC0099FF00FFFF0CFF004CFF0059FF0026FF008CFF00B3FF00C0FF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00CCFF0073FF00C0FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00CCFF00C0FF00E6FF00E6FF00E6FF00E6FF00FFF300FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00B3FF0099FF0066FF00
80FF0099FF00A6FF00A6FF0099FF0019FF0080FF0080FF0073FF004CFF0033FF0000FF0C0CFF00\
00FF8000FF73000CFF00FF0066FF0073FF0000FF0C0CFF00B3FF00C0FF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00CCFF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF003FFF0073FF00
8CFF00B3FF00B3FF00B3FF00B3FF0099FF0099FF008CFF0080FF0066FF0033FF003FFF003FFF00\
00FF1919FF000CFF0026FF0080FF008CFF0099FF00A6FF0080FF00CCFF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00C0FF0099FF0073FF00
B3FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF0099FF0059FF0033FF0000FFCC66FF0073FF00\
59FF0059FF003FFF004CFF0080FF0099FF00B3FF00C0FF00C0FF00CCFF00D9FF00
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00B3FF0059FF00B3FF00
C0FF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF0099FF0019FF0073FF0066FF0080FF008CFF00\
80FF0073FF004CFF004CFF0073FF0059FF00B3FF00C0FF00CCFF00D9FF00D9FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF00B3FF0019FF00C0FF00CCFF00
CCFF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF003FFF00A6FF00A6FF0059FF008CFF0099FF00\
8CFF0073FF0000FF4C73FF0099FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFFF00FFFF00E6FF003FFF0000FF0099FF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF00\
99FF0073FF0066FF0026FF0099FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFFF00FFFF00E6FF00C0FF008CFF00CCFF00D9FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00\
A6FF0099FF0080FF0033FF0099FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00
E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFFF00F3FF00A6FF0073FF0019FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00\
B3FF00A6FF008CFF003FFF008CFF00A6FF00B3FF00C0FF00CCFF00D9FF00D9FF00
E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFFF00F3FF00F3FF00E6FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00\
B3FF00A6FF008CFF0059FF0073FF0080FF0099FF00A6FF00C0FF00CCFF00D9FF00
D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00\
B3FF00A6FF008CFF0066FF004CFF0033FF0073FF0059FF00A6FF00C0FF00CCFF00
CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00\
B3FF0099FF0073FF003FFF008CFF0080FF0000FF0C99FF008CFF0073FF00A6FF00
00FF33CCFF0099FF00E6FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00\
A6FF0099FF004CFF0026FF0099FF00B3FF00A6FF00C0FF00C0FF00B3FF0080FF00
19FF0059FF0080FF00D9FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF00A6FF00\
99FF008CFF0059FF008CFF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00CCFF00
C0FF00C0FF00CCFF0099FF00E6FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF004CFF00\
59FF0059FF004CFF003FFF00A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF00A6FF0073FF00\
66FF0073FF0099FF00A6FF0019FF00C0FF00D9FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00B3FF00B3FF00A6FF0099FF0066FF003FFF00\
80FF00A6FF00B3FF00C0FF00C0FF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00C0FF008CFF0066FF0099FF008CFF0080FF004CFF00\
8CFF00A6FF00C0FF00CCFF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00B3FF00C0FF00C0FF00C0FF00A6FF0080FF00\
73FF00A6FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00D9FF00CCFF00CCFF00B3FF008CFF00\
00FF8C26FF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF00\
80FF0080FF00B3FF00C0FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF00\
99FF000CFF0080FF00A6FF00B3FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF00\
8CFF0000FF0099FF00B3FF00A6FF00C0FF00E6FF00F3FF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00A6FF008CFF00\
59FF0080FF00C0FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF008CFF00\
80FF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00D9FF00C0FF00A6FF00\
26FF00B3FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00D9FF00C0FF008CFF00\
00FF00B3FF00CCFF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00D9FF00C0FF008CFF00\
99FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF003FFF00\
C0FF00D9FF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0099FF0099FF00\
CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00D9FF00B3FF0073FF00A6FF00\
C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00B3FF0080FF0026FF00\
80FF00D9FF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00B3FF00B3FF0099FF0073FF00A6FF00\
C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00CCFF00A6FF00A6FF0080FF0073FF00A6FF00\
C0FF00CCFF00D9FF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF004CFF0033FF00\
B3FF00C0FF00C0FF00CCFF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF0099FF004CFF00\
8CFF0099FF0033FF00C0FF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF0099FF0073FF00\
73FF00A6FF00C0FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00B3FF00A6FF0059FF004CFF00\
80FF00B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF008CFF0080FF0000FF5980FF00\
99FF00B3FF00CCFF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00B3FF0099FF0026FF0080FF00\
A6FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF0066FF0080FF00\
A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00CCFF008CFF00
C0FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF008CFF0059FF0000FF264CFF00\
8CFF00A6FF00A6FF00A6FF00B3FF00CCFF00CCFF00CCFF00C0FF0019FF0080FF00
D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFF300FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300F3FF00CCFF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00B3FF00A6FF0073FF0080FF0080FF008CFF00\
26FF0073FF0033FF0019FF00A6FF00B3FF00C0FF00B3FF00A6FF0080FF00CCFF00
D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFF300E6FF00FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF008CFF00E6FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00A6FF00CCFF00D9FF00
D9FF00CCFF00B3FF0080FF00B3FF00A6FF0026FF0000FF268CFF0099FF0099FF00B3FF00B3FF00\
8CFF0073FF0000FF0C3FFF0000FF0099FF0099FF0033FF0099FF00C0FF00D9FF00
E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFCC00FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300F3FF008CFF00F3FF00FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00F3FF0099FF00C0FF00
D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00A6FF00A6FF00C0FF00
C0FF00C0FF00B3FF0073FF0066FF0073FF0026FF0099FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
B3FF008CFF008CFF008CFF008CFF0066FF003FFF0000FF26A6FF00CCFF00D9FF00
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFCC00FFD900E6FF0059FF00D9FF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00F3FF00B3FF00F3FF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00D9FF00C0FF0019FF00
80FF00D9FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0033FF0099FF00
99FF00A6FF0099FF004CFF0080FF008CFF0066FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
C0FF00B3FF00B3FF00B3FF00A6FF0099FF0000FF0C8CFF00B3FF00CCFF00D9FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
FFFF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFCC00FFCC00FFE600D9FF00F3FF00D9FF00E6FF00F3FF00F3FF00\
E6FF00FFFF00FFFF00FFFF00F3FF0099FF00E6FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF00B3FF00
99FF00CCFF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0099FF0066FF00
4CFF0099FF0080FF000CFF0099FF00B3FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00CCFF00\
CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0080FF0066FF008CFF004CFF00CCFF00
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00D9FF00CCFF00\
0CFF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600FFE600FFF300CCFF00A6FF00C0FF00\
CCFF00F3FF00F3FF00E6FF00D9FF0033FF00CCFF00D9FF00E6FF00F3FF00F3FF00
A6FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00C0FF00
99FF00B3FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF0099FF0026FF00
59FF0073FF0059FF0080FF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00C0FF00A6FF0033FF004CFF00A6FF00C0FF00CCFF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00E6FF00D9FF00C0FF00B3FF00\
E6FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300D9FF00D9FF00\
99FF00CCFF003FFF00A6FF0026FF00B3FF0033FF003FFF00D9FF00E6FF00E6FF00
99FF00E6FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00
B3FF0099FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00A6FF00A6FF0099FF0066FF00
00FFE60CFF0026FF0073FF00A6FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00CCFF00C0FF0099FF004CFF008CFF00A6FF00C0FF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00C0FF008CFF00B3FF00\
F3FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300F3FF00\
CCFF0099FF00C0FF00B3FF00CCFF00D9FF00C0FF0080FF00C0FF00A6FF00C0FF00
4CFF00D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00
C0FF00A6FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00A6FF0080FF0000FF0C4CFF00
00FF7300F3FF73FF008CFF003FFF00A6FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00CCFF00C0FF0099FF003FFF0080FF0099FF00B3FF00C0FF00
CCFF00CCFF00CCFF00CCFF0000FF00CCFF00D9FF00D9FF00CCFF00C0FF003FFF00C0FF00E6FF00\
FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFFF00\
D9FF00B3FF00F3FF00F3FF00F3FF00E6FF00D9FF00B3FF0099FF00A6FF00A6FF00
99FF00B3FF00D9FF00A6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00
B3FF0073FF00B3FF00C0FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF0080FF0059FF00
59FF0033FF0066FF00B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00CCFF00A6FF008CFF0099FF004CFF0033FF0099FF00B3FF00
C0FF00C0FF00A6FF00A6FF0000FF26A6FF00C0FF00C0FF00B3FF008CFF00CCFF00E6FF00F3FF00\
FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFFF00\
80FF00F3FF00FFFF00FFFF00FFFF00F3FF00E6FF00B3FF00CCFF00D9FF00D9FF00
C0FF0059FF0033FF00B3FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00
B3FF0080FF000CFF00B3FF00CCFF00CCFF00CCFF0000FF33CCFF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF0033FF0080FF00
8CFF000CFF008CFF00B3FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00CCFF0099FF00C0FF00C0FF00A6FF008CFF0073FF000CFF00
99FF0099FF008CFF0026FF0059FF0066FF0080FF0099FF004CFF0099FF00D9FF00E6FF00F3FF00\
FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900FFE600FFFF00\
80FF00FFFF00FFF300FFF300FFF300FFFF00F3FF00A6FF00E6FF00F3FF00E6FF00
CCFF00CCFF00CCFF0099FF00C0FF00E6FF00E6FF00E6FF00F3FF00F3FF00E6FF00B3FF00C0FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00
C0FF0080FF0073FF00A6FF00B3FF00C0FF00B3FF0066FF00C0FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00A6FF00A6FF008CFF004CFF00A6FF00
A6FF0059FF0080FF00B3FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF0099FF003FFF0099FF00
99FF0066FF0066FF0073FF008CFF00B3FF00A6FF0099FF0080FF00B3FF00CCFF00E6FF00F3FF00\
FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600\
FFF300FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00FFFF00FFFF00FFFF00
F3FF00F3FF00E6FF00D9FF00B3FF008CFF00CCFF00B3FF00D9FF00E6FF00D9FF00C0FF0080FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00
B3FF008CFF0066FF008CFF000CFF00A6FF0073FF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF0026FF0000FF8080FF00B3FF00
C0FF00C0FF00C0FF00A6FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF0066FF003FFF008CFF00C0FF00
C0FF00C0FF00B3FF00A6FF00C0FF00CCFF00C0FF00B3FF0073FF0099FF00A6FF00CCFF00F3FF00\
FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00F3FF00F3FF00D9FF0000FF2600FF0CA6FF00CCFF00CCFF00CCFF00A6FF00B3FF00\
CCFF00D9FF00E6FF00E6FF00E6FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00
99FF004CFF008CFF0066FF0000FFCC4CFF0033FF0099FF00B3FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0073FF008CFF00A6FF0099FF00C0FF00
D9FF00D9FF00D9FF00B3FF00D9FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00C0FF008CFF00A6FF00CCFF00
D9FF00D9FF00CCFF00CCFF00D9FF00D9FF00CCFF00C0FF00A6FF0000FF4CB3FF00D9FF00E6FF00\
F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00F3FF00E6FF00D9FF00B3FF008CFF00B3FF003FFF00A6FF0073FF00A6FF00\
C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00C0FF008CFF00B3FF0099FF003FFF00
80FF00A6FF00B3FF00A6FF00A6FF0099FF0080FF0000FF8CA6FF00B3FF00C0FF00C0FF00B3FF00\
C0FF00C0FF00C0FF00B3FF0099FF000CFF008CFF00B3FF00CCFF00CCFF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00C0FF0059FF00CCFF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00C0FF0066FF008CFF00C0FF00CCFF00D9FF00\
E6FF00E6FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF0033FF00A6FF0073FF0099FF0099FF0000FF00\
80FF00C0FF00CCFF00CCFF00CCFF00C0FF00B3FF0033FF0066FF0073FF008CFF00
B3FF00C0FF00C0FF00C0FF00B3FF00A6FF0059FF0073FF0099FF00A6FF00B3FF00A6FF008CFF00\
99FF00A6FF00A6FF0099FF0000FF99A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00D9FF00B3FF00C0FF00D9FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF00B3FF0059FF00A6FF0099FF00CCFF00\
C0FF00CCFF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFFF00FFFF00F3FF00C0FF00C0FF00CCFF00CCFF00C0FF00B3FF0059FF00\
8CFF00B3FF00C0FF00C0FF00C0FF00B3FF0019FF0000FF2600FF2659FF0066FF00
C0FF00CCFF00CCFF00CCFF00C0FF00B3FF0073FF0073FF0019FF008CFF008CFF0073FF0000FF33\
59FF0033FF0073FF004CFF0080FF00B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00D9FF0099FF00C0FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF0099FF00B3FF0099FF008CFF0033FF00\
C0FF00E6FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFFF00F3FF0066FF00D9FF00D9FF00D9FF00CCFF00C0FF008CFF00\
80FF0099FF00B3FF00B3FF00A6FF0080FF0019FF008CFF0073FF0080FF00C0FF00
CCFF00CCFF00D9FF00D9FF00CCFF00B3FF00A6FF00A6FF0080FF0059FF008CFF0080FF0059FF00\
8CFF0099FF0099FF0059FF008CFF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00F3FF00CCFF0000FF00CCFF00E6FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00B3FF00B3FF00D9FF00CCFF00C0FF008CFF00\
A6FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00B3FF0099FF00\
99FF0033FF0073FF0080FF0026FF008CFF0000FFFFB3FF00B3FF00A6FF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00B3FF0019FF0099FF00B3FF00C0FF00A6FF00\
C0FF00B3FF00B3FF0099FF0019FF0033FF00C0FF00D9FF00E6FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00F3FF00D9FF00B3FF00C0FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF0099FF00D9FF00E6FF00E6FF00CCFF000CFF00\
33FF0059FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00B3FF00C0FF00\
C0FF00A6FF0080FF0080FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF0099FF00A6FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00B3FF0073FF0066FF00B3FF00CCFF00D9FF00E6FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00C0FF00E6FF00F3FF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00\
A6FF00C0FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00E6FF00D9FF00\
CCFF00B3FF0000FF2680FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF003FFF00C0FF00CCFF00D9FF00D9FF00\
D9FF00CCFF00C0FF008CFF0066FF00A6FF00C0FF00CCFF00E6FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFFF0080FF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00\
D9FF00B3FF00D9FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00\
CCFF00A6FF0073FF00A6FF00C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF0059FF00CCFF00D9FF00E6FF00E6FF00\
E6FF00D9FF00C0FF0099FF00A6FF0066FF0073FF0066FF00E6FF00F3FF00F3FF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
E6FF0066FF0000FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00\
D9FF00C0FF0073FF0099FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF008CFF00CCFF00E6FF00E6FF00E6FF00\
E6FF00E6FF0026FF00CCFF00CCFF00A6FF008CFF00CCFF00E6FF00F3FF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00\
E6FF00C0FF00A6FF00C0FF00A6FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00\
D9FF00C0FF0000FF26C0FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF0099FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0000FF26D9FF00E6FF00F3FF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00\
E6FF00C0FF00A6FF0073FF00C0FF00D9FF00E6FF00F3FF00F3FF00F3FF00E6FF00
FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00\
CCFF008CFF00A6FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00E6FF00D9FF0059FF00D9FF00E6FF00F3FF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00\
F3FF00E6FF00CCFF0000FF19B3FF00D9FF00D9FF00E6FF00E6FF00C0FF00D9FF00
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00\
3FFF0000FF66B3FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00E6FF00D9FF004CFF00C0FF00E6FF00F3FF00FFFF00
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFFF00F3FF00D9FF0099FF00A6FF00B3FF00A6FF00CCFF00C0FF0073FF00E6FF00
F3FF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00\
C0FF0033FF00B3FF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00B3FF0099FF00D9FF00E6FF00F3FF00
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFFF00F3FF00CCFF0066FF00B3FF0073FF008CFF008CFF003FFF00CCFF00E6FF00
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00F3FF00E6FF00D9FF00CCFF00\
80FF0000FF0099FF00C0FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00F3FF00E6FF0099FF0073FF00C0FF00C0FF00F3FF00
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300\
FFFF00E6FF00C0FF00D9FF00D9FF00CCFF00C0FF008CFF00A6FF00CCFF00E6FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFFF00FFFF00D9FF00F3FF00A6FF00FFF300\
FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00A6FF0080FF00\
00FF26A6FF00C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF00C0FF0026FF00CCFF00F3FF00
FFFF00FFFF00FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFF300FFFF00F3FF00F3FF00E6FF00E6FF00CCFF008CFF0080FF00C0FF00E6FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00D9FF00B3FF00F3FF00FFF300\
FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00C0FF00\
8CFF0099FF00C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00E6FF008CFF0099FF00CCFF00E6FF00
F3FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFF300FFF300FFFF00FFFF00F3FF00E6FF00C0FF0066FF00B3FF00CCFF00D9FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00D9FF008CFF0059FF00F3FF00FFF300\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00\
A6FF0073FF00C0FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFFF00F3FF00CCFF00A6FF0073FF00CCFF00
D9FF00E6FF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFF300FFF300FFFF00FFFF00D9FF00CCFF00B3FF0073FF00C0FF00CCFF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00D9FF0080FF00B3FF00E6FF00FFFF00FFF300\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00E6FF00CCFF00C0FF00\
A6FF0066FF0073FF0099FF008CFF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300F3FF00CCFF00E6FF00D9FF0059FF00
E6FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00C0FF008CFF0099FF00C0FF00
C0FF00A6FF00A6FF00C0FF00D9FF00D9FF00C0FF0099FF00C0FF00E6FF00F3FF00FFFF00FFF300\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00F3FF00E6FF00E6FF00D9FF003FFF00A6FF00\
73FF0066FF00B3FF00CCFF00D9FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFFF00FFFF00FFFF00E6FF004CFF00
E6FF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFF300FFFF00F3FF00E6FF0099FF0073FF00B3FF0080FF00
8CFF003FFF008CFF008CFF00A6FF00B3FF0099FF00B3FF00D9FF00F3FF00FFFF00FFF300FFF300\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFF300FFF30080FF00CCFF00B3FF00CCFF00CCFF00C0FF00B3FF0073FF00\
80FF0099FF00C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00D9FF00
F3FF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFF300FFFF00F3FF00D9FF0080FF00CCFF00D9FF00CCFF00
8CFF00C0FF00C0FF00C0FF00B3FF003FFF0099FF00C0FF00E6FF00F3FF00FFFF00FFF300FFF300\
FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFF300FFF300FFFF00CCFF00C0FF00B3FF0099FF00A6FF0099FF0066FF00\
80FF00A6FF00C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300F3FF00
E6FF00FFF300FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFF300FFFF00D9FF0099FF00E6FF00E6FF00F3FF00E6FF00
CCFF00D9FF00D9FF00D9FF00CCFF008CFF0099FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00E6FF00D9FF00A6FF0066FF003FFF0000E6FF\
33FF0099FF008CFF00CCFF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300
A6FF00FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFE600FFF300F3FF0073FF00CCFF00F3FF00FFFF00FFFF00F3FF00
F3FF00F3FF00E6FF00D9FF00CCFF00B3FF0073FF00B3FF00C0FF00E6FF00FFFF00FFFF00FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00F3FF00D9FF004CFF00A6FF0066FF0000FF66\
4CFF0080FF0073FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFE600FFF300F3FF00C0FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00E6FF00CCFF00A6FF0059FF00A6FF00CCFF00E6FF00F3FF00FFFF00FFFF00\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF00B3FF0099FF0000FF40\
99FF00A6FF0099FF00A6FF00CCFF00D9FF00F3FF00FFFF00FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFE600F3FF00FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00F3FF00E6FF00C0FF0066FF0099FF00C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFFF00FFF300FFE600FFE600FFD900FFCC00FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF0066FF0073FF0026FF00\
A6FF00C0FF00CCFF00CCFF0000FF0C4CFF00E6FF00FFFF00FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFFF00F3FF00D9FF00A6FF0080FF00B3FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300F3FF008CFF00CCFF00C0FF00F3FF00FFD900FFCC00FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFFF00F3FF00E6FF00C0FF00B3FF008CFF008CFF00A6FF00\
00FF66D9FF00E6FF00E6FF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300
FFF300FFFF00E6FF0080FF00A6FF00B3FF008CFF00C0FF00CCFF00E6FF00E6FF00F3FF00F3FF00\
F3FF00FFFF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFFF0066FF00D9FF00C0FF00E6FF00FFF300FFE600FFD900FFCC00FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00C0FF00B3FF0099FF00A6FF00C0FF00\
D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFF300FFFF00D9FF00D9FF00E6FF00CCFF008CFF0033FF00C0FF00D9FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00E6FF00B3FF00E6FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
E6FF0073FF0066FF00D9FF00FFF300FFE600FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00D9FF00CCFF0099FF0066FF00C0FF00\
D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFF300FFFF00FFFF00F3FF00E6FF00CCFF00B3FF00A6FF00C0FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF0000FF00CCFF00E6FF00F3FF00F3FF00E6FF00D9FF00CCFF00
73FF003FFF00F3FF00FFFF00FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00B3FF003FFF00B3FF00\
CCFF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFF300FFFF00F3FF00E6FF00CCFF00A6FF008CFF008CFF00A6FF0066FF00CCFF00\
C0FF0059FF0019FF00A6FF008CFF00C0FF00D9FF00D9FF00CCFF00A6FF00D9FF00
F3FF00FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00A6FF0080FF0080FF00C0FF00\
CCFF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFE600FFE600FFF300FFF300F3FF0099FF0066FF0066FF00C0FF00D9FF00C0FF0073FF0033FF00\
8CFF00A6FF00C0FF00D9FF00B3FF00B3FF00A6FF0099FF004CFF00B3FF00F3FF00
FFFF00FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFE600FFE600FFE600FFE600FFF300\
FFF300FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF0066FF00C0FF00D9FF00\
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFE600FFE600FFF300FFF300FFFF00E6FF00A6FF00CCFF00E6FF00E6FF00E6FF00D9FF008CFF00\
CCFF00E6FF00E6FF00E6FF00E6FF00D9FF00C0FF008CFF00C0FF00E6FF00F3FF00
FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFA600FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFE600B3FF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00C0FF0080FF00C0FF00E6FF00\
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFE600FFF300FFF300F3FF00D9FF00A6FF0080FF00F3FF00FFFF00FFFF00F3FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00CCFF0073FF00C0FF00E6FF00FFFF00
FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFFF004CFF00D9FF00D9FF00\
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF00B3FF00C0FF00D9FF00E6FF00\
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFE600FFF300FFFF00E6FF0099FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00C0FF0080FF00D9FF00E6FF00
FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFF300F3FF00C0FF00C0FF00\
A6FF00CCFF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00B3FF0066FF00C0FF00D9FF00E6FF00\
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFE600FFF300F3FF0066FF00B3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF00C0FF0080FF00C0FF00D9FF00
FFFF00FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600F3FF00F3FF00E6FF00\
C0FF0099FF00CCFF00E6FF00F3FF00F3FF00F3FF00F3FF00D9FF00A6FF00E6FF00
E6FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00B3FF0066FF0099FF00D9FF00E6FF00\
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFE600FFFF00E6FF0099FF00E6FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFFF00E6FF003FFF0019FF00A6FF00E6FF00F3FF00
FFF300FFE600FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFF300FFFF00FFFF00\
E6FF00D9FF0099FF00CCFF00D9FF00D9FF00E6FF00E6FF00CCFF004CFF00D9FF00
D9FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF008CFF0080FF00B3FF00CCFF00D9FF00\
F3FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFE600D9FF0073FF00D9FF00F3FF00FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF0066FF00CCFF00E6FF00F3FF00
FFFF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFFF00\
FFFF00F3FF00D9FF008CFF00B3FF00C0FF00D9FF00CCFF00C0FF0000FFCCC0FF00
CCFF00D9FF00D9FF00CCFF00C0FF008CFF008CFF0073FF00A6FF0099FF0080FF0099FF00CCFF00\
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFD900FFE600FFF300E6FF00D9FF00FFFF00FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFF300FFFF00F3FF00B3FF0000FF0CB3FF00D9FF00D9FF00
F3FF00FFFF00FFF300FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300\
FFFF00F3FF00D9FF00C0FF00A6FF0099FF00C0FF0073FF0066FF0073FF0080FF00
B3FF00CCFF00CCFF00B3FF003FFF0019FF00A6FF00C0FF00CCFF00C0FF0099FF008CFF00CCFF00\
D9FF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFD900FFD900FFF30080FF00E6FF00FFFF00FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFF300FFFF00A6FF00CCFF00D9FF00C0FF00A6FF008CFF00
D9FF00D9FF00B3FF00FFF300FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300\
FFFF00FFFF00F3FF00D9FF00B3FF0073FF0026FF008CFF00B3FF00B3FF0080FF00
99FF00A6FF00A6FF0073FF00A6FF00B3FF00CCFF00D9FF00D9FF00CCFF0080FF0099FF00B3FF00\
CCFF00CCFF00A6FF00F3FF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFD900F3FF00FFFF00FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFFF00CCFF00F3FF00FFFF00F3FF00E6FF00CCFF00
A6FF00F3FF00FFF300FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300\
FFFF00FFFF00F3FF00E6FF00CCFF0073FF00C0FF00CCFF00CCFF00CCFF00B3FF00
99FF008CFF0000FF26C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00D9FF00C0FF008CFF0099FF00\
80FF008CFF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFD900E6FF00FFE600FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFE600C0FF00FFFF00FFF300FFF300FFFF00F3FF0099FF00
A6FF00F3FF00FFF300FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300\
FFFF00FFFF00F3FF00D9FF00B3FF00B3FF00CCFF00D9FF00D9FF00D9FF00B3FF00
CCFF00C0FF0000FF4CC0FF00D9FF00E6FF00F3FF00F3FF00F3FF00E6FF00B3FF00CCFF00D9FF00\
CCFF008CFF00D9FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFE600FFE600FFE600FFE600FFF300F3FF00A6FF00
B3FF00E6FF00FFF300FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFF300FFF300\
FFFF00F3FF00E6FF00D9FF0080FF00C0FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00C0FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00F3FF00B3FF00E6FF00E6FF00\
D9FF00C0FF00B3FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300F3FF00
CCFF00E6FF00FFF300FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00\
FFFF00F3FF00D9FF00C0FF0059FF0073FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00CCFF00C0FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00E6FF0026FF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFE600FFF300
E6FF00E6FF00FFF300FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00\
F3FF00E6FF00B3FF0080FF0099FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00
FFFF00F3FF00E6FF0099FF00E6FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00F3FF00CCFF00C0FF00CCFF00F3FF00FFFF00FFF300FFF300FFE600FFE600
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFE600FFF300
F3FF00B3FF00FFFF00FFE600FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00\
F3FF00E6FF00C0FF004CFF0080FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00E6FF00F3FF00FFF300FFF300FFF300FFE600FFE600FFF300FFF300FFF300\
FFF300FFFF00D9FF00C0FF00C0FF00E6FF00F3FF00F3FF00FFF300FFE600FFE600
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600
FFFF0099FF00F3FF00FFF300FFE600FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFE600FFE600E6FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
E6FF00D9FF0066FF00B3FF00D9FF00E6FF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300F3FF00CCFF0099FF008CFF00CCFF008CFF00FFFF00FFF300FFE600
FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFE600
F3FF0099FF00B3FF00E6FF00FFFF00FFD900FFD900FFCC00FFCC00FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFF300FFFF0080FF00D9FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00CCFF0066FF008CFF00E6FF00F3FF00FFFF00FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFFF004CFF00D9FF00C0FF0099FF00E6FF00FFFF00FFF300FFF300
FFE600FFE600FFD900FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFD900FFE600
FFF300F3FF00C0FF00D9FF00FFF300FFE600FFD900FFD900FFCC00FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFF300FFFF00E6FF00B3FF00CCFF00CCFF00CCFF00D9FF00\
D9FF00C0FF00B3FF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFF300FFFF00F3FF00CCFF00A6FF00D9FF00F3FF00FFFF00FFFF00
FFF300FFE600FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900
FFE600FFFF0099FF00E6FF00FFFF00FFF300FFF300FFE600FFCC00FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00CCFF0066FF008CFF008CFF00C0FF00\
8CFF0066FF00B3FF00D9FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFF300FFFF00E6FF00A6FF00C0FF00CCFF00E6FF00E6FF00
C0FF00FFFF00FFD900FFD900FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900
FFE600FFFF0099FF003FFF0099FF00E6FF00B3FF00FFF300FFCC00FFCC00FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFA600FFA600FFA600FFA600FFA600
FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600FFA600\
FFA600FFA600FFA600FF9900FF9900FF9900FF9900FF9900FF9900FF9900FF9900
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00E6FF00E6FF00D9FF00C0FF00A6FF0059FF0033FF0026FF003FFF00
8CFF004CFF0000FF5999FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0080FF004CFF0066FF0099FF00A6FF00
B3FF00B3FF00A6FF0080FF008CFF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF008CFF0059FF0033FF0000FF66
0CFF0000FF9900D9FF00FFA63FFF0059FF0066FF0073FF0099FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF0099FF0080FF00
3FFF003FFF0073FF0080FF008CFF00A6FF00A6FF00A6FF00A6FF0080FF003FFF0059FF00B3FF00\
B3FF00A6FF0073FF0000FF00B3FF00C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00E6FF00E6FF00CCFF00B3FF004CFF0026FF0099FF0066FF000CFF00
3FFF0000FF8066FF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
C0FF00C0FF00B3FF00B3FF00A6FF0099FF0059FF0000FF8C66FF008CFF0099FF00
A6FF00A6FF0099FF004CFF008CFF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF0080FF0066FF003FFF00
00FF000CFF000CFF0000FF003FFF0073FF008CFF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0080FF00
00FF0000FF004CFF003FFF0073FF008CFF0099FF0099FF008CFF0080FF003FFF0073FF0099FF00\
99FF0026FF0066FF0080FF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00E6FF00D9FF00C0FF0059FF00A6FF00B3FF00B3FF008CFF0080FF00
8CFF0073FF0019FF0066FF0033FF00A6FF00B3FF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF00\
A6FF00A6FF00B3FF00A6FF00A6FF0099FF0073FF0000FF6666FF0080FF0073FF00
8CFF008CFF0080FF0033FF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF004CFF000CFF00
3FFF004CFF0033FF0000FF3359FF0073FF008CFF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF008CFF004CFF00
80FF0080FF0000FFBF0CFF0066FF0080FF0080FF0080FF0073FF000CFF0000FF2600FF0C3FFF00\
73FF004CFF0066FF0099FF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00
FFCC00FFD900FFD900FFE600FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00
99FF0080FF004CFF0066FF008CFF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF0080FF0066FF00\
80FF008CFF0099FF0099FF0099FF008CFF0059FF0019FF0000FF194CFF0019FF00
66FF0073FF004CFF0073FF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0073FF0066FF0059FF0000FF0C
3FFF0066FF004CFF000CFF003FFF0073FF0080FF0099FF00A6FF00B3FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF000CFF0099FF00
A6FF0099FF0073FF0066FF0000FF0C0CFF0000FF1900FF0C33FF0000FF3300FF2673FF0080FF00\
00FF0059FF0066FF008CFF00B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00
FFCC00FFD900FFF300FFFF00FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00
A6FF003FFF0000FF0073FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF0099FF0080FF0000FF59\
26FF0073FF008CFF0073FF0080FF0073FF0000FF804CFF0066FF003FFF0000FF59
00FF2633FF0019FF0073FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF0073FF0000FF8C19FF003FFF00
80FF0080FF0000FF0059FF0000FF4026FF000CFF0080FF0080FF00A6FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00B3FF00B3FF00B3FF00
B3FF00A6FF0099FF0073FF0000FF0073FF008CFF008CFF0073FF000CFF0073FF008CFF0099FF00\
99FF0080FF000CFF0066FF0073FF0099FF00CCFF00D9FF00D9FF00E6FF00F3FF00
FFD900FFD900FFF30099FF00FFF300FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00
A6FF0080FF0000FF7366FF0080FF008CFF0099FF00A6FF00A6FF0099FF008CFF0073FF004CFF00\
00FF4000FF4066FF0019FF0000FF8066FF0073FF0080FF0080FF0059FF0000FF73
66FF0066FF0000FF004CFF0033FF008CFF0099FF00A6FF00A6FF00A6FF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF0099FF008CFF0080FF0066FF0000FF0059FF0080FF0059FF00
8CFF0099FF0099FF0080FF004CFF0073FF0066FF004CFF0099FF00B3FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00
C0FF00B3FF0099FF004CFF0026FF0059FF00A6FF00A6FF0099FF0073FF0066FF00A6FF00A6FF00\
A6FF0099FF0080FF0000FF268CFF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00
FFD900FFE600FFF300D9FF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00
8CFF004CFF0026FF0000FF3333FF0066FF008CFF0099FF0099FF008CFF0073FF0019FF0000FF26\
00FF4C00FF0033FF0033FF0073FF008CFF008CFF0099FF0099FF008CFF0080FF00
80FF0073FF0059FF0000FF7366FF008CFF0099FF0099FF0099FF0099FF0080FF0080FF0099FF00\
99FF0099FF0099FF008CFF004CFF000CFF0066FF008CFF0099FF0099FF0099FF00
A6FF00A6FF00A6FF008CFF008CFF0099FF008CFF003FFF00A6FF00C0FF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
C0FF00B3FF008CFF0066FF0066FF00A6FF00B3FF00B3FF00B3FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00A6FF0080FF003FFF008CFF00A6FF00B3FF00C0FF00C0FF0099FF00D9FF00
FFD900FFE600FFF300C0FF00CCFF00FFFF00FFF300FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0073FF00
73FF008CFF008CFF0059FF0000FF404CFF0073FF0073FF0073FF0073FF004CFF0000FF803FFF00\
00FF0C0CFF0000FF004CFF0080FF0099FF0099FF00A6FF00A6FF0099FF0099FF00
8CFF0080FF0033FF0026FF0066FF0080FF008CFF008CFF008CFF0080FF004CFF004CFF0073FF00\
8CFF008CFF008CFF0073FF0033FF003FFF0080FF0099FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00B3FF00B3FF008CFF00B3FF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00C0FF00B3FF0059FF0080FF00A6FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF0080FF0000FF8073FF0080FF0080FF00A6FF000CFF00C0FF00D9FF00
FFD900FFE600FFFF00CCFF00CCFF00F3FF00FFFF00F3FF00FFF300FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00B3FF00
B3FF00A6FF0099FF0059FF0066FF003FFF003FFF0033FF0033FF0066FF0066FF0066FF0066FF00\
3FFF0000FF2659FF0080FF008CFF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF008CFF0073FF000CFF003FFF0000FF8073FF0080FF0080FF0019FF004CFF0000FF2659FF00\
73FF0080FF0073FF0000FF400CFF0000FF0C80FF00A6FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF0059FF00CCFF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
CCFF00C0FF00B3FF0026FF00A6FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00A6FF003FFF0073FF0000FF334CFF0000FF66A6FF00CCFF00D9FF00
FFE600FFF30099FF00B3FF00B3FF00CCFF00CCFF00D9FF00FFF300FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00
C0FF00B3FF00A6FF0099FF0080FF0059FF0026FF0066FF0080FF008CFF008CFF008CFF008CFF00\
66FF003FFF0000FF3373FF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF008CFF003FFF0066FF003FFF0000FF1959FF0000FF4059FF0000FF0C00FFD900FF8C00FF00\
00FF194CFF000CFF0000FF2659FF0080FF0099FF00A6FF00B3FF00B3FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
CCFF00C0FF00A6FF0073FF00B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00C0FF00A6FF0080FF00A6FF0059FF0099FF0066FF008CFF00C0FF00D9FF00
FFE600FFF300FFFF00F3FF00B3FF00A6FF00C0FF00F3FF00FFF300FFF300FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00
C0FF00B3FF00A6FF0099FF0073FF004CFF003FFF0080FF008CFF0099FF00A6FF00A6FF0099FF00\
00FF7380FF0059FF0073FF0099FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF0080FF0080FF008CFF0073FF0059FF0000FF2619FF0066FF004CFF000CFF0026FF0000FF19\
73FF0066FF0059FF0000E6FF59FF0080FF0099FF00A6FF00B3FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00C0FF008CFF0080FF00B3FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF0066FF00B3FF00C0FF00C0FF00B3FF0080FF0059FF0073FF00CCFF00
FFE600FFE600FFF300FFFF00E6FF00B3FF00B3FF00F3FF00FFFF00FFF300FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00
C0FF00B3FF0099FF0080FF0059FF003FFF0066FF0033FF0099FF00A6FF00A6FF00B3FF00A6FF00\
A6FF00A6FF0080FF0099FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00A6FF00A6FF0099FF008CFF0000FF5900FF0073FF008CFF008CFF0000FF6600FF4073FF00\
8CFF0080FF0073FF0000FFB326FF0080FF008CFF00A6FF00B3FF00C0FF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00C0FF0019FF0073FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00CCFF0059FF00CCFF00CCFF00CCFF00C0FF0099FF00A6FF0073FF00C0FF00
FFE600FFE600FFF300FFFF00D9FF003FFF0019FF00D9FF00E6FF00FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00
C0FF00B3FF0099FF0080FF0059FF0059FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00A6FF0080FF0059FF0066FF008CFF0099FF0099FF008CFF0059FF0099FF00\
99FF0099FF0080FF0066FF0033FF0000FF004CFF0099FF00B3FF00C0FF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
D9FF00A6FF008CFF0000FF0CC0FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00A6FF00A6FF00
FFE600FFE600FFF300FFFF00F3FF00D9FF00B3FF00B3FF00F3FF00FFFF00FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
C0FF00B3FF00A6FF0099FF0059FF0059FF008CFF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00B3FF00B3FF0099FF003FFF0073FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF008CFF0066FF0000FF0C66FF0099FF00A6FF00B3FF00C0FF00CCFF00
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00D9FF00C0FF0000FF0CA6FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF004CFF00
FFE600FFE600FFF300FFF300FFFF00E6FF0080FF00C0FF00F3FF00FFFF00FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300E6FF00F3FF00FFF300FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
C0FF00B3FF00A6FF0066FF0026FF004CFF0000FF19A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00B3FF0099FF0026FF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF0080FF0059FF003FFF0080FF0099FF00A6FF00B3FF00C0FF00CCFF00
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00CCFF00B3FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00A6FF00
FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF00A6FF00E6FF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFFF0059FF00F3FF00FFFF00FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00
C0FF00B3FF00A6FF0080FF0059FF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00B3FF0000FF0066FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF0099FF0066FF0000FF0C66FF0066FF00A6FF00B3FF00C0FF00CCFF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00D9FF00C0FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF0099FF00
FFE600FFE600FFF300FFF300FFFF00F3FF00D9FF00A6FF00E6FF00F3FF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFFF0080FF0066FF00D9FF00F3FF00FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00
B3FF00A6FF0080FF004CFF008CFF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00B3FF008CFF0066FF00A6FF00C0FF00C0FF00CCFF00CCFF00CCFF00C0FF00\
C0FF00B3FF008CFF004CFF0080FF0000FF4C33FF0080FF0066FF008CFF00CCFF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00
FFE600FFF300FFF300FFF300FFFF00F3FF00D9FF0066FF00CCFF00E6FF00F3FF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00E6FF00B3FF000CFF00D9FF00FFFF00FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00B3FF00
A6FF0059FF0000FF738CFF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00C0FF0099FF0066FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00B3FF0033FF0099FF0099FF008CFF0066FF0073FF00A6FF00C0FF00CCFF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00
FFE600FFF300FFF300FFFF00FFFF00E6FF00CCFF0073FF00C0FF00CCFF00B3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00F3FF00E6FF0099FF00C0FF00E6FF00FFFF00FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFFF00F3FF00E6FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF0080FF0099FF00
8CFF0066FF0066FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00B3FF0099FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00CCFF00\
CCFF00C0FF00B3FF00B3FF00B3FF0099FF004CFF0080FF00B3FF00C0FF00CCFF00
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00
FFF300FFF300FFF300FFFF00FFFF00E6FF00CCFF00B3FF008CFF0033FF00CCFF00E6FF00F3FF00\
F3FF00F3FF00E6FF00C0FF00E6FF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00F3FF00E6FF00C0FF008CFF00E6FF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFFF00E6FF0099FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00B3FF00CCFF00D9FF00D9FF00D9FF00D9FF00\
CCFF00C0FF00A6FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF008CFF000CFF00
3FFF003FFF0073FF0059FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00C0FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00C0FF00C0FF0099FF008CFF0000FFBFB3FF00CCFF00CCFF00
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00
FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00C0FF0099FF0099FF00CCFF00E6FF00E6FF00\
E6FF00E6FF00D9FF0099FF00CCFF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00C0FF00A6FF00E6FF00F3FF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00E6FF000CFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00A6FF0033FF00C0FF00CCFF00CCFF00CCFF00\
C0FF00B3FF004CFF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF0080FF00
00FF3373FF008CFF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF003FFF00B3FF00CCFF00CCFF00
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00
FFF300FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00B3FF0000FF19A6FF00C0FF00CCFF00D9FF00\
D9FF00D9FF00CCFF000CFF00D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00E6FF00D9FF0099FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
F3FF00D9FF0033FF00C0FF00D9FF00D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF0099FF00A6FF00A6FF00C0FF00C0FF00\
C0FF00A6FF0080FF008CFF00A6FF00B3FF00A6FF00A6FF0099FF008CFF000CFF00
0040FF59FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF0059FF00B3FF00C0FF00CCFF00
D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00C0FF008CFF0099FF00B3FF0073FF00C0FF00\
CCFF00CCFF008CFF00C0FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF0073FF0000FF0CC0FF00D9FF00E6FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
E6FF0099FF00A6FF0000FF8099FF00C0FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF004CFF0000FF7380FF00A6FF00B3FF00\
B3FF00A6FF0080FF0080FF0099FF0099FF008CFF0073FF008CFF0080FF0066FF00
00FF4073FF008CFF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00B3FF0019FF0099FF00B3FF00CCFF00
D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF008CFF004CFF004CFF004CFF0073FF00\
B3FF00B3FF004CFF00B3FF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00CCFF0099FF003FFF00CCFF00D9FF00E6FF00E6FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00F3FF00E6FF00E6FF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00
F3FF00D9FF00CCFF00A6FF0080FF00CCFF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00B3FF0080FF0066FF0099FF008CFF00\
99FF0099FF0066FF003FFF0073FF008CFF0080FF0033FF0073FF0066FF0059FF00
00FF2619FF0066FF0073FF0099FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF008CFF0000FF40A6FF00C0FF00
CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00B3FF0026FF00A6FF00B3FF00A6FF0059FF00\
73FF0000FFD93FFF00A6FF00B3FF00CCFF00D9FF00E6FF00E6FF00E6FF00D9FF00
CCFF00D9FF00D9FF00D9FF00CCFF00C0FF003FFF0099FF00C0FF00CCFF00CCFF0026FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00B3FF00CCFF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00
F3FF00E6FF00CCFF00A6FF008CFF00C0FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00B3FF008CFF0019FF0059FF0019FF00\
80FF0080FF0033FF0026FF0066FF0073FF0073FF004CFF0026FF0000FF400CFF00
59FF0073FF008CFF008CFF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF0073FF0073FF00A6FF00C0FF00
C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
D9FF00D9FF00D9FF00D9FF00D9FF00C0FF00A6FF0059FF00A6FF00C0FF00CCFF00C0FF0080FF00\
A6FF00B3FF008CFF003FFF0099FF00CCFF00D9FF00D9FF00D9FF00CCFF00B3FF00
A6FF00CCFF00CCFF00CCFF00C0FF00B3FF0073FF0073FF0033FF00B3FF00A6FF00B3FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00D9FF0099FF00D9FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00E6FF00CCFF00B3FF0059FF0080FF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00A6FF003FFF0073FF0080FF0066FF0000BFFF\
26FF0059FF0019FF0026FF004CFF000CFF003FFF003FFF0026FF004CFF0059FF00
19FF008CFF0099FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00B3FF004CFF0066FF0000FF3399FF00
73FF00C0FF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
CCFF00A6FF00C0FF00CCFF00C0FF00A6FF0080FF00C0FF00CCFF00D9FF00D9FF00D9FF00CCFF00\
CCFF00C0FF00B3FF004CFF0099FF00C0FF00CCFF00CCFF00CCFF00C0FF008CFF00
99FF0099FF00A6FF00B3FF0099FF0080FF008CFF00A6FF0000FF0066FF0059FF00B3FF00CCFF00\
D9FF00D9FF00D9FF00D9FF00CCFF008CFF00D9FF00E6FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00E6FF00D9FF00CCFF0073FF00A6FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF00A6FF00A6FF0080FF004CFF00\
66FF0066FF004CFF0033FF0000FF4C00FF1900FF0C00FF263FFF0066FF0073FF00
80FF0099FF00A6FF00B3FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00B3FF00B3FF00A6FF0080FF0073FF00
B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
73FF004CFF0059FF0066FF0099FF003FFF0066FF00CCFF00D9FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00CCFF00B3FF0080FF008CFF008CFF00B3FF00C0FF00C0FF00A6FF0000FF59
73FF0000FF0C59FF0080FF003FFF00B3FF00C0FF00C0FF0099FF00A6FF0066FF008CFF00C0FF00\
CCFF00C0FF00C0FF00CCFF00B3FF003FFF00CCFF00D9FF00E6FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
E6FF00E6FF00D9FF00CCFF00B3FF0099FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00B3FF0099FF008CFF00\
80FF0073FF0066FF003FFF0000FF1900D9FF0073FF00FF3300FF264CFF0080FF00
8CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00B3FF0066FF0080FF00
B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
A6FF0073FF0099FF00B3FF0099FF0080FF00C0FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00C0FF0073FF008CFF0066FF008CFF00A6FF0080FF0059FF00A6FF00
B3FF003FFF0099FF0073FF00A6FF00C0FF00CCFF00CCFF00CCFF00C0FF0080FF0080FF00A6FF00\
B3FF0066FF008CFF00A6FF008CFF0066FF00A6FF00B3FF00D9FF00D9FF00B3FF00
E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00D9FF00CCFF00B3FF00A6FF00C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF00\
8CFF0080FF0066FF0026FF0000FF6600000000000000FF7300FF1959FF0073FF00
80FF008CFF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00B3FF0080FF0080FF00
A6FF00B3FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
D9FF00A6FF00CCFF00CCFF00B3FF0080FF00C0FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00D9FF00B3FF00B3FF00C0FF0099FF0073FF0000FF8C73FF00C0FF00CCFF00
CCFF00C0FF00C0FF0073FF0099FF00D9FF00D9FF00D9FF00D9FF00C0FF0073FF008CFF0073FF00\
4CFF008CFF003FFF0059FF00A6FF0099FF0066FF00A6FF00C0FF00C0FF00A6FF00
D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00CCFF00A6FF0059FF00B3FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF00\
8CFF0080FF0066FF003FFF0000FF2600FF6600FF4C00FFA633FF0059FF0066FF00
73FF0073FF0066FF0099FF00A6FF00B3FF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0026FF008CFF00
33FF0099FF00A6FF0000FF8073FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
E6FF00E6FF00E6FF00D9FF00A6FF00B3FF00D9FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF008CFF00CCFF00CCFF00C0FF00A6FF0059FF0099FF00CCFF00D9FF00
D9FF00D9FF00D9FF008CFF00D9FF00E6FF00E6FF00E6FF00E6FF00CCFF00C0FF00B3FF0059FF00\
A6FF00C0FF00C0FF00A6FF00C0FF00C0FF003FFF0073FF0000FF1980FF0099FF00
CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00B3FF00CCFF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00D9FF00CCFF0080FF003FFF0059FF00A6FF0000FF33C0FF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF00\
4CFF0066FF0059FF003FFF0000FF0C26FF0000FF8033FF000CFF0000FF0000FF26
33FF0033FF0019FF0080FF0099FF0099FF0073FF0073FF00B3FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00CCFF0073FF00B3FF00C0FF00
8CFF0080FF0099FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
F3FF00F3FF00F3FF00F3FF00D9FF00D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00A6FF0080FF00C0FF00CCFF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0073FF00\
B3FF00CCFF00D9FF00D9FF00D9FF00CCFF00C0FF0066FF00B3FF00B3FF0066FF00
80FF00C0FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00B3FF00B3FF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00CCFF00C0FF00A6FF0066FF000CFF00A6FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
C0FF00B3FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF008CFF0080FF0080FF00\
59FF0000FF3319FF0000FF333FFF0066FF004CFF0059FF003FFF0026FF0066FF00
66FF0026FF000CFF003FFF0059FF0066FF00A6FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00CCFF0099FF00D9FF00CCFF00
C0FF0000FF40A6FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
F3FF00FFFF00FFFF00F3FF00F3FF00E6FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00C0FF0059FF00A6FF00D9FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF008CFF00\
CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00CCFF00A6FF00CCFF00CCFF0073FF00
C0FF0080FF00C0FF00C0FF00CCFF00A6FF00CCFF00D9FF00D9FF00D9FF00CCFF00B3FF00B3FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00CCFF00CCFF00C0FF00A6FF003FFF003FFF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
80FF00A6FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF008CFF0073FF0000FF80\
00FF4C4CFF003FFF0059FF003FFF0073FF0080FF0073FF0019FF0059FF0080FF00
8CFF0073FF004CFF0080FF0026FF008CFF00B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
CCFF00A6FF0033FF00D9FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF003FFF00CCFF00E6FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF008CFF00\
D9FF00E6FF00F3FF00F3FF00F3FF00E6FF00D9FF00D9FF00E6FF00E6FF00E6FF00
D9FF00CCFF003FFF0000FF59A6FF0066FF00C0FF00CCFF00CCFF00CCFF00C0FF008CFF00B3FF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00D9FF00CCFF00
CCFF00CCFF00C0FF00B3FF008CFF0059FF0073FF0099FF00A6FF00B3FF00B3FF00B3FF00A6FF00\
00FF00B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF008CFF0073FF00\
19FF0073FF0080FF0080FF0000FF268CFF008CFF0080FF0066FF0033FF008CFF00
99FF0099FF0099FF0099FF0059FF0080FF00B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00D9FF000CFF00D9FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00F3FF00E6FF00CCFF00A6FF00D9FF00E6FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF004CFF0080FF00\
D9FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00CCFF0066FF0080FF0073FF0099FF00B3FF00A6FF00B3FF00B3FF0066FF0099FF00\
C0FF00C0FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00A6FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF0099FF0066FF0066FF0080FF000CFF0099FF00A6FF00A6FF0073FF00\
99FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF0000FF80\
00FF4073FF008CFF0099FF0099FF00A6FF00A6FF0099FF0080FF0080FF00A6FF00
B3FF00B3FF00B3FF00A6FF0066FF0000FFFF4CFF00C0FF00D9FF00D9FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00E6FF0080FF00CCFF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00F3FF00E6FF00C0FF0099FF00D9FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFFF00FFFF00FFFF00FFFF00F3FF00E6FF008CFF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00D9FF00C0FF00CCFF0099FF0000FF338CFF0019FF0059FF0059FF004CFF003FFF00\
8CFF00A6FF00CCFF00CCFF00CCFF00CCFF00C0FF0099FF0080FF00A6FF004CFF00
B3FF00B3FF00A6FF0099FF0073FF003FFF0073FF0033FF0000FF3359FF008CFF0073FF003FFF00\
99FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF0099FF008CFF0066FF00\
59FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00A6FF008CFF0073FF00A6FF00
B3FF00C0FF00C0FF00B3FF0099FF00A6FF0033FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF0099FF0080FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFFF00FFFF00E6FF00C0FF00A6FF00D9FF00F3FF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00E6FF00D9FF00C0FF008CFF0099FF00A6FF0080FF00A6FF00A6FF0080FF00\
59FF00A6FF00C0FF00C0FF00C0FF00C0FF00B3FF008CFF0019FF0080FF0000FF26
99FF0099FF0066FF0000FF0C73FF008CFF0099FF008CFF004CFF0019FF0000FF330CFF0073FF00\
99FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0080FF0026FF0000FF00\
00FF0080FF00A6FF00B3FF00B3FF00C0FF00C0FF00B3FF00A6FF004CFF00A6FF00
C0FF00CCFF00CCFF00CCFF00C0FF00C0FF00A6FF008CFF00CCFF00D9FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00B3FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFFF00E6FF00A6FF00B3FF00E6FF00F3FF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00E6FF00D9FF0099FF00C0FF00CCFF00C0FF00C0FF00B3FF008CFF00\
66FF0099FF00A6FF00B3FF00B3FF00B3FF0099FF0080FF0033FF003FFF0033FF00
66FF0000FF0C66FF0099FF00A6FF00A6FF00A6FF00A6FF0000FF0080FF008CFF0066FF0026FF00\
80FF0000FF19B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF0073FF004CFF008CFF00\
99FF004CFF00A6FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF0099FF00B3FF00
CCFF00CCFF00D9FF00D9FF00CCFF00CCFF00C0FF004CFF0099FF00D9FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFFF00A6FF00C0FF00A6FF00E6FF00F3FF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00F3FF00CCFF008CFF00CCFF00D9FF00D9FF00CCFF00C0FF00A6FF00\
4CFF0033FF0066FF0099FF00A6FF0099FF0073FF0066FF0073FF004CFF003FFF00
0CFF0073FF008CFF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF004CFF00\
66FF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0080FF0059FF0073FF00A6FF00\
B3FF00B3FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00D9FF00E6FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFFF00D9FF008CFF0080FF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00F3FF00CCFF00B3FF00E6FF00E6FF00E6FF00D9FF00CCFF0099FF00\
99FF0099FF0000FF2673FF0066FF0059FF0099FF0099FF00A6FF0033FF008CFF00
59FF0080FF00A6FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0066FF0000FF00\
73FF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF0073FF00A6FF00B3FF00
C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0073FF0080FF0033FF0080FF0099FF00A6FF00B3FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFF300FFFF00E6FF00D9FF00FFFF00FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF00A6FF00\
C0FF00B3FF00A6FF0080FF0073FF00A6FF00B3FF00C0FF00C0FF008CFF00A6FF00
80FF0080FF00A6FF00C0FF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF008CFF0000FF0C\
73FF0080FF0099FF00A6FF00A6FF00A6FF0099FF0066FF0026FF0099FF00A6FF00
B3FF00B3FF00B3FF00B3FF00A6FF0099FF0073FF0026FF0066FF0099FF00A6FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFF300C0FF00FFFF00FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00\
D9FF00C0FF00A6FF003FFF0066FF00B3FF00C0FF00CCFF00CCFF00CCFF00C0FF00
A6FF00B3FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF0099FF0059FF0066FF00\
33FF003FFF008CFF0099FF0099FF0099FF008CFF0059FF0033FF0080FF0073FF00
A6FF00A6FF00A6FF00A6FF0099FF008CFF0066FF000CFF008CFF00A6FF00B3FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600F3FF00FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00\
D9FF00CCFF0073FF0026FF00A6FF00C0FF00CCFF00D9FF00D9FF00D9FF00CCFF00
C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF0000FF0C99FF0099FF00\
66FF0000FFCC73FF0073FF0080FF0073FF004CFF004CFF0033FF0000FF2680FF00
8CFF0099FF0099FF0099FF0073FF0066FF0059FF0000FF8C80FF00A6FF00B3FF00C0FF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00\
E6FF00D9FF00C0FF0073FF0073FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF00\
99FF0073FF0000FF0C3FFF0073FF003FFF0059FF000CFF0000FFE619FF0033FF00
66FF0080FF008CFF0073FF0066FF0000FF004CFF0073FF0080FF0099FF00C0FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00\
E6FF00D9FF00C0FF0080FF00C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00\
99FF004CFF004CFF008CFF0099FF0099FF008CFF004CFF0033FF0033FF0033FF00
3FFF003FFF0000FF0000FF1919FF0059FF0080FF008CFF00A6FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00\
E6FF00CCFF004CFF00C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00\
80FF003FFF008CFF00A6FF00A6FF00A6FF0099FF0080FF0066FF0019FF0080FF00
80FF008CFF0080FF0073FF0066FF004CFF0080FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00\
E6FF00A6FF008CFF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00CCFF00B3FF00\
8CFF000CFF0099FF00B3FF00B3FF00B3FF00B3FF00A6FF0000FF2659FF0099FF00
99FF0099FF0099FF008CFF0073FF0000FF2619FF008CFF00A6FF00B3FF00C0FF00C0FF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00\
D9FF00A6FF0059FF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF00B3FF00\
4CFF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00B3FF008CFF00A6FF00B3FF00
B3FF00A6FF00A6FF0099FF0066FF000CFF0059FF008CFF0099FF00A6FF00B3FF00C0FF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00E6FF00\
A6FF003FFF00C0FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00B3FF0000FF0C\
99FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00A6FF0099FF008CFF0073FF0000FF8C59FF0073FF0059FF0066FF00B3FF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00\
D9FF0080FF00C0FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00A6FF0033FF00\
B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00B3FF00B3FF00A6FF008CFF0073FF0000FF2666FF008CFF0099FF00A6FF00C0FF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00\
CCFF00B3FF00C0FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF0099FF0033FF0099FF00\
C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
C0FF00C0FF00B3FF0099FF0080FF0033FF0000FF0C73FF0099FF00B3FF00C0FF00C0FF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00\
A6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00CCFF008CFF00A6FF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00C0FF00B3FF003FFF0033FF0033FF0073FF008CFF00A6FF00B3FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00C0FF008CFF00C0FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00
CCFF00C0FF00B3FF00A6FF0080FF0000FF8073FF0099FF00A6FF00B3FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00C0FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
CCFF00C0FF00B3FF0099FF0073FF0000FF0C73FF008CFF0099FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
CCFF00C0FF00A6FF0080FF004CFF0073FF0019FF0059FF004CFF0099FF00B3FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00
C0FF0099FF004CFF0099FF0099FF0099FF0080FF0000FF8C3FFF0099FF00A6FF00B3FF00C0FF00\
C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00
C0FF003FFF00A6FF00B3FF00B3FF00B3FF008CFF0000FF0000FF0080FF0099FF0099FF0099FF00\
99FF00A6FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF0080FF000CFF0019FF0073FF0080FF00\
8CFF00C0FF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF008CFF0000FF4C8CFF00A6FF00C0FF00\
C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00B3FF00A6FF0066FF0000FF660CFF00B3FF00CCFF00\
CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00B3FF008CFF003FFF0080FF00A6FF00C0FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00A6FF0099FF0080FF0033FF00A6FF00C0FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF0099FF0059FF0066FF0073FF00CCFF00\
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0000FF8066FF00B3FF00C0FF00CCFF00\
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF0059FF00B3FF00CCFF00D9FF00\
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0099FF00A6FF00C0FF00CCFF00D9FF00\
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF0059FF0099FF00C0FF00CCFF00D9FF00\
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00A6FF000CFF0099FF00C0FF00CCFF00D9FF00\
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF0080FF0033FF008CFF00B3FF00CCFF00D9FF00\
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00E6FF00E6FF00D9FF0099FF0026FF0026FF0073FF00A6FF00B3FF00CCFF00CCFF00\
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00E6FF00E6FF00D9FF00C0FF00B3FF0099FF000CFF0073FF00B3FF00C0FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF0066FF0080FF0099FF0099FF0099FF00\
CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF00A6FF0080FF003FFF0080FF0099FF00B3FF00\
CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00E6FF00E6FF00D9FF00CCFF00C0FF004CFF0066FF0000FF0059FF00A6FF00B3FF00CCFF00\
CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
E6FF00E6FF00D9FF00CCFF00CCFF00B3FF00A6FF0066FF0073FF0099FF00B3FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
E6FF00D9FF00B3FF00B3FF00A6FF0099FF0073FF003FFF0080FF00A6FF00B3FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
D9FF00B3FF0066FF0059FF0099FF0073FF0073FF004CFF0080FF0099FF00A6FF00C0FF00C0FF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
E6FF00D9FF00CCFF00C0FF00C0FF00B3FF00A6FF008CFF0000FF6680FF008CFF00A6FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
E6FF00E6FF00D9FF00CCFF00CCFF00C0FF00B3FF0099FF000CFF0000FF0073FF00A6FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00B3FF008CFF0033FF0033FF0059FF00A6FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00CCFF00D9FF00E6FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
E6FF00E6FF00E6FF00D9FF00CCFF00CCFF00C0FF00A6FF0080FF0066FF0000FF4099FF00A6FF00\
A6FF00B3FF00B3FF0073FF0099FF0066FF00A6FF00CCFF00E6FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF008CFF0059FF0066FF0073FF00\
66FF004CFF0073FF0000FF7373FF00A6FF00CCFF00D9FF00E6FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF0073FF0033FF003FFF00\
73FF0099FF00A6FF00A6FF00C0FF00C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF008CFF0033FF003FFF008CFF00\
99FF00B3FF00C0FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00C0FF00B3FF00B3FF00A6FF008CFF0080FF0073FF003FFF0080FF0099FF00\
B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00D9FF00CCFF00B3FF0066FF0073FF008CFF0080FF0000FF5926FF003FFF0059FF0099FF00\
B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
D9FF00D9FF00CCFF00C0FF00A6FF008CFF004CFF0033FF0059FF0073FF0080FF008CFF0066FF00\
A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00CCFF00C0FF00B3FF0099FF0080FF0033FF0080FF008CFF0099FF00A6FF00B3FF00\
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00C0FF00C0FF00B3FF0099FF0000FF4C3FFF0080FF0099FF00A6FF00B3FF00B3FF00\
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFFF00E6FF00CCFF00D9FF00CCFF00C0FF00B3FF00C0FF00B3FF00CCFF00CCFF00
CCFF00C0FF00B3FF00B3FF00A6FF0080FF0000FFD900FF8066FF0099FF00A6FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFFF00F3FF00D9FF0080FF008CFF0000FF4C4CFF008CFF0073FF0073FF00B3FF00
B3FF00A6FF0019FF0099FF0099FF0080FF0000FF0026FF008CFF00A6FF00B3FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFFF00F3FF00F3FF00D9FF0059FF00B3FF00B3FF0099FF0099FF008CFF004CFF00
3FFF0080FF003FFF0000FF0073FF0066FF004CFF0080FF0099FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFFF00FFFF00F3FF00E6FF00CCFF00D9FF00CCFF00C0FF00C0FF00C0FF00B3FF00
80FF0066FF0080FF0059FF0033FF003FFF003FFF0080FF0099FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00
A6FF0099FF00A6FF0073FF0080FF0073FF0000FF264CFF0099FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00B3FF00D9FF00D9FF00\
0CFF00E6FF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00
C0FF00C0FF00B3FF00A6FF00A6FF008CFF0080FF000CFF008CFF00A6FF00A6FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00A6FF003FFF00B3FF00\
D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00
CCFF00C0FF00C0FF00B3FF00B3FF00A6FF008CFF0000FF6680FF0099FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF003FFF00B3FF00D9FF00\
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00
CCFF00CCFF00C0FF00C0FF00B3FF00A6FF008CFF0026FF0073FF008CFF008CFF00A6FF00A6FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF00C0FF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00B3FF0066FF0000FF0C99FF00D9FF00\
F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00
CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0080FF0059FF0019FF003FFF0080FF0099FF0099FF00\
99FF0066FF008CFF00A6FF00A6FF0099FF0026FF00C0FF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF0099FF0000FF19B3FF00CCFF00E6FF00\
F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00
CCFF00CCFF00C0FF00C0FF00B3FF00A6FF008CFF0073FF0026FF0059FF0080FF008CFF008CFF00\
8CFF0073FF0073FF008CFF0066FF0059FF00A6FF00B3FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00A6FF0000FF00A6FF00CCFF00D9FF00E6FF00\
F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00
CCFF00CCFF00C0FF00C0FF00A6FF0099FF0080FF0059FF0026FF0066FF0073FF0080FF0080FF00\
80FF0066FF0000FF0C33FF0000FF0C73FF00A6FF00B3FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00C0FF00B3FF0099FF0099FF0073FF00B3FF00CCFF00D9FF00E6FF00E6FF00\
F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
CCFF00CCFF00C0FF00B3FF0099FF004CFF003FFF0000FF0033FF0059FF0066FF0066FF0059FF00\
66FF0059FF0000FF0C4CFF0066FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF008CFF0059FF0099FF00C0FF00CCFF00D9FF00E6FF00E6FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00
CCFF00C0FF00B3FF00B3FF00A6FF008CFF0073FF0059FF0019FF003FFF004CFF0033FF0000FF99\
33FF0026FF0026FF0059FF0073FF008CFF0099FF0099FF008CFF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF0080FF004CFF00A6FF00C0FF00CCFF00D9FF00E6FF00E6FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00
B3FF00A6FF00A6FF00A6FF0099FF008CFF0080FF0066FF0033FF0000FF0026FF0000FF0000FF00\
0CFF0000FF1926FF0033FF0059FF0080FF0080FF0080FF0033FF0099FF00A6FF00
B3FF00B3FF00A6FF0099FF003FFF000CFF0059FF008CFF00C0FF00CCFF00D9FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00
B3FF0073FF0080FF0000FF008CFF0080FF0066FF004CFF000CFF0000FF2600FF8000FF6600B3FF\
00FFFF00FF5900FF3300FF6600FF0066FF0073FF0000FF0C73FF008CFF0099FF00
99FF00A6FF0099FF008CFF0066FF0059FF008CFF00A6FF00C0FF00CCFF00CCFF00D9FF00E6FF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00\
CCFF00D9FF00D9FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
C0FF00A6FF0066FF0000FF0073FF0073FF003FFF0019FF0000FF0C00FF6600A6FF000000000000\
0000000059FF00000000D9FF19FF0033FF004CFF000CFF004CFF004CFF0080FF00
73FF0080FF0080FF003FFF0026FF0066FF008CFF0099FF00B3FF00B3FF00B3FF00CCFF00D9FF00\
E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00\
A6FF008CFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00
B3FF00A6FF0080FF000CFF004CFF004CFF0026FF0000A6FF00FF8C00FFFF000000000000000000\
000000000000CC00FF00FFB300FF1900FF8000FF003FFF0019FF0019FF0019FF00
4CFF0059FF004CFF0059FF0073FF0059FF0059FF004CFF0099FF0099FF0080FF00CCFF00D9FF00\
D9FF00E6FF00E6FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300
FFF300FFFF00F3FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00\
C0FF0000FF19C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
B3FF008CFF0066FF0019FF0033FF0000FF590CFF0000FFFF000000000000000000000000000000\
0000000000000C00FF00FFBF00FF0033FF004CFF0059FF0066FF004CFF003FFF00
80FF008CFF0099FF0099FF0099FF0080FF0026FF004CFF0059FF0000FF19A6FF00C0FF00CCFF00\
CCFF00D9FF00C0FF00C0FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFFF00
FFFF00F3FF00E6FF0080FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00\
C0FF0080FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
B3FF0099FF0080FF0073FF0059FF0000FF0C00FF733300FF000000000000000000000000000000\
00000000000000000000FF6600FF0026FF004CFF0066FF0073FF0080FF0059FF00
8CFF0099FF00A6FF00A6FF00A6FF0099FF008CFF008CFF0073FF0059FF0080FF00B3FF00C0FF00\
C0FF00C0FF008CFF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFF300FFFF008CFF00
E6FF0026FF00CCFF0099FF0033FF008CFF0080FF00C0FF00CCFF00CCFF00C0FF00CCFF00C0FF00\
B3FF0080FF008CFF00A6FF0066FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF0099FF008CFF0080FF0066FF0033FF0000FF7300FFE6000000000000000000000000000000\
00000000000000E6FF00FF7300FFD900FF194CFF0073FF0080FF008CFF0099FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF0073FF004CFF008CFF00A6FF00A6FF00\
8CFF0099FF0059FF00C0FF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFFF00E6FF00
E6FF00C0FF0059FF00C0FF00C0FF00C0FF00A6FF00C0FF004CFF0059FF0080FF00B3FF0080FF00\
73FF0000FF4C00FF0066FF008CFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF0099FF008CFF0080FF0059FF0000FF4000FF33008CFF000000000000000000000000000000\
000000A600FF00FFFF00FF5900FF0C19FF003FFF0073FF008CFF0099FF0099FF00
A6FF00B3FF00B3FF00B3FF00C0FF00B3FF00B3FF00A6FF0080FF003FFF0033FF0080FF0066FF00\
3FFF008CFF004CFF00A6FF00C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300FFF300
FFFF00F3FF003FFF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF000CFF0066FF0019FF00\
00FF0099FF008CFF004CFF0080FF00A6FF00A6FF00B3FF00B3FF00A6FF00A6FF00
99FF008CFF0080FF0073FF0066FF0033FF0000FF33000000000000000000000000000000000000\
000000000000B300FF00FF8C00FF1933FF0059FF0073FF0080FF008CFF00A6FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF0073FF0099FF0073FF0073FF0099FF00\
73FF00B3FF000CFF004CFF0073FF0099FF00D9FF00D9FF00D9FF00D9FF00E6FF00
D9FF00CCFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300
FFF300FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00C0FF004CFF00B3FF00\
B3FF00B3FF00A6FF0066FF0073FF0080FF0000FF0099FF00A6FF0099FF0099FF00
8CFF0059FF0059FF0066FF0059FF0019FF0000FF0C00FF3300FF6600FFB300CCFF0026FF000000\
000000000000CC00FF0099FF00FFA600FF334CFF0066FF0073FF0080FF008CFF00
B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0080FF0080FF00C0FF00\
C0FF00CCFF00C0FF00B3FF00C0FF00B3FF0080FF00A6FF00B3FF00C0FF00CCFF00
B3FF00CCFF00E6FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00A6FF00C0FF00CCFF00\
CCFF00CCFF00B3FF0073FF0073FF0000FF003FFF0080FF008CFF0080FF0080FF00
59FF0000FF4026FF0000FF400CFF0000FF0000FF4026FF0000FF0C00FFB300FF5900FF990073FF\
00000000000000000000FF8C00FF0C00FF0000FF2626FF0019FF0073FF0099FF00
B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00A6FF00A6FF00C0FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00C0FF0080FF00A6FF0066FF0080FF00
A6FF0000FF4C59FF00E6FF00E6FF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00B3FF00D9FF00D9FF00\
D9FF00CCFF0073FF0099FF00A6FF0000FF1973FF0000FF4019FF0059FF0080FF00
73FF0073FF0073FF0066FF0033FF0066FF0066FF0033FF0000FFCC0CFF0000FF6600FF3300FF8C\
00FFE60059FF00000000FFA600FF003FFF004CFF003FFF004CFF008CFF00A6FF00
C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00B3FF0073FF00CCFF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF0073FF00D9FF00CCFF00B3FF00
D9FF00D9FF00E6FF00D9FF00D9FF00CCFF00FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00\
E6FF00D9FF00C0FF00C0FF00C0FF00A6FF008CFF003FFF0073FF008CFF0099FF00
99FF0099FF0099FF0080FF0066FF0080FF0080FF0059FF004CFF003FFF0026FF0000FF0C00FF26\
00FF6600FF6600FFCC00FFBF00FF5933FF0066FF0066FF0000FF0059FF00A6FF00
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00A6FF00CCFF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF0080FF00
F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00\
E6FF00E6FF00D9FF00CCFF00C0FF00A6FF0080FF0000FF0073FF00A6FF00B3FF00
B3FF00B3FF00A6FF0080FF008CFF008CFF008CFF0080FF0066FF004CFF0000FF1900FF0026FF00\
26FF0000FF1900FF0C00FF4033FF0000FF0080FF0080FF0059FF0080FF0066FF00
B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00E6FF00D9FF00CCFF00A6FF0073FF0080FF00A6FF00B3FF00B3FF00
C0FF00C0FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0066FF004CFF0026FF004CFF0059FF00\
33FF0026FF0033FF0000FF0C4CFF0073FF008CFF0099FF00A6FF00A6FF00A6FF00
B3FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00E6FF00D9FF00CCFF00B3FF0080FF0080FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00A6FF008CFF004CFF0019FF000CFF000CFF0066FF0073FF00\
59FF0066FF0059FF003FFF003FFF0066FF008CFF00A6FF00B3FF00C0FF00C0FF00
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
F3FF00F3FF00E6FF00D9FF00C0FF00A6FF0059FF00A6FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF003FFF0073FF0073FF0000FF4080FF0080FF00\
80FF0080FF0066FF004CFF003FFF0066FF0000FF0C99FF00B3FF00C0FF00CCFF00
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
F3FF00E6FF00D9FF00C0FF0099FF008CFF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00B3FF0000FF668CFF0099FF0099FF0019FF008CFF0099FF00\
8CFF0080FF0073FF0000FF1933FF008CFF0099FF00B3FF00C0FF00C0FF00CCFF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00\
F3FF00E6FF00CCFF00B3FF0019FF00B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00B3FF008CFF00B3FF00B3FF00A6FF0066FF0099FF00A6FF00\
99FF008CFF0000FF4019FF0066FF0099FF00A6FF00B3FF00C0FF00CCFF00CCFF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00\
F3FF00E6FF00B3FF0073FF0099FF00C0FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00\
A6FF0099FF008CFF0066FF003FFF008CFF00A6FF00B3FF00C0FF00CCFF00CCFF00
D9FF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00\
F3FF00D9FF00B3FF0099FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00\
B3FF00A6FF0099FF0080FF003FFF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00
D9FF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00\
E6FF0099FF00B3FF0080FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00\
B3FF00A6FF0099FF008CFF003FFF008CFF00A6FF00A6FF00B3FF00C0FF00CCFF00
CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00C0FF00\
B3FF00A6FF00A6FF008CFF003FFF004CFF008CFF008CFF00A6FF00B3FF00B3FF00
CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00\
B3FF00B3FF00A6FF008CFF0066FF003FFF004CFF0066FF008CFF008CFF0099FF00
C0FF00CCFF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00\
B3FF00A6FF0099FF008CFF0059FF0066FF0066FF0000FF3359FF0059FF0073FF00
A6FF00C0FF00C0FF00CCFF00D9FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00\
B3FF00A6FF0073FF0066FF004CFF0080FF008CFF008CFF0073FF0099FF0099FF00
66FF008CFF00A6FF0073FF00C0FF00C0FF00C0FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00\
B3FF00A6FF008CFF003FFF0019FF008CFF00A6FF00A6FF008CFF00C0FF00C0FF00
C0FF00A6FF0080FF0059FF008CFF0066FF00C0FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF00\
A6FF0099FF008CFF004CFF0073FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00C0FF00B3FF0099FF00C0FF00B3FF00C0FF00E6FF00FFFF00FFFF00FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF0073FF0073FF00\
8CFF0080FF0073FF0000FF1980FF00A6FF00B3FF00C0FF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00B3FF00D9FF00E6FF00E6FF00E6FF00FFFF00FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF0080FF00\
3FFF000CFF0000FF2673FF0059FF0099FF00B3FF00CCFF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00C0FF00B3FF0099FF0073FF00\
59FF0080FF0059FF0099FF00A6FF008CFF0066FF00CCFF00D9FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF00B3FF00B3FF00A6FF008CFF0073FF0059FF00\
66FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00E6FF00D9FF00CCFF0099FF0033FF0059FF0073FF003FFF0059FF0000FF0C\
80FF0099FF00B3FF00C0FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00E6FF00A6FF00A6FF0026FF00B3FF00B3FF00B3FF00A6FF0099FF0080FF00\
73FF0099FF00B3FF00C0FF00CCFF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0080FF00\
4CFF004CFF00A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF008CFF00\
33FF003FFF0099FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF00\
73FF003FFF0099FF00B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00\
A6FF0080FF0080FF0099FF00B3FF00C0FF00CCFF00D9FF00E6FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00\
A6FF0080FF0066FF0073FF000CFF0000FF0033FF00C0FF00E6FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF00\
80FF0059FF008CFF00B3FF00C0FF00C0FF00CCFF00D9FF00E6FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00B3FF008CFF0066FF00\
26FF0073FF0033FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00B3FF00A6FF008CFF00\
66FF00A6FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF00\
33FF0099FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF00\
73FF0000FF808CFF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF0080FF00\
73FF00B3FF00C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF0099FF00\
00FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF0080FF00\
B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00C0FF0099FF008CFF00\
C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF0066FF004CFF008CFF00\
C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF003FFF0099FF00\
B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF0099FF0073FF0026FF00\
4CFF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF00C0FF00B3FF0080FF0073FF0099FF00\
B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00C0FF0000FF3373FF0019FF0000FF3380FF00A6FF00\
C0FF00CCFF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF00C0FF00A6FF0099FF0059FF008CFF00\
B3FF00C0FF00CCFF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00CCFF00C0FF0099FF0000FF004CFF00\
A6FF00B3FF00B3FF00A6FF00B3FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF0066FF00\
80FF0033FF0073FF0066FF00C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF0080FF00\
59FF004CFF00A6FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF00A6FF0080FF0066FF00\
73FF00A6FF00B3FF00CCFF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF004CFF0073FF0080FF004CFF003FFF00\
80FF0073FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF00A6FF0080FF0026FF0080FF00\
99FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF008CFF000CFF0080FF00\
A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF008CFF0059FF0080FF00\
99FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00C0FF00A6FF00B3FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00A6FF0080FF0073FF004CFF0066FF00\
8CFF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00
C0FF00A6FF008CFF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00B3FF00\
F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF0066FF003FFF0073FF0073FF00\
59FF0073FF008CFF0000FF1980FF0099FF00B3FF00C0FF00C0FF00C0FF00C0FF00
A6FF0080FF00B3FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFFF00FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00CCFF00\
D9FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
73FF00C0FF00C0FF00C0FF0080FF00A6FF0099FF0099FF000CFF0059FF0099FF0099FF0099FF00\
80FF0026FF004CFF0019FF0026FF0080FF00A6FF00B3FF00B3FF0073FF0026FF00
73FF00B3FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFF300D9FF00F3FF00FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00E6FF00\
B3FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00E6FF00D9FF0080FF00B3FF00CCFF00D9FF00CCFF00CCFF00C0FF00
A6FF0080FF00B3FF00A6FF008CFF003FFF003FFF0099FF0099FF008CFF00A6FF00B3FF00B3FF00\
A6FF0080FF0066FF0019FF004CFF004CFF0073FF0099FF008CFF0073FF008CFF00
B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFFF00D9FF008CFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00F3FF00D9FF00\
66FF00CCFF00D9FF0099FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00E6FF00D9FF00C0FF0026FF00C0FF00C0FF00C0FF00C0FF00C0FF00
A6FF003FFF0080FF0066FF0059FF008CFF0099FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00A6FF0066FF0080FF0080FF008CFF0080FF0033FF003FFF0000FF0C26FF00
C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFD900B3FF00F3FF00FFFF00\
F3FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFFF00D9FF00B3FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF0000FF59\
99FF0080FF0099FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00D9FF00CCFF00A6FF0066FF00A6FF008CFF00B3FF00B3FF00
99FF0073FF0073FF0066FF003FFF0099FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
C0FF00B3FF0099FF00B3FF00A6FF00A6FF0099FF008CFF0019FF008CFF00A6FF00
C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFE600FFF30099FF00\
80FF00C0FF00E6FF00FFFF00FFF300FFFF00E6FF00FFF300FFF300FFF300FFFF00
F3FF00E6FF0099FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF00\
CCFF00B3FF0080FF00CCFF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00D9FF00CCFF0073FF003FFF0066FF0080FF0099FF0099FF00
73FF0019FF008CFF00A6FF00A6FF0073FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF003FFF0066FF00A6FF00
B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00C0FF00FFFF00FFF300FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFD900FFE600D9FF00\
FFFF00F3FF00D9FF00D9FF00E6FF00F3FF0080FF00F3FF00FFFF00FFFF00F3FF00
F3FF00CCFF00A6FF00D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00\
D9FF00A6FF0080FF00B3FF00CCFF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00D9FF00D9FF00CCFF00B3FF0099FF0066FF004CFF008CFF008CFF00
66FF0059FF0099FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF0080FF000CFF0000FF0C
26FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00CCFF0099FF00B3FF00E6FF00FFFF00FFF300FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFE600\
FFE600FFF300FFFF00D9FF00B3FF00B3FF0099FF00E6FF00F3FF00E6FF00E6FF00
D9FF00CCFF0080FF00CCFF00CCFF00D9FF00F3FF00F3FF00F3FF00C0FF00E6FF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00\
D9FF00C0FF00A6FF008CFF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00D9FF00CCFF00C0FF00B3FF0066FF0000FF0059FF0066FF0073FF00
00FF008CFF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0099FF0000FF6633FF0099FF00
B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00CCFF00C0FF0080FF00E6FF00F3FF00FFFF00FFF300FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFE600FFF300F3FF00D9FF00D9FF0080FF00CCFF00D9FF00B3FF00B3FF00
8CFF008CFF00A6FF0073FF0019FF00CCFF00E6FF00E6FF00E6FF00C0FF00D9FF00F3FF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00\
E6FF00CCFF00A6FF0059FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00D9FF00CCFF00B3FF00B3FF00A6FF008CFF0066FF0000FF2600FFBF00FF00
0CFF0080FF00A6FF00B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF008CFF0000FF8080FF00A6FF00
B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00B3FF0066FF00A6FF00D9FF00FFFF00FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFE600FFF300FFFF00F3FF00C0FF0066FF0066FF0099FF00A6FF00
99FF00CCFF00CCFF00B3FF0033FF00C0FF00CCFF00CCFF00CCFF0066FF00D9FF00E6FF00F3FF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00\
E6FF00D9FF00C0FF0000FF19C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00C0FF0080FF0059FF0073FF0066FF004CFF00000CFF00FFBF4CFF00
66FF0073FF0073FF00A6FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF008CFF0059FF0080FF0099FF00
B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF0099FF00CCFF00D9FF00D9FF00D9FF00\
D9FF00CCFF00C0FF0066FF00B3FF00E6FF00F3FF00FFFF00FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFE600FFF300FFFF00E6FF0080FF00CCFF00E6FF00D9FF00
E6FF00E6FF00D9FF00C0FF008CFF0099FF008CFF004CFF0059FF0059FF00B3FF00D9FF00E6FF00\
E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00\
E6FF00D9FF00C0FF0000FF0CB3FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00CCFF00B3FF00A6FF0080FF003FFF0026FF0000FF0C0CFF0066FF00
8CFF00A6FF00A6FF00A6FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF004CFF0073FF0033FF0073FF00
8CFF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF0066FF00C0FF00CCFF00CCFF00CCFF00\
C0FF0099FF0099FF00CCFF00D9FF00F3FF00F3FF00FFFF00FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFE600FFE600FFF300E6FF00C0FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00D9FF00B3FF008CFF00C0FF0080FF00C0FF00B3FF0066FF00C0FF00C0FF00\
CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
D9FF00CCFF000CFF0000FF1999FF00A6FF00C0FF00CCFF00D9FF00D9FF00CCFF00
C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00CCFF00CCFF00C0FF00A6FF0099FF004CFF0073FF0073FF0059FF004CFF00
8CFF00B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00CCFF008CFF0066FF00A6FF00A6FF008CFF0000FFE6
59FF00A6FF00B3FF00B3FF00B3FF00B3FF0073FF008CFF004CFF0099FF00A6FF00C0FF00C0FF00\
A6FF0000FF0CC0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFE600FFFF00B3FF00E6FF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00E6FF00B3FF00CCFF00D9FF00D9FF00D9FF00CCFF003FFF0080FF0080FF00\
A6FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
D9FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
D9FF00CCFF00C0FF0099FF0059FF008CFF00B3FF00C0FF00CCFF00CCFF00C0FF00
73FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00C0FF00B3FF00A6FF0066FF004CFF008CFF008CFF003FFF0066FF00
99FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00D9FF00A6FF00C0FF00C0FF00C0FF00B3FF0099FF00
73FF0073FF0073FF0099FF004CFF0099FF0080FF0000FF2666FF0073FF004CFF008CFF0080FF00\
3FFF008CFF00B3FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFE600FFFF0066FF00F3FF00FFF300FFF300FFF300
FFF300FFFF00FFFF00E6FF008CFF00E6FF00E6FF00F3FF00E6FF00D9FF00B3FF00CCFF00C0FF00\
80FF00B3FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00E6FF0000FF00
C0FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00CCFF00C0FF0099FF0000FF268CFF00B3FF00B3FF00C0FF00C0FF00A6FF00
80FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00C0FF00B3FF00A6FF0099FF0066FF0059FF00A6FF00A6FF008CFF008CFF00
00FF0CB3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF00
73FF0073FF0099FF008CFF0073FF0000FF0C4CFF0059FF0080FF00A6FF00A6FF00A6FF008CFF00\
80FF00A6FF00C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFE600FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00F3FF00D9FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00\
CCFF00B3FF00C0FF00CCFF00D9FF00CCFF00E6FF00E6FF00E6FF00D9FF00B3FF00
A6FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
CCFF00CCFF00C0FF0099FF0019FF008CFF0099FF0099FF00A6FF00A6FF0080FF00
A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00C0FF0099FF0073FF0073FF0000FF0099FF00B3FF00C0FF00B3FF00B3FF00
99FF00C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00B3FF008CFF00
00FF0080FF00B3FF00C0FF00B3FF00A6FF0066FF00A6FF00A6FF00C0FF00C0FF00C0FF00A6FF00\
00FF0073FF00B3FF00C0FF00D9FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
E6FF00CCFF0099FF00B3FF00B3FF00C0FF00D9FF00D9FF00D9FF00CCFF00B3FF00
A6FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00C0FF00B3FF008CFF0026FF004CFF004CFF0000FF0000FFA680FF0000FF4C
A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00B3FF0099FF0059FF0073FF008CFF0099FF00C0FF00CCFF00CCFF00CCFF00
C0FF0080FF00CCFF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00B3FF0099FF00
80FF00B3FF00CCFF00CCFF00CCFF00CCFF00A6FF00C0FF00CCFF00CCFF00CCFF00CCFF00C0FF00\
A6FF0073FF003FFF00B3FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF0066FF00A6FF0080FF0080FF00C0FF00CCFF00CCFF00C0FF0080FF00
A6FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00C0FF00C0FF00\
A6FF00A6FF008CFF0019FF008CFF0099FF008CFF0066FF0080FF0073FF0019FF00
8CFF0099FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
B3FF0099FF0026FF0080FF00B3FF00C0FF008CFF00C0FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF0099FF00
59FF00B3FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00\
A6FF0066FF008CFF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
F3FF00F3FF00D9FF00CCFF0080FF0073FF00A6FF008CFF0099FF0099FF004CFF00
99FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF000CFF00A6FF00A6FF00\
80FF0019FF0080FF00A6FF00B3FF00B3FF00A6FF00A6FF00A6FF008CFF0066FF00
4CFF0099FF00B3FF00C0FF00C0FF00C0FF00B3FF00B3FF00C0FF00C0FF00C0FF00B3FF0066FF00\
73FF008CFF00A6FF00B3FF00CCFF00CCFF00CCFF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF008CFF00
C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF00\
59FF0073FF00A6FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00F3FF00E6FF00D9FF00C0FF0059FF0099FF008CFF0066FF0099FF008CFF00
4CFF0073FF00A6FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF0059FF0059FF0080FF00\
26FF008CFF00A6FF00B3FF00C0FF00C0FF00C0FF00B3FF00B3FF0099FF0019FF00
73FF0099FF00A6FF00B3FF00B3FF00A6FF0099FF008CFF00A6FF00A6FF00B3FF00A6FF0080FF00\
80FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00B3FF0099FF00
CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00\
B3FF0073FF0099FF00A6FF008CFF00CCFF00CCFF0099FF00D9FF00FFFF00FFFF00
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00F3FF00E6FF00B3FF00A6FF00C0FF00C0FF00C0FF00B3FF00A6FF00
80FF0066FF00B3FF00C0FF00C0FF00CCFF00CCFF00C0FF0099FF0080FF0000FF5900FFA600FF19\
33FF0099FF00B3FF00C0FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0033FF00
33FF0066FF0099FF0099FF0099FF0073FF0000FF0C33FF0073FF0080FF008CFF0073FF0000FFA6\
00FF59B3FF00CCFF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00CCFF0059FF00B3FF00
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF00\
B3FF0080FF0099FF003FFF0059FF0099FF0080FF00CCFF00E6FF00F3FF00FFFF00
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFFF00FFFF00F3FF00D9FF0099FF00CCFF00D9FF00D9FF00CCFF00CCFF00B3FF00
73FF0080FF00A6FF00B3FF00B3FF00C0FF00C0FF00B3FF0099FF0000FF0073FF000CFF0066FF00\
99FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF0073FF0099FF00
8CFF0026FF0066FF0033FF0000FF5900FF0026FF003FFF0073FF0073FF0080FF004CFF0080FF00\
A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00A6FF0000FF33
CCFF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00CCFF00\
73FF00C0FF00CCFF00B3FF00B3FF008CFF00A6FF00D9FF00E6FF00F3FF00FFFF00
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFFF00F3FF0073FF00D9FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00
4CFF0033FF0066FF0059FF00A6FF00A6FF00A6FF008CFF0059FF0080FF0099FF008CFF0033FF00\
B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00B3FF00B3FF00
A6FF008CFF0019FF0099FF00A6FF0099FF008CFF0099FF00A6FF00A6FF00A6FF0080FF0000FFB3\
99FF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00E6FF00A6FF004CFF00C0FF00
D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00B3FF00\
C0FF00D9FF00D9FF00D9FF00CCFF0000FF3399FF00CCFF00E6FF00F3FF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00A6FF00
99FF00A6FF008CFF0000FF2673FF0073FF0066FF008CFF00A6FF003FFF00B3FF00C0FF008CFF00\
C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00
B3FF0073FF0080FF00B3FF00C0FF00C0FF00B3FF00C0FF00C0FF00B3FF00B3FF0099FF0066FF00\
3FFF0066FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00C0FF00A6FF00
D9FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00B3FF00\
E6FF00E6FF00E6FF00E6FF00CCFF0033FF0019FF0099FF00CCFF00F3FF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00A6FF00
C0FF00C0FF00B3FF0099FF0080FF0073FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00
C0FF0099FF008CFF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF008CFF0026FF00\
8CFF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00C0FF00CCFF00
E6FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF0080FF00D9FF00E6FF00F3FF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00
D9FF00CCFF00C0FF00A6FF0066FF0066FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
C0FF0019FF00B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF0099FF0026FF00\
99FF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00A6FF00F3FF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00A6FF00CCFF00E6FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00
D9FF00D9FF00C0FF0073FF0066FF0099FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
C0FF003FFF00B3FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF008CFF008CFF00\
00FF598CFF00B3FF00B3FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF0099FF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00C0FF00A6FF00D9FF00E6FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00
E6FF00D9FF00CCFF00B3FF0073FF0099FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00
C0FF0059FF00C0FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00A6FF00A6FF00B3FF00\
A6FF0080FF0026FF00C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00C0FF008CFF00B3FF00D9FF00
E6FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
E6FF00D9FF00CCFF00B3FF000CFF00A6FF00C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
D9FF0099FF004CFF00E6FF00E6FF00F3FF00F3FF00E6FF00E6FF00E6FF00CCFF00CCFF00CCFF00\
C0FF0073FF00A6FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00D9FF0099FF00A6FF00C0FF00
C0FF00C0FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
E6FF00D9FF00CCFF00B3FF0073FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF0073FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00\
CCFF00B3FF0019FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00C0FF00C0FF0080FF0080FF00
66FF00CCFF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00FFFF00FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00
E6FF00D9FF00CCFF0080FF00B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
D9FF00CCFF0073FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF00CCFF0073FF00
80FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00A6FF00D9FF00FFFF00FFFF00FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00
E6FF00CCFF00B3FF0066FF00A6FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00\
E6FF00CCFF0033FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFFF00F3FF00E6FF00C0FF008CFF00
A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00CCFF004CFF00B3FF00F3FF00FFFF00FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00
D9FF00C0FF0080FF008CFF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
E6FF00C0FF0066FF00B3FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00E6FF00D9FF0099FF00
26FF0099FF008CFF0099FF00C0FF00A6FF0073FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00
D9FF00CCFF00A6FF0073FF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
E6FF00D9FF00A6FF0066FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00E6FF00B3FF00A6FF00
C0FF0099FF0073FF008CFF0080FF0000FF40B3FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00
CCFF00A6FF0066FF0073FF000CFF00A6FF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
F3FF00D9FF0099FF0080FF00B3FF00CCFF00CCFF00F3FF00FFFF00FFFF00FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00CCFF00C0FF00D9FF00
D9FF00CCFF00CCFF00C0FF0099FF008CFF00C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00B3FF00
FFFF00FFE600FFE600FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF0099FF0000FFE6
99FF0080FF0080FF00A6FF00C0FF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
F3FF00C0FF00CCFF00B3FF0080FF0099FF00CCFF00F3FF00FFFF00FFFF00FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00E6FF00F3FF00F3FF00
E6FF00E6FF00D9FF00C0FF00A6FF003FFF0059FF00CCFF00E6FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00E6FF0033FF004CFF00F3FF00
FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00D9FF00CCFF00
C0FF0099FF008CFF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00F3FF00E6FF00CCFF000CFF00A6FF00D9FF00E6FF00F3FF00FFFF00FFF300
FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00FFFF00
F3FF00E6FF00D9FF00C0FF0080FF008CFF00C0FF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00A6FF00D9FF00FFFF00
FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00
CCFF00B3FF0000FF2673FF00C0FF00D9FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00F3FF00CCFF0080FF00B3FF00CCFF00E6FF00F3FF00FFFF00FFF300
FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00
FFFF00F3FF00CCFF008CFF004CFF0099FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF008CFF008CFF0080FF00F3FF00
FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00
CCFF00B3FF0026FF0099FF00C0FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFFF00F3FF00CCFF0099FF0080FF004CFF00CCFF00CCFF00B3FF00FFFF00
FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFFF00F3FF00D9FF00CCFF00B3FF003FFF0099FF00C0FF00CCFF00D9FF00D9FF00D9FF0066FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00B3FF004CFF00D9FF00F3FF00FFFF00
FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00
C0FF00B3FF0099FF0066FF0033FF00A6FF0099FF00D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFFF00F3FF00A6FF00D9FF00D9FF00C0FF0059FF00D9FF00F3FF00FFF300
FFF300FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300
FFFF00FFFF00F3FF00D9FF00CCFF00A6FF0080FF00B3FF00C0FF00CCFF00C0FF00C0FF0000FF33\
C0FF00D9FF00D9FF00D9FF004CFF008CFF00B3FF00D9FF00F3FF00FFFF00FFFF00
FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF0099FF00
B3FF008CFF0080FF0080FF00A6FF00C0FF00B3FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300E6FF00F3FF00F3FF00F3FF00CCFF0099FF00E6FF00FFFF00FFF300
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300
FFFF00FFFF00F3FF00E6FF0099FF0019FF0099FF0099FF0073FF00A6FF008CFF000CFF0073FF00\
00FF33B3FF00CCFF00B3FF0099FF00B3FF00D9FF00E6FF00F3FF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFFF00F3FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00A6FF00
59FF003FFF0033FF0073FF00C0FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFFF00FFFF00E6FF00C0FF00E6FF00FFFF00FFF300
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300
FFF300FFFF00F3FF00D9FF00B3FF00A6FF00CCFF00CCFF0099FF0080FF0099FF004CFF00B3FF00\
8CFF0080FF008CFF0059FF0059FF0000FF26D9FF00F3FF00F3FF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFFF00CCFF00A6FF003FFF00B3FF00CCFF00C0FF00C0FF00A6FF00
80FF0073FF0099FF00B3FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFFF00D9FF00F3FF00FFF300FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300
FFF300FFFF00E6FF00B3FF00A6FF00C0FF00E6FF00E6FF00D9FF00B3FF00CCFF00CCFF00CCFF00\
CCFF00C0FF0099FF0080FF00B3FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFFF00F3FF00CCFF00C0FF00C0FF003FFF0073FF00A6FF0080FF00
66FF004CFF0099FF00B3FF00C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300E6FF00D9FF00FFF300FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300
FFFF00F3FF00CCFF00B3FF00E6FF00E6FF00F3FF00F3FF00E6FF00D9FF00E6FF00E6FF00D9FF00\
D9FF00CCFF00B3FF0059FF00A6FF00CCFF00D9FF00E6FF00F3FF00FFFF00FFFF00
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFFF00F3FF00F3FF00E6FF00D9FF00C0FF0066FF0080FF0059FF00
00FF6600FFE680FF00A6FF008CFF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300C0FF00FFF300FFE600
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300
FFFF00CCFF00A6FF0073FF00F3FF00F3FF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
D9FF00CCFF00C0FF0099FF0080FF00C0FF00CCFF00D9FF00F3FF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00C0FF0066FF008CFF004CFF00
00FFE600FF1926FF0000FF40A6FF00CCFF00E6FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFF300FFE600FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFF300
FFFF00C0FF00C0FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00\
D9FF00CCFF00C0FF0099FF0059FF0099FF00A6FF00D9FF00F3FF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00C0FF00A6FF0080FF00
00FF2659FF0099FF008CFF0080FF00B3FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600FFE600
E6FF00E6FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00\
E6FF00A6FF008CFF003FFF0073FF00C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00C0FF00B3FF008CFF00
26FF0099FF00B3FF00B3FF00B3FF008CFF00B3FF00CCFF00D9FF00F3FF00FFFF00FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00\
E6FF00CCFF0099FF008CFF00B3FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300F3FF00F3FF00FFF300FFF300FFF300FFE600
FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00C0FF0080FF0066FF00
59FF008CFF00C0FF00CCFF00D9FF00CCFF00C0FF00A6FF008CFF00F3FF00FFFF00FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00E6FF00\
D9FF00B3FF008CFF008CFF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00F3FF008CFF00C0FF0066FF00C0FF00FFF300
FFD900FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF00C0FF00A6FF003FFF008CFF00
A6FF00A6FF00B3FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFFF00F3FF00CCFF00\
73FF008CFF00A6FF003FFF00A6FF00C0FF00CCFF00D9FF00E6FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00A6FF00E6FF00D9FF00CCFF00D9FF00FFF300FFE600FFD900
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00F3FF00D9FF004CFF00A6FF008CFF000CFF00A6FF00
C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300F3FF0073FF00\
CCFF00D9FF00CCFF00B3FF003FFF0099FF00B3FF00D9FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00E6FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00D9FF0073FF0073FF00E6FF00FFFF00FFE600FFD900FFD900
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00C0FF0080FF0099FF00
C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFFF00F3FF00\
F3FF00E6FF00E6FF00CCFF00B3FF0099FF00A6FF00CCFF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF0000FF00D9FF00E6FF00F3FF00F3FF00FFFF00F3FF00F3FF00\
F3FF00E6FF00C0FF00A6FF00D9FF00E6FF00A6FF00FFF300FFE600FFD900FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300FFB300FFB300FFB300\
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFA600
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00C0FF0000FF80CCFF00\
D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00F3FF00D9FF00B3FF0073FF00A6FF00CCFF00A6FF00D9FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00B3FF0066FF008CFF008CFF00B3FF00B3FF00\
B3FF00B3FF00A6FF0080FF0080FF0099FF00A6FF00A6FF0099FF0099FF0099FF00
8CFF0080FF0059FF0000FF1966FF008CFF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF0026FF008CFF00B3FF00\
C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF00A6FF0000FF00B3FF00\
C0FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00F3FF00CCFF00C0FF00A6FF0059FF0080FF00B3FF00D9FF00E6FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00A6FF008CFF0033FF008CFF00A6FF00A6FF00\
A6FF00A6FF0099FF0073FF0066FF008CFF0099FF0099FF008CFF0000FF2680FF00
80FF0080FF0066FF0019FF0066FF0080FF008CFF0099FF00A6FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00A6FF0019FF0080FF0099FF00\
B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00B3FF0080FF008CFF00\
C0FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
F3FF00E6FF00CCFF00E6FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00F3FF00F3FF00E6FF00D9FF00C0FF00A6FF0066FF00C0FF00D9FF00E6FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF0099FF0000FFA680FF008CFF008CFF00\
99FF0099FF008CFF0066FF0019FF0059FF0080FF008CFF0080FF004CFF0066FF00
66FF0059FF003FFF0000FF3300FFB300FF0C59FF004CFF008CFF00B3FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00B3FF0099FF003FFF008CFF00\
B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
E6FF00E6FF00D9FF00CCFF00D9FF00E6FF00D9FF00D9FF00D9FF00CCFF0026FF0033FF0099FF00\
C0FF00CCFF00CCFF00CCFF008CFF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00D9FF0033FF00D9FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00E6FF00D9FF00CCFF0099FF0080FF00C0FF00CCFF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF0099FF0059FF0059FF0066FF0000FFB3\
59FF0080FF0080FF000CFF0000FF0C59FF0073FF0073FF0073FF004CFF0000FF19
26FF0000FF0C19FF004CFF0073FF0080FF008CFF0080FF00A6FF00B3FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0033FF003FFF0099FF00\
B3FF00C0FF00CCFF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
D9FF00D9FF00C0FF00B3FF00CCFF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF0000FF198CFF00\
99FF00B3FF00C0FF00A6FF00B3FF00D9FF00E6FF00E6FF00F3FF00E6FF00E6FF00
E6FF00CCFF0073FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00E6FF00D9FF0066FF00A6FF0033FF0099FF0059FF00D9FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00B3FF0099FF0073FF0066FF0073FF004CFF0000FFBF\
3FFF0066FF0066FF003FFF000CFF004CFF0059FF003FFF0059FF004CFF0000FF4C
26FF003FFF003FFF0026FF0080FF008CFF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF008CFF0026FF0073FF00\
8CFF00A6FF00A6FF0099FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
CCFF00C0FF003FFF00A6FF00B3FF00A6FF00C0FF00C0FF00C0FF00B3FF0080FF0000FF1980FF00\
33FF0099FF0099FF0073FF00C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
D9FF00C0FF0099FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF0099FF0073FF00C0FF00D9FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00D9FF00CCFF0099FF0099FF0099FF0099FF008CFF003FFF0000FF00\
0CFF0033FF0000FF000CFF0000FF1933FF0026FF0000FF0C26FF0000FF0026FF00
4CFF0066FF0073FF0073FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF0080FF0099FF0099FF003FFF00\
59FF0000FFCC80FF00C0FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
C0FF00B3FF0080FF0080FF0099FF0026FF00A6FF00B3FF0073FF0033FF0099FF00A6FF00A6FF00\
8CFF003FFF004CFF0073FF00A6FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
CCFF0099FF00B3FF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF008CFF0073FF00C0FF00D9FF00
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00B3FF00A6FF00A6FF0066FF0019FF00\
73FF0073FF0066FF0059FF003FFF0000FF0C00FF2600FF4C00FF3300FFBF26FF00
4CFF0066FF0073FF0080FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF0099FF00\
4CFF0080FF00B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
B3FF008CFF003FFF0080FF0026FF0000FF2673FF0073FF0000FF40A6FF00C0FF00C0FF00C0FF00\
A6FF00A6FF0099FF0059FF0099FF00C0FF00C0FF00C0FF0099FF00C0FF00C0FF00
C0FF008CFF0099FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00B3FF0033FF00C0FF00CCFF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF008CFF00\
8CFF0080FF0073FF0066FF003FFF000CFF0000FF590000000059FF00FF4C00FF59
00FF0066FF0080FF008CFF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0099FF00\
26FF008CFF00B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
80FF0073FF00A6FF00B3FF008CFF0080FF0099FF0066FF0099FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00C0FF00A6FF003FFF008CFF00A6FF00B3FF00A6FF0000FFF38CFF00A6FF00
A6FF004CFF008CFF00B3FF0099FF00D9FF00D9FF00D9FF00C0FF00E6FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF0073FF00C0FF00CCFF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00B3FF00A6FF0099FF00\
8CFF0080FF0073FF0059FF0033FF0000FF3300A6FF00000000000000FF8000FF4C
4CFF0066FF0073FF0080FF008CFF0099FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF0099FF00\
00FF338CFF00A6FF00B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
A6FF00B3FF00C0FF00C0FF00C0FF00B3FF00B3FF0080FF0080FF00CCFF00D9FF00D9FF00D9FF00\
CCFF00CCFF00B3FF003FFF0066FF008CFF008CFF0059FF0073FF0000FF8C4CFF00
80FF0099FF0059FF0000FF66B3FF00CCFF00CCFF00C0FF00A6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00A6FF0019FF004CFF00C0FF00
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF00\
8CFF0080FF0073FF0066FF0000FF0000FF0000FF6600FFE600FFA600FFB326FF00
4CFF0066FF0073FF0080FF0080FF0080FF0080FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00A6FF00\
33FF003FFF004CFF0066FF00B3FF00C0FF00B3FF00C0FF00E6FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
B3FF00CCFF00CCFF00D9FF00D9FF00CCFF00CCFF003FFF00CCFF00D9FF00D9FF00E6FF00D9FF00\
D9FF00CCFF004CFF00B3FF0099FF0073FF0080FF00A6FF00A6FF0099FF0033FF00
B3FF00B3FF00A6FF0019FF0099FF00A6FF00A6FF008CFF00B3FF00D9FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00CCFF00
D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00B3FF0099FF0059FF00A6FF00B3FF00
C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00B3FF00A6FF0099FF00\
8CFF0080FF0073FF0066FF004CFF0000FF0000FF0C00FF3300FF1900FF0000FF40
3FFF004CFF0059FF0066FF0059FF004CFF0059FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00\
C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF004CFF00\
99FF00A6FF003FFF004CFF0059FF0080FF00A6FF00CCFF00E6FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF008CFF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00CCFF00CCFF00B3FF003FFF0099FF00C0FF00C0FF00C0FF00B3FF00
CCFF00CCFF00C0FF0099FF0026FF0059FF0000FF0080FF0026FF00C0FF00B3FF00D9FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF0059FF00
C0FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00A6FF0099FF0059FF0080FF0099FF00
59FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF008CFF00\
73FF004CFF004CFF004CFF0033FF000CFF003FFF0026FF0000FF8C3FFF003FFF00
00FF6600FF4000FF1900FFD900FFBF19FF000CFF0080FF008CFF0066FF0073FF004CFF00A6FF00\
C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF004CFF00B3FF00\
C0FF00C0FF00B3FF0099FF0000FF26B3FF00D9FF00E6FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00D9FF00C0FF008CFF0026FF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00C0FF0026FF00B3FF00B3FF00B3FF0059FF0033FF00A6FF00CCFF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00A6FF00
99FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00A6FF0080FF0026FF0000FF4C
A6FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF0080FF00C0FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0099FF0066FF0080FF0080FF00\
66FF0033FF0000FF000CFF0000FF0C19FF0059FF0066FF0059FF0066FF004CFF00
00FF404CFF0066FF0066FF0059FF0000FF4000FF4C19FF004CFF0000FF6699FF00B3FF00C0FF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00B3FF00CCFF00\
D9FF00CCFF00CCFF0099FF0073FF00C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00D9FF00CCFF0026FF00C0FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00D9FF00C0FF0099FF00CCFF00CCFF00CCFF0073FF00C0FF0099FF00A6FF00CCFF00\
CCFF00D9FF00CCFF00B3FF00D9FF00D9FF00E6FF00D9FF00D9FF00CCFF00A6FF00
A6FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF008CFF003FFF004CFF00
A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00A6FF0066FF00C0FF00CCFF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF0099FF0080FF0073FF0000FF33\
26FF0000FF0C59FF0000FF1959FF000CFF0066FF0080FF0080FF0073FF0033FF00
0CFF0059FF0080FF008CFF0073FF003FFF0073FF0073FF004CFF0073FF00A6FF00B3FF00CCFF00\
CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00CCFF008CFF0000FF598CFF00D9FF00E6FF00F3FF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00E6FF00C0FF008CFF00CCFF00D9FF00E6FF00E6FF00F3FF00
F3FF00E6FF00E6FF00CCFF00A6FF00D9FF00E6FF00D9FF00D9FF00D9FF00CCFF00A6FF003FFF00\
A6FF00C0FF00B3FF00A6FF00CCFF00D9FF00D9FF00D9FF00CCFF00C0FF0099FF00
B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0059FF0000FF4059FF008CFF00
A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00B3FF0066FF0073FF00B3FF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF008CFF0073FF00\
3FFF0059FF0073FF0073FF0080FF004CFF0073FF008CFF008CFF0080FF0033FF00
00FF5973FF008CFF0099FF0099FF0080FF0099FF008CFF0066FF004CFF0099FF00C0FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00D9FF0066FF00A6FF00D9FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00E6FF00C0FF0080FF00CCFF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00B3FF00\
00FF193FFF0073FF0099FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF0073FF00
80FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF0099FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF0080FF0000FF0080FF00
8CFF0099FF0073FF00A6FF00B3FF00A6FF0099FF0000FF3399FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF008CFF0073FF00\
26FF004CFF0080FF008CFF008CFF0080FF0073FF0099FF0099FF0099FF0080FF00
00FF8080FF0099FF00A6FF00A6FF00A6FF00A6FF0099FF0066FF0059FF008CFF00A6FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00CCFF00A6FF00D9FF00F3FF00F3FF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00CCFF000CFF00CCFF00E6FF00F3FF00F3FF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF00\
8CFF00A6FF0099FF000CFF00A6FF00B3FF004CFF0099FF00A6FF0099FF003FFF00
8CFF00B3FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF004CFF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF008CFF0073FF0000FF003FFF00
73FF004CFF0073FF0099FF0099FF0099FF004CFF008CFF00B3FF00C0FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF008CFF0059FF00\
00FF3359FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
26FF008CFF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF0033FF0080FF004CFF00A6FF00C0FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00E6FF00D9FF0026FF00CCFF00F3FF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00F3FF00E6FF00A6FF00E6FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00CCFF00\
CCFF00CCFF00B3FF0073FF0066FF0080FF0000FF1900FF1959FF004CFF0073FF00
19FF008CFF003FFF00B3FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF008CFF003FFF0099FF00\
A6FF0066FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF003FFF0059FF0073FF00
59FF000CFF0026FF0080FF008CFF0059FF0000FF4C80FF00A6FF00B3FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF008CFF0080FF0066FF00\
33FF0073FF008CFF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF0099FF00
26FF0080FF00A6FF00B3FF00C0FF00C0FF00C0FF00B3FF0099FF00A6FF0066FF0099FF00C0FF00\
CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00E6FF00C0FF0099FF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00F3FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00\
E6FF00D9FF00CCFF00B3FF0066FF0099FF00A6FF008CFF0073FF00A6FF0099FF00
73FF0026FF0099FF00B3FF00C0FF00C0FF00CCFF00C0FF00C0FF00B3FF0099FF0026FF0080FF00\
8CFF004CFF0099FF0099FF0080FF0073FF0019FF0066FF0066FF0099FF0099FF00
80FF003FFF000CFF0000FFA64CFF0026FF0066FF008CFF00A6FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF0059FF0033FF0026FF00\
3FFF0059FF008CFF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00B3FF00A6FF00
80FF0080FF00A6FF00C0FF00C0FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0026FF00A6FF00\
CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00E6FF003FFF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00E6FF00D9FF00C0FF004CFF00B3FF00C0FF00B3FF00B3FF00C0FF00B3FF00
99FF0019FF008CFF00A6FF00B3FF00C0FF00C0FF00C0FF00B3FF00A6FF008CFF0059FF0059FF00\
33FF0059FF0073FF0059FF003FFF0066FF008CFF0099FF00A6FF00A6FF00A6FF00
99FF0059FF0066FF0080FF0073FF0059FF0000FF2680FF008CFF0099FF00B3FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF008CFF0066FF004CFF0073FF00\
8CFF0080FF0073FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
99FF0026FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00B3FF0066FF00\
66FF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00E6FF00D9FF0099FF00B3FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
8CFF0066FF0073FF008CFF004CFF00A6FF00B3FF00B3FF00A6FF008CFF0019FF0000FF4C33FF00\
00FF3300FF1933FF0033FF0059FF0080FF00A6FF00B3FF00B3FF00B3FF00B3FF00
A6FF008CFF0099FF0099FF008CFF0066FF0033FF003FFF0059FF0099FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF0073FF000CFF0066FF0099FF00\
A6FF00A6FF0099FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00C0FF00
C0FF0099FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00B3FF00\
8CFF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00D9FF0000FFA6CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
B3FF0000FF9973FF003FFF004CFF0099FF0099FF008CFF0080FF0000FF1973FF003FFF0080FF00\
00FF3359FF0059FF0066FF008CFF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00
B3FF00B3FF00A6FF00A6FF0099FF0080FF004CFF004CFF008CFF0099FF00A6FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00A6FF00A6FF0099FF0080FF0059FF004CFF008CFF0099FF00A6FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00A6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
CCFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00F3FF00E6FF00B3FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00
80FF0099FF00A6FF008CFF003FFF0059FF004CFF003FFF008CFF0099FF0099FF00A6FF0099FF00\
66FF008CFF0073FF003FFF0099FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00A6FF0099FF003FFF0000FF0066FF008CFF0099FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF008CFF0099FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00A6FF0026FF0080FF0073FF0026FF0073FF0099FF00A6FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00F3FF00E6FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00CCFF00
8CFF00C0FF00C0FF00B3FF0099FF0080FF003FFF008CFF00A6FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF008CFF0026FF0019FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00B3FF0099FF0080FF000CFF0066FF0080FF008CFF0099FF00A6FF00A6FF00\
A6FF00A6FF0099FF0073FF004CFF0080FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF008CFF003FFF0000FF5959FF0073FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00
D9FF00CCFF00CCFF00C0FF00A6FF0080FF0000FF1999FF00B3FF00C0FF00C0FF00CCFF00C0FF00\
C0FF00C0FF0099FF0059FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00B3FF0099FF0073FF000CFF0033FF003FFF0059FF008CFF0099FF0099FF00\
99FF0099FF008CFF0073FF003FFF0080FF008CFF0080FF00A6FF00A6FF00B3FF00
B3FF00A6FF00A6FF0099FF008CFF0059FF003FFF0080FF0099FF00A6FF00B3FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00
E6FF00D9FF00CCFF00C0FF0099FF0000FF408CFF00A6FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00B3FF00B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00C0FF00A6FF0059FF0080FF008CFF0073FF0000FF264CFF0080FF008CFF008CFF00\
8CFF0073FF0073FF0059FF0019FF0066FF0059FF0080FF0099FF00A6FF00A6FF00
A6FF0099FF008CFF0080FF0073FF004CFF0059FF008CFF0099FF00B3FF00B3FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
E6FF00E6FF00D9FF00C0FF00A6FF0066FF0099FF00B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00C0FF0033FF0099FF00A6FF0099FF008CFF004CFF0000FF3359FF0059FF0059FF00\
66FF004CFF000CFF0033FF0000FFCC00FF0026FF0073FF008CFF008CFF0099FF00
99FF008CFF0080FF0000FF0000FF2600FF6600FF7366FF008CFF00B3FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00E6FF00D9FF00CCFF00B3FF0066FF0080FF00A6FF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF008CFF0066FF0033FF000CFF0073FF00\
73FF0059FF0059FF0033FF0000FF2600FF8C19FF0019FF0066FF0066FF0080FF00
80FF0073FF0066FF0026FF004CFF0019FF0080FF008CFF0099FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00E6FF00D9FF00CCFF00B3FF0026FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0099FF0080FF004CFF0059FF008CFF0099FF00\
99FF008CFF0080FF0059FF0026FF0000FFF33FFF0000FF0026FF003FFF0033FF00
00FF0C00FF0033FF0033FF0066FF0080FF008CFF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00
F3FF00E6FF00D9FF00CCFF008CFF00B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0026FF000CFF0066FF0080FF0099FF00A6FF00\
A6FF00A6FF0099FF0026FF0073FF0026FF0059FF0073FF004CFF0080FF0080FF00
73FF0066FF004CFF0026FF0073FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00
F3FF00E6FF00D9FF00B3FF0026FF00C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF0066FF0066FF0099FF00A6FF00B3FF00\
B3FF00B3FF00A6FF0099FF0080FF003FFF0073FF008CFF0099FF0099FF0099FF00
8CFF0080FF0073FF0000FF404CFF0073FF0099FF00A6FF00B3FF00B3FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
F3FF00E6FF00CCFF00A6FF0099FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00B3FF00A6FF0019FF0073FF00A6FF00B3FF00C0FF00\
C0FF00C0FF00B3FF00A6FF008CFF0073FF004CFF0099FF00A6FF00A6FF00A6FF00
99FF008CFF0080FF0019FF0000FF3366FF008CFF00A6FF00A6FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
F3FF00D9FF00C0FF0033FF0059FF00C0FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF0073FF0099FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF004CFF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF0099FF0066FF0000FF1900FF4C66FF008CFF0099FF00A6FF00A6FF00B3FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00
E6FF0073FF0000FF668CFF00C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00D9FF00CCFF00B3FF008CFF0080FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
A6FF0099FF008CFF0073FF0059FF004CFF0066FF0080FF0080FF0080FF0099FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00
F3FF00D9FF00C0FF004CFF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00D9FF00CCFF00B3FF003FFF0099FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00
A6FF00A6FF0099FF0080FF0066FF0000FF2633FF0073FF0073FF0073FF00A6FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00
F3FF00E6FF00B3FF0073FF00B3FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00CCFF00B3FF0080FF0059FF0073FF00C0FF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00
B3FF00A6FF008CFF0073FF0059FF0033FF0080FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00
F3FF00D9FF0059FF00D9FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00E6FF00E6FF00D9FF00B3FF0080FF00A6FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF00
A6FF008CFF0080FF004CFF0000FF0C4CFF004CFF0099FF00B3FF00B3FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00
F3FF0073FF00D9FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00E6FF00D9FF00C0FF0080FF00A6FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00
A6FF0073FF0066FF000CFF0066FF0080FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
F3FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00E6FF00D9FF00B3FF00B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00
B3FF0099FF0080FF0000FF9900FF0080FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00D9FF00C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00
B3FF0099FF0080FF004CFF0066FF0080FF0099FF00A6FF00B3FF00B3FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF00
A6FF008CFF0019FF0000FF0000FF1973FF0080FF008CFF0099FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF00
8CFF004CFF0066FF0080FF0080FF0019FF004CFF000CFF008CFF00A6FF00B3FF00C0FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF0000FF8C73FF00
80FF0099FF0099FF0099FF0099FF0066FF0000FF7319FF0080FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF008CFF008CFF00
A6FF00B3FF00B3FF00B3FF00A6FF0080FF0000D9FF00FF4073FF008CFF0099FF00A6FF00A6FF00\
99FF0073FF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF004CFF00B3FF00B3FF00
C0FF00C0FF00C0FF00B3FF00B3FF008CFF0080FF0080FF0000FF7359FF0019FF0033FF0033FF00\
59FF008CFF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00B3FF00B3FF0099FF008CFF0066FF0059FF0073FF00A6FF00A6FF00\
B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF008CFF0066FF0066FF0099FF00B3FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0000FF0C19FF0066FF0000FF0CB3FF00C0FF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00CCFF00C0FF00A6FF008CFF0059FF0073FF0099FF00A6FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00CCFF00B3FF0000FF338CFF0080FF0033FF008CFF00B3FF00C0FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00D9FF00D9FF00CCFF00CCFF00B3FF00B3FF0099FF004CFF0080FF0099FF00B3FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF0073FF0073FF0099FF00B3FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF0059FF0000FF1999FF00B3FF00CCFF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF003FFF0066FF00C0FF00CCFF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00A6FF000CFF00B3FF00C0FF00CCFF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00B3FF0073FF008CFF00B3FF00C0FF00CCFF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0066FF000CFF008CFF00B3FF00C0FF00CCFF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF0033FF008CFF00A6FF00C0FF00CCFF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00CCFF00CCFF00B3FF0080FF0059FF0073FF0099FF00C0FF00CCFF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00C0FF0099FF0099FF0080FF0059FF0099FF00B3FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00C0FF0099FF0099FF0073FF0059FF008CFF00A6FF00C0FF00C0FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00CCFF00C0FF00B3FF0099FF0026FF0066FF00A6FF00B3FF00B3FF00C0FF00\
CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF0073FF0059FF008CFF0099FF008CFF0073FF00\
80FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF0080FF003FFF0033FF008CFF008CFF00A6FF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00D9FF00D9FF00CCFF00B3FF008CFF008CFF0059FF003FFF008CFF00A6FF00B3FF00C0FF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00
D9FF00D9FF00CCFF00C0FF00B3FF008CFF0026FF0066FF0080FF0080FF00B3FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00
CCFF00CCFF00C0FF00C0FF00A6FF008CFF0019FF0073FF0099FF00A6FF00B3FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00
00FF33A6FF00A6FF00A6FF0066FF0073FF0000FF2680FF0099FF00A6FF00B3FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00B3FF0066FF00
00FF594CFF0080FF0019FF0066FF0000FF9900FF1980FF0099FF00A6FF00B3FF00C0FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00C0FF00
C0FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF003FFF0080FF008CFF00A6FF00B3FF00C0FF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00
CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF0000FF194CFF0033FF0059FF00A6FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00
D9FF00D9FF00CCFF00C0FF00C0FF00B3FF0099FF0059FF0000FF663FFF0080FF00A6FF00B3FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0080FF003FFF0026FF0000FF3380FF00A6FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF008CFF00C0FF00CCFF00CCFF00E6FF00
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0000FF1973FF0026FF0066FF0099FF00A6FF00\
A6FF00B3FF00B3FF00B3FF0099FF00A6FF0080FF003FFF0099FF00C0FF00E6FF00
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00B3FF00A6FF008CFF0080FF0059FF0080FF008CFF00\
8CFF008CFF0099FF0080FF0066FF0026FF0080FF00B3FF00CCFF00D9FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF008CFF0059FF003FFF0026FF00\
33FF0059FF0080FF0059FF000CFF00A6FF0099FF00C0FF00D9FF00D9FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF0080FF0059FF0059FF0066FF00\
4CFF0099FF00A6FF00B3FF00B3FF00C0FF00CCFF00CCFF00D9FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00
D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF008CFF0066FF0000FF404CFF008CFF00\
99FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00
CCFF00C0FF00B3FF00B3FF00B3FF00A6FF0073FF0080FF0080FF0066FF000CFF0080FF0099FF00\
A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00
CCFF008CFF004CFF0059FF0099FF0099FF0080FF000CFF0033FF0000FF0C0CFF0073FF0099FF00\
A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
CCFF00B3FF0099FF0080FF0019FF0059FF004CFF0026FF004CFF004CFF0073FF004CFF0073FF00\
A6FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
CCFF00C0FF00B3FF00A6FF0080FF0033FF0033FF0066FF0080FF0080FF0099FF0099FF0080FF00\
99FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00C0FF00B3FF00A6FF008CFF0073FF0059FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00\
B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00\
E6FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
C0FF00C0FF00B3FF00A6FF008CFF004CFF003FFF0080FF0099FF00A6FF00A6FF00B3FF00B3FF00\
C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00E6FF00D9FF00\
D9FF0080FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
B3FF00B3FF00A6FF0099FF0000FF1900FF1900FF0066FF0099FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00F3FF00D9FF008CFF00C0FF0000FFA6\
C0FF008CFF0099FF00B3FF0080FF00B3FF00C0FF00C0FF00C0FF00B3FF0080FF00
99FF00A6FF0099FF008CFF0066FF0026FF004CFF0073FF0099FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00B3FF0073FF00\
3FFF0080FF0073FF0066FF0059FF0080FF0099FF00B3FF00A6FF00A6FF008CFF00
73FF0080FF008CFF0080FF0066FF0033FF0073FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00D9FF00B3FF00\
B3FF00C0FF00A6FF0099FF00A6FF008CFF008CFF003FFF0059FF0080FF004CFF00
26FF0019FF0073FF0066FF0019FF0066FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00C0FF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF008CFF0000FF0059FF00
80FF004CFF0000FF2619FF0000FF0C59FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00A6FF0080FF0099FF00
99FF0073FF0073FF0073FF0019FF004CFF0073FF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00F3FF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00CCFF00B3FF00B3FF00B3FF00
A6FF008CFF0099FF008CFF0059FF004CFF0066FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00C0FF00A6FF00C0FF0099FF00A6FF00E6FF00F3FF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00
B3FF00B3FF00A6FF0099FF008CFF0073FF0059FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00CCFF00C0FF008CFF0073FF00C0FF00D9FF00F3FF00F3FF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00
C0FF00B3FF00B3FF00A6FF0099FF0080FF0033FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00C0FF00B3FF004CFF00B3FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00
C0FF00C0FF00B3FF00A6FF0099FF0080FF000CFF0066FF0080FF008CFF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00C0FF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
B3FF004CFF0073FF004CFF00B3FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
C0FF00C0FF00B3FF00A6FF0099FF0000FF263FFF0000FF0066FF0000FF408CFF0099FF0099FF00\
A6FF0099FF003FFF0099FF00A6FF00A6FF00A6FF0099FF008CFF00C0FF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00\
B3FF004CFF0099FF00B3FF00C0FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
C0FF00C0FF00B3FF00A6FF0099FF008CFF0066FF0033FF000CFF0073FF008CFF008CFF0099FF00\
99FF008CFF0019FF008CFF0099FF008CFF0080FF0000FF00A6FF00B3FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF00\
3FFF0000FF00A6FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
C0FF00C0FF00B3FF00A6FF0099FF008CFF0059FF0000FF0C00FF7373FF0080FF008CFF008CFF00\
8CFF0080FF0059FF0073FF0073FF0073FF004CFF008CFF00A6FF00B3FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF0099FF00\
4CFF00B3FF00C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
C0FF00B3FF00A6FF0099FF008CFF0080FF0059FF000CFF0059FF0073FF0073FF0080FF0080FF00\
80FF0073FF0059FF0019FF0026FF000CFF0000FF3380FF00A6FF00B3FF00B3FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF0066FF0099FF0073FF008CFF00\
B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00
C0FF00B3FF0099FF0000FF0000FF194CFF0026FF0026FF0059FF0066FF0066FF0066FF0059FF00\
73FF0066FF004CFF0000FF264CFF0059FF0073FF008CFF00A6FF00A6FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF0099FF0026FF004CFF0099FF00\
C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00
B3FF00B3FF00A6FF008CFF0080FF004CFF003FFF0000FF0C3FFF0059FF004CFF004CFF0026FF00\
4CFF003FFF0019FF0033FF0059FF0073FF0080FF008CFF0099FF0099FF00A6FF00
A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF000CFF0080FF00A6FF00\
C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00B3FF00
B3FF00A6FF0099FF008CFF0080FF0073FF0059FF0026FF0000FF0033FF0033FF0000FF8C0CFF00\
26FF0000FF0C00FF1933FF004CFF0066FF0073FF008CFF008CFF008CFF0073FF00
8CFF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF008CFF0080FF0059FF004CFF0073FF00\
B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF0080FF0080FF00A6FF00
A6FF0099FF0099FF008CFF0080FF0073FF0059FF0033FF0000FF2619FF0000FF0000FF2600FF26\
00FF2600FF4000FF0019FF0026FF003FFF003FFF0080FF0080FF0080FF0000FF66
8CFF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0073FF0026FF0026FF0080FF00A6FF00\
C0FF00CCFF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00B3FF0099FF004CFF00
80FF0059FF0080FF0080FF0073FF0059FF004CFF0019FF0000FF2600FF1900FF8C00FF8C0080FF\
00CCFF00FF7300FF4C00FF2600FFCC19FF004CFF0066FF0073FF004CFF0059FF00
80FF008CFF0099FF0099FF0099FF0099FF0099FF008CFF0073FF000CFF0080FF0099FF00A6FF00\
B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00A6FF0073FF00
00FF4033FF0073FF0073FF0066FF000CFF0026FF0000FF0000FF4000FF6600CCFF000000000000\
4C00FF008CFF0099FF0040FF00FF800CFF0026FF004CFF0059FF0019FF003FFF00
66FF0073FF0080FF0066FF0080FF008CFF0080FF0000FF194CFF004CFF0080FF008CFF00A6FF00\
B3FF00B3FF00C0FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00CCFF00B3FF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF00
66FF0019FF0059FF0059FF004CFF0000FF5900FF0C00FF6600FFBF00A6FF000000000000000000\
0000000000000000003300FF00FFBF00FF5900FF990CFF00004CFF19FF0000FF59
00FF8C59FF000CFF0000FF0000FFF300FF0019FF003FFF0000FF0059FF0059FF0066FF004CFF00\
99FF00A6FF008CFF008CFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00C0FF008CFF00B3FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF00
73FF0033FF0000FF003FFF0033FF0019FF0000FF6600FFFF000000000000000000000000000000\
0000000000000000000040FF00FF7300FF190CFF0019FF003FFF004CFF004CFF00
3FFF0000FF803FFF0073FF0066FF0080FF008CFF0080FF008CFF0080FF0033FF0000FF4000FFE6\
80FF0066FF0080FF00B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00C0FF00
E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFF300FFF300FFF300FFFF00FFFF00E6FF00D9FF00E6FF00F3FF00E6FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00A6FF008CFF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0000D9FF00FF0C
3FFF004CFF004CFF000CFF000CFF0000FF4C00FFFF000000000000000000000000000000000000\
00000000000000000000CCFF00FF7300FF5919FF003FFF004CFF0066FF0066FF00
66FF0066FF004CFF0080FF008CFF0099FF0099FF0099FF0099FF0099FF0073FF0000FF4066FF00\
00FF0059FF0099FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00B3FF00B3FF00
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300\
FFF300FFFF00FFFF00F3FF00F3FF00D9FF003FFF00D9FF00D9FF000CFF00D9FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00B3FF0066FF00B3FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF008CFF00
80FF0073FF0066FF0019FF0000FF0C00FF73000CFF000000000000000000000000000000000000\
00000000000000000000000000FF7300FF1919FF0033FF0059FF0066FF0073FF00
80FF0080FF0073FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF008CFF00\
73FF0000FF4C59FF00A6FF00B3FF00C0FF00C0FF00C0FF00B3FF0059FF00CCFF00
D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300\
F3FF00D9FF00E6FF00D9FF00D9FF00CCFF008CFF0073FF00B3FF0033FF00B3FF00
CCFF00CCFF00CCFF008CFF00CCFF00CCFF00C0FF00C0FF00A6FF0059FF008CFF00A6FF0099FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF00
8CFF0080FF0066FF003FFF0019FF0000FF4000BFFF000000000000000000000000000000000000\
00000000000000000000F3FF00FF9900FFA600FF2619FF0059FF0073FF0080FF00
8CFF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF00\
80FF0000FFBF80FF0099FF00A6FF00A6FF0059FF00A6FF008CFF0066FF00C0FF00
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300\
E6FF00CCFF00CCFF004CFF0080FF000CFF00A6FF00A6FF008CFF00B3FF00A6FF00
8CFF0099FF00A6FF0059FF00A6FF00B3FF00A6FF0099FF008CFF0033FF004CFF0080FF004CFF00\
A6FF00B3FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF00
8CFF0080FF0000FFBF00FF660CFF0000FF4C0066FF000000000000000000000000000000000000\
0000000000002600FF00FFF300FFA600FF1900FF0000FF590CFF0066FF0080FF00
8CFF0099FF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
8CFF0033FF0066FF0080FF008CFF0080FF0019FF0000FF1959FF0026FF0000FF0C
C0FF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFF300\
FFF300FFFF00F3FF00E6FF00CCFF00C0FF00D9FF00D9FF008CFF00D9FF00D9FF00
CCFF00C0FF008CFF008CFF0080FF0099FF0066FF0033FF004CFF008CFF004CFF003FFF0080FF00\
99FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF00
8CFF0080FF0066FF0019FF0000FF0C00FFE6000000000000000000000000000000000000000000\
00000000000000000000B3FF00F3FF00FF5919FF0033FF0059FF0073FF0080FF00
8CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF00\
4CFF0080FF0000FF2600FF2619FF0059FF003FFF0099FF00A6FF0080FF008CFF00
99FF00A6FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00D9FF00F3FF00FFFF00\
FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFF300FFF300FFFF00FFFF00E6FF00D9FF00E6FF00F3FF00E6FF00E6FF00E6FF00
E6FF00D9FF00CCFF00B3FF0099FF0066FF008CFF004CFF00A6FF00A6FF0099FF0033FF0073FF00\
8CFF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF004CFF0080FF00
80FF0073FF0066FF003FFF0019FF0000FF7300E6FF00FFF30059FF000000000000000000000000\
0000000000000000008C00FF00FFD900FF2619FF0033FF0059FF0073FF0080FF00
8CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
8CFF00A6FF0099FF003FFF008CFF00A6FF00A6FF00B3FF00C0FF00A6FF0073FF00
99FF004CFF00B3FF00CCFF00CCFF00D9FF004CFF00D9FF00D9FF00D9FF0099FF00F3FF00FFFF00\
FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFF300FFF300FFFF00FFFF00F3FF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00D9FF00CCFF00B3FF0080FF00C0FF00C0FF00C0FF00B3FF0099FF0073FF0026FF00\
80FF0073FF0073FF0099FF0099FF0099FF0099FF0099FF008CFF0073FF003FFF00
3FFF0059FF0059FF0026FF0000FF0000FF9900FF2600FF5900FFA600FFF300FFF300A6FF000000\
0000000000000000001900FF00FFE600FF6600FF1900FF0C4CFF0066FF0066FF00
73FF0073FF0099FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00B3FF00A6FF0073FF0073FF00B3FF00C0FF00CCFF00CCFF00C0FF00A6FF00
CCFF00C0FF00B3FF008CFF0099FF00A6FF0059FF00C0FF00C0FF00B3FF00A6FF00D9FF00F3FF00\
FFFF00FFFF00FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00E6FF00D9FF0080FF00C0FF00CCFF00CCFF00CCFF00C0FF00B3FF0080FF003FFF00\
26FF0000CCFF59FF0080FF008CFF0080FF008CFF0080FF0059FF0033FF0033FF00
00FF0000FFCC26FF0000FF0033FF0019FF0019FF0000FF0C00FF5900FF4C00FF8000FFA60033FF\
0000000000000000009900FF00FF8C00FF2600FF0000FF8C00FF0C3FFF0019FF00
59FF0080FF0099FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00B3FF008CFF00A6FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00C0FF008CFF0080FF008CFF008CFF0000FF0C99FF0099FF0019FF00CCFF00\
E6FF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00E6FF00A6FF00D9FF00D9FF00D9FF00D9FF00CCFF00A6FF0073FF0099FF00\
8CFF0000FF194CFF004CFF0059FF003FFF000CFF0033FF0059FF003FFF0073FF00
00FF194CFF0000FF0C59FF0059FF004CFF0026FF0000FF0C00FF0C00FF0000FFBF00FF4C00FFBF\
00000000B3FF2600FF0080FF00FF8000FF8026FF0033FF003FFF0033FF0033FF00
73FF0099FF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00C0FF0019FF008CFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF008CFF00CCFF00C0FF00A6FF00B3FF00CCFF00D9FF00D9FF00D9FF00\
A6FF008CFF00E6FF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF0066FF00B3FF00B3FF00\
A6FF0099FF008CFF0066FF003FFF004CFF0080FF008CFF008CFF0059FF008CFF00
8CFF0073FF0000FF7373FF0073FF0066FF0000FF2633FF0026FF0026FF000CFF0000FF1900FF66\
00FF8C00B3FF00FFB30033FF00FFB300FF8C26FF004CFF0059FF0059FF0019FF00
73FF008CFF00A6FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00A6FF0033FF00C0FF00D9FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00CCFF00C0FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00CCFF00C0FF00\
B3FF00A6FF008CFF0066FF0059FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00
99FF0073FF0073FF0080FF0080FF0080FF0066FF0059FF004CFF0033FF0019FF0000FF1900FF00\
00FF1900FF3300FF4C00FF99004CFF00FF0C00FFA659FF0073FF0073FF004CFF00
00FF1980FF00A6FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00B3FF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00C0FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00CCFF00\
C0FF0099FF0073FF0000FF003FFF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00
A6FF0073FF008CFF0099FF008CFF008CFF0080FF0066FF0059FF0033FF0000FF260CFF0026FF00\
26FF000CFF0000FF2600FF0C00FF2626FF004CFF0066FF0080FF008CFF0073FF00
8CFF0080FF0073FF00B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00\
C0FF008CFF0066FF0073FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00B3FF00
B3FF00A6FF00A6FF00A6FF0099FF008CFF0080FF0066FF0059FF0033FF0033FF004CFF004CFF00\
4CFF0000FF0C00FF0C33FF000CFF0033FF0066FF0080FF008CFF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00\
C0FF00A6FF0080FF0080FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00A6FF0099FF0080FF0066FF004CFF0000FF0000FF334CFF0066FF0066FF00\
66FF0059FF0059FF0059FF003FFF0033FF0066FF0080FF008CFF0099FF00A6FF00
B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00\
C0FF0099FF0059FF0080FF0099FF00C0FF00C0FF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00B3FF00B3FF00A6FF0080FF003FFF003FFF004CFF0026FF004CFF0073FF0080FF00\
80FF0073FF0073FF0066FF004CFF0000FF1919FF0059FF0080FF0099FF00B3FF00
C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF00\
A6FF0059FF0099FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00B3FF00A6FF0080FF0000FF1980FF0080FF0073FF0066FF0080FF008CFF00\
8CFF0080FF0080FF0066FF004CFF0000FF0066FF0080FF0033FF008CFF00B3FF00
C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF0099FF00\
59FF00A6FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00B3FF008CFF0080FF0099FF0099FF0099FF0080FF0066FF008CFF0099FF00\
99FF008CFF0080FF0066FF0000E6FF3FFF0073FF0099FF00A6FF00B3FF00C0FF00
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00C0FF0073FF00\
99FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00C0FF0000FF33A6FF00B3FF00B3FF00A6FF0099FF008CFF0099FF00A6FF00\
99FF0099FF0080FF003FFF0019FF0059FF0080FF0099FF00A6FF00B3FF00C0FF00
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00CCFF000CFF004CFF0059FF00\
A6FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF0099FF0080FF0080FF0066FF0000FF1926FF0099FF00A6FF00B3FF00C0FF00
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00B3FF0066FF00B3FF00\
C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
A6FF00A6FF0099FF008CFF0073FF0019FF0080FF0099FF00A6FF00B3FF00C0FF00
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00CCFF0073FF0099FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00A6FF00A6FF0099FF008CFF004CFF0080FF0099FF00A6FF00B3FF00B3FF00
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF004CFF00A6FF00C0FF00B3FF00CCFF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00A6FF0099FF008CFF003FFF0073FF008CFF00A6FF00A6FF00B3FF00
C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
B3FF00B3FF00A6FF00A6FF008CFF003FFF0033FF0073FF008CFF008CFF00A6FF00
B3FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
B3FF00B3FF00A6FF00A6FF008CFF0080FF0000FF5966FF0073FF0000FF4099FF00
99FF0099FF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00\
B3FF00B3FF00A6FF0099FF008CFF0080FF000CFF0033FF0033FF0019FF0080FF00
00FF403FFF0099FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00\
B3FF00B3FF00A6FF0099FF0080FF0059FF0059FF0073FF0080FF0019FF0000FF00
4CFF0073FF0019FF0099FF00B3FF00B3FF00C0FF00C0FF00CCFF00D9FF00D9FF00E6FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00\
B3FF00B3FF00A6FF003FFF0059FF0019FF0073FF008CFF0099FF008CFF0066FF00
99FF00A6FF00A6FF008CFF0073FF0080FF00A6FF003FFF00C0FF00C0FF00A6FF00D9FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00\
B3FF00A6FF0099FF008CFF0019FF0000FF4C66FF0099FF00A6FF00A6FF0099FF00
A6FF00C0FF00C0FF00B3FF00A6FF0073FF0000FF333FFF0099FF0073FF0080FF00CCFF00E6FF00\
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00B3FF00\
A6FF00A6FF0099FF008CFF0059FF0000FF3380FF00A6FF00B3FF00B3FF00C0FF00
C0FF00CCFF00CCFF00CCFF00C0FF008CFF00B3FF0099FF0059FF00A6FF008CFF0000FF00D9FF00\
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0099FF0099FF00\
99FF0099FF008CFF0080FF0059FF0080FF0099FF00A6FF00B3FF00C0FF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF0059FF00CCFF00D9FF00CCFF0080FF00\
D9FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0080FF0019FF00\
80FF0066FF0073FF0033FF0000FF1959FF0099FF00A6FF00C0FF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00D9FF00D9FF0080FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0080FF00\
00FFD900FF0019FF003FFF0073FF0066FF0066FF0099FF00B3FF00CCFF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF0080FF00\
00FF1973FF0073FF0000FF1999FF00A6FF0099FF0000FF0099FF00CCFF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00D9FF00CCFF00CCFF00C0FF00B3FF00B3FF00A6FF0059FF008CFF0066FF00\
19FF0080FF0099FF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00CCFF00D9FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00E6FF00E6FF00D9FF00C0FF008CFF0099FF0080FF008CFF0066FF004CFF0033FF0033FF00\
73FF008CFF00A6FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00E6FF00D9FF00C0FF00A6FF0000FF9959FF008CFF0099FF008CFF0080FF000CFF0000FF59\
73FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00E6FF00CCFF00B3FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF00\
4CFF008CFF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00E6FF00E6FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF008CFF00\
00FF2673FF0073FF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFB300FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF0099FF00\
59FF0000FF0C19FF008CFF00B3FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0066FF00\
59FF004CFF0059FF0099FF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00\
99FF0080FF000CFF0099FF00B3FF00C0FF00C0FF00CCFF00D9FF00D9FF00E6FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00\
A6FF0099FF0059FF0080FF0099FF00A6FF00B3FF00C0FF00C0FF00D9FF00E6FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00\
A6FF0099FF0066FF0059FF004CFF0066FF004CFF0073FF003FFF00C0FF00E6FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00\
99FF008CFF0000FF0C8CFF00A6FF00B3FF00B3FF00B3FF00C0FF00CCFF00E6FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF00A6FF00\
66FF0000FF0000FF0C99FF00B3FF00C0FF00CCFF00CCFF00D9FF00E6FF00E6FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00C0FF008CFF0000FF2659FF00\
19FF0080FF0099FF00A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00B3FF00A6FF0099FF00\
0CFF008CFF00A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00CCFF00C0FF00A6FF00\
33FF0066FF00A6FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF00\
8CFF003FFF0099FF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0099FF00\
3FFF0073FF00A6FF008CFF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0099FF00\
4CFF00A6FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0099FF00\
00FF333FFF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF008CFF00\
19FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF008CFF0066FF00\
B3FF00CCFF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF00B3FF008CFF0080FF00\
B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00B3FF0080FF004CFF0099FF00\
B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF0000FF338CFF00\
B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF0073FF003FFF00\
3FFF008CFF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00C0FF00A6FF004CFF0000FF198CFF00\
A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00D9FF00B3FF00A6FF0099FF0099FF0073FF003FFF008CFF00A6FF00\
B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0099FF0099FF0099FF0080FF004CFF008CFF00A6FF00\
B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0080FF0059FF0080FF00\
A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF008CFF0000FF264CFF00\
99FF00B3FF00B3FF00C0FF00B3FF00B3FF00C0FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0080FF003FFF00\
80FF0099FF0099FF0099FF0073FF00A6FF00CCFF00D9FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF0080FF00\
00FF993FFF0059FF008CFF00A6FF00C0FF00D9FF00D9FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF0080FF00\
26FF0080FF0099FF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00B3FF0099FF0073FF0066FF00\
4CFF008CFF00A6FF00C0FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00A6FF0066FF008CFF0080FF004CFF000CFF00\
66FF0019FF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00B3FF0099FF008CFF004CFF004CFF0080FF00\
8CFF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0099FF0080FF0000FF0080FF00\
99FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0026FF0000FF5919FF00\
99FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00D9FF00CCFF00D9FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF008CFF004CFF0073FF00\
99FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF008CFF0080FF00C0FF00E6FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00A6FF0080FF008CFF0073FF004CFF0066FF00\
8CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00B3FF0080FF00B3FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0080FF000CFF0019FF0059FF0033FF00\
59FF008CFF0099FF0099FF0059FF0099FF0080FF00B3FF00C0FF00C0FF00CCFF00
CCFF00C0FF00C0FF00B3FF0073FF0066FF0000FF40D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFD900FFD900FFD900FFE600FFE600FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00
D9FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0080FF0066FF0066FF0080FF008CFF008CFF00\
80FF000CFF0073FF0080FF003FFF0059FF004CFF00A6FF00B3FF00C0FF00C0FF00
C0FF00B3FF00B3FF008CFF003FFF00B3FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFD900FFE600FFE600FFE600FFFF00CCFF00FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00
E6FF008CFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00B3FF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00A6FF0080FF00C0FF00
C0FF00B3FF0099FF0099FF0099FF0080FF0080FF0000FF0C59FF008CFF00A6FF00A6FF00A6FF00\
99FF0080FF0000FF0C00FF1919FF0000FF5959FF0073FF0099FF00A6FF00B3FF00
A6FF0033FF0033FF0099FF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFE600FFE600FFE600FFF300F3FF00C0FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00
E6FF0073FF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF0099FF00\
80FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF004CFF00A6FF00
A6FF00A6FF0099FF0000FFB33FFF0080FF0099FF00A6FF00A6FF0099FF00B3FF00B3FF00B3FF00\
B3FF003FFF0080FF0059FF0026FF003FFF004CFF003FFF0066FF0099FF0099FF00
80FF0026FF0099FF00B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFE600FFE600FFF300FFFF00E6FF0066FF0000FF00FFFF00FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00
E6FF00B3FF00B3FF00D9FF00D9FF00CCFF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF00\
73FF0099FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF008CFF0026FF00
80FF0080FF0066FF0066FF008CFF0099FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF0099FF003FFF0080FF003FFF008CFF0073FF0073FF0033FF0066FF00
3FFF0066FF0059FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFE600FFF300FFF300FFFF00F3FF0080FF00D9FF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00
CCFF004CFF0099FF00C0FF00B3FF00A6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00\
C0FF0033FF0099FF00B3FF008CFF00B3FF00B3FF00B3FF00A6FF008CFF0019FF00
3FFF0033FF0000FF008CFF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00A6FF008CFF00A6FF0099FF00A6FF00A6FF0099FF0080FF0059FF00
73FF0099FF00A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFF300FFF300FFFF00FFFF00F3FF00C0FF00CCFF00F3FF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00E6FF00
CCFF00CCFF003FFF0073FF0080FF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00\
C0FF008CFF0080FF008CFF0033FF00A6FF00A6FF00A6FF0080FF0059FF0066FF00
8CFF008CFF008CFF0073FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0066FF00
26FF008CFF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFFF00FFFF00FFFF00F3FF00E6FF00C0FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00
E6FF00D9FF00C0FF0099FF0073FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00\
C0FF008CFF0066FF003FFF0066FF008CFF0099FF0099FF0073FF0000FF8C73FF00
99FF00A6FF00A6FF00A6FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF0080FF00
4CFF0080FF0099FF00A6FF00B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00CCFF00D9FF00D9FF0066FF00F3FF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
FFFF00FFFF00F3FF00F3FF00D9FF00A6FF00B3FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00
E6FF00D9FF00C0FF0059FF0073FF00B3FF00B3FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00\
C0FF00B3FF0099FF0066FF0000FF0C73FF008CFF0080FF0066FF003FFF0073FF00
A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF008CFF00
73FF0000FF1959FF0080FF00B3FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
D9FF008CFF003FFF00CCFF00E6FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
F3FF00E6FF00E6FF00E6FF00D9FF0066FF00A6FF00CCFF00D9FF0099FF00F3FF00F3FF00F3FF00\
F3FF00E6FF0033FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
E6FF00E6FF00CCFF00C0FF0099FF0073FF00C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00\
C0FF00A6FF004CFF000CFF003FFF0066FF0073FF0073FF0033FF0080FF0099FF00
A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF0080FF00
4CFF0066FF0099FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00
CCFF0073FF00C0FF00E6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
D9FF00C0FF00CCFF0099FF00A6FF0000FF0C26FF00A6FF0099FF00C0FF00E6FF00E6FF00E6FF00\
E6FF00D9FF0080FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
E6FF00E6FF00D9FF00CCFF0073FF0080FF00C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00C0FF00\
B3FF00A6FF008CFF0066FF0000FF0C33FF003FFF004CFF0033FF0080FF0099FF00
B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00A6FF0059FF0019FF00
59FF0080FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00C0FF00
80FF004CFF00C0FF00E6FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
B3FF0080FF004CFF0059FF00A6FF00C0FF00B3FF0099FF0026FF00C0FF00D9FF00D9FF00D9FF00\
D9FF00C0FF00C0FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
E6FF00E6FF00D9FF00CCFF00C0FF0033FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00B3FF008CFF008CFF00\
99FF008CFF0080FF0059FF0000FF4000CCFF00FF403FFF004CFF0026FF0080FF00
A6FF00B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0099FF004CFF00
4CFF008CFF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00A6FF00
59FF00CCFF00D9FF00E6FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
C0FF00C0FF00B3FF00C0FF00D9FF00D9FF00CCFF00C0FF003FFF00B3FF00C0FF00C0FF00C0FF00\
C0FF0099FF00A6FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
E6FF00E6FF00D9FF00CCFF00C0FF003FFF00B3FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00C0FF00A6FF008CFF00\
73FF0026FF004CFF004CFF0000FFBF00E6FF00FF4C59FF0080FF0080FF0080FF00
00FF9959FF00C0FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF0000FF0059FF00
59FF008CFF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
8CFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00A6FF008CFF00
B3FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300FFB300
D9FF00E6FF00D9FF00E6FF00E6FF00E6FF00D9FF00A6FF00A6FF0066FF0099FF0059FF0080FF00\
3FFF0080FF0099FF0059FF00D9FF00E6FF00D9FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00D9FF00CCFF00C0FF0073FF004CFF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00\
99FF0080FF003FFF003FFF003FFF0026FF0000FF0C66FF008CFF00A6FF00B3FF00
A6FF00B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF0099FF0019FF0080FF00
80FF004CFF0026FF0080FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
19FF00B3FF00C0FF00CCFF00CCFF00CCFF00C0FF008CFF0066FF00A6FF00CCFF00
D9FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00C0FF0019FF00B3FF00C0FF0099FF00\
C0FF00B3FF008CFF00A6FF00C0FF00CCFF0059FF00E6FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00CCFF00A6FF004CFF008CFF00A6FF008CFF00C0FF00CCFF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00\
A6FF008CFF003FFF0066FF0073FF0066FF003FFF0033FF0066FF00B3FF00C0FF00
CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF0080FF0080FF00A6FF00A6FF00
99FF0066FF0000FFA659FF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF0066FF008CFF00\
00FF0099FF0080FF00B3FF00C0FF00C0FF00B3FF008CFF008CFF00C0FF00D9FF00
E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00A6FF00CCFF00D9FF00D9FF00\
D9FF00CCFF0099FF0073FF0026FF008CFF00B3FF00D9FF00E6FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00D9FF00D9FF00CCFF00B3FF0099FF000CFF0073FF008CFF00C0FF00CCFF00CCFF00CCFF00\
CCFF00C0FF0080FF00C0FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00\
99FF0073FF004CFF0080FF008CFF0080FF0000FF5973FF0099FF00B3FF00C0FF00
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00C0FF0026FF00B3FF00C0FF00C0FF00
B3FF0099FF0080FF003FFF0080FF008CFF0099FF00A6FF0099FF00A6FF0099FF0073FF003FFF00\
19FF0000FF1900FF3380FF00A6FF00A6FF0080FF0033FF0073FF00B3FF00D9FF00
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00A6FF00CCFF00E6FF00E6FF00E6FF00\
E6FF00D9FF00B3FF00B3FF00B3FF00B3FF0073FF00B3FF00D9FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00CCFF00CCFF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00CCFF00C0FF00A6FF0080FF0059FF0099FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00B3FF0066FF0080FF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00\
8CFF0026FF0059FF0099FF0099FF008CFF0059FF0000FF3380FF0026FF00CCFF00
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00B3FF0099FF0080FF0000FF3326FF0066FF0026FF0033FF0080FF0066FF0019FF000CFF00\
73FF0099FF008CFF008CFF0073FF0033FF000CFF0099FF00B3FF00CCFF00D9FF00
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00E6FF0059FF00D9FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00A6FF00CCFF00D9FF00CCFF00A6FF0059FF00B3FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00E6FF00E6FF00D9FF00B3FF00A6FF00D9FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00CCFF00CCFF00C0FF0073FF000CFF0073FF0099FF00A6FF00B3FF00B3FF00B3FF00\
B3FF0099FF0000FF66B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF0099FF00A6FF0099FF00\
8CFF0026FF0080FF00A6FF00B3FF00A6FF003FFF0099FF0033FF00B3FF00CCFF00
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00
C0FF00B3FF0099FF0080FF000CFF0099FF00A6FF00A6FF0099FF0066FF0080FF0019FF008CFF00\
00FF19A6FF00B3FF00B3FF00A6FF0099FF0033FF008CFF00B3FF00C0FF00D9FF00
E6FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00F3FF00D9FF00F3FF00F3FF00FFFF00FFFF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF0059FF00C0FF00CCFF00
D9FF00C0FF00D9FF00E6FF00E6FF00E6FF00D9FF00D9FF0099FF0099FF00CCFF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00CCFF00C0FF00B3FF00A6FF0073FF0066FF008CFF0099FF0099FF00A6FF00A6FF00\
99FF0059FF0099FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF0099FF003FFF0059FF00\
4CFF0066FF0099FF00B3FF00C0FF00C0FF00B3FF00C0FF00A6FF00A6FF00CCFF00
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
C0FF00A6FF0080FF004CFF0059FF00A6FF00C0FF00C0FF00C0FF00A6FF00A6FF0033FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00B3FF0073FF000CFF0099FF00B3FF00C0FF00
CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF0099FF0080FF00B3FF00
B3FF0000FF0CCCFF00D9FF00D9FF00D9FF00D9FF00CCFF00B3FF0099FF00CCFF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00C0FF00C0FF00B3FF0099FF004CFF0033FF004CFF0059FF0033FF0080FF008CFF00\
73FF0000FF0099FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00A6FF0099FF0033FF0073FF00\
80FF0073FF0099FF00C0FF00CCFF00CCFF00CCFF00CCFF00C0FF0073FF00B3FF00
D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00
CCFF00A6FF008CFF0080FF00A6FF00C0FF00CCFF00CCFF00CCFF00CCFF00C0FF0033FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00A6FF008CFF003FFF0033FF0099FF00
CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFB300
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00A6FF0059FF00
00FF738CFF00C0FF00CCFF00CCFF00CCFF00CCFF00C0FF008CFF00A6FF00CCFF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF00CCFF00CCFF00
C0FF00C0FF00B3FF00A6FF0099FF0073FF0066FF008CFF008CFF0073FF0026FF004CFF0059FF00\
00FF3373FF0099FF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF0080FF0066FF0080FF00A6FF00\
B3FF00B3FF0033FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00C0FF0073FF00
D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00
CCFF00C0FF0099FF0059FF00A6FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00C0FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0099FF0026FF00A6FF00C0FF00
D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00D9FF00C0FF00C0FF00
A6FF0059FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF0073FF0080FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF008CFF00B3FF00C0FF00
B3FF0099FF008CFF0080FF003FFF008CFF0099FF00A6FF00A6FF0099FF008CFF0099FF008CFF00\
80FF0000FF1966FF004CFF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF0000FF0C8CFF008CFF00B3FF00\
C0FF00CCFF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00
D9FF00C0FF008CFF00A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00A6FF0073FF0033FF00A6FF00C0FF00
CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00
66FF008CFF008CFF0099FF004CFF0000FF000CFF0073FF0000FF198CFF00A6FF00A6FF00C0FF00\
CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF0073FF0099FF00
A6FF008CFF0000FF0066FF008CFF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF00\
8CFF0066FF0059FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00B3FF00A6FF00
A6FF00B3FF00C0FF00C0FF00B3FF00B3FF0080FF0019FF0080FF00A6FF00B3FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00
D9FF00C0FF008CFF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00C0FF0099FF0080FF0080FF00A6FF00C0FF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00
CCFF008CFF0073FF0099FF0099FF0059FF008CFF0099FF008CFF0019FF0073FF0080FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF008CFF0000FF4000FF0C
80FF0073FF0059FF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00\
4CFF003FFF0073FF008CFF00A6FF00A6FF00B3FF00B3FF00A6FF00A6FF0080FF00
8CFF00A6FF00A6FF00A6FF00A6FF0099FF0080FF0066FF00A6FF00B3FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00
CCFF0099FF00A6FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF0099FF0000FF0C99FF00A6FF00
A6FF00C0FF00CCFF00C0FF0080FF00CCFF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00E6FF00
CCFF008CFF00B3FF00C0FF00C0FF00B3FF00C0FF00B3FF00A6FF008CFF0033FF0099FF00B3FF00\
C0FF00C0FF00CCFF00CCFF00C0FF00C0FF00A6FF0080FF000CFF004CFF0000FF26
26FF0000FF4073FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00\
99FF004CFF004CFF0066FF008CFF0099FF00A6FF0099FF008CFF0073FF0059FF00
59FF0080FF0073FF008CFF008CFF0073FF0000FF190CFF0099FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00
00FF0026FF00B3FF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00C0FF0073FF0073FF004CFF0059FF00
33FF0080FF0099FF0033FF00C0FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00
99FF00B3FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00A6FF0066FF0066FF0099FF00A6FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0073FF0059FF0019FF0000FF0C
59FF0000FFBF99FF0099FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF00\
33FF0080FF0080FF0019FF0033FF0080FF0080FF0066FF0066FF003FFF0000FF33
00FFB34CFF0066FF0059FF0026FF0000FF0080FF0099FF00B3FF00C0FF00CCFF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00D9FF00
CCFF008CFF00A6FF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00CCFF00A6FF0099FF00C0FF00C0FF000CFF00
A6FF0099FF003FFF00B3FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF00
4CFF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00B3FF0099FF0000FF198CFF0099FF00\
99FF00B3FF00B3FF00B3FF00B3FF0080FF008CFF0000FF7380FF0080FF0066FF00
00FF8C99FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00CCFF00CCFF00CCFF00B3FF00\
80FF00A6FF00A6FF008CFF0066FF003FFF0080FF0073FF004CFF0080FF0000FF00
80FF0080FF0099FF0099FF008CFF0066FF0000FF0099FF00B3FF00C0FF00CCFF00D9FF00D9FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00D9FF00
C0FF0073FF00B3FF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00E6FF00C0FF0026FF00C0FF00CCFF00CCFF00CCFF00
C0FF00B3FF0080FF0066FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF008CFF0059FF0073FF0026FF00\
73FF0099FF00A6FF0099FF0099FF0073FF003FFF0059FF0099FF00A6FF00A6FF00
80FF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
C0FF00C0FF00B3FF0099FF003FFF0059FF00A6FF00A6FF00A6FF00A6FF0033FF00
A6FF00B3FF00B3FF00A6FF00A6FF0066FF0000FF338CFF00A6FF00B3FF00CCFF00D9FF00D9FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF0080FF00
B3FF0066FF00C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00E6FF00C0FF00B3FF00D9FF00D9FF00D9FF00D9FF00
CCFF00C0FF0033FF00A6FF00C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF008CFF0099FF00A6FF00A6FF0033FF00\
4CFF0059FF0066FF0033FF008CFF008CFF00A6FF008CFF00B3FF00C0FF00C0FF00
A6FF0099FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00C0FF00B3FF0080FF0026FF0099FF00B3FF00C0FF00C0FF00C0FF00B3FF00
C0FF00C0FF00C0FF00B3FF00A6FF0099FF0073FF000CFF0080FF00A6FF00CCFF00D9FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00
D9FF00B3FF0099FF00CCFF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF0099FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00A6FF0099FF004CFF0080FF00B3FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00C0FF003FFF00C0FF00C0FF00B3FF00A6FF00\
99FF0080FF0059FF0080FF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF0066FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00C0FF00B3FF0000FF008CFF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00B3FF008CFF0000FF0C3FFF00A6FF00C0FF00CCFF00D9FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00
E6FF008CFF00CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00C0FF00CCFF00B3FF004CFF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00\
A6FF0080FF0059FF0099FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00CCFF00CCFF00A6FF008CFF00B3FF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00CCFF00CCFF00C0FF00B3FF008CFF0019FF008CFF00A6FF00C0FF00CCFF00D9FF00D9FF00\
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
E6FF00B3FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00E6FF00D9FF00CCFF00A6FF00C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF00\
99FF0000FF4C80FF0099FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00CCFF008CFF008CFF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00B3FF008CFF0000FF1980FF0099FF00B3FF00C0FF00CCFF00D9FF00\
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
F3FF00B3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00E6FF00D9FF00C0FF00B3FF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF0080FF00\
80FF0019FF0099FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00CCFF0099FF0066FF00C0FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00D9FF00D9FF00CCFF00B3FF0073FF0099FF008CFF000CFF0099FF00A6FF0099FF008CFF00\
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFFF00F3FF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00E6FF00CCFF0073FF00C0FF00CCFF00E6FF00E6FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00\
B3FF008CFF0080FF00A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00D9FF00C0FF0066FF00A6FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00CCFF0073FF00B3FF00C0FF00B3FF0099FF0066FF008CFF00C0FF00D9FF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00F3FF00E6FF00CCFF00B3FF0066FF00C0FF00D9FF00D9FF00D9FF00E6FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00\
B3FF0073FF008CFF008CFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00D9FF00C0FF0073FF00B3FF00E6FF00E6FF00E6FF00F3FF00F3FF00
E6FF00E6FF00E6FF00D9FF00CCFF00CCFF00CCFF00C0FF00A6FF0000FF00A6FF00CCFF00D9FF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00F3FF00F3FF00D9FF00B3FF0066FF00B3FF00C0FF00C0FF0000FF26E6FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00\
B3FF0066FF00A6FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00CCFF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF0000FF1980FF0099FF00CCFF00E6FF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00D9FF0073FF00A6FF0000FF338CFF0066FF00C0FF00D9FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00D9FF00C0FF00\
99FF0099FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00D9FF00D9FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00A6FF0099FF00CCFF00E6FF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00F3FF00D9FF00D9FF00CCFF00B3FF008CFF0099FF00CCFF00D9FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00E6FF00D9FF00B3FF00F3FF00FFFF00FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00D9FF008CFF00
C0FF00D9FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00B3FF004CFF0080FF008CFF00\
59FF0000FF1973FF008CFF0080FF0033FF0059FF0059FF0066FF0099FF0099FF00
8CFF004CFF0073FF0080FF0059FF0000FF008CFF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF0080FF0066FF0000FFF3
4CFF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
66FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00A6FF0073FF0099FF0099FF008CFF0000FF400CFF0080FF0099FF0099FF00A6FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00D9FF00CCFF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00C0FF008CFF0099FF00B3FF00A6FF00\
8CFF0066FF0066FF0000FF0019FF0066FF0099FF00A6FF00A6FF00B3FF00A6FF00
99FF0026FF0099FF0099FF0059FF003FFF008CFF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF0059FF004CFF0033FF00
73FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF008CFF00\
59FF0099FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00A6FF0080FF0000FF0C73FF0059FF0000FFCC80FF0099FF00A6FF00A6FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0066FF00C0FF00C0FF00C0FF00\
B3FF0099FF008CFF0059FF0073FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00
B3FF0099FF00A6FF00A6FF008CFF0033FF0080FF0099FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF008CFF0066FF0000FF0C
66FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF003FFF003FFF00\
3FFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF008CFF0073FF0000FF194CFF0066FF003FFF0099FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00CCFF00CCFF00C0FF00\
C0FF00A6FF008CFF0059FF0073FF0099FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF008CFF0073FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF0080FF0000FF593FFF00
00FF004CFF0000FF6680FF0099FF0099FF0099FF00A6FF0099FF0099FF008CFF0073FF0000FF00\
66FF008CFF008CFF008CFF00A6FF00A6FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF0099FF008CFF0073FF0019FF0066FF0080FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00\
C0FF00A6FF0073FF0059FF008CFF00A6FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00A6FF00A6FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00A6FF0080FF0000FF2659FF0080FF00
66FF0000FF0026FF0073FF008CFF008CFF0099FF0099FF008CFF0080FF0080FF0066FF0000FF40\
59FF0073FF0066FF0000FF2699FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
8CFF008CFF0080FF0066FF0000FF3366FF008CFF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00\
B3FF0066FF0066FF0073FF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00CCFF00CCFF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00C0FF0099FF0066FF0099FF0099FF008CFF00
80FF0000FF0000FF1966FF0073FF0073FF0080FF0080FF0080FF004CFF0059FF0059FF0026FF00\
3FFF003FFF004CFF0080FF008CFF0099FF0099FF0099FF0099FF0099FF008CFF00
00FF0C66FF0066FF0059FF0000FF5966FF008CFF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00\
CCFF00B3FF0099FF0059FF0099FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF00A6FF00A6FF00A6FF00A6FF00
8CFF0073FF0066FF0019FF0026FF0033FF000CFF0000FF2633FF0000FF9900FF0000FF3300FF0C\
00FF8000FF403FFF0066FF0080FF0080FF008CFF008CFF008CFF008CFF0080FF00
73FF0019FF0000FF0C0CFF004CFF0059FF0019FF0073FF00A6FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00\
CCFF00C0FF008CFF0059FF0066FF00B3FF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF00
99FF008CFF0073FF003FFF004CFF0019FF0080FF0080FF0066FF0066FF004CFF003FFF0019FF00\
00E6FF00FF0C00FF4000FF0C59FF004CFF0073FF0080FF0080FF0073FF0073FF00
59FF0000FF004CFF0059FF0073FF008CFF008CFF0099FF00B3FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00\
CCFF00C0FF0080FF0099FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00B3FF00
99FF0080FF0066FF0000FF6673FF008CFF008CFF0099FF008CFF008CFF0080FF0066FF0000FF0C\
19FF0000FF1933FF0000FF2600FF2633FF000CFF0000FFA63FFF003FFF0000FF00
33FF0033FF0066FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00\
CCFF00A6FF0099FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00A6FF00
80FF0059FF0019FF0059FF0033FF0099FF00A6FF00A6FF00A6FF0099FF008CFF0000FF0059FF00\
59FF0000FF0C59FF0066FF0000FF0073FF0073FF0073FF0066FF004CFF0033FF00
26FF003FFF0073FF0080FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00\
C0FF0066FF00A6FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00
8CFF0073FF003FFF0080FF0099FF00A6FF00A6FF00B3FF00A6FF00A6FF0099FF0080FF0080FF00\
4CFF0000FF2666FF0080FF0080FF008CFF008CFF008CFF0080FF0080FF0073FF00
66FF0026FF0066FF0080FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF0099FF00\
8CFF0059FF00A6FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00
A6FF0080FF004CFF008CFF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF008CFF00\
66FF0000FF0073FF008CFF0099FF0099FF0099FF0099FF0099FF008CFF0080FF00
73FF0033FF0033FF0033FF0073FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00CCFF00\
99FF000CFF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00
99FF0019FF0080FF0000FF40A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF0099FF00\
3FFF008CFF0059FF0099FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF00
59FF0000FF8000FFD94CFF0080FF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00D9FF0099FF00\
80FF003FFF00A6FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF00
80FF008CFF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF0099FF00\
99FF00A6FF00A6FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF00
59FF0000FFA600FF0C59FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00CCFF00A6FF0080FF00\
8CFF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF008CFF00
73FF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF00
80FF0066FF003FFF004CFF0073FF0080FF008CFF008CFF0099FF0026FF00B3FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00D9FF00CCFF00A6FF00\
80FF00C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0073FF003FFF00
73FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF00
8CFF0080FF0066FF0026FF0026FF0000FF7300FF1926FF0000FF0066FF0073FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00D9FF00A6FF00\
8CFF00C0FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF008CFF0059FF00
A6FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF00
8CFF0080FF0066FF0026FF004CFF003FFF0080FF008CFF0099FF00A6FF00B3FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00C0FF003FFF00\
8CFF00A6FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00A6FF0099FF003FFF0080FF00
66FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF00
8CFF0073FF0059FF000C00FF66FF008CFF0099FF00A6FF00A6FF00B3FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00F3FF00E6FF00C0FF0099FF00\
CCFF00D9FF00C0FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF00B3FF0099FF0073FF00A6FF00
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF008CFF00
80FF004CFF0000FF193FFF0026FF008CFF00A6FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00F3FF00D9FF00A6FF00D9FF00\
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0099FF0080FF00B3FF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF003FFF0026FF00
26FF0000FF0C59FF0073FF0080FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00F3FF00C0FF00D9FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00C0FF004CFF0099FF0099FF00
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF008CFF00
73FF0033FF0059FF0080FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00E6FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF0099FF00B3FF00CCFF00CCFF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF00
73FF0000FF193FFF0080FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00B3FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF008CFF00
73FF004CFF0059FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF0059FF00
00FF3300FF6600FF0066FF0080FF008CFF008CFF0099FF00B3FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0099FF008CFF004CFF00
66FF0066FF0073FF0033FF003FFF0066FF0033FF0059FF00A6FF00B3FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF008CFF004CFF0080FF0080FF00
8CFF0099FF008CFF0073FF0000FF3326FF004CFF0080FF00A6FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00CCFF00B3FF003FFF000CFF008CFF00A6FF00A6FF00
A6FF00A6FF0099FF0073FF0026FF0000FFBF19FF0080FF0099FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00CCFF00A6FF0059FF0099FF00A6FF00B3FF00B3FF00
B3FF00B3FF00A6FF008CFF004CFF004CFF0000FF0C66FF008CFF0099FF008CFF00A6FF00A6FF00\
00FF4099FF008CFF00B3FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00C0FF00A6FF00A6FF00B3FF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF0080FF0080FF0080FF0073FF0000FF4C66FF0066FF0033FF003FFF0033FF00\
3FFF0000FF0099FF00A6FF00C0FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0073FF0000FF004CFF0066FF0099FF00A6FF00\
A6FF00A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00B3FF00A6FF0099FF008CFF0059FF0000FF0C80FF0099FF00A6FF00B3FF00\
C0FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00C0FF00B3FF00B3FF0099FF008CFF0066FF003FFF0080FF00A6FF00B3FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00C0FF00B3FF00A6FF0099FF0033FF0000FF1966FF0073FF0080FF00C0FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
CCFF00CCFF00C0FF00B3FF00A6FF008CFF004CFF0066FF008CFF00A6FF00B3FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00CCFF00C0FF0099FF0000FF8066FF0066FF0059FF008CFF00A6FF00B3FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00CCFF00C0FF00A6FF00A6FF0099FF008CFF0000FF0073FF0099FF00B3FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00CCFF00C0FF00B3FF00A6FF0099FF0073FF003FFF0073FF0080FF00B3FF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0099FF0073FF004CFF0099FF00A6FF00C0FF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0033FF000CFF0080FF00A6FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF0073FF0073FF00B3FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF0026FF0099FF00B3FF00C0FF00CCFF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF0080FF00B3FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00CCFF00C0FF00B3FF0073FF008CFF00B3FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00CCFF00CCFF00B3FF008CFF0000FF198CFF00B3FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00CCFF00C0FF00B3FF0099FF000CFF008CFF00A6FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00CCFF00C0FF00B3FF0099FF0066FF0059FF0000FF733FFF00C0FF00CCFF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00
D9FF00CCFF00C0FF00B3FF00A6FF003FFF0000FF2680FF0099FF00B3FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00
D9FF00C0FF0073FF0099FF008CFF0059FF0066FF0099FF00A6FF00B3FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00
D9FF00C0FF008CFF008CFF000CFF0066FF0066FF008CFF00A6FF00B3FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00
D9FF00CCFF00C0FF00B3FF00A6FF008CFF0000FF1933FF0099FF00B3FF00B3FF00C0FF00C0FF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00
D9FF00CCFF00C0FF00B3FF00A6FF0000FF0000FF1959FF008CFF00A6FF00A6FF00B3FF00B3FF00\
C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00
D9FF00CCFF00C0FF00C0FF00B3FF0099FF0080FF000CFF0066FF0059FF0080FF0059FF0073FF00\
A6FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00CCFF00C0FF00B3FF00A6FF0099FF0080FF004CFF0059FF0073FF008CFF0099FF00A6FF00\
C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00
CCFF00CCFF00C0FF0099FF0099FF0073FF0059FF0000FF9980FF0099FF00A6FF00B3FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
CCFF00C0FF00B3FF008CFF003FFF0033FF004CFF0066FF0033FF00A6FF00B3FF00C0FF00C0FF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00
CCFF00C0FF00B3FF0099FF0080FF0000FF2673FF008CFF0099FF00A6FF00B3FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00C0FF00
C0FF00B3FF00A6FF0099FF0066FF0000FF0C66FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF008CFF00A6FF0080FF00
A6FF0099FF0073FF0019FF0059FF0059FF0080FF0099FF00A6FF00B3FF00B3FF00C0FF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00E6FF00C0FF0099FF0000FF0C00FF264CFF0080FF00
80FF004CFF003FFF0066FF0059FF0019FF0080FF0099FF00A6FF00A6FF00B3FF00C0FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF008CFF0099FF008CFF0073FF0066FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00CCFF00C0FF00C0FF00
C0FF00B3FF00B3FF00A6FF0099FF0080FF0000FF0066FF0073FF0080FF008CFF00A6FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00
C0FF00C0FF00C0FF00B3FF00A6FF0080FF003FFF003FFF0000FF2659FF008CFF00A6FF00B3FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00
CCFF00C0FF00C0FF00B3FF00A6FF008CFF0059FF0000FF3326FF0066FF008CFF00A6FF00B3FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
CCFF00CCFF00C0FF00B3FF00A6FF0066FF003FFF0019FF0026FF0059FF008CFF00A6FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF004CFF00C0FF00CCFF00
CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
CCFF00CCFF00C0FF00C0FF00A6FF008CFF004CFF0073FF0033FF0059FF008CFF0099FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0080FF0080FF0073FF00
66FF00C0FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF008CFF0073FF0000FF4080FF008CFF0099FF00\
99FF008CFF00A6FF00A6FF00A6FF0099FF0066FF0080FF0000B3FF99FF00B3FF00
CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0066FF0059FF0073FF0033FF00\
80FF004CFF0080FF008CFF0073FF0066FF0066FF0059FF0080FF00B3FF00CCFF00
D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0073FF0026FF0026FF0000FF26\
4CFF0026FF000CFF008CFF003FFF008CFF0099FF00A6FF0099FF00C0FF00CCFF00
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0073FF004CFF0059FF0066FF00\
59FF0080FF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00CCFF00D9FF00
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00
CCFF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF004CFF000CFF0066FF0080FF00\
8CFF008CFF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00
C0FF00C0FF00B3FF00B3FF00A6FF0099FF0099FF008CFF0080FF004CFF000CFF0026FF008CFF00\
99FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00B3FF00B3FF00
A6FF00B3FF00B3FF00A6FF0099FF003FFF0080FF0073FF0073FF004CFF0059FF0080FF0099FF00\
A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF004CFF00
26FF0080FF0099FF0099FF008CFF0073FF0000FF0000FF193FFF0000FF0C3FFF0080FF0099FF00\
A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00A6FF00
80FF0073FF0059FF004CFF0073FF0033FF0033FF004CFF0000FF9966FF0066FF0000FF6666FF00\
99FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF00
A6FF0099FF0000FF194CFF0026FF0026FF0059FF0073FF0073FF0080FF008CFF008CFF0033FF00\
66FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00
B3FF00A6FF008CFF0080FF0026FF0066FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00\
B3FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00
B3FF00A6FF0099FF0080FF0033FF0066FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00
A6FF0099FF008CFF0033FF0000FF3366FF0080FF0099FF0099FF00A6FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00C0FF008CFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00B3FF00
A6FF008CFF0033FF0033FF0000FF193FFF0073FF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00D9FF0073FF00B3FF00CCFF00C0FF00CCFF00B3FF0033FF00B3FF00C0FF00B3FF00\
B3FF00C0FF00C0FF00CCFF00C0FF00C0FF00B3FF0026FF00A6FF00A6FF00A6FF00
99FF008CFF004CFF0000FF260CFF004CFF0019FF008CFF00A6FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00F3FF00D9FF00CCFF0073FF0000FF19A6FF0080FF0033FF0026FF0099FF008CFF00\
8CFF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF008CFF0080FF0099FF0099FF00
99FF008CFF0073FF0026FF0026FF0066FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00F3FF00E6FF00E6FF00CCFF0099FF0059FF0080FF00A6FF004CFF004CFF0033FF00\
4CFF0000FF1980FF00A6FF00A6FF0099FF0099FF008CFF0019FF0073FF0080FF00
80FF0080FF0066FF0000FF0C73FF0080FF0099FF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00C0FF00A6FF00C0FF00C0FF00A6FF0099FF00A6FF00\
99FF0099FF0099FF0026FF0033FF0066FF0073FF0033FF0033FF0019FF0059FF00
66FF0066FF003FFF0059FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF0026FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00A6FF008CFF0059FF004CFF0000FF2673FF004CFF0000FF26
00FF2600FF1900FF004CFF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00C0FF00B3FF00A6FF0080FF008CFF0099FF008CFF0080FF0026FF00
66FF0066FF004CFF0019FF0073FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00C0FF00B3FF003FFF00A6FF00A6FF00A6FF008CFF0073FF00
8CFF0080FF0059FF0019FF003FFF0066FF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00C0FF00C0FF00
CCFF00CCFF00CCFF00A6FF00CCFF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF00
99FF008CFF0080FF0066FF0019FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00C0FF0059FF00
8CFF0066FF00A6FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00
A6FF0099FF008CFF0080FF004CFF0073FF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF008CFF00
8CFF008CFF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00
A6FF00A6FF0099FF008CFF0059FF0066FF0080FF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00A6FF003FFF00
99FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00
B3FF00A6FF0099FF008CFF0066FF0000FF2673FF008CFF008CFF0099FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF004CFF0099FF008CFF003FFF00
A6FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00
B3FF00A6FF0099FF008CFF0066FF0033FF0066FF0073FF0073FF0026FF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF008CFF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF0080FF00
A6FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00A6FF004CFF000CFF0099FF00
99FF0059FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00
B3FF00A6FF0099FF0080FF0066FF0000FF4000FF6659FF0000D9FF80FF008CFF0099FF0099FF00\
99FF0099FF008CFF0033FF0099FF00A6FF00A6FF00A6FF00A6FF008CFF0000FF19
B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00A6FF0099FF0000FF0CA6FF00C0FF00
CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00
B3FF00A6FF0099FF008CFF0080FF0066FF0033FF0026FF0066FF0080FF008CFF008CFF0099FF00\
99FF008CFF0080FF0026FF0080FF0099FF0099FF0066FF0080FF004CFF0099FF00
B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00B3FF008CFF0026FF0000FF19A6FF00CCFF00
D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00
B3FF00A6FF0099FF008CFF0073FF0059FF0000FF330CFF0066FF0080FF0080FF008CFF008CFF00\
8CFF008CFF0080FF004CFF0073FF0080FF0073FF0066FF004CFF008CFF00A6FF00
B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0033FF008CFF00B3FF00C0FF00CCFF00
D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00
A6FF0099FF0099FF008CFF0073FF0033FF0026FF004CFF0066FF0073FF0080FF0080FF0080FF00\
80FF0080FF0073FF003FFF0000FF5959FF0026FF0033FF0059FF008CFF00A6FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF0099FF00A6FF00A6FF0026FF004CFF0099FF00B3FF00C0FF00CCFF00D9FF00
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00
80FF0066FF0073FF0073FF0059FF0033FF000CFF0059FF0066FF0073FF0073FF0073FF0073FF00\
73FF0073FF0066FF004CFF0000FF2600FF733FFF0019FF0066FF0080FF0099FF00
A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF0099FF0000FF2673FF003FFF0099FF00B3FF00C0FF00CCFF00D9FF00D9FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00
99FF0073FF004CFF0000FF2600FF0000FF4026FF004CFF0059FF0066FF0066FF0066FF0000FF00\
66FF0066FF0059FF004CFF0000FF404CFF0059FF0073FF0080FF008CFF0099FF00
A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00A6FF008CFF0026FF0080FF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF00
99FF008CFF0080FF0066FF0059FF003FFF0000FF003FFF004CFF004CFF0000FF003FFF0019FF00\
4CFF0033FF003FFF000CFF0026FF004CFF0066FF0073FF0080FF008CFF0099FF00
99FF0099FF0099FF0099FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
A6FF0099FF0080FF0000FF4C8CFF00A6FF00B3FF00CCFF00CCFF00D9FF00D9FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF00
99FF008CFF0080FF0073FF0066FF0059FF0026FF000CFF0033FF003FFF0026FF0000FF260CFF00\
33FF0026FF0000FF4000FF4026FF004CFF0059FF0073FF0080FF008CFF008CFF00
8CFF008CFF0059FF008CFF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
8CFF008CFF0073FF0000FF1966FF0080FF00A6FF00C0FF00CCFF00D9FF00D9FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00C0FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF008CFF0080FF0073FF0066FF0059FF0033FF0000FF8C19FF0026FF0019FF0000FF4000FF0C\
00FF2600FF0000FF8C0CFF0026FF0033FF0019FF0059FF0066FF0080FF0080FF00
80FF0080FF0000FF0080FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF00\
66FF004CFF0026FF0033FF0080FF0099FF00B3FF00C0FF00CCFF00D9FF00D9FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00C0FF0080FF003FFF008CFF0099FF0073FF008CFF00
8CFF008CFF0080FF0073FF0066FF0033FF0000FF2600FF4C00FF0000FF0C00FF2600FF6600FF73\
00FF8000FF5900FF4000FF2600FF330CFF0000FF1900FF0059FF0073FF0073FF00
73FF0059FF0059FF0080FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF00\
80FF003FFF0059FF0073FF0099FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0099FF0026FF0066FF003FFF0073FF00
80FF0080FF0073FF0000FF734CFF003FFF0019FF0000FF0C00FF4000FF4000FF8C00FFF30026FF\
2600FF00CCFF00FFF300FFB300FF7300FF9900FF0033FF004CFF0066FF0066FF00
59FF0019FF004CFF0080FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF008CFF0080FF00\
66FF000CFF0033FF0080FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00
C0FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF000CFF0000FF1900FF4C4CFF00
73FF0073FF0066FF003FFF0000FF2626FF0000FF0C00FF3300FF8C00FFBF5900FF000000000000\
000000CC00FF00A6FF0066FF00000000FFFF00FF5919FF000CFF004CFF004CFF00
3FFF0000FFE64CFF0059FF0066FF0080FF0073FF0066FF0080FF0080FF0080FF0073FF0000FF40\
3FFF0000FF0C66FF0080FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00
C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
CCFF00B3FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF0073FF0000FF004CFF00
59FF0066FF004CFF0000FFE600FF4C00FF0C00FFCC00FF7300FFB3004CFF000000000000000000\
0000000000000000000000009900FF00F3FF00FFBF00FF4000FF3319FF0000FF00
00FF4019FF0000FF7300FF004CFF0059FF003FFF0000FFCC26FF0019FF0019FF0026FF003FFF00\
00FF264CFF003FFF0066FF0066FF0066FF0099FF00A6FF00A6FF0073FF0080FF00
C0FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00
8CFF003FFF0099FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF0080FF004CFF0026FF00
4CFF004CFF003FFF0026FF0000FF0C00FF4C00FF992600FF000000000000000000000000000000\
00000000000000000000000000000000FFA600FF4000FF0C0CFF0000FF0C26FF00
3FFF004CFF003FFF0033FF000CFF0026FF0019FF0066FF0033FF0073FF0080FF0073FF0073FF00\
80FF0080FF0059FF0026FF000CFF004CFF0080FF008CFF0080FF004CFF00A6FF00
C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00D9FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00
CCFF0099FF0073FF00B3FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00B3FF00B3FF0099FF0080FF0066FF0000FF1926FF00
00FF330CFF0026FF000CFF0000FF3300FF99000000000000000000000000000000000000000000\
000000000000000000F300FF00A6FF00FFE600FF6600FF0C19FF0033FF003FFF00
59FF0059FF0059FF0059FF004CFF0000FF4C66FF0080FF008CFF008CFF008CFF0099FF0099FF00\
99FF008CFF0080FF004CFF0019FF0033FF004CFF0059FF0026FF0099FF00B3FF00
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00CCFF004CFF00C0FF00E6FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF0080FF00C0FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
CCFF00B3FF0073FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0073FF004CFF0066FF0059FF0059FF00
4CFF0019FF0000FF0C00FF1900FF8C000000000000000000000000000000000000000000000000\
000000000000000000000000004CFF00FF8C00FF4000FF1926FF003FFF004CFF00
59FF0066FF0073FF0073FF0073FF0059FF0066FF008CFF0099FF0099FF0099FF00A6FF00A6FF00\
99FF0099FF008CFF004CFF004CFF0073FF0073FF0033FF0073FF0099FF00B3FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00C0FF0033FF00A6FF00E6FF00E6FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF0099FF00CCFF00D9FF00CCFF00\
C0FF00D9FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
C0FF00B3FF0073FF0099FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF008CFF0080FF0073FF0073FF00
59FF0000FF4C00FF0000FF4C00FFD92600FF000000000000000000000000000000000000000000\
00000000000000000000000000000000FF9900FF3300FF0C19FF0026FF003FFF00
66FF0073FF0073FF0080FF0080FF0080FF0073FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0059FF003FFF0000FF00A6FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00A6FF0099FF00CCFF00D9FF00E6FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFF300FFFF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF0066FF008CFF00B3FF00A6FF00\
99FF00C0FF00CCFF00D9FF00D9FF00CCFF003FFF00CCFF00CCFF00CCFF00C0FF00
C0FF00A6FF0080FF003FFF0099FF00A6FF00A6FF00A6FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0073FF00
59FF003FFF0019FF0000FF2600FFCC00B3FF000000000000000000000000000000000000000000\
00000000000000000000000000CCFF00FF9900FF8C00FF3300FF190CFF004CFF00
66FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF0066FF0000FF1980FF0099FF00
A6FF00A6FF00A6FF0080FF00A6FF00A6FF0000FF0CA6FF00CCFF00D9FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFF300C0FF008CFF0059FF00A6FF00B3FF008CFF00B3FF0059FF00A6FF00A6FF003FFF003FFF00\
8CFF004CFF003FFF00B3FF00B3FF00B3FF0080FF00B3FF00C0FF00C0FF00A6FF00
A6FF0099FF0073FF0066FF0080FF008CFF0059FF0099FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF0099FF008CFF0080FF0073FF00
4CFF0019FF0019FF0000FFD900FFA60073FF000000000000000000000000000000000000000000\
0000000000000000000C00FF0099FF00FFFF00FF4000FF3300FF0C0033FF00FF26
59FF0073FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF008CFF0066FF0033FF0073FF008CFF00
99FF0099FF0080FF0026FF003FFF0073FF0059FF0099FF008CFF00CCFF00D9FF00D9FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFF300FFFF00F3FF00F3FF00E6FF00B3FF0099FF003FFF00C0FF00CCFF00CCFF0073FF00C0FF00\
CCFF00CCFF00C0FF0073FF003FFF000CFF0000FF0C3FFF00A6FF00A6FF0019FF00
66FF003FFF003FFF0059FF000CFF0059FF0073FF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0073FF00
4CFF0000FF3300FF1900FF4000D9FF000000000000000000000000000000000000000000000000\
0000000000000000000033FF00FFFF00FF8C00FF4000FF1919FF0026FF003FFF00
59FF0073FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF0059FF0059FF0026FF004CFF00
80FF0073FF0059FF0000FF1980FF008CFF0073FF0033FF0099FF00B3FF0099FF00CCFF00D9FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF000CFF00D9FF00E6FF00E6FF00C0FF00D9FF00\
D9FF00D9FF00D9FF00CCFF0099FF00A6FF0099FF0059FF0080FF0073FF0000FF0C
00FFBF80FF0099FF008CFF0080FF003FFF0059FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF008CFF0080FF0080FF0073FF00
59FF000CFF000CFF0000FF3300BFFF5900FF0000003300FF000000000000000000000000000000\
00000000000000000000000000000000FFE600FF7300FF5919FF003FFF004CFF00
66FF0073FF0080FF008CFF0099FF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF0073FF0080FF008CFF0073FF0059FF00
3FFF0080FF0073FF004CFF0099FF00A6FF00A6FF0019FF0073FF0026FF0073FF00C0FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00F3FF00
FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF0059FF00E6FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00CCFF00CCFF00B3FF0099FF0019FF0099FF0099FF00
33FF00A6FF00A6FF00A6FF008CFF0033FF0066FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF0099FF008CFF0059FF0073FF0073FF0073FF0066FF00
59FF003FFF0026FF0000FF590059FF00FFD900FFFF00CCFF3F00FF000000000000000000000000\
00000000000000000000000000000000BFFF00CCFF00FF1919FF0026FF0033FF00
66FF0073FF0080FF0080FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF0080FF00A6FF00A6FF0099FF0000FF99
4CFF00A6FF00A6FF00B3FF00B3FF00C0FF00B3FF0099FF008CFF00A6FF0073FF0019FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00A6FF00D9FF00D9FF00D9FF00C0FF00CCFF00F3FF00
FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00B3FF0019FF00B3FF00B3FF00
B3FF00C0FF00B3FF00B3FF0033FF0066FF0026FF0080FF0080FF0080FF0080FF0099FF00A6FF00\
A6FF00A6FF0099FF0099FF008CFF0080FF0059FF004CFF0000FF0066FF0059FF00
4CFF0000FF000CFF0000FF1900FF8C00FF4C00FF6600FFE6000CFF0059FF0066FF00B3FF3F00FF\
0000000000000000000000000000000099FF00FF8000FF9900FF0C00FF193FFF00
59FF0066FF0073FF0073FF0080FF0073FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF0099FF0073FF00
73FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00A6FF00B3FF00C0FF00C0FF00C0FF004CFF00\
99FF008CFF00B3FF00A6FF00A6FF00CCFF00CCFF00C0FF008CFF00CCFF00E6FF00
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF0099FF00A6FF00C0FF00CCFF00
CCFF00CCFF00C0FF00B3FF00A6FF0080FF0000FF0C0CFF004CFF000CFF0073FF008CFF0099FF00\
99FF008CFF008CFF008CFF0073FF0073FF004CFF0000FF0000FF003FFF003FFF00
33FF0000FF1900FF0000FF3319FF0000FF0C00FF1900FF4000FFD900FF7300FF9900D9FF0033FF\
0000000000000000000000000000FF00FFD900FFCC00FF1900FF0C00FF4019FF00
3FFF004CFF003FFF0000FF4026FF0073FF0099FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF00
99FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00CCFF00CCFF00D9FF00D9FF00CCFF00C0FF00\
A6FF0000FF1966FF0080FF0033FF00A6FF00A6FF0059FF0099FF0033FF00B3FF00
D9FF00F3FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF008CFF00C0FF00CCFF00D9FF00
D9FF00CCFF00CCFF00C0FF00A6FF0066FF0080FF008CFF0059FF0000FF2600FF6673FF0080FF00\
80FF0000FF664CFF0066FF003FFF0033FF0019FF0059FF0033FF0000FF0000FF00
00FF264CFF004CFF000CFF0033FF0026FF0000FF0000FFFF00FFFF00FF2600FF5900FFBF00E6FF\
8000FF5900FFD900FF000000004CFF00FFD900FF6600FF2619FF0019FF0026FF00
00FF0000FF1926FF0073FF008CFF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF0099FF00
66FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
CCFF00B3FF00B3FF00C0FF0080FF0066FF0099FF008CFF00C0FF00A6FF00B3FF00
99FF00C0FF00D9FF00E6FF00FFFF00FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00C0FF0066FF0099FF00A6FF00A6FF0080FF004CFF0066FF0033FF004CFF00\
33FF0000FF3319FF0073FF0066FF0066FF0066FF0080FF003FFF0066FF0026FF00
33FF0066FF0066FF0059FF004CFF0000FF4000FFA600FF000CFF0000FF1900FF4000FF4000FFBF\
00000000FFFF00D9FF0059FF2600FF00FFCC00FF4000FF0C26FF003FFF004CFF00
4CFF0033FF0026FF0066FF008CFF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF00
00FF0CB3FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00CCFF00CCFF00D9FF00CCFF00A6FF00B3FF00D9FF00D9FF00D9FF00E6FF00
E6FF00D9FF00B3FF00CCFF004CFF00FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00C0FF008CFF00B3FF00B3FF00B3FF00A6FF0099FF0080FF0066FF000CFF00\
59FF0000FF408CFF0099FF0099FF008CFF008CFF008CFF008CFF0080FF004CFF00
19FF0073FF0073FF0073FF004CFF0033FF0033FF0019FF0026FF0019FF0000FF0000FF1900FF66\
00FF4C00FF6600FF9900FFBF0073FF00A6FF00FF6600FF0C26FF004CFF0059FF00
66FF0059FF0000FF0066FF008CFF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00B3FF00
73FF0099FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00CCFF00A6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFF300FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF0099FF008CFF0066FF0019FF00\
80FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0080FF0000FF00
73FF0080FF0080FF0080FF0073FF0066FF0059FF004CFF003FFF0026FF000CFF0000FF2600FF0C\
00FF0C00FF5900FF3300FF4C00FFCC004CFF00FF8000FF0C0CFF0059FF0073FF00
73FF0066FF003FFF0000FF1933FF0099FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
C0FF008CFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF0099FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0099FF0033FF003FFF0000FF0C\
80FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00A6FF00A6FF0080FF0059FF00
8CFF008CFF008CFF008CFF0080FF0073FF0066FF0059FF003FFF0000FF2600FFA600FF1919FF00\
26FF0019FF0000FF0000FF4C00FF2600FF7300FF3326FF0033FF0059FF0080FF00
80FF0080FF004CFF0080FF0066FF0080FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF0066FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0099FF0059FF003FFF0066FF0080FF00\
80FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF00
99FF0099FF0099FF008CFF0080FF0073FF0066FF0059FF004CFF000CFF0019FF0033FF0026FF00\
3FFF0026FF0000FF3300FF0019FF0019FF0000FF7319FF0066FF0073FF0080FF00
8CFF008CFF008CFF0099FF0099FF008CFF0066FF00B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF0066FF0066FF0099FF00\
A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00
A6FF00A6FF0099FF008CFF0080FF0073FF0066FF004CFF0033FF0026FF004CFF0059FF0059FF00\
59FF0033FF0033FF0000FF333FFF0026FF0000FF0C4CFF0066FF0080FF008CFF00
99FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF0099FF0073FF0073FF0099FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00A6FF00A6FF008CFF0066FF0059FF003FFF0000FF1900FFD933FF0059FF0066FF0073FF00\
66FF000CFF0059FF0059FF0059FF004CFF0019FF004CFF0066FF0073FF008CFF00
99FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF0080FF000CFF0073FF008CFF00\
B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00A6FF008CFF0066FF0000FF0C00FF8C3FFF004CFF0026FF0066FF0073FF0080FF00\
80FF0073FF0073FF0073FF0066FF0059FF0033FF0000FF1926FF0059FF0073FF00
8CFF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF0000FF0C8CFF00A6FF00B3FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00B3FF00A6FF0099FF0066FF0033FF0073FF0073FF0073FF0033FF0073FF0080FF0080FF00\
8CFF0080FF0080FF0073FF0066FF0059FF0000FF1933FF004CFF0073FF004CFF00
33FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF0099FF0019FF00A6FF00B3FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00B3FF00A6FF0080FF0033FF004CFF008CFF008CFF008CFF0019FF0073FF008CFF008CFF00\
8CFF008CFF008CFF0080FF0073FF004CFF0019FF003FFF0073FF008CFF0099FF00
A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0059FF0026FF0080FF00B3FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00B3FF004CFF0000FF0099FF00A6FF00A6FF00A6FF0099FF004CFF0080FF0099FF0099FF00\
99FF0099FF008CFF0080FF0066FF0033FF0033FF0066FF0080FF0099FF00A6FF00
A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
F3FF00F3FF00E6FF00D9FF00CCFF00B3FF0073FF008CFF00B3FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00C0FF004CFF0099FF00B3FF00B3FF00B3FF00B3FF00A6FF003FFF0099FF00A6FF00A6FF00\
99FF0099FF008CFF0080FF0026FF0033FF0026FF0066FF0080FF0099FF00A6FF00
B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
F3FF00F3FF00D9FF0059FF0099FF0073FF0000FF668CFF00C0FF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF0099FF0059FF0073FF0073FF0033FF0033FF0026FF0099FF00A6FF00
B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
F3FF00F3FF00E6FF00CCFF00A6FF0080FF00A6FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF0099FF008CFF0080FF0059FF003FFF0080FF0099FF00A6FF00
B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
F3FF00E6FF00D9FF00C0FF0099FF0080FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00A6FF00A6FF0099FF0099FF008CFF0066FF000CFF008CFF0099FF00A6FF00
B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
F3FF00E6FF00CCFF0099FF0059FF008CFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF004CFF008CFF0099FF00A6FF00
A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
F3FF00B3FF0099FF00B3FF00CCFF00A6FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00A6FF0099FF0099FF0080FF0000FF2673FF008CFF0099FF00
A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
E6FF00CCFF00D9FF00E6FF00E6FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00A6FF00A6FF0099FF0066FF0026FF004CFF000CFF008CFF00
99FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF0066FF000CFF0066FF0080FF00
80FF004CFF0099FF00A6FF00A6FF008CFF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0073FF000CFF003FFF000CFF00
33FF0073FF008CFF008CFF008CFF0073FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00A6FF0099FF0099FF0080FF0073FF0000FF2659FF004CFF00
4CFF003FFF0073FF0019FF0033FF0066FF0099FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00A6FF0099FF008CFF0066FF0026FF0066FF0080FF0080FF00
73FF004CFF000CFF0066FF0080FF004CFF003FFF0099FF00A6FF00B3FF00C0FF00C0FF00B3FF00\
CCFF00D9FF00D9FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
B3FF00B3FF00A6FF00A6FF0073FF0066FF003FFF003FFF0073FF008CFF008CFF00
8CFF008CFF0033FF008CFF00A6FF008CFF0099FF0073FF0066FF0073FF00A6FF00A6FF0000FF8C\
C0FF00C0FF00C0FF0026FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
B3FF00B3FF00A6FF0099FF008CFF003FFF0000FF4C26FF004CFF0099FF0099FF00
A6FF00A6FF0073FF0099FF00B3FF00B3FF00B3FF00B3FF0066FF0066FF0066FF0000FF0C66FF00\
A6FF0099FF0099FF00B3FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00\
B3FF00A6FF00A6FF0099FF008CFF0066FF0026FF003FFF0019FF0099FF00A6FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00A6FF0099FF00A6FF0000FF00\
66FF0000FF4C8CFF008CFF00B3FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00\
A6FF00A6FF0099FF0099FF008CFF0073FF0000FF0059FF008CFF00A6FF00B3FF00
B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00\
00FF33B3FF00C0FF0099FF0073FF00CCFF00E6FF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00A6FF0099FF0099FF00\
99FF0099FF008CFF008CFF0080FF0066FF0059FF0080FF0099FF00A6FF00B3FF00
C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
4CFF00CCFF00D9FF00D9FF00D9FF0073FF0080FF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF0073FF0000FF40\
80FF0080FF0026FF0073FF0059FF003FFF0000FF0080FF0099FF00A6FF00B3FF00
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
B3FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF0080FF00\
00FF264CFF0000FF593FFF000CFF0059FF0059FF0033FF008CFF00A6FF00B3FF00
C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF008CFF00\
66FF003FFF0059FF004CFF0000FF1980FF008CFF008CFF0059FF004CFF0099FF00
C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00A6FF0099FF004CFF00\
19FF0066FF0080FF0080FF0073FF008CFF00A6FF00A6FF00A6FF0080FF0073FF00
B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0080FF0080FF0066FF00\
00FF734CFF008CFF0099FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
D9FF00D9FF00CCFF0019FF00A6FF0099FF008CFF008CFF008CFF0080FF0000FF664CFF004CFF00\
66FF0080FF0099FF00A6FF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
D9FF00CCFF00B3FF0099FF000CFF000CFF0073FF008CFF0019FF0000FF8C73FF003FFF004CFF00\
59FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00
C0FF008CFF0033FF003FFF0099FF0000FF00A6FF00A6FF00A6FF0073FF0099FF008CFF0080FF00\
3FFF0080FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00
CCFF00CCFF00C0FF0080FF00B3FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF008CFF00\
3FFF0026FF008CFF0099FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF00\
00FF0C59FF0073FF0080FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF00\
73FF000CFF0019FF0000FF0066FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF0080FF00\
33FF000CFF0000FF2673FF0099FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF00\
8CFF0073FF0066FF004CFF0099FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00\
A6FF0099FF0080FF0000FF2699FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00\
B3FF00A6FF008CFF0033FF0073FF008CFF0026FF00A6FF00B3FF00C0FF00C0FF00
CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00\
B3FF00A6FF008CFF0066FF003FFF0026FF0066FF0066FF0080FF0073FF008CFF00
B3FF00CCFF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00\
A6FF0099FF0080FF0000FF8080FF008CFF00A6FF00A6FF008CFF0099FF00A6FF00
B3FF00A6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF00\
26FF0080FF0066FF0059FF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00
D9FF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF0099FF00\
80FF0026FF0000FF7359FF0059FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF0099FF0033FF0000FF194CFF00\
33FF0066FF008CFF0099FF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF00A6FF0099FF00\
73FF0073FF0099FF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF00\
80FF000CFF0019FF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFC000FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00\
99FF0059FF008CFF00A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00\
99FF0073FF0000FF5980FF0099FF00C0FF00D9FF00D9FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00B3FF0099FF00\
73FF0000FF268CFF00A6FF00A6FF00C0FF00D9FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00B3FF0099FF00\
59FF008CFF00A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF00\
73FF0080FF00B3FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF0099FF00\
59FF00A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF008CFF00\
99FF00B3FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF0073FF0000FF80\
A6FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF0080FF0073FF00\
A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0000FF0080FF0033FF008CFF00\
B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF008CFF003FFF0099FF00\
B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF004CFF008CFF00\
A6FF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF008CFF0066FF0000FF40\
19FF0080FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00C0FF00B3FF0080FF0033FF0026FF0080FF00\
A6FF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00D9FF00CCFF00C0FF0099FF00B3FF00A6FF0099FF0080FF000CFF0080FF0099FF00\
B3FF00C0FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00D9FF00B3FF0026FF0066FF003FFF000CFF003FFF0033FF0066FF008CFF00A6FF00\
B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00CCFF00B3FF00B3FF00A6FF00A6FF008CFF008CFF0000FF4080FF0099FF00\
A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF004CFF0059FF0073FF00\
73FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0066FF0000FF003FFF00\
8CFF00A6FF00B3FF00B3FF00C0FF00C0FF00A6FF00C0FF00CCFF00D9FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF008CFF0033FF004CFF00\
80FF0099FF00A6FF00A6FF00A6FF008CFF0000FF00A6FF00CCFF00D9FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF008CFF0080FF00\
4CFF0073FF0073FF0059FF0059FF0073FF0000FF00C0FF00CCFF00D9FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF0080FF00\
59FF0026FF0000FF268CFF00A6FF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00B3FF00A6FF0099FF0080FF00\
19FF0073FF008CFF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF0080FF0073FF00\
3FFF0073FF0099FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00B3FF00A6FF0099FF0099FF0080FF0033FF0000FF19\
3FFF0000FF7373FF00A6FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00A6FF004CFF004CFF0059FF004CFF0000FF3366FF00\
73FF008CFF0099FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF0099FF0080FF0059FF0059FF0080FF00\
8CFF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF0073FF004CFF0080FF00\
99FF00A6FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF0033FF0000FF8026FF00\
8CFF00A6FF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
4CFF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00B3FF00A6FF0099FF0073FF003FFF0066FF00\
8CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00A6FF00B3FF0099FF0099FF00\
D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF008CFF0080FF004CFF0073FF00\
8CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0073FF0019FF00CCFF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0000FF8C80FF0066FF0066FF0026FF0000FF0C\
66FF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00A6FF00B3FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF0099FF0099FF008CFF00C0FF00D9FF00\
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFC000\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00E6FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0080FF0019FF0033FF0000FF0C66FF0026FF00\
00FF1980FF008CFF008CFF0099FF0080FF0099FF0099FF0059FF00A6FF00C0FF00
C0FF00C0FF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF0080FF0066FF0099FF0000FF00D9FF00\
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00E6FF00D9FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00A6FF008CFF0073FF0000FF2680FF0059FF008CFF008CFF00\
80FF0019FF004CFF0073FF0080FF0066FF0073FF0066FF0066FF00A6FF00B3FF00
B3FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0080FF0000FF00A6FF00C0FF00CCFF00D9FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00D9FF0080FF00E6FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00C0FF00A6FF00C0FF00C0FF00C0FF00C0FF00B3FF00
73FF00A6FF00A6FF0099FF0099FF008CFF0033FF0000FF2673FF0099FF0099FF0099FF00A6FF00\
99FF0080FF0000FF004CFF004CFF004CFF000CFF0000FF6673FF008CFF008CFF00
B3FF00B3FF00B3FF00B3FF000CFF008CFF0000FF2680FF00A6FF00C0FF00CCFF00D9FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00C0FF00CCFF00E6FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF0080FF00B3FF00B3FF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00B3FF0073FF0099FF00B3FF00B3FF00B3FF00A6FF00
8CFF0080FF0080FF0000FFA666FF0073FF0073FF008CFF0066FF00A6FF00A6FF00B3FF00B3FF00\
A6FF0099FF003FFF0066FF004CFF0000FF0C00FF9926FF0000FF0C33FF0080FF00
99FF00A6FF00A6FF0099FF0080FF0066FF008CFF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00E6FF00A6FF00B3FF00C0FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF0073FF004CFF0099FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00B3FF0099FF0000FF0099FF0099FF0099FF0099FF00
80FF004CFF0033FF0080FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF0099FF008CFF0059FF000CFF0000FF1966FF0073FF0059FF0000FF0C
80FF008CFF008CFF0059FF0059FF0080FF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF00C0FF003FFF00C0FF00\
D9FF00D9FF00CCFF00D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00A6FF0073FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0000FF6659FF0073FF0059FF0080FF00
33FF0073FF008CFF008CFF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF0099FF0059FF0080FF0080FF0073FF008CFF0080FF0080FF00
66FF004CFF0059FF003FFF000CFF0080FF008CFF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00D9FF00B3FF0066FF00A6FF00\
C0FF00C0FF0000FF73D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF0073FF00A6FF00B3FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00A6FF0099FF0080FF000CFF0000FF194CFF0000FF4C
59FF008CFF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00A6FF0080FF0099FF00A6FF0099FF00A6FF0099FF0099FF00
8CFF0073FF0000FF3373FF008CFF0099FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF000CFF00C0FF00B3FF0000FF00\
8CFF000CFF00C0FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF0066FF008CFF0099FF0080FF00\
99FF00A6FF00B3FF00A6FF0099FF008CFF0066FF0066FF0080FF0080FF0080FF00
66FF008CFF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
99FF008CFF0059FF0059FF008CFF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF00\
99FF008CFF00C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF0033FF003FFF0066FF0000FF66\
8CFF0099FF00A6FF0099FF008CFF0000FF2600FF4073FF008CFF0099FF00A6FF00
99FF0033FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00
A6FF0099FF0000FF3300FF7373FF0099FF00A6FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00F3FF00F3FF00\
E6FF00CCFF004CFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF00\
19FF0073FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF0099FF0080FF0066FF0000FF0C\
66FF008CFF0099FF008CFF0080FF0000FF6600FF2680FF0099FF00A6FF00B3FF00
B3FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
A6FF0099FF0080FF0066FF0066FF0080FF008CFF008CFF0099FF00CCFF00CCFF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF0080FF00CCFF00B3FF00\
C0FF00A6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00CCFF0099FF00\
4CFF0059FF00A6FF00A6FF00CCFF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF008CFF0073FF0019FF00\
66FF0080FF008CFF0080FF0073FF003FFF0066FF0080FF00A6FF00B3FF00B3FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00
A6FF0099FF008CFF0073FF0000FF2633FF0073FF008CFF00B3FF00CCFF00CCFF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0066FF0026FF00\
D9FF00E6FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF00\
B3FF0099FF0026FF00A6FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0080FF0059FF000CFF00\
59FF0073FF0073FF0073FF0059FF0033FF0080FF0099FF00A6FF00B3FF00C0FF00
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00
A6FF0099FF0073FF0059FF0033FF0080FF0099FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00B3FF0073FF00CCFF00\
E6FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00\
C0FF00A6FF0059FF00B3FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF0080FF0059FF0019FF00\
3FFF004CFF0059FF0059FF0019FF0066FF008CFF0099FF00A6FF00B3FF00C0FF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00
8CFF0059FF004CFF003FFF0066FF0000FF0CA6FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF004CFF00A6FF0099FF00A6FF00CCFF00\
E6FF00F3FF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00\
CCFF00B3FF008CFF008CFF00C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF00A6FF00A6FF0099FF0080FF0073FF0033FF00\
00FF6600FF5919FF0000FFE626FF0000FF1973FF0099FF00A6FF00B3FF00C0FF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00
A6FF008CFF0059FF0066FF0080FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF0066FF0073FF00B3FF003FFF00\
E6FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00\
CCFF00C0FF0099FF0099FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00CCFF00B3FF004CFF003FFF0080FF008CFF0059FF0073FF0066FF000CFF00\
00FFB300000000FF404CFF0059FF0033FF004CFF0080FF0099FF00A6FF00C0FF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00
A6FF008CFF0066FF003FFF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00B3FF0066FF008CFF00CCFF00D9FF00E6FF00\
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00\
CCFF00C0FF0099FF0099FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00CCFF00C0FF00A6FF0099FF008CFF0000FF0C00FF004CFF004CFF0000FF00\
00FF6600FFD900FF994CFF0073FF0080FF008CFF0080FF004CFF0066FF00B3FF00
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00
A6FF0026FF004CFF0000FF0080FF008CFF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF0099FF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0080FF0099FF00C0FF00D9FF00E6FF00F3FF00\
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00\
CCFF00C0FF008CFF0073FF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00CCFF00C0FF00B3FF00B3FF0099FF0080FF0059FF0026FF0026FF0026FF00\
00FFBF00FF2600FF3366FF0080FF0099FF00A6FF00A6FF00A6FF00A6FF008CFF00
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF00
8CFF003FFF0073FF0080FF0033FF0073FF0080FF008CFF00A6FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF008CFF00A6FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF0099FF008CFF0073FF00B3FF00CCFF00D9FF00E6FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000FFC000
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
CCFF00B3FF008CFF0073FF00A6FF00B3FF00B3FF00C0FF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF0080FF003FFF0059FF0066FF00\
66FF0059FF0033FF0026FF003FFF0099FF00B3FF00C0FF00C0FF00CCFF00CCFF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF00A6FF0066FF00
8CFF0099FF0099FF0099FF0059FF000CFF0026FF0059FF0099FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00B3FF0099FF0099FF0099FF0073FF0073FF00A6FF0099FF00C0FF00
C0FF00C0FF00C0FF00B3FF0099FF0066FF00A6FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
C0FF0066FF0080FF0000FF6680FF0099FF0059FF00B3FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00B3FF00C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF0066FF003FFF0073FF0080FF00\
80FF0066FF0033FF0059FF008CFF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF008CFF008CFF00
B3FF00B3FF00B3FF00A6FF008CFF0066FF0059FF0000FF668CFF0099FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00A6FF0099FF0033FF0073FF003FFF0073FF0073FF0066FF00A6FF00
B3FF00B3FF00B3FF0066FF0080FF0066FF00A6FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFC000FFC000FFC000FFC000FFC000FFC000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00C0FF003FFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF008CFF0080FF004CFF0019FF00
66FF0080FF008CFF0099FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00C0FF00C0FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF0080FF0073FF0059FF000CFF00
66FF0080FF008CFF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00C0FF00B3FF00B3FF00A6FF008CFF0059FF000CFF0000FF003FFF00
00FF5966FF0080FF0080FF008CFF0099FF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00C0FF00C0FF00B3FF00A6FF0099FF0073FF003FFF0059FF0033FF0073FF00
66FF0000FFB34CFF0066FF0059FF0059FF0033FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00C0FF00B3FF0099FF0080FF004CFF004CFF0066FF0080FF008CFF008CFF00
80FF004CFF0019FF003FFF0000FF3359FF008CFF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00\
C0FF0099FF0099FF0080FF004CFF0080FF0099FF0099FF0099FF0099FF0099FF00
8CFF0073FF0033FF0000FF260CFF004CFF0073FF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00\
C0FF00A6FF0073FF0066FF0066FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0080FF0059FF0000FF3300FF004CFF0080FF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00\
C0FF0000FF260CFF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF008CFF003FFF0033FF004CFF0000FF9973FF008CFF008CFF008CFF008CFF0099FF0099FF00\
8CFF0099FF008CFF008CFF00B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00\
26FF0099FF00A6FF00A6FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
A6FF0059FF0080FF0073FF0073FF0066FF003FFF0066FF0000FF3373FF003FFF0066FF0066FF00\
00FF6633FF0059FF008CFF00A6FF00A6FF00CCFF00D9FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00A6FF0099FF0099FF008CFF0080FF0059FF0000FF0C26FF0000FF4073FF008CFF008CFF00\
4CFF0099FF004CFF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
B3FF00B3FF00A6FF0099FF0099FF008CFF0066FF0000FF0066FF0080FF008CFF00A6FF00B3FF00\
B3FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00B3FF00B3FF00A6FF0099FF008CFF004CFF0000FFA673FF0099FF00A6FF00B3FF00B3FF00\
C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00
C0FF00B3FF00B3FF00A6FF008CFF0080FF0066FF0019FF0073FF0099FF00A6FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00
C0FF00B3FF00B3FF0099FF0019FF0033FF000CFF0059FF0073FF004CFF00A6FF00C0FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
C0FF00B3FF00A6FF0099FF0080FF0000FF4066FF0080FF0099FF00A6FF00B3FF00C0FF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
C0FF00A6FF008CFF0080FF0000FF4C00FF2673FF008CFF0099FF00A6FF00B3FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
B3FF0066FF0066FF008CFF0080FF0066FF0033FF0073FF0099FF00A6FF00B3FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00
C0FF00B3FF00A6FF00A6FF0099FF0073FF0000FF3326FF0099FF00A6FF00B3FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00C0FF00B3FF00B3FF00A6FF008CFF0066FF004CFF0073FF008CFF008CFF00B3FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00
CCFF00C0FF00C0FF00B3FF00A6FF0099FF0073FF0000FF0C26FF008CFF0073FF00B3FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00C0FF00B3FF00A6FF008CFF0026FF0059FF0099FF00B3FF00B3FF00C0FF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
CCFF00CCFF00C0FF00C0FF0099FF0080FF0026FF0080FF00A6FF00B3FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
CCFF00CCFF00C0FF00C0FF00B3FF0099FF0066FF0033FF0099FF00C0FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
CCFF00CCFF00C0FF00C0FF00B3FF0099FF0000FF4099FF00B3FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
CCFF00CCFF00C0FF00C0FF00B3FF0099FF0073FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
CCFF00CCFF00C0FF00B3FF0099FF0033FF008CFF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
CCFF00CCFF00C0FF00B3FF0099FF0033FF0080FF00A6FF00C0FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
CCFF00CCFF00B3FF0080FF0073FF0059FF008CFF00A6FF00C0FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
CCFF00C0FF00B3FF0099FF0080FF004CFF008CFF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00
CCFF00C0FF00B3FF00A6FF0080FF0019FF0080FF008CFF0099FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00
C0FF00C0FF00B3FF008CFF0073FF0000FF8C3FFF0080FF00A6FF00C0FF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00
C0FF00B3FF00A6FF0080FF0000FFCC66FF008CFF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF00B3FF00
8CFF008CFF008CFF0066FF0019FF0080FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF0099FF00
8CFF008CFF0066FF0026FF0000FF3380FF008CFF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00
B3FF00A6FF0099FF008CFF0059FF004CFF0059FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00
C0FF00B3FF00A6FF0099FF0059FF0000A6FF59FF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00
C0FF00B3FF00B3FF0099FF0066FF004CFF0059FF008CFF0099FF00A6FF00A6FF00A6FF0080FF00\
B3FF00C0FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00
C0FF00B3FF00B3FF00A6FF008CFF0073FF0000FFA659FF0066FF0080FF0073FF003FFF0080FF00\
A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00
C0FF00B3FF00A6FF0099FF008CFF0073FF003FFF004CFF004CFF0080FF008CFF0099FF0066FF00\
C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00
B3FF00A6FF0099FF008CFF0073FF0066FF0000FFCC73FF008CFF0099FF00A6FF00B3FF00C0FF00\
C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00
A6FF0026FF0073FF0073FF0026FF0019FF0000FF2673FF0099FF00A6FF00B3FF00C0FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00
B3FF0099FF0073FF000CFF004CFF0066FF0080FF0033FF0099FF00B3FF00B3FF00C0FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00
A6FF0099FF0080FF004CFF0066FF0080FF008CFF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00
A6FF0099FF0073FF0000FF7300FF0C80FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00\
E6FF00D9FF00D9FF00CCFF00B3FF00A6FF00B3FF00A6FF00A6FF00A6FF0099FF00
0066FF73FF0066FF0000F3FF73FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00\
D9FF00C0FF00B3FF0099FF0099FF004CFF0080FF0000FF1959FF0080FF0073FF00
26FF0000FF3300FF1926FF0073FF008CFF0099FF00A6FF00A6FF00B3FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00\
D9FF00CCFF00B3FF008CFF0066FF008CFF0000FF0C99FF0099FF008CFF0066FF00
73FF0073FF0073FF0033FF0059FF0080FF0099FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00D9FF00CCFF00C0FF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF00
99FF0099FF008CFF0080FF0000FF2673FF0080FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00
A6FF00A6FF0099FF008CFF003FFF0019FF0066FF0073FF004CFF008CFF008CFF00B3FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
B3FF00B3FF00A6FF008CFF0073FF0000FF0C4CFF0033FF0019FF004CFF008CFF00B3FF00B3FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00B3FF00A6FF0080FF0033FF0026FF000CFF0000FF800CFF0080FF0099FF00A6FF00B3FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00
C0FF00B3FF00A6FF0099FF0073FF0026FF0000FF400CFF004CFF0066FF0099FF00A6FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00
C0FF00B3FF00A6FF0080FF003FFF0000FF4026FF0033FF003FFF0073FF0099FF00A6FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00A6FF00
A6FF00C0FF00CCFF00CCFF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
C0FF00B3FF0099FF008CFF0073FF0066FF0066FF003FFF003FFF0073FF0099FF0099FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF0099FF00
73FF0099FF0099FF008CFF00A6FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
C0FF00C0FF00B3FF00A6FF0099FF008CFF0080FF0033FF003FFF0066FF008CFF0099FF0099FF00\
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00A6FF0099FF008CFF0099FF003FFF00
73FF003FFF00B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0080FF0073FF004CFF0080FF008CFF008CFF00\
8CFF008CFF0073FF0099FF0099FF0099FF008CFF0080FF000CFF0059FF0066FF00
99FF00B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0019FF0019FF0066FF0026FF00\
73FF0066FF0026FF0059FF0066FF004CFF0026FF0000FF2680FF0066FF0073FF00
A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0066FF0000FF5900FF000CFF00\
3FFF0000FF0C66FF0000FF408CFF008CFF008CFF0073FF00A6FF00B3FF00B3FF00
99FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0066FF0000FF0059FF0066FF00\
4CFF0033FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00
CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00B3FF00B3FF00A6FF0099FF0099FF008CFF0073FF0026FF0000FF4C66FF0080FF00\
80FF0073FF008CFF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00B3FF00B3FF00A6FF0099FF0099FF008CFF0080FF004CFF0000FF6600FFBF73FF008CFF00\
99FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00A6FF008CFF008CFF008CFF008CFF0080FF0066FF0000FF2600FF0C80FF008CFF00\
99FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00C0FF00B3FF00B3FF0099FF00A6FF00A6FF00
A6FF00A6FF0099FF0073FF0033FF0073FF0073FF0073FF0059FF0033FF0073FF008CFF0099FF00\
A6FF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0099FF0066FF004CFF0073FF0099FF00
99FF0099FF008CFF0080FF000CFF004CFF0033FF004CFF000CFF0000FFBF59FF0080FF0099FF00\
A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00B3FF0099FF0066FF0066FF004CFF00
80FF003FFF0080FF0066FF003FFF0033FF0026FF0000FF404CFF0059FF003FFF0066FF0080FF00\
99FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF0080FF00
19FF0000FF3359FF0033FF0000FFF359FF0066FF0059FF0066FF0080FF0080FF0066FF0000FF0C\
00FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00B3FF00A6FF008CFF00
73FF004CFF0000FF0C3FFF0059FF0073FF0080FF0080FF0080FF008CFF0099FF0099FF0080FF00\
99FF008CFF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00B3FF00A6FF0099FF00
8CFF0073FF004CFF0033FF0073FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF00
8CFF0080FF004CFF0059FF0073FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF00
8CFF0066FF0026FF0000FF4073FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
D9FF00CCFF008CFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0080FF00
73FF003FFF000CFF004CFF0066FF0080FF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00F3FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
D9FF00C0FF0080FF00B3FF00C0FF00CCFF00CCFF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF00
00FF0000FF1900FF5900FFCC3FFF0080FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00F3FF00B3FF0099FF00A6FF00CCFF00CCFF00C0FF00
C0FF00B3FF0073FF0099FF00A6FF00B3FF00B3FF0033FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF0080FF0099FF00A6FF00A6FF00A6FF0099FF0099FF0080FF00
59FF0000FFA600FF0C3FFF0000FF660CFF008CFF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00F3FF00E6FF00CCFF00C0FF0080FF0080FF008CFF00
A6FF008CFF0073FF0000FF6666FF0099FF0099FF0073FF00A6FF00A6FF00B3FF00C0FF00C0FF00\
B3FF00B3FF00A6FF008CFF003FFF0099FF0099FF0099FF0099FF008CFF0080FF00
66FF0000FF0C19FF004CFF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF0059FF00
4CFF004CFF008CFF008CFF0000FF1959FF0026FF0026FF0073FF004CFF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF008CFF0026FF0080FF0080FF008CFF008CFF0080FF0080FF00
66FF0000FF0C66FF0073FF008CFF0099FF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00A6FF00
99FF00B3FF00B3FF00A6FF008CFF008CFF0099FF0099FF0059FF0080FF0066FF0080FF008CFF00\
33FF008CFF008CFF0080FF003FFF003FFF0019FF0073FF0073FF0073FF0066FF00
4CFF0059FF0073FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF004CFF00
C0FF00C0FF00C0FF00C0FF0080FF00A6FF00B3FF00B3FF00A6FF00A6FF00A6FF008CFF0000FF8C\
3FFF0066FF0059FF0000FF004CFF004CFF0019FF004CFF0059FF004CFF004CFF00
00FF0C66FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00C0FF00
CCFF00CCFF00CCFF00CCFF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF00\
73FF003FFF0059FF004CFF0073FF0073FF003FFF0000FF1900FF0C00FF5933FF00
00FF194CFF0073FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00\
99FF0059FF008CFF008CFF008CFF008CFF0073FF0019FF0066FF0059FF0059FF00
33FF003FFF0073FF0080FF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF00\
A6FF0066FF0099FF00A6FF0099FF0099FF0066FF0073FF0080FF0080FF0073FF00
33FF0026FF0059FF004CFF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF0080FF00CCFF00D9FF00D9FF00D9FF00D9FF00\
B3FF0073FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00\
B3FF00A6FF00B3FF00B3FF00A6FF00A6FF004CFF008CFF0099FF008CFF0073FF00
59FF004CFF0000FF3366FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00A6FF00A6FF00C0FF00B3FF00B3FF0099FF00\
8CFF00D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF00
80FF0073FF0026FF004CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00B3FF0000FF0C80FF0080FF00A6FF00CCFF00\
D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00
8CFF0080FF0066FF0066FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0080FF008CFF0099FF00A6FF00D9FF00\
E6FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF00
99FF008CFF0066FF0000FF4080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF000CFF008CFF00C0FF00CCFF00D9FF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00
99FF008CFF004CFF0000FF8033FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00C0FF0073FF00A6FF00A6FF0099FF0000FF26A6FF00C0FF00D9FF00E6FF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF00
99FF008CFF0073FF0000FF2659FF0073FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF0099FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00C0FF00A6FF0000FF7366FF0066FF0066FF0073FF00B3FF00CCFF00E6FF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF00
99FF0080FF0059FF0000FF4C4CFF0066FF0073FF0066FF000CFF008CFF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF0099FF0080FF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00
A6FF0099FF0000FF19A6FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00C0FF00B3FF00A6FF0073FF0073FF0080FF00A6FF00B3FF0073FF004CFF00E6FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00
99FF0080FF0073FF0059FF0000FFB33FFF004CFF0000FF0C66FF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF008CFF0000FF3380FF0099FF00A6FF00A6FF00A6FF00A6FF00
99FF003FFF0059FF00A6FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00A6FF0099FF0059FF008CFF00B3FF00C0FF00CCFF00CCFF00D9FF00E6FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF00
99FF008CFF0080FF0066FF004CFF0000FF0019FF0066FF0073FF008CFF008CFF0099FF0099FF00\
99FF0099FF008CFF0080FF0000FF8C73FF008CFF0099FF0099FF0080FF0080FF00
73FF0059FF0099FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00B3FF0080FF0026FF004CFF008CFF00B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF00
99FF008CFF0080FF0066FF003FFF000CFF003FFF0066FF0073FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF0080FF0059FF0066FF0080FF0080FF0080FF0073FF0000FF0C
33FF008CFF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
B3FF00B3FF0099FF0073FF0080FF00A6FF00A6FF0099FF00CCFF00D9FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF00
99FF008CFF0066FF0000FF0C0CFF0019FF004CFF0066FF0073FF0080FF0080FF008CFF008CFF00\
8CFF008CFF0080FF0073FF004CFF004CFF0066FF0066FF0059FF0059FF0019FF00
80FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00
A6FF0099FF0073FF0080FF0080FF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF00
8CFF0080FF0073FF004CFF0000FF0C3FFF0059FF0066FF0073FF0073FF0080FF0080FF0080FF00\
80FF0080FF0080FF0073FF0059FF000CFF003FFF0033FF0000FF9900FF0019FF00
66FF008CFF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF0080FF0099FF0099FF00
8CFF0033FF0099FF00A6FF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0066FF0073FF0066FF00
73FF0073FF004CFF003FFF0000FF1933FF0059FF0066FF0066FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0066FF0059FF0026FF0000FF2600FF0C3FFF0000FF0066FF00
73FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF008CFF0000FF0073FF00
3FFF0073FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF0059FF0000FF80
3FFF0019FF0000FF190CFF0000FF263FFF004CFF0059FF0066FF0066FF0066FF0066FF0000FF0C\
66FF0066FF0066FF0059FF004CFF0026FF0026FF004CFF0059FF0066FF0073FF00
80FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0080FF0000FF00
73FF008CFF00A6FF00C0FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0080FF00
73FF0059FF004CFF0033FF0000FF1926FF004CFF004CFF0059FF0059FF004CFF004CFF0000FF0C\
4CFF0059FF003FFF004CFF0000FF7300FF193FFF0059FF0066FF0073FF0080FF00
8CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF0073FF0000FF00
73FF0099FF00B3FF00C0FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF0099FF008CFF00
80FF0073FF0066FF0059FF003FFF0000FF3333FF003FFF004CFF003FFF0000FFBF19FF0000FFBF\
33FF003FFF0019FF0026FF0000FF000CFF003FFF0059FF0066FF0073FF0080FF00
80FF008CFF008CFF0099FF0099FF0099FF0080FF008CFF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0019FF00
73FF0099FF00A6FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF00
80FF0073FF0066FF0059FF004CFF000CFF0000FF1926FF0033FF0033FF0019FF0000FF6600FF00\
26FF0026FF000CFF0000FFA600FF0C19FF003FFF004CFF0059FF0066FF0073FF00
80FF008CFF008CFF008CFF008CFF0080FF0000FFA68CFF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF003FFF0080FF0080FF0073FF003FFF00
19FF0059FF0000FFBF99FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF00
80FF0073FF0066FF0059FF003FFF0000FF0C00FF3319FF0026FF0019FF000CFF0000FF4000FF19\
00FF1900FF0C00FF0C00FF6600FF0019FF0033FF0033FF0033FF0059FF004CFF00
73FF0080FF0080FF0080FF0080FF0066FF004CFF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF0099FF0080FF003FFF004CFF0000FF0C26FF00
73FF008CFF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00\
A6FF0019FF0066FF008CFF0099FF0099FF0080FF008CFF008CFF008CFF0080FF00
80FF0073FF0066FF004CFF0000FF3300FF4000FF3300FF0000FF0000FF7300FF2600FF9900FF59\
00FFA600FF9900FFBF00FF4000FF1900FF0C0CFF000CFF0000FF0000FF664CFF00
66FF0073FF0073FF0073FF0066FF003FFF0066FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF0099FF0099FF0080FF0066FF0000FFE659FF0066FF00
80FF0099FF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00\
B3FF00A6FF008CFF0033FF0073FF0073FF003FFF0080FF0080FF0080FF0080FF00
66FF004CFF0059FF004CFF0033FF000CFF0000FF2600FFCC00FF2600FF8000FFA600FFB300F3FF\
9900FF00A6FF00FF8C00FF7300FF5900FF5900FF3300FFA600FF0026FF004CFF00
59FF0066FF0066FF0066FF003FFF0033FF0066FF0080FF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF0080FF0080FF003FFF0000FF4066FF0080FF00
8CFF00A6FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00\
B3FF00B3FF0099FF0080FF0026FF003FFF003FFF0073FF0073FF0073FF0073FF00
66FF0033FF000CFF0033FF0026FF000CFF0000FF2600FF6600FF5900FF995900FF000CFF000000\
0000000019FF00FFF300FFD900FFFF00F3FF00FFB300FF4C00FF0C26FF0033FF00
19FF0059FF0059FF0059FF0026FF000CFF0059FF0073FF0073FF0080FF0080FF0059FF0080FF00\
8CFF008CFF008CFF008CFF0080FF004CFF0066FF004CFF0033FF0073FF0080FF00
8CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00CCFF00C0FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00B3FF00A6FF0080FF0073FF004CFF0000FF4059FF0066FF0066FF0066FF00
59FF0033FF0000FF3319FF000CFF0000FF4C00FF3300FF8C00FFBF0026FF000000000000000000\
0000000000003300FF3300FFC000FF000000000000008CFF00FF330CFF0000FF0C
26FF003FFF004CFF003FFF000CFF0026FF003FFF004CFF004CFF0073FF0073FF0059FF0066FF00\
73FF0073FF0080FF0073FF0066FF0026FF0000FF6600FF4019FF0066FF0080FF00
8CFF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00A6FF008CFF00B3FF00CCFF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00D9FF00CCFF0080FF00C0FF00C0FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00B3FF00A6FF0099FF0080FF003FFF000CFF004CFF0059FF0059FF0059FF00
33FF0000FF2600FFA600FF0C00FF2600FF7300FFA600FFB300CCFF000000000000000000000000\
000000000000000000000000000000000000008CFF00FFBF00FF7300FF5900FFBF
00FF260CFF0000FF0C00FF3319FF000CFF0000FF5900FF403FFF0059FF0033FF0019FF0000FF00\
26FF0000FFBF0CFF0019FF0000FF0C3FFF0059FF0059FF0059FF003FFF0059FF00
66FF0066FF0073FF0099FF00A6FF00A6FF00A6FF0073FF008CFF00C0FF00CCFF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00D9FF00C0FF0066FF0080FF00B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
B3FF00B3FF00A6FF0099FF0080FF0066FF000CFF0033FF004CFF004CFF004CFF00
3FFF0026FF0000FF0000FF7300FF6600FFCC00BFFF2600FF3F00FF000000000000000000000000\
00000000000000000000000000000000000000D9FF00FFB300FF3300FF1900FF00
00FF0C00FF3326FF003FFF004CFF003FFF003FFF0033FF000CFF0033FF0000FFFF33FF0059FF00\
0CFF0073FF0073FF0073FF0066FF0073FF0080FF0080FF0073FF003FFF000CFF00
3FFF0000FF0C66FF008CFF0099FF008CFF0080FF0066FF00A6FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00CCFF00B3FF000CFF00A6FF00C0FF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
B3FF00A6FF0099FF008CFF0080FF0026FF0019FF0000FF260CFF0033FF0019FF00
26FF0000FF0000FF1900FF5900FFF3000000000000000000000000000000000000000000000000\
0000000000000000000000000000000066FF00CCFF00FFE600FF4000FF1919FF00
26FF0026FF003FFF004CFF0059FF0059FF0059FF004CFF0026FF0019FF004CFF0066FF0073FF00\
80FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0073FF0033FF00
00FFA626FF0000FF4C73FF0073FF004CFF0073FF0099FF00B3FF00C0FF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00CCFF00C0FF0059FF00D9FF00E6FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00F3FF00D9FF00D9FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00CCFF00B3FF0099FF0073FF00B3FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
B3FF0099FF0073FF0026FF0000FF0000FF663FFF004CFF003FFF0000FF0C00FFBF
0CFF0000FF2600FF8000F3FF0080FF000000000000000000000000000000000000000000000000\
0000000000000000000000000000000080FF00F3FF00FF8C00FF8000FF2619FF00
33FF003FFF004CFF0059FF0066FF0066FF0066FF0066FF0066FF0059FF004CFF0073FF0080FF00\
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF0059FF00
00FF1966FF0059FF003FFF0019FF004CFF0080FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF003FFF00C0FF00D9FF00E6FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00F3FF00F3FF00D9FF0066FF00D9FF00E6FF00E6FF00
E6FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00C0FF00A6FF0059FF00A6FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00A6FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF0033FF0000FF0C
00FF2600FF3300FFA6000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000008000FF00F3FF00FF8C00FF3300FF0C19FF00
33FF003FFF004CFF0059FF0066FF0073FF0073FF0073FF0073FF0073FF0026FF0066FF008CFF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0019FF00
80FF0080FF0080FF0073FF004CFF0026FF0080FF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00C0FF00A6FF0073FF00C0FF00D9FF00E6FF00E6FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00A6FF00C0FF00CCFF00D9FF00
CCFF004CFF00D9FF00D9FF00D9FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00C0FF00B3FF0099FF0000FF0C99FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00A6FF0099FF008CFF008CFF0080FF0073FF0073FF0059FF0000FF0C00FF00
00FF0000FF9900D9FF00B3FF000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000066FF00FF7300FF3300FF730CFF00
19FF0019FF0033FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF003FFF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF008CFF0080FF0066FF0026FF0000FF3300FF26A6FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF008CFF00A6FF00CCFF00D9FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFFF00FFFF00F3FF00\
F3FF00F3FF00E6FF00D9FF00D9FF00D9FF00CCFF00A6FF008CFF0073FF00B3FF00
B3FF0059FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00CCFF00A6FF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00B3FF0099FF003FFF003FFF0099FF00A6FF00A6FF00A6FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00A6FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF004CFF0033FF00
0CFF0000FF2600FFBF00FFF3000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000004CFF00FFF300FFCC00F3FF00FF3300FF0C
00FF3326FF004CFF0066FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF00\
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF0099FF0099FF008CFF0066FF0026FF0059FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00\
99FF00A6FF00A6FF008CFF0066FF00B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300E6FF00D9FF00C0FF00\
B3FF00CCFF00CCFF00B3FF00C0FF00C0FF0080FF0019FF0099FF0066FF008CFF00
00FFBF8CFF0073FF003FFF0099FF00C0FF00C0FF00C0FF00C0FF0026FF00B3FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00A6FF0099FF0000FF6673FF008CFF0099FF0099FF003FFF00
A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0073FF0059FF003FFF0026FF00
0CFF00B300FF00FF8000FFFF1900FF000000000000000000000000000000000000000000000000\
000000000000000000000000D900FF00A6FF00FFBF00FF7300FF4000FF8C00FF19
00FF9900FF003FFF0059FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF0099FF008CFF004CFF0026FF0073FF0080FF0099FF0099FF0099FF0099FF0033FF00\
66FF0073FF008CFF0066FF0073FF00A6FF00B3FF00CCFF00D9FF00D9FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFFF00E6FF00CCFF00\
D9FF00D9FF0080FF008CFF0059FF008CFF0059FF00A6FF00C0FF00B3FF0000FFBF
B3FF00C0FF0000FF4CB3FF00A6FF004CFF0059FF00A6FF0099FF000CFF00A6FF00B3FF00B3FF00\
A6FF0080FF0099FF008CFF0080FF0019FF004CFF0019FF0080FF0066FF0073FF00
A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0066FF0026FF0000FF8C00FF00
00FF0000FF3300FFA6000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000019FF00CCFF00FFBF00A6FF00FF3300FF1900FF00
0CFF0000FF8C00FF0000FF1966FF0080FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF008CFF0073FF0019FF0059FF004CFF0080FF008CFF008CFF0080FF0066FF00\
00FF594CFF0073FF0073FF0019FF0073FF0099FF00C0FF00C0FF00C0FF00D9FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00FFFF00\
F3FF00F3FF00D9FF00D9FF00C0FF0066FF00C0FF00CCFF00D9FF00CCFF0000FF00
CCFF00CCFF00CCFF00CCFF00CCFF0000FFE680FF000CFF0000FF1973FF0066FF0099FF00A6FF00\
8CFF0033FF0059FF0000FF1966FF0080FF0073FF0000FF0019FF0019FF0080FF00
99FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0059FF0033FF0000FF59
00FFB300FF66000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000006600FF0080FF0099FF00FF8000FF4C00FF660CFF00
26FF0033FF004CFF0059FF0073FF0080FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00A6FF008CFF0059FF0066FF004CFF0000FF404CFF0066FF0066FF0000FF2633FF00\
19FF0080FF0099FF0099FF0080FF003FFF008CFF00A6FF00A6FF0099FF00CCFF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFFF00\
FFFF00FFFF00F3FF00E6FF00D9FF008CFF00D9FF00E6FF00E6FF00D9FF00C0FF00
D9FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF00A6FF00B3FF0099FF0000FF0066FF0080FF00\
00FF193FFF0019FF0073FF008CFF0099FF008CFF0080FF0066FF0019FF0000FF26
99FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00\
99FF0099FF008CFF008CFF0080FF0080FF0073FF0073FF0059FF0000FF0026FF00
0CFF0000FF4000FFFF0000005900FFA600FF1900FF000000000000000000000000000000000000\
00000000000000000000000000000000000000D9FF00FFA600FF6600FF9900FF66
33FF003FFF0059FF0066FF0073FF0080FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF00A6FF004CFF0080FF008CFF008CFF0073FF0059FF004CFF0080FF008CFF0066FF00\
4CFF0099FF00A6FF00A6FF0099FF0059FF0066FF003FFF0026FF008CFF00C0FF00
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF0099FF00\
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFFF00FFFF00F3FF00E6FF003FFF00E6FF00E6FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00CCFF00C0FF0099FF0099FF0073FF0073FF00\
8CFF008CFF004CFF0099FF00A6FF00A6FF0099FF008CFF0059FF003FFF0073FF00
8CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF0080FF0066FF0080FF0080FF0073FF0073FF0066FF0059FF004CFF0033FF00
0CFF0000FFBF00CCFF00E6FF0066FF00F3FF0059FF0000FF000000000000000000000000000000\
0000000000000000000000000000000000001900FF00FFD900FF7300FF190CFF00
26FF0033FF003FFF0066FF0073FF0073FF0080FF008CFF008CFF0099FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF0080FF00A6FF00A6FF0099FF008CFF003FFF0000FF1999FF00A6FF00A6FF00\
A6FF00B3FF00C0FF00C0FF00B3FF0099FF0080FF0099FF0099FF0033FF0059FF00
C0FF00CCFF00CCFF00CCFF00D9FF00CCFF0066FF00D9FF00D9FF00D9FF00D9FF00CCFF004CFF00\
D9FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFFF00FFFF00F3FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF0073FF0099FF00\
B3FF00B3FF00A6FF00B3FF00B3FF00B3FF00A6FF008CFF000CFF0000FF9966FF00
80FF008CFF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00\
8CFF0080FF003FFF0066FF0066FF0066FF0066FF0066FF0059FF003FFF0026FF00
19FF0000FF1900FF8C00FF6600FFA600FF8C00FFB300FFFF9900FF0099FF0066FF0066FFA600FF\
0000000000000000000000000000000000000000000099FF00FFCC00FFD900FF00
00FF0000FF003FFF0059FF0066FF0073FF0073FF0080FF0080FF008CFF0099FF00A6FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF004CFF004CFF0073FF00A6FF00B3FF00C0FF00\
C0FF00C0FF00CCFF00C0FF00C0FF00A6FF00A6FF00C0FF00C0FF00A6FF00A6FF00
73FF008CFF00A6FF00B3FF00C0FF00B3FF004CFF00C0FF00CCFF00CCFF00CCFF00B3FF00A6FF00\
D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF0059FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF0099FF008CFF0059FF004CFF00
66FF0073FF0019FF0033FF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00\
80FF0073FF0059FF0000FF1933FF004CFF0059FF0059FF004CFF0033FF0000FF8C
00FF2600FF3300FF0C00FF3300FF8000FF4000FF5900FF8C00FFA600FFBF00FFD900CCFF0059FF\
00000000000000000000000000000000000000BFFF00FFF300FF5900FF4C00FF33
00FF800CFF003FFF004CFF0059FF0059FF0000FFD966FF0059FF003FFF0073FF00A6FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0080FF0073FF00A6FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF00CCFF00CCFF00CCFF00CCFF00
B3FF004CFF0066FF0080FF0099FF0080FF0066FF004CFF00C0FF00B3FF008CFF008CFF0080FF00\
99FF00D9FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00A6FF0099FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF008CFF0026FF0059FF00
59FF0000FF0000FF663FFF0019FF0080FF008CFF008CFF008CFF008CFF008CFF0080FF0073FF00\
66FF0059FF0000FF1933FF0019FF0026FF0019FF0033FF000CFF0000FF6619FF00
26FF0000FF1926FF000CFF0000FF0000FF1900FF4C00FF8C00FF4C00FF7300FF8000FFBF00A6FF\
8000FF0000000000000000000000000000000080FF00FF8C00FF4000FF1900FF00
00FF0000FF3300FF1933FF003FFF0000FF3300FFFF59FF0059FF0066FF0099FF00A6FF00B3FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF0099FF00B3FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00B3FF00B3FF0073FF0080FF0099FF0080FF0080FF0099FF0080FF0059FF00A6FF0099FF00\
8CFF0080FF00C0FF00E6FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00A6FF00B3FF00CCFF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00A6FF0080FF003FFF008CFF00
8CFF0059FF0033FF0000FF3300FF4C73FF0080FF0080FF0073FF004CFF0000FF0C66FF004CFF00\
00FF0026FF0033FF0059FF004CFF000CFF0000FF3300FF000CFF004CFF004CFF00
4CFF0019FF003FFF0026FF000CFF0000FF0C00FF5900FF4C00FF2600FF4000FF8000FFBF00E6FF\
00A6FF0000006600FF0000000000007300FF0066FF00FFB300FF8000FF2619FF00
26FF0000FF0026FF0026FF0000FF0C0CFF004CFF0073FF008CFF0099FF00A6FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF008CFF0073FF00B3FF00C0FF00CCFF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00CCFF0080FF00B3FF00C0FF00A6FF008CFF004CFF00A6FF00A6FF00CCFF00C0FF00\
00FF0CC0FF00B3FF00A6FF003FFF00C0FF00E6FF00FFFF00FFF300FFF300FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00C0FF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF008CFF0073FF0099FF00A6FF00
99FF0080FF0059FF0066FF0059FF0019FF0059FF0019FF003FFF004CFF0059FF0073FF0059FF00\
73FF004CFF0073FF0073FF0066FF0059FF0059FF0000FF2600FF0059FF0066FF00
66FF0059FF004CFF0000FF0C00FF5900FF7300FF000CFF0000FF0000FF5900FF8C00FF4000FFBF\
0080FF0073FF00E6FF0099FF0073FF00000000CCFF00FF8C00FF4000FF2619FF00
33FF003FFF004CFF004CFF003FFF0000FF994CFF0073FF008CFF0099FF00A6FF00B3FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF0099FF0000FFA699FF00C0FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF0080FF00CCFF00D9FF00CCFF00C0FF008CFF00C0FF00CCFF00D9FF00D9FF00\
8CFF00E6FF00E6FF00D9FF00B3FF00C0FF00C0FF003FFF00FFFF00FFF300FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF004CFF00A6FF00B3FF00B3FF00
A6FF0099FF0099FF008CFF0080FF0066FF0000FF0C3FFF0033FF0066FF0080FF008CFF008CFF00\
8CFF0073FF0080FF008CFF008CFF0080FF0073FF003FFF003FFF0066FF0073FF00
73FF0066FF0059FF0000FF0C26FF0019FF0019FF0026FF0019FF000CFF0000FF1900FF2600FF4C\
00FF8C00FFB300FF9900FFA600FFCC0099FF0033FF00FFB300FF4000FF1919FF00
33FF004CFF0059FF0059FF0059FF0033FF0019FF0066FF008CFF0099FF00A6FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF0000FF1999FF00C0FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00A6FF00C0FF00D9FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFF300FFF300FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00A6FF00A6FF0099FF0080FF0066FF0000FF0066FF0080FF0080FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF0080FF0033FF0066FF0073FF0080FF00
80FF0073FF0059FF0059FF0059FF0026FF0033FF0033FF0026FF0019FF0000FF0000FF2600FF4C\
00FF3300FF3300FFCC00FF4C00FF8C00FFBFE600FF00E6FF00FF5900FF9900FF33
00FF0C59FF0066FF0066FF0066FF0033FF0026FF0059FF0066FF008CFF00A6FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF0026FF00A6FF0033FF00C0FF00D9FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00B3FF00B3FF00E6FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00
C0FF00B3FF00A6FF0099FF0080FF0066FF0000FF0073FF008CFF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF0099FF0099FF0073FF003FFF0080FF0080FF008CFF00
80FF0080FF0073FF0073FF0066FF0059FF004CFF003FFF0033FF0019FF0000FF0000FF6600FF00\
0CFF0000FF3300FF2600FF2600FF4C00FFA600FFB33F00FF00FF4C00FF0000FF33
3FFF0066FF0073FF0073FF0073FF0066FF0000FF0026FF0000FF0C8CFF00A6FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF0099FF00CCFF00D9FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00CCFF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00
C0FF00B3FF00A6FF008CFF0019FF0026FF0000FF0C66FF008CFF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF0099FF0066FF0066FF008CFF008CFF008CFF00
8CFF008CFF0080FF0073FF0073FF0066FF0059FF004CFF0000BFFF00FF4000FF9900FF190CFF00\
26FF0026FF000CFF0000FF0C00FF6600FF4C00FF4000FF4C00FF2626FF0033FF00
00FF0C66FF0080FF0080FF0080FF0080FF003FFF0080FF0073FF0059FF008CFF00A6FF00B3FF00\
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00D9FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00
C0FF00A6FF0073FF0059FF0000FF1966FF0080FF0073FF008CFF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0066FF008CFF0099FF0099FF0099FF00
8CFF008CFF0080FF0080FF0073FF0066FF0059FF004CFF0033FF0000FF6626FF0033FF000CFF00\
3FFF0033FF0019FF0000FF2600FF0C19FF000CFF000CFF0000FF4026FF0059FF00
66FF0073FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF008CFF0033FF0059FF00B3FF00\
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00
C0FF00A6FF008CFF0080FF0000FF2673FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF008CFF0080FF0073FF0073FF0066FF0059FF003FFF000CFF0033FF004CFF004CFF003FFF00\
4CFF003FFF0000FF0000FF0000FF2633FF0033FF0019FF0000FF0C3FFF0066FF00
73FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00
C0FF00B3FF00A6FF008CFF0000FF0066FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
99FF008CFF0080FF0073FF0059FF0059FF003FFF0026FF0000FF194CFF0059FF0066FF0066FF00\
66FF0059FF0026FF004CFF003FFF004CFF004CFF0026FF0000FF334CFF0066FF00
73FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00
C0FF00B3FF00A6FF008CFF0059FF0073FF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00
99FF0073FF0033FF003FFF0000FF1933FF0000FF8C19FF0000FF194CFF0066FF0073FF0073FF00\
73FF0066FF0059FF0066FF0066FF0059FF0059FF004CFF0019FF0033FF0059FF00
66FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00
C0FF00B3FF0099FF0026FF003FFF0080FF0073FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00
A6FF008CFF0073FF003FFF003FFF0033FF004CFF004CFF0000FF334CFF0066FF0073FF0080FF00\
80FF0080FF0073FF0073FF0073FF0066FF0066FF004CFF0033FF0000FF400CFF00
00FF0C66FF0073FF008CFF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00
C0FF00A6FF0080FF0026FF0099FF00A6FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
A6FF008CFF0073FF000CFF0066FF0073FF0073FF0073FF0059FF004CFF0073FF0080FF0080FF00\
80FF0080FF0080FF0080FF0073FF0073FF0066FF004CFF000CFF0026FF004CFF00
66FF0059FF000CFF0000FF3399FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00
00FF9973FF008CFF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00
99FF008CFF0000FF4C59FF0080FF008CFF008CFF0080FF0066FF0059FF0080FF008CFF008CFF00\
8CFF008CFF008CFF0080FF0080FF0073FF0066FF004CFF0026FF003FFF0066FF00
80FF008CFF008CFF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00A6FF00A6FF00
80FF0080FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00A6FF00
8CFF003FFF008CFF0099FF0099FF0099FF0099FF008CFF0073FF003FFF0080FF008CFF0099FF00\
99FF008CFF008CFF008CFF0080FF0073FF004CFF0000FF3300FFCC3FFF0033FF00
8CFF0099FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00D9FF00CCFF00A6FF003FFF00
73FF0066FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00A6FF00
59FF008CFF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0080FF0000FF198CFF0099FF0099FF00\
99FF0099FF0099FF008CFF0080FF0073FF004CFF0000FF0C4CFF0066FF0080FF00
8CFF0099FF00A6FF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00CCFF00B3FF00A6FF0000FF0C
99FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00A6FF00
8CFF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF0099FF00A6FF00A6FF00\
A6FF0099FF0099FF008CFF0080FF003FFF0033FF003FFF0026FF0066FF0080FF00
8CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00E6FF00CCFF003FFF00A6FF008CFF0026FF0019FF00
99FF00B3FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF004CFF0066FF0073FF0066FF0026FF003FFF004CFF00
73FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00C0FF00A6FF0000FF008CFF00A6FF00
73FF00B3FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0073FF004CFF0026FF0073FF00
8CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00A6FF0000FF40A6FF00C0FF00
C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0073FF0033FF0033FF0080FF00
99FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00B3FF0099FF0080FF00B3FF00CCFF00
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0073FF0019FF0080FF00
99FF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00F3FF00E6FF00D9FF00C0FF0073FF000CFF003FFF00B3FF00CCFF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0033FF0080FF00
8CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00F3FF00D9FF00A6FF00A6FF008CFF00C0FF00C0FF008CFF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF0073FF0000FFA659FF00
8CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00F3FF00A6FF00B3FF00D9FF00D9FF00D9FF00D9FF00CCFF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0073FF000CFF0059FF00
66FF0080FF0099FF0099FF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0073FF0059FF0026FF00
3FFF0073FF008CFF008CFF0066FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF0080FF0073FF0026FF00
3FFF0066FF0073FF0073FF0000FF998CFF0099FF00A6FF0099FF0080FF0099FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0073FF004CFF00
19FF0033FF000CFF0033FF0059FF0080FF008CFF008CFF008CFF0019FF0099FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0073FF003FFF00
3FFF004CFF003FFF004CFF0000FF5966FF0073FF000CFF004CFF004CFF008CFF00A6FF00B3FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00A6FF0099FF0099FF008CFF0073FF000CFF003FFF00
66FF0073FF0073FF0073FF0000FF0000FF4026FF0026FF0073FF0059FF0059FF0066FF00A6FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0073FF0000FF0C00FF3359FF00
80FF0080FF008CFF0080FF0066FF0059FF0066FF008CFF0099FF008CFF0080FF0059FF0080FF00\
8CFF0099FF0099FF00B3FF00B3FF003FFF00C0FF00CCFF00CCFF00CCFF00CCFF00
D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00A6FF00A6FF008CFF0000FF194CFF0000FF1933FF0066FF00
80FF008CFF0099FF0099FF0099FF0080FF0073FF0099FF00A6FF00A6FF00A6FF00A6FF0080FF00\
26FF0033FF0080FF0099FF0099FF0080FF00B3FF00C0FF00C0FF00C0FF0059FF00
CCFF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00A6FF0099FF008CFF0073FF000CFF0000FF6619FF0019FF00
8CFF0099FF00A6FF00A6FF00A6FF0099FF0019FF00A6FF00B3FF00B3FF00C0FF00B3FF00B3FF00\
4CFF008CFF0000FF263FFF004CFF004CFF0099FF00A6FF0099FF008CFF00B3FF00
CCFF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0059FF0000FF4C33FF0000FF19
8CFF0099FF00A6FF00B3FF00B3FF00B3FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF0080FF0099FF0099FF004CFF0059FF0066FF004CFF0080FF0066FF00
C0FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00\
B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0066FF000CFF003FFF0080FF00
99FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF003FFF00B3FF00B3FF0099FF0059FF0099FF00A6FF00B3FF004CFF00
59FF00C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0066FF0033FF0080FF0099FF00
A6FF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF008CFF00B3FF00CCFF00CCFF00C0FF00
C0FF0073FF00A6FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF0080FF0080FF0080FF00\
99FF0099FF008CFF008CFF0080FF0080FF0073FF0033FF0059FF0080FF0099FF00
A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF004CFF00B3FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00C0FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0080FF0019FF00\
73FF0080FF0073FF004CFF0073FF0066FF003FFF0000FF2626FF0073FF008CFF00
A6FF00B3FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF0080FF00\
33FF0033FF004CFF0000FF193FFF004CFF0000FF0C59FF0033FF0000FF2673FF00
99FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF008CFF00\
73FF0033FF0033FF004CFF000CFF0000FF0C66FF0080FF0080FF0080FF0066FF00
73FF008CFF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF00\
66FF0019FF0066FF0073FF0073FF0066FF0073FF008CFF0099FF0099FF0099FF00
73FF004CFF003FFF00B3FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0099FF008CFF0073FF00\
19FF0033FF0073FF0080FF008CFF008CFF0073FF0099FF00A6FF00B3FF00B3FF00
A6FF0000FF26A6FF0080FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00
CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF003FFF0080FF0080FF0073FF00\
33FF003FFF0073FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00
C0FF0026FF00A6FF00A6FF0066FF0099FF0099FF0099FF008CFF0066FF0019FF0059FF0059FF00\
3FFF0073FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00CCFF00
B3FF008CFF0073FF0073FF003FFF0000FF4066FF0000FF0026FF0019FF0066FF0026FF003FFF00\
33FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00C0FF00B3FF00
99FF0033FF0080FF004CFF008CFF0099FF0099FF0099FF0080FF0080FF008CFF0073FF0073FF00\
26FF0073FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF0099FF0000FF0C73FF00
0CFF008CFF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF00\
59FF0066FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00CCFF00
B3FF0099FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF00\
66FF0026FF0073FF008CFF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF00\
73FF0033FF0066FF0073FF0080FF0099FF00B3FF00C0FF00C0FF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF0099FF00\
80FF0033FF000CFF0033FF0019FF0073FF004CFF00B3FF00C0FF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF00\
66FF004CFF0000FF1919FF0059FF008CFF00A6FF00B3FF00C0FF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF000CFF00\
4CFF004CFF004CFF0000FF3359FF008CFF00A6FF00B3FF00C0FF00C0FF00CCFF00
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF00\
99FF004CFF0073FF0066FF0033FF008CFF00A6FF00B3FF00C0FF00C0FF00CCFF00
CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00\
A6FF0099FF008CFF0066FF000CFF008CFF0099FF00A6FF00B3FF00C0FF00C0FF00
CCFF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00\
B3FF00A6FF0099FF008CFF0059FF0073FF008CFF0099FF0099FF00B3FF00B3FF00
C0FF00C0FF00CCFF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00\
B3FF00A6FF0099FF008CFF0066FF003FFF0000FF4073FF0066FF0099FF00A6FF00
A6FF00A6FF00B3FF00B3FF00D9FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00\
B3FF00A6FF0099FF0080FF0059FF0059FF0059FF004CFF0080FF0080FF003FFF00
00FF1973FF0026FF0080FF00C0FF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00\
A6FF0099FF008CFF0073FF0000FF2673FF008CFF008CFF00A6FF00B3FF00A6FF00
A6FF0099FF00A6FF00C0FF00B3FF00C0FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00B3FF00\
8CFF0080FF0080FF0066FF0033FF008CFF00A6FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00B3FF00A6FF00\
8CFF0059FF0000FF260CFF0019FF0080FF00A6FF00B3FF00C0FF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF0099FF008CFF008CFF00\
73FF0000FF7366FF0059FF008CFF008CFF0066FF00C0FF00CCFF00CCFF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF0080FF0026FF0066FF0080FF004CFF00\
26FF004CFF0080FF0099FF00A6FF00B3FF00B3FF00C0FF00CCFF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00B3FF00A6FF0099FF00\
8CFF000CFF0080FF0099FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00B3FF00A6FF00\
8CFF0033FF0000FF4C80FF00A6FF00C0FF00C0FF00CCFF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00\
99FF004CFF0000FF008CFF00A6FF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00\
A6FF008CFF0059FF0080FF0099FF00A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00A6FF00\
99FF0080FF0000FF004CFF0073FF0000FF2659FF00C0FF00D9FF00D9FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF008CFF00\
80FF0000FF0C00FF0C99FF00A6FF00B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF00\
73FF0066FF0099FF00A6FF00C0FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00A6FF00\
8CFF0019FF0099FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00A6FF00\
66FF0066FF0059FF00B3FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF00\
59FF0099FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF008CFF00\
8CFF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF008CFF0019FF00\
A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00A6FF0080FF0073FF00\
A6FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00B3FF00A6FF008CFF003FFF000CFF00\
0CFF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFCC00FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0066FF0073FF0019FF0066FF008CFF00\
A6FF00C0FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF0080FF004CFF008CFF00\
A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF008CFF0033FF0080FF00\
99FF00A6FF00B3FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF008CFF0066FF004CFF00\
73FF0059FF0000FF26C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF0073FF0080FF0019FF003FFF0073FF00\
8CFF0099FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF0099FF0073FF004CFF0066FF0066FF00\
A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
D9FF00CCFF00C0FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF004CFF0059FF008CFF0099FF00\
A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
D9FF0099FF0066FF000CFF0000FF4C19FF0073FF0066FF0000FF1919FF0073FF008CFF0099FF00\
A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
D9FF00CCFF00B3FF00A6FF0099FF00A6FF0099FF0059FF0073FF0059FF0073FF008CFF0099FF00\
A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0080FF0000FF7373FF008CFF00\
99FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF008CFF004CFF003FFF004CFF00\
00FF0CA6FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF008CFF000CFF0000FFB333FF00\
80FF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00B3FF00A6FF00C0FF00C0FF00
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00B3FF008CFF0080FF004CFF004CFF00\
59FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF0099FF0026FF008CFF00C0FF00
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF008CFF0073FF00\
00FF1980FF008CFF0080FF008CFF008CFF0073FF0000FF4C8CFF00C0FF00CCFF00
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00A6FF0099FF0080FF00\
59FF003FFF0026FF000CFF000CFF0080FF008CFF00A6FF00B3FF00C0FF00CCFF00
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00A6FF0099FF008CFF00\
73FF0026FF0059FF003FFF008CFF00A6FF00B3FF00B3FF00C0FF00CCFF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0080FF00\
33FF0000FF0C80FF008CFF00A6FF00B3FF00B3FF00C0FF00CCFF00CCFF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00A6FF008CFF0080FF0073FF00\
59FF004CFF0080FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00CCFF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF003FFF0033FF00\
00FF0026FF0073FF008CFF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00CCFF00CCFF00B3FF008CFF0073FF0073FF008CFF0080FF0073FF000CFF003FFF00\
3FFF0073FF0066FF0073FF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00C0FF00A6FF008CFF0073FF0059FF0000FF0C33FF003FFF0073FF00\
80FF008CFF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF008CFF0073FF004CFF0066FF0080FF00\
8CFF0099FF00A6FF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF008CFF0059FF004CFF0080FF00\
8CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF0080FF004CFF0019FF0066FF00\
8CFF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0080FF0059FF0000FF1926FF00\
80FF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00C0FF00CCFF00CCFF00A6FF00C0FF00E6FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00\
FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00FFCC00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
C0FF00C0FF00B3FF0099FF0080FF0000FF4080FF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
C0FF00C0FF00B3FF00A6FF0080FF0019FF0073FF0073FF00B3FF00C0FF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
C0FF00C0FF00B3FF00A6FF0080FF0066FF0099FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
C0FF00C0FF00B3FF0099FF0073FF008CFF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
C0FF00B3FF00A6FF008CFF0059FF0099FF00B3FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
C0FF00B3FF0099FF0059FF0073FF0099FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00
B3FF00A6FF0099FF0066FF0000FF0026FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00
80FF0073FF004CFF0000FF6680FF0099FF00B3FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00
A6FF0099FF0080FF0019FF0073FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00
B3FF00A6FF008CFF0000FF4C66FF008CFF0099FF00A6FF00C0FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00
B3FF0099FF008CFF0066FF0026FF003FFF0019FF0066FF00B3FF00C0FF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00
A6FF000CFF0066FF003FFF0059FF0080FF0099FF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00B3FF00A6FF00
99FF0080FF0033FF0059FF0073FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF008CFF008CFF0099FF00
66FF0066FF0000FF5973FF008CFF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00A6FF0059FF0066FF0066FF0066FF00
00FF1900FFFF26FF0073FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF00A6FF0099FF00
8CFF0080FF0059FF0059FF0073FF008CFF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00
99FF008CFF0066FF0019FF0000FF0059FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00B3FF00
A6FF008CFF0066FF0000FF2619FF0066FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00
A6FF008CFF0066FF004CFF000CFF0073FF008CFF0099FF0099FF00A6FF00A6FF00A6FF0066FF00\
B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00
A6FF0099FF008CFF0080FF0059FF0066FF0073FF0080FF008CFF008CFF0080FF0080FF003FFF00\
66FF0099FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00
A6FF0099FF008CFF0080FF0066FF0000FF5900FF4000FF0026FF0026FF0000FF0C3FFF008CFF00\
B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00B3FF00
A6FF0099FF008CFF0080FF0059FF0000FF0066FF003FFF008CFF0099FF0099FF00A6FF00A6FF00\
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF00A6FF00
99FF008CFF0073FF0066FF004CFF0026FF0080FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00A6FF003FFF0066FF00
80FF0073FF0033FF0000FF0C00FF8C3FFF0080FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF0080FF00
26FF0026FF0000FF0C59FF0059FF0073FF0000FF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF008CFF00
80FF004CFF0059FF0073FF0080FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF00A6FF008CFF00
73FF0019FF004CFF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF0099FF008CFF00
4CFF0000FF2633FF0073FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00\
80FF00B3FF00B3FF00A6FF00B3FF00B3FF00A6FF0099FF0033FF0080FF0073FF00
66FF000CFF0066FF0080FF0099FF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00C0FF00B3FF00\
80FF0080FF008CFF0066FF0080FF0099FF008CFF0080FF0059FF0026FF004CFF00
3FFF004CFF0073FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00C0FF003FFF004CFF0073FF0080FF00\
00FFA666FF000CFF0073FF0066FF0073FF000CFF0033FF000CFF0059FF0026FF00
4CFF000CFF0059FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF0000FF4C\
99FF0099FF0059FF0099FF00A6FF00A6FF0099FF0066FF0080FF0080FF0066FF00
73FF0066FF0000FF0C80FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF0073FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF0099FF0099FF0099FF00
8CFF0080FF0019FF0059FF0073FF008CFF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF00A6FF00
99FF008CFF0000FF1900FF263FFF0073FF0080FF0000FF008CFF0099FF0099FF00B3FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00
99FF008CFF0073FF0033FF003FFF0059FF0059FF0000FF404CFF004CFF008CFF00B3FF00B3FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00
A6FF008CFF0066FF0026FF0026FF0033FF0000FF8C3FFF0066FF008CFF00A6FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00
A6FF008CFF0066FF004CFF0019FF0000FF400CFF0059FF0073FF008CFF00A6FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00
A6FF008CFF0073FF004CFF0000FF0C00FF2619FF003FFF0059FF0073FF0099FF00A6FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00
99FF0080FF004CFF0033FF0000FF8C33FF0026FF0026FF0066FF008CFF0099FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF0099FF00A6FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00
33FF0073FF0059FF0033FF0059FF0059FF003FFF0026FF0073FF008CFF0099FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF0099FF008CFF00A6FF00A6FF00B3FF00A6FF00A6FF00C0FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00
A6FF0099FF008CFF0066FF0080FF0073FF003FFF0000FF264CFF0080FF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF00
A6FF0099FF008CFF0000FF0C59FF0073FF008CFF0099FF00C0FF00D9FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00
B3FF00A6FF0099FF0099FF008CFF0080FF0066FF0059FF003FFF0080FF008CFF0099FF0099FF00\
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0000FF4C
8CFF0080FF000CFF0080FF0099FF00A6FF00C0FF00CCFF00CCFF00D9FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
B3FF00B3FF00A6FF0099FF0099FF008CFF0080FF0073FF0033FF0073FF0080FF008CFF008CFF00\
8CFF008CFF0080FF0080FF0099FF0099FF0099FF008CFF008CFF0080FF003FFF00
00FF663FFF0073FF0099FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0059FF003FFF004CFF0073FF003FFF00\
73FF0080FF0066FF003FFF0066FF0066FF0073FF0066FF0000FF803FFF0026FF00
80FF0080FF003FFF0099FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0066FF003FFF0033FF000CFF0000FF0C\
26FF0059FF0000FF6659FF0019FF0080FF0080FF0059FF0080FF0073FF008CFF00
A6FF00A6FF0099FF004CFF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0073FF0059FF0000FF6626FF004CFF00\
00FF2600FF1966FF0080FF008CFF0099FF0099FF00A6FF00A6FF0099FF0099FF00
B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0073FF004CFF003FFF0066FF0066FF00\
33FF0066FF0066FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00A6FF00A6FF00A6FF0099FF008CFF0080FF0073FF003FFF0000FF994CFF0073FF0080FF00\
80FF008CFF0066FF008CFF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF004CFF0000FF2600FF4C0CFF0073FF008CFF00\
8CFF0099FF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
A6FF0099FF0099FF0099FF008CFF008CFF0080FF0066FF0033FF0000FF3359FF0066FF008CFF00\
99FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
99FF0000FF4073FF0080FF0080FF0080FF0073FF0066FF0033FF004CFF0073FF0080FF0099FF00\
99FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
CCFF0099FF0099FF00A6FF0066FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0073FF0000FF2666FF0066FF0066FF0066FF0059FF0000FF2659FF0073FF008CFF0099FF00\
99FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
CCFF00C0FF0099FF004CFF0000FF4C73FF0073FF0099FF0099FF0099FF008CFF00
8CFF0080FF003FFF0019FF0033FF003FFF003FFF0000FF190CFF0026FF0066FF0080FF008CFF00\
99FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00C0FF00A6FF008CFF008CFF0066FF0000FF0C73FF0080FF0073FF0080FF00
80FF0066FF004CFF0000FF0033FF0000FF5900FF4C3FFF0059FF0000FF0C00FF5973FF0080FF00\
99FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00C0FF00C0FF00B3FF00A6FF0099FF008CFF0066FF0033FF004CFF0059FF00
66FF0000FF0000FF264CFF0059FF0059FF0033FF0066FF0073FF0073FF0073FF0033FF0000FF80\
73FF0099FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF004CFF004CFF000CFF00
3FFF0000FF3333FF0059FF0073FF0073FF0066FF0066FF008CFF008CFF008CFF0080FF0066FF00\
73FF0059FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF0073FF004CFF00
0CFF004CFF0066FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0080FF0066FF00
33FF004CFF0073FF0080FF008CFF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF0080FF0073FF00
00FF4066FF0073FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0059FF00
008CFF59FF0073FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00D9FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF0080FF0033FF0033FF00
0CFF0059FF0073FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF0059FF0080FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF003FFF0059FF004CFF0019FF00
26FF003FFF0059FF0073FF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00B3FF0000FF4CB3FF00C0FF00CCFF00CCFF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0073FF0000FF0C00FF0C00FF66
00FF4C00FF6626FF0073FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00E6FF0073FF00B3FF00A6FF00C0FF00CCFF00\
CCFF00C0FF00CCFF00C0FF00B3FF0000FF26A6FF00B3FF00B3FF00B3FF00A6FF00
3FFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF008CFF0099FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF0073FF004CFF0000FF1900FF26
19FF003FFF0033FF000CFF0073FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00D9FF00A6FF003FFF008CFF0000FF33\
A6FF00A6FF00B3FF00A6FF0099FF004CFF0073FF0033FF00A6FF00A6FF0099FF00
8CFF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF008CFF0000FF00\
8CFF0099FF0099FF0099FF0099FF0099FF008CFF0080FF0066FF004CFF000CFF00
19FF0059FF0073FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00E6FF00D9FF00CCFF008CFF00\
80FF000CFF008CFF0033FF0000FF1980FF0066FF0000FF1980FF0000FF0C73FF00
59FF0080FF0099FF008CFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF0066FF00\
80FF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0066FF0019FF0026FF00
59FF003FFF0080FF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00\
B3FF008CFF0059FF0080FF0073FF0099FF0099FF0066FF0000FF0026FF0073FF00
73FF004CFF0026FF0033FF0019FF00A6FF00A6FF00A6FF0099FF00A6FF0099FF008CFF003FFF00\
33FF0073FF0000FF0080FF0080FF0080FF0080FF0073FF0066FF0000FF3300FF0C
73FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00\
CCFF00A6FF008CFF00B3FF00B3FF00B3FF00A6FF0099FF0059FF0099FF0099FF00
99FF0059FF008CFF0000FF8033FF0080FF0080FF0080FF0080FF008CFF0080FF0080FF0066FF00\
0CFF0033FF000CFF0066FF0073FF0073FF0073FF0066FF004CFF003FFF0066FF00
80FF008CFF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00\
CCFF0026FF00B3FF00C0FF00C0FF00C0FF00C0FF0099FF008CFF00B3FF00B3FF00
A6FF0099FF00A6FF00A6FF0099FF0066FF0000FF0000FF6600FFB373FF004CFF0026FF0026FF00\
59FF003FFF0000FF004CFF0059FF0033FF0059FF004CFF0019FF004CFF0073FF00
80FF008CFF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00\
CCFF00A6FF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF00B3FF00C0FF00C0FF00
C0FF00B3FF00B3FF00B3FF00B3FF00A6FF0073FF0080FF0026FF0033FF0026FF0033FF0066FF00\
73FF0066FF0000FF400CFF0033FF0000FFFF00FF7300FF0C0CFF004CFF0066FF00
80FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0080FF0000FF0C80FF0080FF0080FF00\
80FF0080FF0066FF0000FF404CFF003FFF003FFF004CFF000CFF0000FF004CFF00
80FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF008CFF0073FF008CFF0099FF0099FF00\
99FF008CFF0073FF004CFF0073FF0073FF0073FF0066FF0033FF0026FF0059FF00
73FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF0073FF008CFF0099FF00A6FF00A6FF00\
99FF0099FF0000FF0073FF0080FF0080FF0080FF0073FF003FFF0000FF4C00FF0C
59FF000CFF0080FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00CCFF008CFF00CCFF00D9FF00D9FF00D9FF00D9FF00
CCFF00C0FF000CFF00C0FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0080FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0019FF008CFF008CFF008CFF008CFF0073FF004CFF0059FF0033FF00
26FF0073FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00CCFF0099FF00A6FF00C0FF00C0FF0059FF00B3FF00
B3FF0073FF00A6FF00D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF0099FF0099FF0099FF0099FF0080FF0080FF0073FF004CFF00
33FF0073FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00B3FF0033FF00A6FF0099FF0059FF0073FF00
C0FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0066FF00
00FF0066FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00C0FF00B3FF008CFF0000FF0059FF003FFF00B3FF00
CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF00
4CFF0066FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00C0FF00C0FF00A6FF0066FF0080FF00A6FF00B3FF00C0FF00
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF00
4CFF003FFF0073FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00C0FF00C0FF00C0FF00B3FF0099FF0000FF0000FF00B3FF00C0FF00CCFF00
D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF0073FF00
33FF0000FF004CFF0073FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
C0FF008CFF00A6FF00A6FF00A6FF0099FF0059FF0099FF00B3FF00CCFF00D9FF00
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF00
66FF0019FF004CFF0073FF0080FF008CFF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
C0FF0099FF0000FF008CFF0066FF0073FF0019FF0080FF00B3FF00C0FF00D9FF00
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF00
59FF0000FF4C4CFF0066FF0073FF0080FF0080FF0080FF008CFF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF0099FF0073FF00A6FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00\
C0FF00A6FF008CFF0000FF0059FF0000FF008CFF0099FF0026FF008CFF00CCFF00
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF0019FF00
00FF0C26FF0026FF003FFF0066FF0066FF0059FF004CFF0080FF0099FF0099FF0099FF0099FF00\
A6FF00A6FF00A6FF0099FF0099FF0080FF0080FF0099FF00A6FF00A6FF00A6FF00
B3FF00A6FF00A6FF00A6FF0099FF0066FF008CFF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
B3FF00A6FF0073FF003FFF008CFF0099FF00A6FF00C0FF00C0FF00C0FF00CCFF00
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0073FF00
66FF004CFF0000FFA626FF004CFF003FFF0000FF0066FF0080FF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF0059FF0059FF008CFF0099FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF0080FF0000FF6659FF00A6FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00\
A6FF0099FF0073FF004CFF0099FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF00
73FF0066FF004CFF0026FF0000FF4033FF0066FF0073FF0080FF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF008CFF0080FF004CFF003FFF0080FF008CFF0099FF0099FF00
99FF0073FF008CFF0080FF0026FF0066FF0099FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00\
73FF004CFF0019FF003FFF0099FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF008CFF00
73FF0066FF004CFF0026FF0000FF004CFF0066FF0073FF0080FF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF0080FF0066FF0026FF0073FF008CFF008CFF008CFF00
80FF0066FF004CFF0000FF0080FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF0099FF00\
73FF0066FF0073FF0099FF0000FF00B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF0080FF00
66FF0059FF0033FF0000FF3300FFA600FFE666FF0073FF0080FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF0080FF0080FF0066FF0019FF0066FF0073FF0073FF0073FF00
73FF004CFF003FFF0073FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0080FF00\
00FFA673FF00A6FF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF00
59FF0033FF0000FFB326FF003FFF0059FF0066FF0073FF0080FF0080FF0080FF0080FF008CFF00\
8CFF0080FF0080FF0080FF0073FF004CFF0000FFB333FF0059FF0059FF0033FF00
59FF003FFF004CFF0073FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF0099FF008CFF0073FF0059FF00\
99FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00B3FF00B3FF00A6FF0099FF0099FF008CFF008CFF0080FF0073FF00
66FF004CFF000CFF0026FF004CFF0059FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0073FF0073FF0059FF003FFF0000FF333FFF0026FF0000FF33
00FF3300FF5900FF5959FF0080FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00B3FF008CFF0080FF0099FF0099FF008CFF0000FF730CFF0099FF00\
B3FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00B3FF00B3FF008CFF0080FF0073FF0073FF0073FF0073FF0066FF00
59FF003FFF0000FF2619FF004CFF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0066FF0059FF003FFF0000FF0C00FF2600FF263FFF00
3FFF003FFF0066FF0066FF0080FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF0099FF004CFF0073FF0073FF003FFF004CFF008CFF00A6FF00\
B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00B3FF00A6FF0099FF0073FF0019FF0000FF3319FF004CFF003FFF00
0CFF0026FF0000FFB333FF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF003FFF00\
66FF0066FF0066FF0066FF0066FF0059FF003FFF0000FF0C33FF003FFF0059FF00
59FF0066FF0073FF0080FF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00A6FF008CFF0059FF0000FFA659FF0080FF008CFF00B3FF00\
C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00A6FF00A6FF008CFF0080FF0073FF0066FF004CFF000CFF00
26FF0000FF0000FF1919FF003FFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0026FF00\
4CFF0059FF0059FF0059FF0059FF004CFF0033FF000CFF003FFF004CFF0059FF00
66FF0073FF0080FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00B3FF00A6FF00A6FF008CFF0073FF0026FF0073FF008CFF00A6FF00B3FF00\
C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0080FF0066FF0059FF00
4CFF003FFF0026FF0000FF3333FF004CFF004CFF0059FF004CFF0033FF004CFF003FFF0000FF0C\
3FFF004CFF004CFF0026FF003FFF0033FF0000FF8026FF004CFF0059FF0066FF00
66FF0073FF0080FF0080FF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF0099FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0033FF0000FF8C4CFF0099FF00A6FF00B3FF00\
C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF008CFF0080FF0073FF0073FF00
66FF0059FF004CFF0000FF8000FF0033FF003FFF003FFF003FFF0026FF000CFF000CFF0000D9FF\
26FF003FFF0033FF000CFF0019FF0000FF1900FF400CFF003FFF0059FF0066FF00
66FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF0080FF0066FF0099FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0073FF0033FF0073FF008CFF0099FF00A6FF00\
B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF00
66FF0059FF004CFF0000FF9900FFFF00FF2626FF0033FF0033FF0026FF0000FF0000FFA600FF00\
19FF0026FF0026FF000CFF0000FF8000FF4C00FF0026FF003FFF004CFF0059FF00
66FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF0080FF0066FF0059FF008CFF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF0099FF0080FF0080FF0080FF0073FF0066FF003FFF0019FF0059FF0059FF003FFF00\
A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF00
66FF0059FF004CFF0033FF0000FF0000FF4C19FF0026FF0026FF0019FF000CFF0000FF5900FF0C\
00FF0000FF260CFF0000FF0000FF5900FF0019FF0026FF0033FF003FFF0000FF80
59FF0066FF0066FF0073FF0080FF0080FF0080FF0080FF0080FF0073FF0000FF0C59FF008CFF00\
99FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF0099FF0073FF0000FF2666FF0033FF003FFF0000FF2666FF0080FF008CFF0099FF00\
B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF0073FF0080FF008CFF0099FF00A6FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0073FF00
66FF004CFF0033FF0026FF0000FF1900FF0C0CFF0019FF0000FF0000FF0000FFA600FF9900FF33\
00FF4000FF4C00FF2600FF4000BFFF00FF0C00FF0019FF0026FF0026FF000CFF00
33FF0033FF0000FF0073FF0073FF0080FF0080FF0080FF0073FF0066FF0000FF0C66FF008CFF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0080FF0066FF0000FF0C00FF330CFF0026FF0073FF0099FF00A6FF00B3FF00\
B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF008CFF0073FF0000FF0C80FF008CFF00\
8CFF0080FF0080FF008CFF008CFF008CFF008CFF0080FF0073FF0073FF0066FF00
59FF004CFF000CFF0000FF6600FF8C00FF2600FF0000FF0C00FF2600FF4000FF4000E6FF00FF8C\
00FF9900FF9900FF8000FF8000FF4000FF2600FF5900FF4000FF0000FF0000FF59
00FF8026FF0059FF0066FF0073FF0073FF0073FF0073FF0066FF0033FF0059FF0073FF008CFF00\
8CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF008CFF0080FF0066FF0026FF004CFF0066FF0073FF008CFF0099FF00A6FF00B3FF00\
B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00A6FF0099FF008CFF0033FF0000FFBF\
73FF0066FF004CFF0080FF0080FF0080FF0080FF0080FF0073FF003FFF0059FF00
4CFF003FFF0033FF0019FF0000FF0000FF8C00FF4C00FF2600FF4C00FF7300FFB300FFE600B3FF\
0000000000FF00FFE600FF8C00FF8000FF5900FFCC00FF4000FF4000FF6600FF0C
19FF0033FF004CFF0059FF0066FF0066FF0066FF0066FF004CFF0000FF1959FF0073FF0080FF00\
8CFF008CFF0099FF0099FF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00
8CFF008CFF0080FF0073FF0059FF0000FF7333FF0073FF0080FF008CFF0099FF00A6FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF0080FF0000FFB3\
00FF193FFF004CFF0073FF0073FF0080FF0073FF0073FF0066FF004CFF000CFF00
19FF0033FF0026FF0019FF0000FF0000FF4000FF5900FF4C00FF8000E6FF000000004CFF4C00FF\
000000D900FF0033FF00FFD900E6FF00FFBF00FFCC00FFFF00FFB300FF4000FF26
19FF0033FF003FFF0026FF0059FF0059FF0059FF0059FF0033FF0000FF193FFF0066FF0073FF00\
73FF0080FF008CFF0080FF004CFF0080FF008CFF008CFF0099FF008CFF008CFF00
80FF0026FF0066FF0066FF004CFF0000FF8C59FF0073FF0080FF008CFF0099FF00A6FF00A6FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0073FF0066FF00\
4CFF0033FF0019FF0059FF0066FF0073FF0073FF0066FF0059FF004CFF000CFF00
00FF8C19FF0019FF0000FF0C00FF1900FF4C00FFA600FF8000FFFFE600FF000000000000000000\
0000000000000000003300FF0099FF0000000066FF00000000BFFF00FFFF00FF59
00FF0019FF0019FF0019FF004CFF004CFF004CFF003FFF0026FF000CFF003FFF0059FF0059FF00\
33FF0073FF0080FF0073FF0059FF0066FF0080FF0080FF0080FF0080FF0080FF00
73FF0059FF000CFF0026FF0019FF000CFF0059FF0073FF0080FF008CFF0099FF0099FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF0099FF00CCFF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00D9FF00CCFF00A6FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0080FF00\
73FF0033FF0026FF004CFF0066FF0066FF0066FF0059FF0033FF0026FF0000FF00
00FF1900FF0000FF1900FFB300FF4000FF5900FFBF00FFD9000000000000000000000000000000\
0000000000000000000000000000000000000000000000003F00FF0080FF00F3FF
00FF4C00FF0000FF4C0CFF0033FF0000FF1933FF0026FF0000FF8000FF990CFF0026FF0019FF00\
4CFF0066FF0066FF0059FF003FFF003FFF0059FF003FFF0066FF0066FF0059FF00
4CFF0000FF0C3FFF0033FF003FFF0026FF0000FF6666FF0073FF0080FF0080FF0080FF008CFF00\
A6FF00A6FF00B3FF00B3FF00A6FF0099FF0066FF00B3FF00CCFF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00D9FF00CCFF0073FF00B3FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF00\
3FFF0033FF0000FF590CFF0059FF0059FF0059FF0059FF003FFF0026FF0000FF00
00FF4000FF4000FF2600FF6600FF8000FFBF00FFE60099FF000000000000000000000000000000\
0000000000000000000000000000000000000000006600FF00D9FF00FFB300FF59
00FF8000FF4C00FF2600FF4C00FF0C00FF2600FF0019FF0026FF0033FF0000FF000CFF0000FF0C\
00FF004CFF004CFF0000FF1919FF0033FF0000FF2633FF0033FF004CFF0000FF73
26FF0033FF0066FF0066FF0066FF0066FF0059FF0033FF0026FF0066FF0000FF0C19FF008CFF00\
99FF0099FF00A6FF0099FF008CFF000CFF004CFF00B3FF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00D9FF00A6FF0080FF0019FF0080FF00C0FF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF00\
73FF0059FF0000FF0026FF003FFF004CFF004CFF004CFF003FFF0026FF0019FF00
00FF1900FF6600FF6600FF9900D9FF3300FF000000B300FF000000000000000000000000000000\
00000000000000000000000000000000000000000000000000A6FF00FF9900FF59
00FF2600FF0C00FF0000FF0000FF1919FF0033FF003FFF004CFF004CFF003FFF003FFF0026FF00\
00FF000CFF0026FF0000FF4C4CFF0066FF004CFF0066FF0073FF0080FF0073FF00
73FF0000FF1980FF0080FF0080FF0080FF0073FF004CFF0026FF0033FF0000FF1933FF003FFF00\
8CFF008CFF008CFF0080FF000CFF0073FF00A6FF00C0FF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00C0FF00B3FF0080FF0080FF00B3FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0080FF00\
73FF0033FF0019FF0000FF2600FF1933FF0033FF0026FF0033FF0026FF0000FF00
00FF2600FF6600BFFF000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000007300FF008CFF00F3FF00FF9900FF4C
00FF2600FF0019FF0026FF0026FF000CFF003FFF004CFF0059FF0059FF0059FF0059FF003FFF00\
0CFF0019FF0000FF0059FF0066FF0073FF0080FF0080FF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0059FF0026FF0000FF3300FF0C26FF004CFF00\
73FF0080FF0066FF003FFF008CFF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF003FFF00D9FF00E6FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00F3FF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00CCFF00B3FF008CFF003FFF008CFF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF0099FF008CFF0066FF0059FF00\
4CFF0000FF4026FF003FFF0033FF0000FF0000FF4C00FF0C19FF000CFF0000FF40
00FF4C00FF990099FF000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000008C00FF00BFFF00FFCC00FFE600FFBF
00FF4000FF0019FF0026FF0033FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0059FF00\
4CFF004CFF0000FF0059FF0073FF0080FF008CFF008CFF008CFF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF008CFF008CFF0073FF0059FF0000FF0C4CFF004CFF003FFF00\
3FFF003FFF0019FF004CFF008CFF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00B3FF0059FF00C0FF00D9FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00C0FF00A6FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF0073FF0080FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF008CFF0033FF0059FF0059FF00\
66FF0000FF0059FF0059FF004CFF0033FF0019FF0000FF4000FF0000FF0C00FF33
00BFFF0026FF000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000A6FF00FFFF00FF7300FF4C
00FF8000FFF319FF0033FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF00\
73FF0066FF004CFF0033FF0073FF008CFF008CFF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF0059FF0059FF0066FF0073FF0073FF00\
66FF003FFF004CFF0073FF008CFF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF008CFF003FFF00A6FF00D9FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00E6FF00D9FF0080FF00CCFF00D9FF00D9FF00E6FF00D9FF00CCFF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF008CFF008CFF00A6FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0080FF0080FF00\
80FF0073FF0073FF0066FF0059FF004CFF0026FF0000FF5900FF4C00FFCC00FF4C
0080FF000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000FFFF0099FF00FF40
00FF1900FF0019FF0026FF0033FF003FFF0059FF0066FF0066FF0073FF0073FF0073FF0073FF00\
80FF0073FF0073FF003FFF0073FF008CFF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF0073FF008CFF008CFF008CFF0080FF00\
73FF0059FF0000FF8C66FF0080FF008CFF00A6FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF0073FF00A6FF00CCFF00D9FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00E6FF00E6FF00CCFF00B3FF00B3FF00CCFF00CCFF00CCFF00CCFF00A6FF00C0FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00A6FF0080FF0073FF0099FF00A6FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF008CFF00\
80FF0080FF0073FF0073FF0066FF004CFF0000FF330CFF000CFF0000FF3300FF66
00FFCC00A6FF000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000E6FF00FF8C00FF40
00FF3300FF0C0CFF0019FF0019FF0000FF194CFF0066FF0066FF0073FF0073FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF00\
80FF0066FF004CFF000CFF003FFF0080FF00A6FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00C0FF00C0FF00B3FF00B3FF0099FF008CFF00B3FF00CCFF00D9FF00D9FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFF300FFF300FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
D9FF00D9FF00D9FF00CCFF00B3FF004CFF00A6FF0099FF00C0FF00B3FF008CFF00B3FF00C0FF00\
C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00B3FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0080FF0000FF0C00FF0099FF00A6FF00B3FF00\
B3FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF00\
8CFF0080FF0080FF0073FF0066FF0059FF003FFF0026FF0019FF0000FF0C00FF4C
00FFA600F3FF000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000007300FF00A6FF00FFCC00FFCC00FF8C
00FF5900FF1900FF0C00FF190CFF0033FF0059FF0066FF0073FF0073FF0080FF0080FF0080FF00\
8CFF008CFF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF00\
80FF0073FF004CFF0026FF0073FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00
A6FF003FFF00A6FF00B3FF00A6FF0099FF0000FFD999FF00C0FF00CCFF00D9FF00D9FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFF300FFFF00F3FF00E6FF00D9FF00CCFF00CCFF00D9FF00D9FF00C0FF00
C0FF00CCFF00C0FF00A6FF008CFF0080FF0066FF000CFF0099FF0059FF0026FF000CFF0099FF00\
00FF0CB3FF00CCFF00CCFF00CCFF00CCFF00C0FF0099FF00A6FF00C0FF00C0FF00
CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0080FF0000FF0073FF008CFF0099FF00A6FF00\
99FF0026FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF00\
8CFF0080FF0080FF0073FF0066FF0059FF003FFF0033FF000CFF0000FF8000FF59
00FF8C00FFFF000CFF000000000000000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000D9FF00FFB300FF7300FF59
00FF7300FF5900FF6600FF4C0CFF0033FF004CFF0066FF0073FF0073FF0080FF0080FF008CFF00\
8CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF00\
80FF0000FF3300FF3359FF0073FF008CFF0099FF0099FF00A6FF00A6FF0099FF00
8CFF0000FF4C8CFF0099FF0099FF0073FF0000FF738CFF00B3FF00C0FF00CCFF00D9FF00D9FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFF300FFFF00D9FF004CFF0080FF00A6FF0099FF0073FF0099FF008CFF00
73FF00B3FF00A6FF0000FF0080FF00B3FF00A6FF0073FF0033FF008CFF00A6FF0099FF0080FF00\
8CFF0059FF00A6FF00B3FF0099FF00B3FF00B3FF008CFF0099FF00B3FF00C0FF00
C0FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0073FF0000FF7366FF0080FF008CFF008CFF00\
80FF0066FF0099FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF00\
8CFF0080FF0080FF0073FF003FFF003FFF000CFF0019FF000CFF0000FF4C00FF73
00FFBF008CFF000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000008000FF00E6FF00FFD900FF8C00FF40
00FF2600FF1900FF0000FF0C00FF7300FF0C33FF004CFF0066FF0073FF0080FF008CFF008CFF00\
8CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF00\
8CFF0073FF0000FF0C4CFF0073FF0080FF008CFF0099FF0099FF0099FF008CFF00
73FF0000FF0C19FF004CFF0059FF0000FF0C59FF0080FF0099FF0073FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFF300FFF300FFFF00F3FF00D9FF00E6FF00E6FF00D9FF00B3FF00B3FF00
99FF0000FF0C80FF00A6FF00A6FF00C0FF00C0FF00B3FF000CFF00B3FF00C0FF00C0FF00B3FF00\
C0FF00B3FF008CFF003FFF0059FF0099FF008CFF0066FF0080FF0073FF00B3FF00
B3FF00A6FF008CFF0080FF0073FF0080FF0073FF004CFF003FFF0000FF730CFF0066FF0073FF00\
00FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF00\
8CFF0080FF0080FF0073FF0059FF0026FF0000FF0C00FF0C00FF0C00FF2600FFA6
00FFE68C00FF000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000004C00FF0080FF00FFFF00FFB300FF8C00FF40
00FF2600FF0C0CFF0019FF000CFF0026FF0033FF0033FF0066FF0080FF0080FF008CFF008CFF00\
8CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF00\
8CFF0073FF0000FF0C26FF0000FF5900FF6673FF0080FF008CFF0080FF0066FF00
66FF0000FF6659FF0066FF0080FF0080FF0059FF000CFF0033FF00A6FF00B3FF00C0FF00B3FF00\
B3FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFFF00FFFF00F3FF00F3FF00F3FF00D9FF00D9FF00
CCFF0099FF0099FF00CCFF00CCFF00D9FF00D9FF00CCFF0080FF00CCFF00D9FF00D9FF00CCFF00\
CCFF00CCFF00C0FF00B3FF0080FF0059FF0033FF0080FF004CFF0080FF0099FF00
99FF0099FF0059FF004CFF004CFF0019FF0066FF0080FF0080FF0073FF0000FF7333FF0000FF0C\
59FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF00\
8CFF0080FF0080FF0073FF0066FF004CFF0026FF0000FF5900FF4000FF8000FFA6
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000C00FF00A6FF00FFD900FF8C00FF59
00FF7300FF0C19FF0026FF0033FF003FFF0059FF0066FF0073FF0080FF0080FF008CFF008CFF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF00\
8CFF0059FF0033FF0073FF0033FF0019FF0026FF0066FF004CFF003FFF0026FF00
19FF0000FF0C66FF008CFF0099FF0099FF008CFF0073FF0026FF0099FF00A6FF00A6FF008CFF00\
B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00F3FF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00
E6FF00C0FF00C0FF00D9FF00D9FF00E6FF00E6FF00D9FF00B3FF00D9FF00D9FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00CCFF0099FF00A6FF00A6FF00A6FF0073FF0059FF0073FF00
8CFF0073FF003FFF0033FF0000FF4C73FF008CFF0099FF0099FF008CFF0080FF0073FF0019FF00\
4CFF0066FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF008CFF00\
80FF0080FF0073FF0073FF0066FF003FFF000CFF0019FF000CFF0000FF2600FF99
0073FF7300FF8C00FF0000008C00FF000000000000000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000E6FF00FFBF00FF8C
00FF8000FF590CFF0026FF003FFF004CFF0059FF0066FF0073FF0080FF0080FF008CFF008CFF00\
8CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF0099FF00\
59FF0073FF008CFF008CFF0073FF0073FF0059FF0026FF0059FF0080FF008CFF00
33FF0073FF0080FF00A6FF00A6FF00A6FF00A6FF0066FF0000FF1973FF0059FF003FFF0066FF00\
A6FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00C0FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00F3FF00
E6FF008CFF00C0FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF0059FF00C0FF00C0FF00B3FF0073FF0080FF0059FF00
00FF0080FF0073FF0080FF0000FF0059FF0099FF00A6FF00A6FF0099FF008CFF0073FF0033FF00\
3FFF0073FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF0073FF0080FF0080FF0080FF00\
80FF0073FF0073FF0066FF0066FF004CFF003FFF0033FF000CFF000026FF00FF99
0000000099FF00CCFF0099FF3F00FF000CFF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000CC00FF00BFFF008CFF00FF99
00FF3300FF0C19FF0026FF0033FF003FFF0059FF0066FF0073FF0073FF0080FF0080FF008CFF00\
8CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF00\
00FF7399FF0099FF0099FF0099FF0080FF0059FF0033FF0080FF0099FF00A6FF00
A6FF00A6FF0099FF00B3FF00B3FF00B3FF00B3FF0099FF0073FF0073FF0073FF008CFF0066FF00\
80FF000CFF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00
D9FF00E6FF00E6FF00E6FF00D9FF00CCFF008CFF00C0FF00E6FF00F3FF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
F3FF00CCFF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF003FFF00
4CFF00A6FF00A6FF00A6FF004CFF00A6FF00B3FF00B3FF00A6FF00A6FF008CFF0073FF0019FF00\
59FF0073FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0000FF0026FF0073FF0073FF00\
73FF0073FF0066FF0066FF0059FF0059FF003FFF0033FF0019FF0000FF1900FF59
00F3FF00FFFF00FF9900FFF300FFE600FFE6C000FF0000007300FF0000000000009900FF8000FF\
0000000000000000000000000000000000000000000000005900FF00000000FF99
00FF4000FF590CFF0019FF0019FF0000FF334CFF0066FF0066FF0073FF0073FF0080FF0080FF00\
8CFF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00A6FF00\
A6FF00A6FF00A6FF00A6FF0099FF0080FF0033FF0066FF008CFF00A6FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF008CFF0099FF00B3FF00B3FF0099FF00\
8CFF0019FF00A6FF00B3FF00C0FF00B3FF00C0FF00CCFF00CCFF00B3FF00A6FF00
CCFF00D9FF00D9FF00D9FF00CCFF00C0FF0000FF8CD9FF00E6FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF0073FF00
8CFF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF008CFF0066FF0066FF00\
00FFCC66FF0080FF0080FF0080FF0080FF0066FF008CFF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF0080FF0073FF004CFF004CFF0059FF00\
59FF0066FF0066FF0059FF0059FF004CFF0026FF0019FF000CFF0000FF0C00FFB3
00FF4C00FF4000FF7300FF7300FF8000FFCC00FFFF4C00FF0019FF00CCFF00BFFF0099FF0019FF\
0000000000000000000000000000000000000000000000000026FF00D9FF00FF8C
00FF8C00FF6600FF0C00FF4000FF0C33FF004CFF0059FF0066FF0066FF0073FF0073FF0073FF00\
80FF0080FF0080FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00A6FF0059FF0073FF003FFF008CFF00A6FF00B3FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00C0FF00C0FF0059FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00B3FF0080FF004CFF0099FF0080FF00B3FF00B3FF00B3FF008CFF00A6FF00
C0FF00CCFF00CCFF00C0FF00C0FF00A6FF008CFF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00A6FF0080FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF008CFF0080FF00\
4CFF003FFF0066FF0066FF0066FF0033FF003FFF0080FF008CFF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF004CFF0000FF1933FF00\
33FF004CFF0059FF004CFF004CFF003FFF0026FF0000FFF300FF3300FF9900FF00
00FF0000FF4000FF4C00FF3300FF4000FF6600FF9900FF9900FFA600FFD900FFD90073FF0080FF\
0000000000000000000000000000000000000000004C00FF00CCFF00FFD900FF8C
00FF4000FF7300FF2600FF4000FF0C26FF003FFF004CFF0059FF0059FF0059FF004CFF0059FF00\
59FF004CFF000CFF0080FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00A6FF008CFF004CFF0099FF00B3FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00A6FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF0099FF0000FF1966FF008CFF0099FF0059FF0019FF0080FF00
99FF00C0FF00B3FF0080FF0073FF0073FF0073FF008CFF00CCFF00CCFF00D9FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF008CFF0099FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF0059FF00\
00FF0C59FF0059FF000CFF0026FF0000FF004CFF0066FF0080FF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0066FF0066FF004CFF0026FF0026FF0026FF00\
00FF0C33FF000CFF003FFF0033FF0019FF0000FF1919FF0019FF0000FF1919FF00
19FF0000FF0000FF0000FF1900FF3300FF5900FF7300FF5900BFFF00FF8C00FF9900FFCC00CCFF\
0000000000000000000000000000000000000000003300FF00E6FF00FF9900FF59
00FF3300FF0C00FF0000FF0000FF4C00FF0000FF003FFF003FFF0026FF0033FF0026FF0059FF00\
59FF0073FF0080FF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00B3FF00B3FF0099FF0073FF00A6FF00B3FF00C0FF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF008CFF00B3FF004CFF0059FF004CFF003FFF0099FF0059FF00
8CFF00A6FF0099FF0073FF0080FF00A6FF0099FF0000FF4C99FF0073FF00CCFF00E6FF00E6FF00\
F3FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0026FF00B3FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00A6FF0099FF0066FF00\
66FF0080FF0080FF0059FF003FFF0000FF4C00FF1933FF0073FF0080FF0080FF00
80FF0073FF003FFF0073FF0073FF0073FF0066FF0000FF003FFF0026FF0000FF0C4CFF004CFF00\
19FF0000FF0C00FFB300FF2600FF6626FF003FFF003FFF003FFF0000FF3333FF00
33FF0026FF000CFF0000FF0000FF3300FF4C00FFA600FF2600FF4000FF5900FFCC00FFF300FFCC\
00A6FF0000000000000000000000000000000000000C00FF00F3FF00FFFF00FF66
00FF5900FF190CFF0019FF000CFF000CFF0000FF0C00FF5900FF0C00FF4000FF0000FF1973FF00\
80FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00B3FF008CFF0066FF00A6FF00B3FF00C0FF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00C0FF0080FF00B3FF00B3FF00B3FF0080FF00
3FFF004CFF0073FF0059FF008CFF00C0FF00C0FF0099FF00A6FF00A6FF0073FF00C0FF00CCFF00\
D9FF00B3FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF0099FF00C0FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00A6FF0073FF0080FF00\
8CFF0099FF0099FF008CFF0059FF0000FF404CFF0000FF8033FF0066FF0073FF00
66FF0066FF0019FF000CFF0026FF0033FF0019FF004CFF0033FF0019FF0066FF0066FF0066FF00\
26FF004CFF003FFF0026FF0000FF003FFF0059FF0059FF0059FF004CFF004CFF00
3FFF0026FF000CFF0000FF0C00FF4000FF0C00FF0C00FF0C00FF4000FF8C00FF6600FF7300FF99\
00FFF37300FF004CFF0080FF0026FF8C00FF000000000CFF00D9FF00FF9900FF66
00FFB300FF0C19FF0026FF0033FF0033FF003FFF003FFF0033FF0000FFBF3FFF0066FF0080FF00\
8CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00B3FF008CFF0059FF0099FF00B3FF00CCFF00
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF0066FF00C0FF00CCFF00C0FF0000FF19
A6FF004CFF00A6FF00C0FF00CCFF00CCFF00CCFF00B3FF00CCFF00D9FF00D9FF00B3FF0033FF00\
99FF0073FF00A6FF00F3FF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF0019FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00B3FF0066FF0033FF0099FF00\
A6FF00A6FF00A6FF0099FF0066FF0073FF0073FF0066FF0059FF0019FF003FFF00
00FF0033FF003FFF0066FF0073FF0080FF0073FF0080FF0073FF000CFF0073FF0080FF0080FF00\
4CFF0066FF0059FF0019FF0026FF004CFF0066FF0066FF0066FF0066FF0059FF00
4CFF000CFF0000FF3300FF2600FF400CFF0019FF000CFF0000FF4C00FF2600FF3300FF4000FF66\
00F3FF00B3FF00FFE600FFF300D9FF00D9FF0066FF00000000E6FF00FFB300FF4C
00FF2600FF0026FF0033FF003FFF004CFF004CFF004CFF004CFF0000FF0000FF264CFF0066FF00\
8CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00A6FF0073FF0080FF00B3FF00C0FF00
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00C0FF00D9FF00D9FF00D9FF00CCFF00
CCFF00A6FF00B3FF00CCFF00D9FF00E6FF00E6FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
8CFF00D9FF00E6FF00CCFF00F3FF00FFF300FFF300FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00B3FF003FFF0099FF00B3FF00\
B3FF00B3FF00A6FF00A6FF0099FF008CFF008CFF0080FF0073FF004CFF0026FF00
4CFF004CFF0059FF0080FF008CFF008CFF008CFF008CFF008CFF003FFF008CFF008CFF008CFF00\
80FF0080FF0073FF004CFF000CFF0059FF0073FF0073FF0073FF0073FF0066FF00
4CFF0000FF2633FF0026FF0000FF1926FF0026FF0019FF000CFF0000FF0000FF0C00FF2600FF4C\
00FFB300FF7300FF8000FFA600FFA600FFA600FFFF0019FF004CFF00FFE600FF59
00FF330CFF0026FF0033FF004CFF0059FF0059FF0059FF0059FF004CFF0019FF003FFF0073FF00\
8CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0059FF0073FF00A6FF00C0FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00B3FF00B3FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00F3FF00FFFF00FFFF00FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF00B3FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF0080FF0073FF0033FF0033FF00
66FF0073FF0073FF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
8CFF008CFF0073FF004CFF0059FF0073FF0073FF0080FF0080FF0073FF0073FF00
00FF0C59FF004CFF003FFF0019FF0033FF0033FF0026FF0019FF000CFF0000FF0000FF3300FF66\
00FF9900FF2600FF4C00FF8C00FF5900A6FF00FF9900B3FF00000000D9FF00FF8C
00FF8C00FF1900FF1900FFFF3FFF0066FF0066FF0066FF0066FF004CFF0000FF193FFF0059FF00\
73FF0059FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00A6FF00A6FF008CFF008CFF00C0FF00
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
D9FF00C0FF0099FF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00B3FF00B3FF00A6FF0099FF0099FF0080FF0073FF0019FF0033FF00
73FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF008CFF0073FF0000FFCC73FF0080FF0080FF0080FF0080FF0080FF0073FF00
73FF0066FF0066FF0059FF004CFF004CFF003FFF0033FF0026FF000CFF0000FF0C00FF5900FF0C\
00FF0000FF0000FFD900FF4C00FF2600FF4000FF6600FFFF00FFD97300FF00FFBF
00FF1900FF0C00FF263FFF0059FF0066FF0073FF0073FF0073FF0066FF004CFF0000FF0000FF80\
00FF0080FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF008CFF00CCFF00
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00D9FF0099FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00C0FF00C0FF00B3FF00A6FF0099FF008CFF0073FF0059FF003FFF004CFF00
73FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF008CFF0066FF0033FF0073FF008CFF008CFF008CFF008CFF0080FF0080FF00
80FF0073FF0066FF0066FF0059FF004CFF003FFF0026FF000CFF0000FF1900FF8C008CFF00FF00\
19FF0019FF000CFF0000FF0000FF0C00FF4C00FF8C00FF4000FF6600E6FF00FF8C
00FF0C19FF0000FF3326FF0059FF0073FF0080FF0080FF0080FF0073FF0059FF0066FF0073FF00\
3FFF004CFF008CFF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF0066FF00CCFF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00C0FF00B3FF00A6FF0099FF0080FF004CFF000CFF0033FF004CFF00
59FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF0099FF0073FF0059FF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0073FF0073FF0066FF0059FF0059FF004CFF0026FF0000FF0C00FF0C00FF0C00FF0C0CFF00\
26FF0033FF0026FF0019FF0000FF0000FF6600FF0C00FF0C00FF7300FF2600FFB3
19FF0033FF004CFF004CFF0033FF0073FF0080FF0080FF008CFF0080FF0059FF0073FF008CFF00\
8CFF0073FF0059FF008CFF008CFF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00D9FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00C0FF00B3FF0000FF0066FF003FFF000CFF0059FF0073FF0080FF00
73FF004CFF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF0000FF598CFF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00
80FF0080FF0073FF0066FF0066FF0059FF004CFF0033FF0000FF0C19FF0033FF0033FF0000FF0C\
3FFF003FFF0033FF000CFF0000FF4000FF660CFF0019FF0019FF000CFF0000FF26
00FFB326FF0059FF0066FF0073FF0080FF008CFF008CFF008CFF008CFF008CFF0099FF0099FF00\
99FF0099FF0080FF0059FF0059FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00C0FF00B3FF008CFF008CFF0073FF0033FF0066FF0080FF0099FF00
99FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF00
80FF0073FF0073FF0066FF0059FF004CFF003FFF0026FF0000FF5933FF004CFF004CFF0000FF26\
4CFF004CFF000CFF0000FF2600FF0C0CFF0019FF0033FF0033FF0019FF0000FF59
26FF004CFF0066FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
CCFF00CCFF00C0FF00C0FF00A6FF0099FF008CFF0033FF0026FF008CFF0099FF00
A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF008CFF00
80FF0073FF0066FF0059FF004CFF003FFF0033FF0000FF193FFF004CFF0059FF0059FF0066FF00\
66FF0059FF004CFF0000FF003FFF003FFF0000FF003FFF003FFF0000FF2600FF40
00FFA659FF0066FF0073FF0080FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00CCFF00C0FF00C0FF00B3FF00A6FF008CFF0059FF0066FF008CFF0099FF00
A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF00
73FF0066FF0000FF264CFF0033FF000CFF0000FF000CFF003FFF0059FF0066FF0066FF0066FF00\
66FF0066FF004CFF004CFF0059FF0059FF0059FF0059FF004CFF003FFF0026FF00
33FF004CFF0066FF0073FF0080FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
CCFF00CCFF00C0FF00C0FF00B3FF008CFF0073FF003FFF0033FF0080FF0099FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF0026FF00
26FF0019FF0000FFB300FF0000FF0C00FFA633FF0000FF1933FF0059FF0066FF0073FF0073FF00\
73FF0073FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF004CFF0033FF00
00FF1933FF004CFF0059FF0073FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
CCFF00CCFF00C0FF00B3FF00A6FF008CFF0026FF004CFF008CFF004CFF0033FF00
B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF00
66FF0026FF003FFF003FFF0019FF0059FF004CFF0000FFD933FF0059FF0073FF0073FF0080FF00\
80FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF003FFF00
0CFF0000FFB30CFF0000FF0C4CFF0066FF0073FF0080FF0099FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
CCFF00CCFF00C0FF00B3FF00A6FF004CFF0033FF0099FF00A6FF00A6FF0099FF00
B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF00
66FF0000FFB359FF0073FF0000FF7373FF0066FF0059FF0019FF0066FF0073FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0066FF0059FF0033FF00
00FF263FFF003FFF0059FF0059FF0019FF0026FF003FFF0099FF00A6FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00\
CCFF00C0FF00A6FF0099FF003FFF008CFF0099FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0073FF00
00FF1900FF0C73FF0080FF008CFF0080FF0080FF0066FF0033FF0073FF0080FF0080FF008CFF00\
8CFF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF004CFF0033FF00
00FF4C4CFF0066FF0073FF0080FF0080FF0073FF008CFF0099FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00\
C0FF00B3FF0099FF0019FF0000FF33A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF0080FF0000FF40
66FF0080FF0080FF0099FF0099FF008CFF008CFF0066FF0033FF0073FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0059FF003FFF0026FF00
00FF333FFF0073FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00B3FF00\
3FFF008CFF0066FF0066FF0099FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0080FF0000FFBF8CFF00
99FF0099FF0099FF00A6FF00A6FF0099FF0099FF0073FF0033FF0073FF008CFF008CFF0099FF00\
99FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF004CFF000CFF0019FF00
3FFF0059FF0073FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00\
A6FF0059FF0073FF008CFF008CFF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF0073FF0080FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF0026FF0066FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF0080FF0073FF0066FF003FFF000CFF003FFF00
59FF0073FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00CCFF00C0FF00B3FF00\
99FF000CFF008CFF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00A6FF0059FF0059FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF0099FF0099FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF008CFF0080FF0066FF0019FF0019FF0033FF0000FF0C
4CFF0073FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00B3FF0026FF00B3FF00A6FF0000FF00\
73FF004CFF0099FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF0080FF0000FF2659FF0066FF0059FF0000FF0C
00FF2659FF0066FF0080FF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00CCFF00B3FF008CFF0033FF0000FF19\
66FF0080FF0073FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF0099FF008CFF0080FF0080FF0080FF0073FF0059FF00
33FF0000FF0059FF0080FF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF00B3FF0080FF008CFF00\
A6FF00A6FF00A6FF0019FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0073FF0059FF00
00FF1926FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF00A6FF0059FF0080FF00\
B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0033FF00
0CFF0059FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00CCFF00B3FF00A6FF000CFF0099FF00\
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0073FF00
4CFF004CFF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0059FF0059FF0033FF00A6FF00\
C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF00
66FF0059FF0080FF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00C0FF0080FF0080FF00A6FF00B3FF0073FF00\
C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF00
59FF004CFF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00F3FF00D9FF0080FF00A6FF00C0FF00C0FF00CCFF00CCFF0099FF00\
C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF0080FF00
66FF0000FF2666FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00F3FF00E6FF0059FF00A6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF0080FF00
4CFF0019FF004CFF0066FF0059FF008CFF0099FF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF0073FF00
66FF004CFF000CFF0019FF0073FF0080FF008CFF008CFF0080FF0080FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF00
80FF0066FF0026FF0026FF0066FF0073FF0080FF0073FF0033FF0080FF0099FF00A6FF00A6FF00\
A6FF0099FF0066FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF00
80FF0033FF0026FF0019FF0059FF004CFF0059FF0059FF004CFF0080FF008CFF0099FF0099FF00\
99FF0080FF0066FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF00
80FF0073FF004CFF0000D9FF00FF1900FF3300FF0C00FF263FFF0066FF0080FF008CFF0080FF00\
80FF0019FF008CFF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF008CFF00
80FF0066FF0033FF003FFF0059FF003FFF0059FF004CFF0000FF0059FF0073FF0066FF000CFF00\
33FF000CFF0066FF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF00
73FF004CFF004CFF0066FF0073FF0073FF0073FF0066FF0026FF0019FF004CFF0019FF000CFF00\
66FF0066FF0019FF0066FF0073FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0026FF00
4CFF0000FF4C66FF0073FF0080FF0080FF0080FF0073FF004CFF0059FF0000FF0073FF0080FF00\
8CFF008CFF004CFF0073FF0019FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF008CFF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF0073FF0073FF004CFF00
00FF194CFF0066FF0080FF008CFF008CFF008CFF008CFF008CFF0080FF003FFF0080FF0099FF00\
99FF0099FF000CFF0099FF0099FF003FFF0059FF008CFF0080FF0099FF00A6FF00
A6FF0099FF008CFF00B3FF00C0FF00CCFF00CCFF00C0FF0080FF00CCFF00E6FF00E6FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF004CFF000CFF0026FF00
00FF8C4CFF0066FF0080FF008CFF0099FF0099FF0099FF0099FF0099FF0066FF0080FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00A6FF0099FF0073FF0019FF004CFF0073FF008CFF00
80FF0059FF0099FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF00CCFF00E6FF00E6FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF0073FF0000FF8000FF26
00FFBF19FF004CFF0080FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF0080FF000CFF00A6FF00\
B3FF00B3FF00C0FF00C0FF00B3FF00B3FF0099FF0099FF0073FF000CFF0000FF00
4CFF0059FF0000FF2699FF00A6FF0033FF0099FF004CFF00B3FF00CCFF00D9FF00E6FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0073FF0059FF0033FF00
00E6FF33FF000CFF0080FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00A6FF008CFF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0059FF0099FF00
99FF0080FF003FFF0073FF0080FF000CFF0066FF0033FF0026FF00C0FF00CCFF00E6FF00E6FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0066FF003FFF00
0CFF0066FF0080FF0080FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF0066FF00B3FF00
B3FF0099FF008CFF004CFF008CFF008CFF00A6FF0099FF0059FF0059FF00C0FF00D9FF00E6FF00\
E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0066FF0019FF00
59FF0073FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF00C0FF00
C0FF00C0FF00B3FF0073FF00A6FF00B3FF00C0FF00B3FF00A6FF00A6FF0066FF00C0FF00CCFF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00A6FF0099FF00\
A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF0000FF00
73FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF0000FFBFB3FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF0059FF0073FF00\
D9FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0073FF0073FF0080FF00\
8CFF0099FF008CFF008CFF0080FF0080FF0080FF0080FF0073FF004CFF003FFF00
73FF008CFF0099FF00A6FF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF0099FF0073FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00D9FF00\
CCFF00E6FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF0099FF0073FF0000FF26\
66FF0080FF0080FF0073FF003FFF0073FF0073FF0059FF003FFF0026FF0000FF00
00FF1980FF008CFF00A6FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0080FF00\
59FF0059FF0066FF0059FF0000FFBF3FFF0059FF003FFF0000FF664CFF004CFF00
33FF004CFF0080FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF00\
73FF003FFF0026FF0000FF7333FF0000FF260CFF0026FF0059FF0073FF0073FF00
4CFF0059FF0066FF008CFF0099FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF00\
80FF0066FF0000FF0C4CFF0059FF0033FF004CFF0019FF0073FF0080FF008CFF00
8CFF008CFF0073FF0033FF003FFF0099FF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF00\
73FF003FFF004CFF0066FF0073FF0073FF0073FF0059FF0073FF008CFF0099FF00
A6FF00A6FF0099FF0080FF0033FF0000FF8C8CFF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF0099FF008CFF0080FF00\
00FF1900FFA64CFF0073FF0080FF008CFF008CFF0080FF0000FF5999FF00A6FF00
A6FF00B3FF00A6FF00A6FF0073FF0099FF008CFF00A6FF00CCFF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0073FF0080FF008CFF0080FF0073FF00\
3FFF0000FF3319FF0073FF008CFF0099FF0099FF0099FF0099FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00B3FF00B3FF00
B3FF00B3FF0099FF00A6FF00A6FF00A6FF00A6FF0099FF0080FF004CFF0066FF0073FF0066FF00\
3FFF0033FF0073FF0080FF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0080FF0099FF00
A6FF0099FF004CFF0080FF0066FF008CFF0080FF0073FF0059FF0000FF4C00FF004CFF003FFF00\
26FF0066FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF0033FF00
3FFF0073FF0033FF0033FF0066FF0073FF0000FF1900FFBF26FF0066FF0059FF003FFF004CFF00\
00FF0C66FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00B3FF0099FF0073FF0033FF00
73FF000CFF008CFF008CFF0099FF0099FF0099FF0080FF0073FF008CFF0080FF0073FF0073FF00\
4CFF0059FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00D9FF00CCFF0099FF0066FF0066FF0000FF4C33FF008CFF00
99FF008CFF0099FF00A6FF00B3FF00B3FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF00\
73FF004CFF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00D9FF00CCFF00A6FF00C0FF00B3FF00A6FF004CFF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF00\
80FF000CFF0066FF0080FF0099FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF0073FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF00\
80FF004CFF003FFF0073FF008CFF008CFF00A6FF00A6FF00B3FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF00\
73FF0026FF004CFF0066FF0073FF0019FF0099FF00A6FF00B3FF00B3FF00C0FF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF00\
80FF0066FF0000FF3326FF003FFF004CFF0066FF0080FF008CFF00B3FF00C0FF00
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00\
8CFF0066FF003FFF0000FF5900FF0C3FFF0033FF008CFF00A6FF00B3FF00C0FF00
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF0099FF00\
73FF0000FF000CFF0000FF0000FF004CFF0080FF0099FF00A6FF00B3FF00C0FF00
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0080FF00\
8CFF0080FF000CFF0059FF0033FF0026FF0059FF0099FF00A6FF00B3FF00C0FF00
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00\
A6FF0099FF0066FF0080FF0066FF0000FF0073FF0099FF00A6FF00B3FF00B3FF00
C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00\
A6FF00A6FF0099FF008CFF0026FF003FFF0059FF0099FF00A6FF00A6FF00B3FF00
B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00\
B3FF00A6FF00A6FF0099FF008CFF0066FF0066FF008CFF0099FF00A6FF00A6FF00
B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00\
B3FF00A6FF00A6FF0099FF008CFF0073FF0000FF6673FF0033FF008CFF0073FF00
99FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
B3FF00A6FF00A6FF0099FF008CFF0080FF003FFF0000FF0C00D9FF59FF0019FF00
66FF008CFF008CFF0099FF008CFF00A6FF008CFF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00\
B3FF00A6FF00A6FF0099FF008CFF0066FF0026FF0066FF004CFF0019FF0080FF00
8CFF0073FF0059FF0000FF2600FFD966FF0073FF004CFF00B3FF00CCFF00D9FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00\
B3FF00A6FF0099FF008CFF0080FF0000FF0000FF4C80FF008CFF0080FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0080FF00B3FF00B3FF00B3FF00A6FF00D9FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00\
A6FF008CFF008CFF0080FF0073FF0019FF0066FF008CFF0099FF00A6FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF008CFF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00B3FF00A6FF00\
99FF0073FF0066FF0000FF6659FF0000FF3373FF008CFF00A6FF00B3FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00B3FF00A6FF0099FF00\
8CFF0080FF003FFF003FFF0000FF3366FF004CFF0080FF00A6FF00B3FF00C0FF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF0059FF0080FF008CFF008CFF00\
59FF0066FF0000FF8C73FF0073FF008CFF0099FF0000FF0C59FF00C0FF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF0026FF0000FF1959FF0066FF0073FF003FFF00\
4CFF000CFF0066FF0080FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00A6FF00A6FF00A6FF0099FF00\
8CFF0073FF0066FF0080FF0099FF00A6FF00B3FF00B3FF00C0FF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF00\
99FF0073FF003FFF0066FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00\
99FF0073FF000CFF0019FF0073FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00B3FF00\
A6FF008CFF0059FF0000FF998CFF00A6FF00B3FF00C0FF00C0FF00CCFF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00\
A6FF0099FF0080FF0033FF0080FF0099FF00A6FF00B3FF00C0FF00CCFF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00\
A6FF0099FF0080FF003FFF0000FF7300FF1980FF008CFF0099FF00C0FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF00\
99FF0000FF2666FF0000FF4080FF0099FF0099FF0073FF00A6FF0073FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF0099FF0000FF26\
66FF003FFF004CFF0066FF0099FF00B3FF00B3FF00C0FF00C0FF00CCFF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0099FF00\
8CFF0000FF0C80FF0099FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF00\
99FF0019FF0073FF0099FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF00\
8CFF0066FF0000FF1973FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF00\
80FF0066FF0099FF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF00\
0CFF004CFF00A6FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF008CFF00\
80FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00A6FF008CFF004CFF00\
8CFF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0073FF0073FF00\
99FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00B3FF0099FF0073FF0059FF00\
8CFF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00A6FF0099FF0099FF0073FF0033FF0073FF00\
8CFF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF0099FF0080FF0059FF0000FFCC73FF008CFF00\
A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF0073FF0066FF008CFF00\
A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF0000FF0000FF1980FF00\
99FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF0080FF004CFF0073FF00\
8CFF0099FF0099FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFCC00FFCC00FFCC00FFCC00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF00
80FF0073FF003FFF0000FFA659FF0073FF0080FF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00\
C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF0099FF0099FF008CFF0059FF00
66FF0059FF004CFF003FFF0073FF0080FF0099FF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00C0FF00B3FF008CFF0000FF263FFF0080FF0073FF0066FF00
00FF8C00FF2600FFCC0CFF0066FF0080FF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00C0FF00C0FF00B3FF00A6FF008CFF0080FF0033FF0000FF2626FF00
0CFF004CFF004CFF0066FF0000FFB300FF0C99FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF008CFF0073FF004CFF0019FF00
59FF0073FF0080FF0080FF008CFF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0080FF0059FF0033FF00
66FF0080FF008CFF008CFF0099FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0066FF0026FF0019FF00
33FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00A6FF0099FF0099FF008CFF0080FF0059FF0000FF3319FF00
3FFF0073FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF003FFF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF0099FF0019FF0080FF0080FF0073FF0066FF0019FF004CFF00
73FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0099FF008CFF0099FF0099FF004CFF0099FF00\
99FF0099FF0099FF008CFF0073FF0000FF6600FF0C66FF0059FF0000FF0C66FF00
80FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00CCFF00C0FF00B3FF00B3FF0000FFBFA6FF008CFF000CFF003FFF0066FF000CFF0059FF00\
33FF0080FF0073FF0073FF0033FF003FFF0000FF4026FF0000FF3300FF4059FF00
73FF008CFF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00D9FF00B3FF00A6FF0073FF0059FF0066FF0019FF0080FF0059FF0066FF0080FF0000FF0C\
8CFF0080FF0066FF0033FF0059FF0073FF0066FF004CFF0059FF0026FF0019FF00
66FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00D9FF00CCFF00CCFF00C0FF00A6FF0066FF0099FF00A6FF0099FF0080FF00A6FF00A6FF00\
A6FF00A6FF0099FF0073FF0080FF008CFF0080FF0073FF0080FF0066FF0026FF00
59FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0019FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF00
26FF0066FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0073FF00
19FF003FFF0000FF4073FF0080FF0080FF0000FF0C99FF0099FF00A6FF00A6FF00B3FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF00
59FF0026FF003FFF0066FF0073FF0066FF004CFF0073FF0080FF0073FF008CFF00B3FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF00
66FF0000FF0C33FF004CFF003FFF003FFF0000FF000CFF0066FF008CFF00A6FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF0073FF00
59FF0019FF0019FF0033FF000CFF0000FF664CFF0066FF0080FF0099FF00A6FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF0059FF00
59FF003FFF0019FF0000FF0C00FF4000FF4059FF0073FF008CFF0099FF00A6FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0080FF00
73FF004CFF0019FF0000FF7300FF5933FF0059FF0066FF0080FF0099FF00A6FF00A6FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0080FF00
66FF0000FF6600FF8000FF0019FF0000FF2600FF0019FF0059FF008CFF00A6FF00A6FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00A6FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF0080FF004CFF00
33FF0000FF1919FF0033FF003FFF000CFF003FFF0066FF0080FF0099FF0099FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF0080FF00A6FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0073FF0080FF0066FF00
59FF003FFF0066FF0066FF0059FF0019FF0033FF0073FF0080FF008CFF0099FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00B3FF00B3FF00A6FF008CFF008CFF00A6FF008CFF00B3FF00B3FF0099FF00\
66FF008CFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF0099FF00
73FF0066FF0080FF0073FF0066FF0000FF9900FF004CFF0073FF008CFF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF00A6FF0099FF0080FF0033FF0000FF4000FF0C66FF0059FF0080FF00\
C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF00
8CFF008CFF008CFF0080FF0059FF0059FF003FFF000CFF0073FF008CFF008CFF0099FF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00A6FF00
A6FF008CFF0073FF0099FF008CFF0066FF000CFF0080FF0080FF0080FF00B3FF00C0FF00C0FF00\
CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00
A6FF0099FF0099FF008CFF0080FF0073FF0059FF0019FF0066FF0080FF008CFF008CFF008CFF00\
99FF0099FF0099FF0080FF0080FF0099FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0080FF0000FF8C59FF0073FF0059FF0000FF3399FF00A6FF00B3FF00C0FF00CCFF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00
A6FF00A6FF0099FF0099FF008CFF0080FF0073FF004CFF0059FF0073FF0080FF0080FF0080FF00\
80FF008CFF008CFF0073FF0066FF008CFF008CFF0099FF0099FF008CFF004CFF00
80FF0000FF193FFF003FFF0000FF3300F3FF80FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0059FF0019FF0033FF0066FF0073FF0059FF00\
66FF0073FF0073FF0059FF0026FF0059FF0000FF0C66FF0073FF0066FF0000FF0C
3FFF003FFF0073FF0080FF0073FF0080FF0073FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0066FF004CFF0000FF264CFF0033FF0026FF00\
3FFF0059FF003FFF0000FF0C59FF003FFF0066FF0080FF0066FF0066FF0073FF00
73FF0026FF008CFF0099FF00A6FF00A6FF008CFF0000FF66B3FF00CCFF00CCFF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0073FF0059FF0026FF0000FFBF00FF3333FF00\
00FF4C0CFF0000FF3359FF0073FF0080FF008CFF0099FF0099FF0099FF0099FF00
99FF003FFF0099FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0073FF0066FF0033FF003FFF0059FF0059FF00\
4CFF004CFF0000FF4C73FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0066FF004CFF0000FF0C59FF0066FF0073FF00\
73FF0073FF0066FF0000FF408CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF0099FF0099FF008CFF0080FF0066FF004CFF0000FF0026FF0059FF0073FF0080FF00\
80FF008CFF008CFF0080FF008CFF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF0099FF0099FF008CFF008CFF0073FF0019FF000CFF0000FF5900FF6600FFD973FF0080FF00\
8CFF0099FF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF00
99FF0099FF008CFF008CFF0080FF0073FF004CFF0033FF0000FF0C26FF0033FF0073FF008CFF00\
99FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0066FF008CFF00
8CFF008CFF008CFF0080FF0080FF0073FF0066FF000CFF0000FF0019FF0073FF0080FF008CFF00\
99FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0073FF0000FF00
73FF0080FF0080FF0080FF0073FF0073FF0059FF003FFF003FFF0066FF0080FF008CFF0099FF00\
99FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF0000FF8099FF0099FF008CFF00\
8CFF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0080FF0066FF00
4CFF0066FF0066FF0059FF0066FF0059FF004CFF000CFF004CFF0066FF0080FF008CFF0099FF00\
99FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF0033FF0059FF004CFF00\
4CFF0080FF0080FF0099FF0099FF0099FF0099FF0099FF008CFF0080FF0073FF00
0CFF0033FF003FFF0033FF004CFF003FFF0000FF0C00FF0C0CFF0059FF0073FF0080FF008CFF00\
99FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF0073FF0080FF00\
4CFF0000FF0C4CFF0080FF008CFF008CFF0080FF0080FF0080FF0073FF0066FF00
4CFF0000FF3300FF1900FF0019FF0000FF3300FF004CFF0019FF0000FF6659FF0080FF008CFF00\
99FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF00\
66FF0080FF0073FF000CFF0066FF0073FF0033FF0073FF0073FF0059FF003FFF00
00FF003FFF004CFF003FFF0033FF0026FF0059FF0066FF0059FF0066FF004CFF004CFF0066FF00\
80FF008CFF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00\
A6FF0099FF008CFF0080FF0026FF0000FF0000FF4C0CFF0059FF003FFF0000FF4C
00FF194CFF0066FF0066FF0059FF0000FF8066FF0080FF0080FF0080FF0080FF004CFF0026FF00\
4CFF0059FF0099FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00\
A6FF00A6FF0099FF008CFF0000FF2659FF004CFF000CFF0033FF0019FF0026FF00
33FF0066FF0073FF0073FF0073FF0059FF0073FF008CFF008CFF008CFF008CFF0080FF0073FF00\
73FF0059FF0073FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00\
B3FF00A6FF00A6FF0099FF0080FF0080FF004CFF004CFF0019FF0033FF0059FF00
66FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00\
B3FF00A6FF00A6FF0099FF008CFF0080FF0073FF0066FF0026FF003FFF0066FF00
73FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00\
B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0066FF003FFF004CFF0066FF00
73FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0066FF0019FF0059FF0073FF00
80FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00A6FF00A6FF0099FF008CFF0080FF0073FF0059FF0000E6FF4CFF0066FF00
80FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
A6FF00A6FF0099FF0099FF008CFF0073FF0026FF0033FF0000FF194CFF0066FF00
73FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF0066FF00B3FF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF008CFF0073FF0073FF0066FF004CFF0000FF0026FF004CFF0059FF00
66FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF008CFF00A6FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF0099FF008CFF0073FF0000FF0C3FFF0026FF0000FF0000FF0C00FF0C33FF00
33FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00D9FF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF0099FF008CFF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00B3FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF0099FF008CFF0080FF004CFF0000FF0C000CFF00FF8000FFBF00FF6619FF00
33FF0073FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00A6FF0033FF008CFF00B3FF00C0FF00
CCFF00CCFF00A6FF00C0FF00C0FF00C0FF00B3FF008CFF0073FF00A6FF00A6FF00B3FF00B3FF00\
B3FF0099FF0019FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF0080FF008CFF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF008CFF0080FF0059FF004CFF000CFF0000FF2619FF003FFF004CFF00
3FFF000CFF0059FF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00D9FF00B3FF00B3FF00A6FF0026FF00
8CFF00A6FF0026FF00B3FF00B3FF00A6FF00A6FF008CFF0033FF0080FF0073FF0099FF00A6FF00\
A6FF0099FF0080FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00A6FF0073FF0000FF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF008CFF0080FF0073FF0059FF003FFF000CFF000CFF004CFF0066FF00
73FF0080FF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00D9FF00CCFF00C0FF00
00FF0000FF2619FF008CFF0099FF0066FF004CFF0033FF0066FF0019FF0026FF008CFF008CFF00\
8CFF0073FF0059FF0080FF0099FF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF008CFF0066FF0073FF008CFF0099FF0099FF0099FF0099FF00\
8CFF008CFF008CFF0080FF0073FF0033FF000CFF0000FF4C3FFF0000FF0073FF00
80FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00
59FF00A6FF0080FF0000FF1973FF0000FF1900FF8C80FF008CFF0080FF0026FF0059FF0066FF00\
0CFF004CFF0000FF004CFF0080FF0073FF008CFF00A6FF00A6FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF0099FF008CFF0073FF004CFF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF0080FF0080FF0073FF0059FF0000FF264CFF0066FF0073FF0080FF00
8CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00
CCFF00C0FF00B3FF0080FF0073FF0099FF0080FF00A6FF00A6FF0099FF0080FF0033FF0073FF00\
66FF0080FF0080FF0026FF000CFF0059FF004CFF0019FF0099FF0099FF0099FF00
8CFF0099FF0099FF0099FF0099FF008CFF0073FF0019FF0059FF0066FF0026FF0073FF0080FF00\
80FF0080FF0080FF0073FF0066FF004CFF0026FF0059FF0073FF0080FF008CFF00
8CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
D9FF00CCFF00C0FF008CFF0099FF00B3FF00B3FF00B3FF00B3FF00B3FF0099FF0026FF008CFF00\
99FF0099FF0099FF0066FF008CFF008CFF0059FF0033FF0059FF0073FF0080FF00
73FF0073FF008CFF008CFF0073FF0073FF0066FF0019FF0026FF003FFF0026FF0066FF0073FF00\
73FF0073FF0073FF0066FF004CFF0000FF2659FF0073FF0080FF0080FF008CFF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00
D9FF00CCFF00B3FF0066FF00B3FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF004CFF00A6FF00\
B3FF00B3FF00A6FF0080FF00A6FF00A6FF00A6FF0099FF008CFF0059FF003FFF00
00FF0C3FFF0073FF0073FF0019FF0019FF0000FF0C4CFF003FFF0033FF0000FF334CFF0066FF00\
59FF004CFF0059FF0059FF0033FF0026FF0059FF0073FF0080FF008CFF008CFF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00D9FF00B3FF0099FF00C0FF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF0080FF00B3FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0080FF0073FF00
73FF0000FF1933FF004CFF0000FF0000BFFF59FF0066FF0066FF0059FF0000FF2626FF004CFF00\
33FF0000FF1926FF0033FF0000FF8033FF0059FF0073FF0080FF008CFF008CFF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00D9FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF0099FF0099FF00
8CFF0073FF003FFF0059FF0066FF0059FF0073FF0080FF0080FF0059FF004CFF0019FF0019FF00\
00FF1900FF4C26FF0033FF0019FF0000FF004CFF0059FF0080FF008CFF008CFF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00
99FF008CFF004CFF0073FF0080FF008CFF008CFF008CFF008CFF0080FF0066FF0000FF1959FF00\
59FF000CFF0059FF0059FF003FFF000CFF0033FF0066FF0073FF0080FF008CFF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00
A6FF008CFF0019FF008CFF0099FF0099FF0099FF0099FF008CFF0080FF0066FF004CFF0073FF00\
73FF0073FF0073FF0066FF003FFF0000FF403FFF0059FF0073FF0080FF0080FF00
8CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00E6FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00
A6FF0073FF0073FF0099FF0099FF00A6FF00A6FF0099FF0099FF008CFF003FFF0066FF0080FF00\
80FF0080FF0080FF0073FF0059FF0000FF0026FF0000FF0059FF0059FF0033FF00
8CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF00C0FF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00A6FF0000FF0CB3FF00E6FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
B3FF0066FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0033FF0080FF008CFF00\
8CFF008CFF0080FF0073FF0000FF0C4CFF0033FF0000FF4C00FF0C59FF0080FF00
8CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF004CFF0019FF00B3FF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF008CFF003FFF00C0FF00D9FF00E6FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF0099FF008CFF0080FF0000FF0066FF0066FF003FFF0000FF4C66FF0080FF00
8CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF008CFF0099FF00B3FF00B3FF00B3FF00\
33FF0073FF0080FF008CFF00C0FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF0099FF008CFF0080FF0080FF0073FF0000FF0000FF404CFF0080FF00
8CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF000CFF008CFF0019FF008CFF00\
00FF19A6FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF008CFF008CFF0080FF0066FF0026FF0059FF0080FF00
8CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00A6FF008CFF0019FF0073FF0066FF00\
80FF00C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0073FF0059FF0059FF0073FF00
80FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF0073FF0073FF0099FF00A6FF00\
A6FF00C0FF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0000FF003FFF0073FF00
80FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF0080FF0000FF0C59FF00A6FF00C0FF00\
C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0073FF004CFF0033FF0066FF00
73FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF008CFF003FFF0073FF00A6FF00C0FF00\
CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0073FF0059FF0000FF9933FF00
00FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00C0FF00B3FF0073FF0099FF00A6FF00A6FF0099FF008CFF000CFF0099FF00B3FF00C0FF00\
CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0066FF0033FF0019FF00
59FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00B3FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00C0FF00B3FF0099FF000CFF0080FF0066FF0080FF0000FF333FFF0073FF00A6FF00B3FF00\
CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0059FF000CFF003FFF00
59FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF0099FF0000FF19B3FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00B3FF00A6FF0080FF0000FF9926FF0000FF1959FF008CFF008CFF0026FF004CFF00\
4CFF00CCFF00D9FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0059FF003FFF0000FF8033FF00
3FFF0059FF0066FF0073FF0073FF004CFF003FFF0080FF008CFF0099FF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0080FF0080FF0099FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0080FF0033FF0099FF00B3FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00B3FF00B3FF00A6FF0080FF0019FF0080FF008CFF0059FF00A6FF00B3FF00B3FF0099FF00\
B3FF0066FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF0099FF008CFF0066FF0059FF0059FF004CFF0000FF00
00FFA63FFF0059FF0059FF004CFF0000FF734CFF0080FF008CFF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0066FF0019FF0080FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF0073FF0059FF0099FF00B3FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00B3FF00A6FF0099FF0059FF0000FF338CFF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0073FF0066FF0000FF40
0CFF000CFF003FFF0000FF4026FF0059FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF0080FF003FFF000CFF0080FF0099FF00
99FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0000FF4080FF0099FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
B3FF008CFF008CFF008CFF0073FF0066FF0099FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0080FF0066FF0059FF00
3FFF0019FF0000FF2600FF0059FF0066FF0073FF0080FF008CFF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF0073FF000CFF004CFF0080FF008CFF00
99FF0099FF0099FF0099FF0073FF0080FF0080FF0073FF0026FF0073FF0099FF00A6FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00
A6FF008CFF0000FF4C0CFF0000FF2600FF008CFF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0073FF0059FF00
4CFF0019FF0000FF403FFF0059FF0073FF0073FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0080FF0073FF0059FF0026FF0073FF0080FF00
8CFF008CFF008CFF008CFF0073FF004CFF003FFF0026FF0080FF008CFF0099FF00A6FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
A6FF008CFF0000FFFF73FF0026FF0099FF0080FF0080FF00C0FF00CCFF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0073FF0066FF0059FF00
19FF000CFF0000FF4C33FF0059FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0080FF0073FF0059FF0033FF0073FF0080FF00
80FF0080FF0080FF0080FF0066FF0033FF003FFF0059FF0080FF0099FF00A6FF00A6FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00
8CFF0059FF0000FF338CFF00A6FF00B3FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0000FF0019FF0033FF00
00FF0C0CFF0033FF003FFF0059FF0066FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF0080FF0080FF0080FF0073FF0059FF0000FF3359FF0066FF00
73FF0059FF0059FF0066FF0059FF0000FF594CFF0073FF008CFF0099FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF0099FF00
4CFF0066FF008CFF0019FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0066FF004CFF0026FF00
00FF3333FF003FFF0059FF0066FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0073FF0066FF0033FF0000FF0C00FF0C4CFF00
59FF004CFF0026FF0033FF003FFF0019FF0059FF0073FF008CFF0099FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00B3FF00A6FF00A6FF00B3FF00A6FF0099FF0000FF1973FF0000FF59
80FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00\
A6FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0066FF0059FF0033FF00
00FF4026FF004CFF0059FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0073FF0073FF0066FF0059FF0033FF0000FF6633FF00
26FF000CFF0000FF0000FF4C00FF4C19FF0000FF0C26FF0073FF008CFF0099FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00A6FF0033FF008CFF0099FF0099FF008CFF0073FF004CFF0059FF00
99FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00\
8CFF008CFF0059FF0073FF0073FF0073FF0073FF0066FF0059FF004CFF0026FF00
00FF8019FF004CFF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0066FF0059FF0033FF0000FF2600FF00
00FF8C00FF5933FF003FFF000CFF0059FF0066FF0066FF0080FF008CFF0099FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00A6FF0080FF0026FF0080FF0080FF0059FF004CFF0066FF0099FF00
A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00\
8CFF0026FF0000FF3326FF0019FF0059FF0059FF004CFF0033FF0033FF0026FF00
00FF4033FF004CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0066FF0066FF00\
66FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF003FFF0000FF0C00FF33
33FF003FFF004CFF0059FF0059FF0066FF0073FF0080FF008CFF0099FF0099FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00A6FF0099FF0080FF0019FF003FFF003FFF003FFF0059FF0080FF00
A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00\
99FF000CFF0073FF0019FF004CFF003FFF0000FF3300FF0000FF0000FF0C00FF26
00FF0033FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0059FF0033FF00\
4CFF0066FF0066FF0066FF0066FF0059FF0059FF004CFF003FFF0000FF2600FF00
3FFF004CFF0059FF0066FF0066FF0073FF0080FF0080FF008CFF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00A6FF00A6FF0099FF008CFF0073FF0000FF1966FF0080FF008CFF00A6FF00
B3FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
99FF008CFF0080FF0080FF0073FF0066FF004CFF0033FF003FFF0000FF0019FF00
00FF9900FF333FFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF004CFF0026FF00\
3FFF0059FF0059FF0059FF004CFF004CFF004CFF0033FF0019FF0019FF003FFF00
4CFF0059FF0066FF0066FF0073FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF0099FF008CFF0066FF0000FF0059FF008CFF0099FF00A6FF00
B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
99FF0099FF008CFF0080FF0080FF0073FF0066FF0059FF0059FF004CFF003FFF00
26FF0000FFA633FF003FFF004CFF004CFF004CFF004CFF004CFF0033FF003FFF0033FF0000FF4C\
26FF003FFF004CFF003FFF0000FF003FFF003FFF0026FF0000FF3326FF003FFF00
4CFF0059FF0066FF0066FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF0099FF0099FF0080FF004CFF0000FF0C3FFF0080FF0099FF00A6FF00
B3FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00\
99FF0099FF008CFF008CFF0080FF0080FF0073FF0066FF0066FF0059FF004CFF00
3FFF0000FF0C00FF3333FF0033FF003FFF004CFF003FFF0033FF0000FF2626FF0000FF1900FF33\
19FF0033FF003FFF0033FF000CFF0019FF0019FF0000FF0000FF590CFF003FFF00
4CFF0059FF0066FF0066FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF00\
99FF0099FF008CFF008CFF0073FF008CFF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF0099FF0099FF008CFF0080FF0073FF0026FF0059FF0080FF008CFF0099FF00
A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00\
99FF0099FF008CFF008CFF0080FF0080FF0073FF0073FF0066FF0059FF0059FF00
3FFF000CFF0000FF190CFF0000FF8033FF003FFF003FFF0033FF0019FF0000FF7300FF4000FF0C\
19FF0026FF0033FF0026FF000CFF0000FF4C00FF3300FF2600FF1919FF0033FF00
4CFF0059FF0059FF0066FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF0080FF004CFF0059FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF00\
8CFF008CFF008CFF0080FF0080FF0066FF004CFF003FFF0059FF0080FF0080FF00
66FF00A6FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF0099FF008CFF008CFF0080FF0080FF0073FF0073FF0066FF0066FF0059FF00
3FFF0026FF0000FF0000FF590CFF0026FF0033FF0033FF0026FF0019FF0000FF0000FFA600FF00\
0CFF0019FF0019FF0019FF000CFF0000FF1900FF2600FF0019FF0026FF0033FF00
3FFF004CFF004CFF0059FF0066FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF00\
8CFF0080FF0073FF004CFF003FFF0080FF0099FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF008CFF00\
0CFF0066FF0073FF0073FF0066FF0059FF0000FF263FFF004CFF0059FF0059FF00
80FF00A6FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF0059FF004CFF00
3FFF0026FF0000FF0C00FF590CFF0019FF0026FF0019FF0019FF000CFF0000FF0C00FF8C00FF19\
00FF0C00FF0C00FF1900FF0000FF0C00FF4000FF1900FF0019FF0026FF0033FF00
33FF0033FF0000FF594CFF0059FF0059FF0059FF0073FF0080FF0080FF0080FF0080FF0080FF00\
80FF0073FF0066FF0000FF0C73FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF00\
73FF004CFF004CFF004CFF0000FF8026FF0033FF0066FF0080FF008CFF0099FF00
A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00
A6FF000CFF0080FF0073FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
8CFF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF0059FF003FFF00
33FF0019FF0000FF0C00FF8C00FF000CFF000CFF0000FF0000FF0C00FF0C00FFCC00FF9900FF33\
00FF3300FFFF00FF3300FF2600FF6600FFA600FF3300FF0C00FF000CFF0019FF00
26FF000CFF000CFF0033FF0019FF0000FF0C59FF0073FF0073FF0080FF0080FF0080FF0080FF00\
73FF0073FF004CFF003FFF0073FF008CFF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF00\
80FF0073FF003FFF0000FFA633FF0000FF663FFF0059FF008CFF0099FF00A6FF00
A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00
B3FF0099FF0073FF0019FF0000FF338CFF008CFF0099FF008CFF0073FF0080FF008CFF008CFF00\
8CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF0059FF004CFF0019FF00
00FF0000FF4000FF7300FF3300FF0C00FF0000FF0C00FF1900FF7300FF2600FF4000FFB300FF73\
00FF8000FFA600FFB300FF6600FFA600FF4C00FF3300FF2600FF3300FF8000FF00
0CFF0000FF0C00FF3300FF4C00FF003FFF0059FF0066FF0073FF0073FF0073FF0073FF0073FF00\
66FF0059FF0000FF0066FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF00\
80FF0073FF004CFF0026FF0059FF0066FF0073FF0080FF008CFF0099FF00A6FF00
B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00
B3FF00A6FF0099FF008CFF0073FF0059FF0073FF0080FF0080FF0059FF0066FF0080FF0080FF00\
80FF0080FF0080FF0080FF0073FF0066FF0059FF0059FF0059FF004CFF003FFF00
26FF000CFF0000FF0000FF3300FF2600FF1900FF2600FF5900FF6600FF6600FF8000FFE600F3FF\
004CFF0019FF8000FF00F3FF00FF8C00FF7300FF7300FF4C00FFA600FF4000FF26
00FF2600FFE600FF0C0CFF0026FF003FFF0059FF0066FF0066FF0066FF0073FF0073FF0066FF00\
4CFF0000FF6633FF0066FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF00\
73FF0059FF0000FF0019FF0059FF0073FF0080FF008CFF0099FF0099FF00A6FF00
B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00B3FF00A6FF0099FF008CFF004CFF0000FF1966FF0066FF003FFF0059FF0073FF0080FF00\
80FF0080FF0080FF0073FF0073FF0059FF0000FF663FFF003FFF003FFF0033FF00
26FF0019FF0000FF0000FF1900FF9900FF3300FF3300FF593F00FF00FFD900B3FF00A6FF0099FF\
0000000000000033FF00FFF300FFCC00FFB300FF9900FF8C00FFA600FFD900FF73
00FF7300FF3300FF0019FF0033FF003FFF004CFF004CFF0059FF0066FF0066FF0066FF0059FF00\
4CFF0019FF0026FF0026FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF00
8CFF0073FF008CFF0099FF0099FF0099FF0099FF0099FF0099FF008CFF0073FF0073FF0073FF00\
73FF0059FF0026FF000CFF004CFF0073FF0080FF008CFF0099FF0099FF00A6FF00
A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00B3FF00B3FF00A6FF0099FF0080FF0019FF0000FF0C19FF0000FF404CFF0066FF0073FF00\
73FF0073FF0073FF0073FF0066FF0059FF003FFF0000FF0000FF1933FF0026FF00
26FF000CFF0000FF0C00FF4000FFE600FF5900FF7300FF9900FFD90059FF0000005900FFA600FF\
0000000000000C00FF00A6FF00E6FF00E6FF00FFF300FFE600FFF300000000FFD9
00FF8000FF4C00FF5900FF0026FF0033FF0033FF0019FF004CFF0059FF0059FF0059FF004CFF00\
00FF2600FF5919FF004CFF0066FF0066FF0066FF0073FF0080FF0080FF0080FF00
73FF0019FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0066FF0000FF1959FF00\
59FF004CFF0026FF003FFF0066FF0073FF0080FF008CFF0099FF0099FF00A6FF00
A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00CCFF00C0FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00B3FF00B3FF00A6FF0099FF0026FF0066FF0059FF004CFF0019FF0000FF334CFF0066FF00\
73FF0073FF0073FF0066FF0066FF0059FF003FFF0000FF0000FF3319FF0019FF00
00FF0000FF1900FF1900FF3300FF6600FFBF00FF8C00B3FF000000000000000000000000000000\
0000000000000000000000004C00FF3300FFC000FFD900FF0040FF0000000066FF
008CFF00E6FF00FF4C00FF0C19FF0019FF0000FF0026FF003FFF004CFF004CFF004CFF003FFF00\
26FF0000FF6633FF004CFF0059FF0059FF0000FF0066FF0073FF0073FF0073FF00
66FF0033FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0066FF0033FF0000FFCC\
26FF0000FF8C00FF6633FF0066FF0073FF0080FF008CFF008CFF0099FF0099FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF0099FF00A6FF0000FF19CCFF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
D9FF00CCFF000CFF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00B3FF00B3FF00A6FF00A6FF008CFF0080FF0073FF0059FF0000FF4C26FF004CFF0059FF00\
66FF0066FF0066FF0066FF0059FF003FFF0026FF0000FF0000FF190CFF0000FF00
00FF1900FFCC00FF3300FF5900FF8C00F3FF00FFE60066FF000000000000000000000000000000\
0000000000000000000000000000008000FF0000000000000000000000008C00FF
2600FF0080FF00FF5900FF5900FF0000FF0000FFA619FF0033FF0026FF0033FF0033FF0026FF00\
00FF3300FF660CFF0000FF1933FF0026FF0033FF0059FF0066FF0066FF0066FF00
4CFF0000FF4C4CFF0066FF004CFF0066FF0066FF0073FF0059FF004CFF003FFF0000FF0C3FFF00\
19FF0033FF0033FF0000FF594CFF0066FF0073FF0080FF0080FF0080FF008CFF00
8CFF00A6FF00A6FF00A6FF00B3FF00B3FF00A6FF00A6FF0080FF003FFF00B3FF00C0FF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
D9FF00CCFF0080FF0073FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0073FF0033FF0000FF8019FF003FFF0059FF00\
59FF0059FF0059FF0059FF004CFF0026FF0000FF0000FF3300FF8C00FF1900FF19
00FF3300FFB300FF6600D9FF00FFA600FFF300CCFF000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000000000000033FF
00F3FF00FFA600FF7300FFA600FFCC00FF6600FF7300FF260CFF0000FF0000FF2600FF7300FF19\
19FF0026FF000CFF00008CFF00FF4000FFCC26FF003FFF0059FF0059FF0000FF00
19FF0019FF000CFF0033FF0000FF0C00FF9900FF5919FF0019FF0000FF0000FF404CFF0059FF00\
59FF0059FF0066FF0059FF0000FF4C4CFF0059FF0066FF0066FF0059FF000CFF00
80FF0099FF00A6FF00A6FF00A6FF00A6FF0099FF0059FF0059FF0080FF00B3FF00C0FF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00C0FF0099FF0080FF0099FF0059FF00C0FF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0066FF004CFF0000FF8026FF004CFF00\
4CFF0059FF0059FF004CFF004CFF0033FF0026FF000CFF0000FF1900FFA600FF33
00FF4C00FFBF00FFA600E6FF00CCFF008CFF3F00FF000000000000000000000000000000000000\
00000000000000000000000000000000000000000000000000000000000000BFFF
00FFD900FFBF00FF4C00FF3300FF2600FF0C00FF0C00FF1900FFBF00FF0C19FF0033FF0033FF00\
3FFF003FFF0033FF0019FF0033FF0026FF0000FFCC33FF003FFF0033FF0000FF26
19FF004CFF004CFF0000FF0059FF0066FF0073FF0073FF0000FF0066FF003FFF0066FF0073FF00\
73FF0073FF0073FF0073FF0059FF000099FF26FF004CFF004CFF0000CCFF4CFF00
80FF008CFF0099FF0099FF0099FF0099FF008CFF004CFF0080FF00A6FF00B3FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00C0FF00A6FF0073FF0000FF0099FF00B3FF00C0FF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00A6FF0099FF0099FF008CFF0080FF0066FF004CFF0026FF000CFF0033FF00\
3FFF004CFF003FFF003FFF003FFF0033FF0026FF000CFF0000FF9900FF9900FF66
00FFFF00FFFF0033FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000CFF
00FFB300FF8000FF4000FF2600FF0C00FF000CFF000CFF000CFF0000FF0033FF003FFF004CFF00\
4CFF004CFF004CFF004CFF004CFF0033FF0000FF3300FF000CFF0000FF0C33FF00
19FF0066FF0066FF0059FF0066FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0080FF00\
80FF0080FF0080FF0080FF0073FF004CFF0000FF6626FF0000FF4000FF8C33FF00
33FF0080FF008CFF008CFF0080FF0066FF000CFF0073FF0099FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00CCFF00B3FF00A6FF0026FF008CFF00A6FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0073FF004CFF0033FF000CFF0000FF0C00FF73\
19FF0033FF0026FF0019FF0033FF0026FF000CFF0000FF0C00FF2600FF4C00FFF3
00A6FF000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000008C00FF008CFF008CFF
00FFB300FFCC00FF4000FF3300FF0C0CFF0019FF0026FF0026FF0026FF003FFF004CFF004CFF00\
59FF0059FF0059FF0059FF0059FF004CFF0000FF1933FF0019FF0000FF0C59FF00
66FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF0080FF0033FF0033FF0000FF4000FF2619FF0026FF00
3FFF0066FF0073FF0073FF0066FF0000FF0080FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
C0FF00C0FF0099FF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00B3FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
CCFF00CCFF00C0FF0026FF0080FF0000FFA680FF00B3FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00A6FF0099FF0073FF0073FF0059FF0059FF003FFF0000FF0019FF0033FF0033FF00\
26FF0000FF3300FF0C00FF0019FF0019FF000CFF0000FF4C00FF4000A6FF00FFE6
0080FF000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000FF00A6FF00FFD9
00FFB300FFCC00FFA600FF4C00FF0C0CFF0026FF0026FF0033FF003FFF004CFF004CFF0059FF00\
59FF0066FF0066FF0066FF0066FF0059FF003FFF004CFF0019FF0000FF5959FF00
73FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF008CFF0080FF0073FF0059FF0026FF0033FF004CFF004CFF00
33FF0000FF264CFF004CFF0000FF0C33FF0073FF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
B3FF0033FF008CFF00CCFF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00C0FF00C0FF00D9FF00E6FF00E6FF00E6FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00C0FF00B3FF0099FF0000FF008CFF00B3FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00A6FF008CFF0033FF0033FF000CFF003FFF004CFF004CFF003FFF004CFF0059FF004CFF00\
3FFF000CFF000CFF0000FF4000FF000CFF0000FF0C00FF4C0066FF00FFD900A6FF
000CFF000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000000066FF0073FF
00FF9900FF7300FF5900FFA600FF4C00FF0026FF0033FF003FFF003FFF004CFF0059FF0059FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0026FF004CFF00
73FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF0080FF0059FF0026FF0000FF0066FF0073FF00
66FF0066FF0033FF0000FF264CFF0073FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
A6FF004CFF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF0080FF00C0FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00C0FF00B3FF00A6FF0080FF008CFF00A6FF00B3FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00A6FF00A6FF008CFF0066FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF00\
4CFF003FFF0019FF0000FF4000FF2600FF1900FF2600FF4C00FFB36600FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000001900FF00FFFF
00FFB300FF7300FF4000FF2600FF0C0CFF0026FF0033FF0033FF003FFF004CFF0059FF0066FF00\
66FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0059FF0019FF00
59FF0080FF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF0099FF008CFF0000FF0073FF0073FF0080FF0080FF00
80FF0073FF0066FF0033FF0033FF0066FF0080FF0099FF00A6FF00A6FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00
73FF0080FF00B3FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF00A6FF00B3FF00CCFF00D9FF00D9FF00\
D9FF00D9FF00CCFF0066FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00C0FF00B3FF00A6FF0073FF0080FF00A6FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00A6FF00A6FF0099FF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF0066FF00\
59FF003FFF0026FF0000FFBF00FF1900FF4C00FF8000FF6600F3FF0000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000008CFF
00FFB300FF8000FF3300FF1900FF000CFF0019FF0026FF0033FF003FFF004CFF0059FF0066FF00\
66FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0073FF0066FF00
59FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00
80FF0080FF0073FF0000FF0C0CFF0059FF0073FF0066FF0000FF0CA6FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF00
33FF0080FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00B3FF0073FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00C0FF0019FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00B3FF0099FF0066FF0066FF008CFF0099FF00B3FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00A6FF00A6FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF00\
59FF000CFF000CFF0019FF000CFF0000FF0C00FFBF00FF6600FFA600E6FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000000000000040FF
00FFB300FFCC00FF4C00FF4000FF260CFF000CFF0019FF0019FF0000FF0000FF0C59FF0066FF00\
66FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF00
8CFF0080FF0073FF0066FF004CFF0000FF0C3FFF0066FF008CFF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00B3FF00B3FF00A6FF0066FF00
99FF00B3FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF0066FF0099FF00A6FF00A6FF00\
C0FF00C0FF00B3FF0000FF66B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00B3FF00B3FF0099FF0073FF0000FF0066FF0073FF00A6FF00A6FF00
B3FF00B3FF00B3FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0066FF00\
59FF004CFF003FFF0033FF0019FF0000FF0000FF2600FF4C00FF9900FFD90066FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000A600FF008CFF00FFF3
00FFB300FFB300FF8000FF6600FF2600FF0C00FF0000FF1900FF0C26FF004CFF0059FF0066FF00\
73FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
8CFF008CFF0080FF0066FF003FFF000CFF0066FF0080FF0099FF0099FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00A6FF008CFF00A6FF00B3FF00B3FF00A6FF00A6FF0080FF0066FF00
A6FF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
E6FF00D9FF00B3FF00C0FF00CCFF00CCFF00C0FF00B3FF00A6FF0033FF0000FFBF3FFF0080FF00\
A6FF008CFF008CFF000CFF0080FF00A6FF00A6FF00B3FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF0066FF0080FF00C0FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00B3FF00B3FF00A6FF0099FF0080FF004CFF0059FF008CFF0099FF00A6FF00
A6FF00A6FF0000FF6659FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0066FF00\
59FF004CFF003FFF0033FF0019FF0000FF2600FF4000FF4C00FFA60033FF0066FF
D900FF000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000005900FF00B3FF0099FF
00FF8C00FF7300FF5900FF7300FF7300FF5900FF5900FF400CFF0033FF004CFF0059FF0066FF00\
73FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF008CFF0073FF0059FF0000FF993FFF0066FF0080FF008CFF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF0099FF0033FF008CFF0099FF0099FF0099FF008CFF0066FF0019FF00
8CFF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
C0FF00C0FF00B3FF00A6FF00C0FF00C0FF0099FF0080FF000CFF0099FF0099FF008CFF004CFF00\
80FF003FFF003FFF008CFF0059FF0073FF0000FF0C80FF0099FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF0099FF0059FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00A6FF00A6FF0099FF0066FF0000FFB366FF0080FF008CFF0099FF00
99FF008CFF0066FF0059FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0066FF00\
59FF003FFF0033FF0026FF0019FF0000FF0C00FF7300FF8000FF9900FFFF0059FF
6600FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000A600FF0059FF00E6FF00BFFF
00FF9900FF7300FF4C00FF4000FF8C00FF1900FF1900FF5900FF5919FF0026FF004CFF0059FF00\
66FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
99FF008CFF0066FF0059FF0000FF334CFF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF004CFF0019FF0059FF004CFF0080FF008CFF0073FF0000FF3373FF00
99FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
3FFF008CFF0026FF0059FF0099FF00A6FF0073FF0066FF0033FF00B3FF00B3FF00A6FF0099FF00\
00FF1999FF00A6FF00B3FF00A6FF008CFF00A6FF0080FF0080FF0099FF00A6FF00
73FF00A6FF00B3FF00A6FF008CFF0080FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF0000FF0C\
A6FF00A6FF0099FF0099FF008CFF0066FF0026FF0059FF0066FF0059FF0080FF00
8CFF0080FF0000FF268CFF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0033FF00\
19FF0019FF0000FF0C0CFF000CFF0000FF0C00FF3300FF8000CCFF00A6FFE600FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000003300FF0099FF00F3FF00D9FF
00B3FF00FF7300FF4000FF2600FF1900FF0000FF0000FF0000FF8000FF6600FF9933FF0000FF19\
66FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
99FF0099FF0080FF0066FF0033FF003FFF0066FF0073FF0073FF0080FF008CFF0099FF0099FF00\
8CFF008CFF0073FF004CFF0000FF0C33FF0019FF003FFF0000FF404CFF004CFF00
73FF008CFF0026FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
CCFF0099FF00C0FF00A6FF0073FF000CFF0099FF00B3FF0073FF00C0FF00CCFF00C0FF00B3FF00\
59FF00B3FF00C0FF00C0FF00C0FF00B3FF00C0FF00C0FF00B3FF0099FF0000FF00
3FFF008CFF008CFF0080FF0073FF0066FF0080FF0099FF00A6FF00B3FF00A6FF0099FF003FFF00\
80FF0080FF0080FF0066FF0066FF0026FF000CFF003FFF0000FF0033FF0066FF00
66FF0000FF8C73FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0059FF00\
4CFF0019FF0000FF1900FF2600FF0C00FF2600FF4000FF9900FFF3004CFF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000A600FF5900FF0099FF00F3FF00FFCC
00FF9900FF6600FF4000FF2600FF0C00FF000CFF0019FF0019FF0000FF0033FF003FFF004CFF00\
66FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF0099FF0080FF0033FF0000FF3326FF0026FF003FFF0019FF0073FF0080FF0080FF0080FF00\
80FF0066FF0066FF0026FF0000FF0066FF0066FF0080FF008CFF0080FF0000FF26
19FF000CFF0099FF00B3FF00B3FF00C0FF00B3FF0059FF00CCFF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00D9FF00D9FF00CCFF00B3FF0000FF4CB3FF00CCFF00CCFF00D9FF00D9FF00CCFF00C0FF00\
4CFF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00A6FF00
66FF0000FF003FFF0000FF2680FF0059FF004CFF008CFF0099FF00A6FF0099FF0080FF000CFF00\
59FF0059FF0000FF2600FF4C66FF0073FF0080FF0073FF003FFF0026FF000CFF00
19FF003FFF0073FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0066FF00\
59FF003FFF0019FF0000FF8C00FF2600FF6600FF6600FFD90000006600FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000008000FF004CFF0066FF00F3FF
00FF9900FF9900FF4C00FF6600FFD90CFF0019FF0026FF0033FF0033FF004CFF0059FF0066FF00\
73FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF008CFF0080FF0026FF0059FF0073FF003FFF0000FFA619FF004CFF0066FF0033FF0066FF00\
3FFF0019FF0033FF0000FF0C3FFF0073FF008CFF0099FF0099FF0099FF008CFF00
73FF0000FF408CFF00A6FF00A6FF00A6FF0099FF00A6FF00CCFF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00D9FF00CCFF0026FF00C0FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
8CFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00
B3FF0000FF0099FF0099FF0099FF0066FF003FFF0073FF008CFF008CFF008CFF0073FF0000FF19\
00FF4000FF0C4CFF0073FF008CFF008CFF008CFF008CFF0073FF0073FF0066FF00
3FFF0033FF0073FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF00\
59FF0033FF0000FF400CFF000CFF0000FF4C00FF4C00FFA60040FF000000000000
000000000000000000C000FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000CC00FF1900FF0073FF
00FFE600000000FFD900FFB300FF3300FF0019FF0033FF0033FF003FFF004CFF0059FF0066FF00\
73FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
A6FF008CFF0000FF8C73FF0080FF008CFF0073FF0059FF0059FF003FFF0000FF6626FF0073FF00\
73FF0073FF0033FF0066FF000CFF0073FF0099FF00A6FF00A6FF00A6FF0099FF00
73FF003FFF0073FF0080FF000CFF0080FF0019FF00A6FF00C0FF00CCFF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
FFFF00F3FF00F3FF00E6FF00CCFF003FFF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00
B3FF0099FF00B3FF00B3FF00B3FF008CFF0059FF0026FF0059FF0059FF004CFF004CFF0026FF00\
66FF003FFF0059FF008CFF0099FF0099FF0099FF0099FF008CFF0080FF0073FF00
4CFF0000FF803FFF0080FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF0066FF00\
59FF003FFF0033FF0026FF0019FF0000FF0C00FF3300FFA60073FF9900FF0059FF
8000FF0000000040FF0026FF000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000000000000080FF
00FFD900FF9900FF6600FF4C00FF6600FF0C19FF0026FF0033FF003FFF004CFF0059FF0066FF00\
73FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
A6FF0073FF0073FF008CFF0099FF0099FF008CFF0080FF0073FF0059FF0000FF1973FF008CFF00\
99FF0099FF008CFF0099FF0066FF0099FF00A6FF00B3FF00B3FF00B3FF0099FF00
73FF0066FF000CFF0000FF0019FF0073FF0000FF3373FF00A6FF00B3FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
FFFF00FFFF00F3FF00F3FF00D9FF0033FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
C0FF00C0FF00CCFF00C0FF00C0FF0000FF7399FF008CFF0059FF0059FF008CFF008CFF004CFF00\
8CFF0033FF008CFF0099FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0073FF00
00FF8C33FF0066FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF008CFF0073FF0066FF0073FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF00\
59FF004CFF003FFF0033FF0026FF0000FF0C00FF8000CCFF00000000D9FF00FFE6
00FFFF00CCFF00F3FF004CFF1900FF000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000000000006600FF
00BFFF00FFD900FF8C00FF3300FF1900FF0019FF0026FF0033FF0033FF003FFF0059FF0066FF00\
73FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
A6FF0000FF1980FF00A6FF00A6FF00A6FF0099FF008CFF0080FF004CFF000CFF0000FF0099FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00B3FF00B3FF00
A6FF003FFF0066FF008CFF0066FF0099FF0073FF0059FF0059FF00A6FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00CCFF008CFF00C0FF00D9FF00D9FF00D9FF00
FFFF00FFFF00FFFF00F3FF00E6FF00CCFF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF008CFF0000FF1973FF0099FF00A6FF00A6FF00\
A6FF003FFF00A6FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0066FF00
26FF004CFF0066FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF008CFF0073FF0033FF004CFF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00\
59FF004CFF003FFF0033FF0026FF000CFF0000FF1900FF4C00FFBF00FFA600FF8C
00FFA600FFBF00FFBF00FFD900D9FFC000FF0000001900FFB300FF0000003F00FF0C00FF7300FF\
000000000000000000000000000000000000000000000000000000000000000000
3F00FF004CFF00FF8C00FF4C00FF4000FF0C0CFF0019FF0019FF0000FF6633FF0059FF0066FF00\
66FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF00
A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00A6FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0073FF0019FF0066FF008CFF0099FF00\
A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF008CFF008CFF00A6FF00B3FF00B3FF0099FF008CFF008CFF0059FF00A6FF00B3FF00C0FF00\
C0FF0066FF00C0FF00CCFF00CCFF00C0FF008CFF00B3FF00CCFF00D9FF00D9FF00
FFF300FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF0059FF008CFF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0073FF0059FF00
66FF0000FF4019FF0073FF0080FF0080FF008CFF0080FF0080FF003FFF008CFF0099FF0099FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00
8CFF008CFF0080FF0066FF0000FF0C59FF0066FF0059FF0066FF0066FF0066FF0066FF0059FF00\
59FF004CFF0033FF0026FF0019FF000CFF0000FF1900FFA600FF5900FF4C00FF59
00FFB300FF9900FF8000FFBF00FFF30059FF0033FF008CFF00B3FF0080FF008CFF0073FF0C00FF\
0000000000000000000000000000000000000000000000000000000000002600FF
1900FF00FFFF00FF9900FFA600FF5900FF1900FF0C00FF1900FF1926FF003FFF004CFF0059FF00\
66FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF0099FF00
A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF008CFF0073FF0066FF000CFF0080FF0099FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00C0FF00
B3FF0080FF0099FF00B3FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF0066FF0073FF0099FF00\
A6FF0066FF00B3FF00C0FF00B3FF00B3FF0073FF00A6FF00C0FF00CCFF00CCFF00
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF0073FF00A6FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF00
80FF004CFF000CFF0059FF0073FF0073FF0073FF0033FF0059FF0059FF0080FF008CFF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00
8CFF0080FF0073FF0066FF0019FF000CFF003FFF0000FF0C4CFF0059FF0059FF0059FF004CFF00\
4CFF003FFF0026FF0000FF7300FF1900FF1900FFE600FF0C00FF4000FF1900FF73
00FFB300FF4000FF7300FF7300FF8000FFB300FFCC00FFE600F3FF00FFF300FFF30099FF0019FF\
0000000000000000000000000000000000000000000000000000000000000059FF
00F3FF00F3FF00FF8000FF4C00FF8000FF4C00FF8C00FF8C00FF0C26FF003FFF004CFF0059FF00\
59FF0066FF0066FF0059FF0066FF0066FF0066FF0000FF0C66FF0059FF008CFF00
A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0080FF0019FF0080FF00A6FF00\
B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00A6FF00A6FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00A6FF0073FF0059FF00\
0CFF003FFF0099FF00A6FF0073FF008CFF0000FF5999FF00A6FF00C0FF00C0FF00
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00B3FF0066FF0099FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF00
80FF0059FF000CFF0000FF4C3FFF003FFF0059FF003FFF0026FF0059FF0073FF0080FF008CFF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0073FF0066FF0059FF003FFF0000FF7300FF7300FF003FFF004CFF004CFF004CFF004CFF00\
3FFF0033FF000CFF0000FF4C00FF0C00FF0C00FF400CFF000CFF0000FF0C00FF19
00FF6600FF2600FF3300FF4C00FF6600FF8C00FF8000FF9900FFE600FFA600FFE600FFF300A6FF\
8000FF0000000000000000000000000000000000000000000000000C00FF00A6FF
00B3FF00FF9900FF9900FF3300FF2600FF1900FF0C00FF1900FF8C0CFF0026FF0033FF004CFF00\
4CFF004CFF004CFF003FFF0000FF0C33FF0000FF2626FF0000FF1973FF0080FF00
99FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF008CFF0000FF1999FF00B3FF00\
B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00CCFF00
CCFF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF0099FF00\
99FF003FFF004CFF0080FF0000FF4C66FF0073FF0033FF008CFF00B3FF00B3FF00
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00A6FF004CFF00A6FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF00
59FF0000FF190CFF0066FF0066FF003FFF000CFF0000FFB300FF004CFF004CFF0073FF0080FF00\
8CFF008CFF008CFF008CFF0073FF0080FF0080FF0080FF0080FF0080FF0066FF00
4CFF0066FF0059FF000CFF0000FF333FFF0033FF0000FF3319FF0026FF0000FF2633FF0033FF00\
00FF0C00FF0C19FF0019FF0033FF0026FF0000FF1926FF0026FF0019FF000CFF00
00FF0000FF0C00FF3300FF6600FFA600FF5900FF4000FF7300FFB300FF8000FF9900FFD900A6FF\
004CFF3F00FF000000000000000000000000000000000000000000F300FF0073FF
00FFCC00FF8C00FF4C00FF3300FF1900FF000CFF0000FF0000FF3300FF2600FF800CFF0033FF00\
3FFF0033FF000CFF000CFF003FFF0066FF0073FF0073FF0080FF008CFF0099FF00
A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF0066FF0099FF00B3FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00\
B3FF0099FF004CFF008CFF0080FF0099FF0099FF0019FF0080FF008CFF0099FF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00A6FF0080FF00B3FF00CCFF00CCFF00CCFF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF00
59FF003FFF0080FF0080FF0080FF0066FF004CFF0019FF0000FF5900FF1919FF0066FF0073FF00\
80FF0080FF0080FF0080FF0059FF0066FF0066FF0066FF0073FF0059FF0059FF00
00FF3333FF003FFF0000FFD926FF0059FF004CFF0033FF0000F3FF00FF0000E6FF00FF3300FF33\
00FF4033FF003FFF004CFF004CFF0033FF000CFF0033FF0033FF0026FF0019FF00
0CFF0000FF0C00FF2600FF5900FF3300FF4000FF2600FF3300FF4C00FF730066FF00FFCC00FFBF\
00D9FF0040FF000000000000000000C000FF0000000000000000000000FF000CFF
00E6FF00FFF300FF6600FF7300FF4C0CFF0019FF0019FF000CFF0000FF1919FF0019FF0000FF40\
00FF2600FF000CFF0026FF000CFF0073FF0080FF008CFF0099FF0099FF00A6FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF008CFF0026FF0099FF00B3FF00\
C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00B3FF0059FF00B3FF00B3FF00B3FF00B3FF0073FF0073FF003FFF000CFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00CCFF0099FF0099FF00C0FF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF0099FF0066FF00
73FF008CFF008CFF0099FF008CFF008CFF0073FF0033FF0026FF003FFF000CFF0000FF4C66FF00\
73FF0073FF0066FF0066FF004CFF0000FF0C26FF0000FF1933FF0000FF6600FF33
4CFF000CFF0000FF8C4CFF0066FF0066FF0066FF004CFF0033FF004CFF003FFF0026FF0000FFB3\
33FF004CFF0059FF0059FF0059FF004CFF003FFF004CFF003FFF0033FF0019FF00
00FF0000FF0C00FF8C00FF1900FF0C00FF1900FF0C00FF3300FF5900FFE600FF6600FF7300FF8C\
00FFD90059FF000000004CFF1900FF004CFF000000B300FF000000F300FF00BFFF
00FFD900FF8C00FF6600FFCC00FF190CFF0026FF0026FF0026FF0000FF003FFF003FFF0033FF00\
26FF000CFF0026FF004CFF0066FF0073FF008CFF008CFF0099FF00A6FF00A6FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF008CFF004CFF008CFF00A6FF00\
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00C0FF0066FF00C0FF00CCFF00CCFF00C0FF008CFF00A6FF008CFF0059FF00
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00CCFF00B3FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF0073FF0059FF00
99FF0099FF00A6FF00A6FF0099FF0099FF0066FF0059FF000CFF0066FF0059FF004CFF0026FF00\
26FF004CFF0019FF004CFF0000FF264CFF004CFF0066FF0073FF0073FF0026FF00
73FF0066FF003FFF0066FF0073FF0080FF0073FF0059FF0059FF0066FF0059FF0026FF0000FF40\
0CFF0059FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF0000FF0C00FF19
00FF3300FF6600FF3300FF000CFF000CFF0000FF0000FF4000FF4C00FF8C00FF4000FF4C00FF8C\
00FFA60099FF008CFF00F3FF00F3FF00D9FF0066FF008CFF0026FFC000FF0080FF
00FFCC00FF8C00FF4C00FF3300FF190CFF0026FF0033FF003FFF003FFF004CFF004CFF004CFF00\
3FFF0026FF0000FF663FFF0059FF0073FF008CFF0099FF0099FF00A6FF00A6FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF0099FF0073FF0019FF0099FF00\
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00CCFF00A6FF00CCFF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF0000FF00
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF0019FF008CFF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF008CFF0080FF0080FF0073FF0073FF000CFF00\
00FF1900FF1926FF0000FF2626FF0066FF0073FF0080FF008CFF008CFF008CFF00
8CFF0080FF004CFF0066FF0080FF008CFF0080FF0080FF0073FF0073FF0059FF0026FF0000FF26\
4CFF0059FF0066FF0073FF0073FF0066FF0066FF0059FF004CFF0033FF0000FF73
0CFF000CFF0000FFB30CFF0019FF0019FF000CFF0000FF0C00FF0C00FF5900FF2600FF3300FF4C\
00FF7300FFCC00FFB300FF9900FFA600BFFF00FFCC00E6FF00A6FF0C00FF0000FF
00FFFF00FFA600FF5900FF2600FF0019FF0026FF0033FF003FFF004CFF0059FF0059FF0059FF00\
4CFF003FFF0026FF0000FF0C19FF0066FF0080FF008CFF0099FF00A6FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF0059FF0073FF00A6FF00\
B3FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF0073FF00
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF0080FF0080FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0073FF0066FF00\
3FFF003FFF0059FF0059FF004CFF0059FF0080FF008CFF008CFF0099FF0099FF00
99FF008CFF0080FF0080FF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0059FF0000FF33\
00FF9966FF0073FF0073FF0073FF0073FF0073FF0066FF004CFF0019FF0026FF00
3FFF0033FF0000FF2626FF0026FF0026FF0026FF0019FF000CFF0000FF0000FF0C00FF2600FF4C\
00FFD900FF4C00FF7300FF6600FFBF00FFB300FF8000FFB300CCFF0099FFA600FF
0073FF00FFB300FF6600FFBF00FF0C0CFF0026FF0033FF004CFF0059FF0059FF0066FF0066FF00\
59FF004CFF003FFF0000FF194CFF0066FF0080FF008CFF0099FF00A6FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF0026FF003FFF0073FF00\
99FF00C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00C0FF000CFF00
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF008CFF0073FF0066FF00\
00FF993FFF0066FF0073FF0080FF0080FF008CFF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF0080FF0073FF004CFF004CFF00\
66FF0073FF0080FF0080FF0080FF0080FF0073FF0066FF0000FF404CFF0059FF00
4CFF003FFF000CFF0033FF0033FF0033FF0026FF0026FF0019FF000CFF0000FF0C00FF3300FF59\
00FF4000FF2600FF2600FF4C00FFA600FF4C00FF5900FF8C00FF8C00FFFF0019FF
F300FF00D9FF00FF7300FF6600FF8C00FF1900FF4000FF0C19FF0059FF0066FF0066FF0066FF00\
66FF0059FF0033FF0000FF003FFF0059FF0066FF0066FF008CFF00A6FF00A6FF00
B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF0080FF00A6FF00A6FF0059FF00\
A6FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00CCFF0000FF00
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0073FF0059FF00\
00FF3326FF0073FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0073FF000CFF0066FF00\
73FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0066FF00
59FF004CFF004CFF004CFF003FFF003FFF0033FF0026FF0019FF0000FF0000FF0C00FF4C00FF19\
00FF0C00FF0C00FF1900FF6600FF4C00FF3300FF3300FF4C00FF7300FFF30073FF
00B3FF00D9FF00FFB300FF2600FF0C00FF260CFF003FFF0059FF0066FF0073FF0073FF0073FF00\
73FF0066FF004CFF0033FF0000FF0C00FF8C19FF0066FF008CFF0099FF00A6FF00
B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF008CFF00\
B3FF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00D9FF00CCFF00
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0080FF0073FF0059FF00\
19FF0059FF0073FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0066FF0000FF4066FF00\
80FF0080FF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0073FF00
66FF0066FF0059FF004CFF004CFF003FFF0033FF0019FF0000FF0000FF0C00FF3300FF4C00FF00\
0CFF0019FF0000FF0000FF0000FF0C00FF0C00FF2600FF4C00FF9900FF4C00FFD9
00FFA60000FF00FFF300FF330CFF000CFF0000FF1933FF0059FF0066FF0073FF0073FF0080FF00\
80FF0073FF0066FF003FFF0059FF0059FF004CFF003FFF0080FF0099FF00A6FF00
B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00B3FF00\
B3FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0080FF0000FF193FFF0033FF00\
0CFF0033FF0073FF0080FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF0059FF004CFF0080FF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0073FF00
66FF0066FF0059FF0059FF004CFF003FFF0000FF0C00FF1900FF6600FF9900FF2600FF7300FF00\
19FF0026FF0026FF0019FF000CFF0000FF0000FF1900FFF300FF3300FF2600FF33
00D9FF00FF8C00FF4C00FF0026FF0033FF0033FF0000FF0C59FF0073FF0080FF0080FF0080FF00\
80FF0080FF0073FF0026FF0073FF0080FF0073FF0066FF0059FF0080FF0099FF00
A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
80FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF008CFF0073FF0059FF0026FF0033FF00\
59FF0066FF000059FF19FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0033FF003FFF0080FF00\
8CFF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0080FF0073FF00
73FF0066FF0066FF0059FF004CFF003FFF0026FF000CFF0000FF190CFF0019FF0019FF000CFF00\
26FF0033FF0033FF0026FF0019FF0000FF0000FF1900FF1900FF000CFF0000FF26
00FF1900FF1900FF7319FF0033FF004CFF0059FF0059FF0066FF0073FF0080FF0080FF008CFF00\
8CFF008CFF0080FF0066FF0080FF008CFF008CFF008CFF0073FF0000FF5973FF00
66FF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00C0FF00B3FF008CFF0066FF0059FF000CFF0019FF004CFF0066FF00\
80FF0080FF0080FF0080FF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF0066FF008CFF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF00
73FF0066FF0066FF0059FF004CFF003FFF0026FF0000FF0C00FF0C33FF0033FF0033FF0000FF26\
33FF003FFF003FFF0026FF000CFF0000FF1900FF4C00FF5919FF0026FF0019FF00
19FF000CFF0000FF3300FFB300FFB34CFF0066FF0066FF0073FF0080FF0080FF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF0066FF00
33FF0099FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00C0FF00B3FF008CFF008CFF0080FF0073FF003FFF0066FF0080FF00\
8CFF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF00
73FF0066FF0059FF0059FF004CFF003FFF0026FF0000FF4033FF003FFF004CFF004CFF0019FF00\
4CFF004CFF004CFF0000FF0000FF2600FF0C0CFF0000FF2626FF0033FF0033FF00
26FF000CFF0000FF6626FF003FFF0059FF0066FF0073FF0080FF0080FF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
A6FF0099FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF0080FF0000FF263FFF0073FF00\
8CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0073FF0073FF00
66FF0059FF0059FF004CFF003FFF000CFF0000FF6633FF004CFF004CFF0059FF0059FF0059FF00\
59FF0059FF0059FF003FFF0000FF4C26FF003FFF0019FF0026FF003FFF003FFF00
33FF0000FF0C00FF2626FF004CFF0059FF0066FF0073FF0080FF0080FF008CFF008CFF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF0080FF000CFF0033FF0073FF00\
99FF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0080FF0073FF0059FF00
59FF0059FF004CFF003FFF0033FF0000FF2600FF333FFF004CFF0059FF0066FF0066FF0066FF00\
66FF0066FF0059FF003FFF0033FF004CFF004CFF004CFF004CFF004CFF004CFF00
3FFF0033FF0000FF0026FF004CFF0059FF0066FF0073FF0080FF0080FF008CFF008CFF0099FF00\
99FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF0080FF0066FF004CFF0080FF00\
99FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF0059FF0066FF0059FF004CFF00
26FF003FFF0033FF0000FF3300FF8C00FF0C00FF003FFF0059FF0066FF0066FF0066FF0073FF00\
73FF0073FF0066FF004CFF004CFF0066FF0066FF0066FF0059FF0059FF0059FF00
4CFF003FFF0026FF0026FF003FFF0059FF0066FF0066FF0073FF0080FF008CFF008CFF0099FF00\
99FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0080FF0059FF003FFF0026FF0059FF00\
8CFF0099FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF004CFF003FFF0000FF190CFF00
0CFF0000FF0000FF260CFF0033FF0026FF0000FF9933FF0059FF0066FF0073FF0073FF0073FF00\
73FF0073FF0073FF0066FF0066FF0073FF0066FF0066FF0066FF0066FF0059FF00
59FF004CFF0033FF0000FF6626FF0026FF004CFF003FFF0066FF0073FF0080FF008CFF0099FF00\
99FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF0080FF0033FF004CFF0080FF0080FF00\
33FF0080FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0066FF004CFF0026FF00
3FFF003FFF0000FF804CFF0059FF003FFF0000FF5933FF0059FF0066FF0073FF0073FF0080FF00\
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF00
59FF004CFF003FFF000CFF0000FFD900FF7319FF0000FF404CFF0066FF0073FF0080FF008CFF00\
99FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0099FF0066FF0059FF008CFF0099FF0099FF00\
8CFF0059FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF0080FF0073FF0000FF2600FF40
66FF0066FF0000FF0066FF0066FF003FFF003FFF0000FFCC4CFF0073FF0073FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0066FF00
59FF004CFF0033FF0000FF1926FF0033FF000CFF004CFF004CFF0000FF1900FF804CFF0073FF00\
99FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF0080FF0066FF0080FF0099FF00A6FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF0073FF0059FF0033FF0059FF00
73FF0080FF0073FF0080FF0080FF0073FF0066FF0000FF1966FF0073FF0080FF0080FF0080FF00\
8CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF00
59FF004CFF0026FF0000B3FF33FF0059FF0059FF0073FF0073FF0066FF0066FF0066FF0073FF00\
73FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
CCFF00CCFF00C0FF00B3FF0059FF008CFF003FFF0080FF0099FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0066FF0033FF004CFF0059FF00
80FF008CFF008CFF008CFF008CFF0080FF0066FF0026FF0066FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF00
59FF004CFF0033FF0000FF663FFF0059FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF00\
A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
CCFF00C0FF00B3FF00A6FF008CFF0026FF0073FF0099FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00A6FF008CFF003FFF0059FF0019FF0080FF0073FF00
8CFF0099FF0099FF0099FF008CFF008CFF003FFF0000FF0C66FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0059FF00
3FFF0033FF0019FF0000FF0C0CFF0059FF0073FF0080FF008CFF0099FF0099FF0099FF00A6FF00\
A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00
C0FF0059FF0099FF008CFF0073FF003FFF008CFF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00B3FF00A6FF008CFF0066FF0059FF008CFF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF008CFF0073FF0019FF0066FF0080FF008CFF008CFF0099FF00\
99FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0059FF00
33FF0000FF6600FF1933FF0059FF0059FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00
C0FF00A6FF0066FF0033FF0066FF0073FF0066FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00B3FF00A6FF0080FF004CFF0080FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0073FF0033FF0066FF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF0059FF00
3FFF004C00FF3FFF0059FF0066FF0073FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00
C0FF00A6FF008CFF0000FF0C8CFF0099FF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00B3FF00A6FF0019FF0026FF0099FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0000FF4080FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0059FF003FFF00
00FF2600FF593FFF0059FF0066FF0080FF0080FF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00CCFF00C0FF00C0FF00
A6FF0099FF0073FF004CFF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF0099FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF0099FF0099FF008CFF0080FF0019FF0000FF4C4CFF00
4CFF003FFF0000FF000CFF0066FF0073FF0080FF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00E6FF00E6FF0099FF00A6FF00A6FF00B3FF00A6FF00
66FF0000FF0066FF0073FF0099FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0073FF0000FF2666FF0066FF00
66FF0059FF0000FFE600FFBF4CFF0066FF0066FF0080FF0099FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF00A6FF0099FF0033FF0066FF00
00FF0C66FF0066FF0066FF008CFF00A6FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0080FF0080FF00
73FF0066FF0059FF0033FF0000FF193FFF004CFF0080FF0099FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00B3FF0099FF0073FF00
80FF0099FF0099FF00A6FF0080FF008CFF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF00
80FF0073FF0059FF0033FF0026FF0066FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF0059FF00
80FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF00
80FF0073FF004CFF0000FF4C4CFF0073FF008CFF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00E6FF00D9FF00D9FF00CCFF00C0FF0099FF0019FF00
26FF00A6FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF00
8CFF0073FF0059FF003FFF0026FF0000FF0C8CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00B3FF00A6FF0099FF0000FF80
99FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
8CFF0080FF0073FF004CFF0026FF0073FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00E6FF00D9FF00D9FF00C0FF008CFF0059FF0033FF0033FF00
A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
8CFF008CFF0080FF0066FF0026FF0073FF008CFF008CFF0099FF0099FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00E6FF00E6FF00D9FF00CCFF008CFF0073FF0099FF0080FF0099FF00
8CFF00B3FF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF008CFF0080FF0066FF0033FF0073FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00E6FF00B3FF00B3FF0066FF008CFF0099FF00B3FF00C0FF00C0FF00
8CFF00A6FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF008CFF0080FF0000FF4000FF004CFF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00D9FF00C0FF008CFF00C0FF00CCFF00CCFF00CCFF00D9FF00CCFF00
C0FF008CFF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF008CFF0080FF0066FF0000FF194CFF0073FF0080FF0080FF008CFF0099FF0099FF00A6FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
F3FF00E6FF00A6FF00A6FF0080FF00D9FF00D9FF00D9FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF008CFF0073FF004CFF0000FF7333FF0059FF0059FF0059FF008CFF008CFF0099FF0099FF00\
99FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00
99FF008CFF0073FF0066FF0059FF0000FF4C19FF0033FF0066FF0080FF008CFF008CFF008CFF00\
8CFF0059FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00
99FF008CFF0080FF0073FF0066FF004CFF0019FF0033FF0066FF0073FF0080FF0080FF0080FF00\
66FF0059FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00A6FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00
99FF008CFF008CFF0080FF0066FF003FFF0000FF403FFF0059FF0066FF0066FF0073FF0066FF00\
26FF0073FF008CFF0099FF0099FF0099FF0099FF0099FF008CFF0066FF00A6FF00
B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00
99FF008CFF008CFF0080FF0073FF004CFF000CFF0026FF004CFF003FFF0000FF0C4CFF003FFF00\
33FF0073FF0080FF008CFF008CFF0099FF008CFF008CFF0059FF0080FF00A6FF00
B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00
99FF008CFF008CFF0080FF0073FF0059FF0033FF0000FF0C00FF2600FF0C00FF330CFF0000FF40\
33FF004CFF0073FF0080FF0080FF0080FF0080FF0073FF004CFF008CFF00A6FF00
B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00
99FF008CFF008CFF0080FF0073FF0059FF0000FF4C3FFF0059FF004CFF003FFF0059FF004CFF00\
19FF004CFF0066FF0073FF0066FF0000FF263FFF003FFF004CFF0073FF0099FF00
A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF008CFF0080FF0073FF0066FF0033FF003FFF0066FF0066FF0073FF0066FF0066FF0059FF00\
19FF0033FF003FFF0059FF0026FF0000FF4C3FFF0066FF004CFF003FFF0080FF00
73FF0099FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF00
8CFF0080FF0073FF0066FF0033FF0026FF0066FF0073FF0073FF0080FF0080FF0080FF0073FF00\
33FF003FFF0026FF0000FF0C59FF0059FF0073FF0080FF0066FF000CFF0000FF66
00FF4C8CFF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF00
80FF0073FF0019FF0033FF0000FF0C3FFF0066FF0080FF0080FF008CFF008CFF008CFF0080FF00\
4CFF0073FF004CFF003FFF0073FF008CFF008CFF008CFF008CFF0000FF4080FF00
4CFF0000FFA68CFF0099FF0099FF00A6FF0073FF00A6FF00B3FF00B3FF00B3FF0066FF00A6FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00E6FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0080FF0073FF00
73FF0066FF004CFF0000FF733FFF0059FF0073FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF0073FF0026FF0080FF0099FF0099FF00A6FF0099FF0080FF0099FF00
99FF008CFF0033FF003FFF0080FF0080FF0059FF0099FF00A6FF00A6FF0099FF0059FF00A6FF00\
B3FF00C0FF00C0FF00CCFF00C0FF00C0FF0059FF00C0FF00D9FF00E6FF00E6FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0080FF0066FF00
19FF003FFF0026FF0000FFBF00FF0C59FF0073FF0080FF008CFF0099FF0099FF0099FF0099FF00\
99FF0099FF008CFF0000FF268CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00
A6FF00A6FF008CFF0000FF0C26FF0000FF264CFF008CFF008CFF008CFF0080FF0066FF0099FF00\
B3FF00B3FF00C0FF00C0FF00B3FF00A6FF0080FF00C0FF00D9FF00E6FF00E6FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF0080FF00
59FF0000FF4000FF1900FF7326FF0033FF0033FF0080FF0099FF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF0099FF0059FF0073FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF0080FF008CFF0080FF0000FF0C66FF0059FF0000FF0C19FF004CFF0059FF00\
A6FF00A6FF00A6FF00A6FF00A6FF000CFF00B3FF00CCFF00D9FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF00
00FF0033FF0019FF0000FF400CFF0000FF0066FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0073FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00A6FF00A6FF0099FF0080FF000CFF0073FF0073FF0080FF003FFF0073FF00\
8CFF0099FF0026FF004CFF0073FF0066FF00A6FF00C0FF00CCFF00D9FF00E6FF00
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF00
66FF0059FF0033FF0000FFCC3FFF0033FF0000FF5980FF0099FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF0099FF0080FF0099FF00A6FF0099FF0059FF0000FF19\
66FF0066FF0026FF0059FF008CFF0073FF0073FF00A6FF00B3FF00D9FF00D9FF00
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF00
73FF0059FF003FFF0000FF4C59FF0073FF0080FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF0080FF0099FF00B3FF00B3FF00A6FF0080FF008CFF00\
3FFF008CFF0099FF0099FF00A6FF008CFF0000FF0C26FF0099FF00CCFF00D9FF00
E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF00
73FF0059FF0000FF264CFF0066FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00B3FF00B3FF00C0FF00C0FF00C0FF00B3FF00A6FF00\
66FF0099FF00B3FF00C0FF00C0FF00B3FF0099FF00A6FF008CFF00B3FF00C0FF00
CCFF00E6FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF00
73FF0059FF0019FF0066FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF00\
0CFF00B3FF00C0FF00CCFF00CCFF00CCFF00C0FF00CCFF00C0FF0099FF0033FF00
99FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0000FF338CFF0099FF008CFF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF00
66FF003FFF004CFF0073FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00\
4CFF00B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF008CFF00
C0FF0080FF00D9FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0059FF0019FF0066FF00\
80FF008CFF008CFF008CFF008CFF0073FF0080FF0080FF0080FF0073FF0066FF00
59FF0026FF0033FF0073FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
B3FF00B3FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00E6FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF000CFF0073FF0026FF00\
33FF0073FF0080FF0080FF0073FF0033FF0066FF0073FF0073FF0066FF003FFF00
33FF0000FF1900FFCC00FF4C73FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF008CFF0080FF00\
66FF003FFF004CFF0066FF0066FF0033FF004CFF0059FF0059FF004CFF0000FF40
26FF004CFF003FFF0033FF004CFF0019FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF00\
80FF0033FF000CFF003FFF0000FF0C00FF9900FF2633FF003FFF0026FF0000FF00
4CFF0066FF0066FF0000FF004CFF003FFF0080FF0099FF00A6FF00A6FF00B3FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF00\
80FF0073FF003FFF0000FF330CFF003FFF003FFF0000FF4C0CFF0019FF0066FF00
73FF0080FF0080FF0059FF0080FF0073FF003FFF0073FF008CFF0099FF00A6FF00B3FF00C0FF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF00\
80FF0073FF004CFF0033FF0059FF0066FF0066FF0033FF0059FF0026FF0066FF00
80FF008CFF008CFF0099FF0099FF008CFF0073FF0033FF0000FF338CFF008CFF00A6FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF00\
73FF0000FF330CFF004CFF0066FF0073FF0073FF0080FF0073FF0066FF0000FF66
8CFF0099FF0099FF00A6FF00A6FF00A6FF0099FF0080FF004CFF0000FF4000FF26A6FF00C0FF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF00\
26FF0033FF0000FF004CFF0073FF0080FF0080FF008CFF008CFF0080FF0066FF00
8CFF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF008CFF0099FF0080FF0066FF00B3FF00\
CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF0080FF008CFF008CFF008CFF008CFF0080FF00\
3FFF000CFF0000FF263FFF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00
99FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF0033FF0080FF0080FF0080FF0073FF00\
59FF0026FF0033FF004CFF0073FF008CFF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00A6FF00A6FF00B3FF00B3FF00B3FF0099FF00
99FF00A6FF0099FF00A6FF0099FF0099FF008CFF0080FF0000FF264CFF0026FF0066FF0066FF00\
4CFF0000FF0059FF0073FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00CCFF00C0FF00B3FF0026FF0099FF0099FF0099FF008CFF00
66FF0080FF0000FF4080FF008CFF0073FF0073FF0059FF0000FF0C19FF0000FF0C3FFF0026FF00\
00FF0C59FF0073FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00C0FF00B3FF008CFF0000FF1966FF0073FF000CFF00
4CFF0000FF7359FF0066FF0000FF4C00FF4C26FF0000FF0C4CFF0066FF003FFF003FFF003FFF00\
0CFF004CFF0073FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00CCFF00C0FF00C0FF00B3FF00A6FF0080FF003FFF0066FF0000FF0066FF00
80FF0080FF008CFF0099FF008CFF0080FF0073FF0066FF0080FF0080FF003FFF0066FF0066FF00\
00FFBF19FF0066FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00\
CCFF00B3FF00B3FF00A6FF0066FF0080FF000CFF0073FF008CFF008CFF0073FF00
99FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF0073FF008CFF008CFF008CFF008CFF0080FF00\
73FF0033FF0066FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00\
99FF0073FF008CFF0000FF6680FF004CFF0080FF0099FF00A6FF00A6FF0073FF00
A6FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF00A6FF0099FF0099FF0099FF008CFF00\
80FF004CFF0059FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00\
CCFF00C0FF00C0FF00B3FF00B3FF0099FF008CFF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF00\
80FF0059FF003FFF0066FF0080FF008CFF0099FF0099FF00A6FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00C0FF00B3FF008CFF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF00\
8CFF0073FF0033FF004CFF0073FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00
B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF00\
8CFF0073FF0000FF404CFF0066FF0073FF0073FF0073FF0099FF00A6FF00B3FF00
B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF00\
26FF004CFF003FFF0026FF0026FF0059FF0033FF0073FF008CFF0099FF00A6FF00
B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF00\
8CFF0080FF0059FF0000FF2600FF3333FF0000FF5900FF0033FF0059FF0073FF00
B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00\
8CFF0073FF0059FF0033FF0000FF3300FF1933FF004CFF0033FF008CFF00A6FF00
B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF0099FF00\
80FF004CFF0019FF000CFF000CFF0000FF4C26FF0066FF0080FF0099FF00A6FF00
B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0066FF00\
73FF0033FF0059FF0000FF0C4CFF0026FF0000FF4C59FF0073FF0099FF00A6FF00
B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF00\
99FF0099FF0080FF0059FF0073FF0066FF004CFF0026FF0066FF008CFF00A6FF00
B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00\
A6FF00A6FF008CFF0080FF0080FF0073FF004CFF003FFF0080FF0099FF00A6FF00
A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00\
B3FF00A6FF00A6FF0099FF008CFF0080FF0066FF0026FF0073FF008CFF0099FF00
A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00A6FF0099FF0099FF008CFF0080FF004CFF0073FF008CFF0099FF00
99FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0059FF004CFF0073FF0080FF00
8CFF0099FF0080FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0066FF0000FF264CFF004CFF00
73FF0073FF0000FF008CFF0099FF00A6FF00A6FF00A6FF0099FF00B3FF00B3FF0080FF00C0FF00\
CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0073FF0026FF0033FF003FFF00
3FFF000CFF0059FF0000FF3373FF0080FF0080FF008CFF0073FF0099FF0099FF0066FF00B3FF00\
CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00A6FF00A6FF0099FF008CFF0073FF0000FF4C33FF0066FF0073FF00
66FF0066FF008CFF008CFF008CFF004CFF0000FF0C00FF0019FF0066FF0000FF5973FF0019FF00\
B3FF00C0FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00\
B3FF00A6FF00A6FF0099FF0099FF008CFF0066FF0000FF0C26FF0080FF008CFF00
8CFF0026FF0099FF00A6FF00A6FF00A6FF008CFF0099FF008CFF0059FF00A6FF00B3FF00B3FF00\
A6FF0099FF00C0FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00\
A6FF00A6FF0099FF008CFF008CFF0080FF0066FF0026FF0059FF0080FF0099FF00
99FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF008CFF00B3FF00C0FF00CCFF00\
CCFF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00\
A6FF008CFF0033FF0080FF0073FF0073FF0059FF0033FF0073FF008CFF0099FF00
A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00D9FF00\
D9FF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00\
99FF008CFF0066FF0033FF0033FF004CFF0000FF8000FF1966FF008CFF00A6FF00
B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF00\
99FF008CFF0073FF0026FF003FFF0026FF0059FF0066FF0059FF0066FF0099FF00
B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF003FFF0099FF0073FF008CFF008CFF00\
00FF0C73FF004CFF0000FF5966FF0073FF0059FF008CFF008CFF0080FF0066FF00
B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00CCFF00C0FF0099FF0080FF0059FF000CFF004CFF0000FF7333FF00\
00FF5926FF0000FF1959FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00
C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
FFD900FFD900FFD900FFD900FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF0080FF008CFF008CFF008CFF0080FF00\
73FF0059FF0026FF0066FF0080FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFD900FFD900FFD900FFD900FFD900\
FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900FFD900
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00B3FF00A6FF008CFF0000FF0000FF1926FF0000FF1900FF0C4CFF00
26FF004CFF004CFF0033FF0000FF5926FF0073FF0080FF008CFF0099FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0059FF00A6FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00B3FF00B3FF00C0FF00CCFF00D9FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00B3FF00B3FF0099FF008CFF008CFF0080FF0073FF0000FF0066FF00
66FF0066FF0059FF0000FF730CFF004CFF0073FF0080FF008CFF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF0059FF0080FF00\
8CFF0099FF008CFF00A6FF0099FF008CFF003FFF0099FF00CCFF00D9FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00B3FF00A6FF00A6FF0099FF0099FF0080FF0059FF0073FF00
80FF0073FF0066FF0033FF000CFF0019FF004CFF0066FF008CFF0099FF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF0080FF00A6FF00A6FF00A6FF0099FF008CFF0066FF0000FFA6\
00FF0026FF0066FF008CFF0080FF008CFF00B3FF00CCFF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF008CFF008CFF00
8CFF0080FF0066FF004CFF004CFF0033FF003FFF0073FF0080FF008CFF0099FF0099FF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF0099FF0059FF008CFF0099FF0099FF0080FF003FFF0019FF0080FF00\
66FF0059FF00A6FF00B3FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF0099FF00
8CFF008CFF0080FF0073FF0066FF0000FF7319FF0066FF0080FF008CFF008CFF008CFF0099FF00\
99FF0099FF0099FF0099FF008CFF0073FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF008CFF0073FF0066FF0073FF0080FF0073FF000CFF0033FF008CFF00\
99FF0099FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF00
99FF008CFF008CFF0080FF0073FF0066FF0033FF0066FF0073FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF0080FF0026FF008CFF0099FF0099FF0099FF0099FF00
99FF008CFF008CFF008CFF0080FF0066FF0000FF590CFF0059FF004CFF0066FF008CFF00A6FF00\
B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF008CFF008CFF0080FF0073FF003FFF0026FF0066FF0066FF0073FF0080FF0073FF00\
73FF0080FF0080FF0080FF0073FF0033FF0073FF0080FF0066FF008CFF008CFF00
8CFF0080FF004CFF0073FF0059FF0000FF0C66FF0000FF4C3FFF0059FF004CFF008CFF00A6FF00\
B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
99FF0099FF008CFF008CFF0080FF0073FF0059FF0000FF0C33FF003FFF0066FF0066FF0059FF00\
4CFF0073FF0073FF0066FF0059FF0000FF4C19FF0059FF000CFF0033FF0066FF00
00FF334CFF0033FF0026FF0000FF2666FF0080FF0080FF0066FF008CFF0073FF0080FF00A6FF00\
B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF008CFF0080FF0080FF0059FF004CFF0019FF0026FF004CFF004CFF0033FF00\
33FF0059FF0066FF000CFF0000FFFF4CFF004CFF0000FF0066FF0073FF0073FF00
66FF0000FFBF73FF0066FF004CFF0080FF0099FF0099FF00A6FF00A6FF0099FF000CFF0059FF00\
B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF008CFF008CFF0080FF0073FF0059FF000CFF0000FF1919FF0000FF9919FF00\
00FF0C33FF003FFF0000FF1926FF0066FF0073FF0059FF0080FF008CFF008CFF00
8CFF0080FF0099FF0099FF0080FF0073FF00A6FF00A6FF00B3FF00B3FF00B3FF00A6FF0099FF00\
B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF004CFF0000FF8033FF0033FF004CFF00\
3FFF0000FF400CFF000CFF0066FF0080FF008CFF008CFF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0080FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF008CFF0080FF0080FF0073FF0066FF003FFF0026FF004CFF0059FF0066FF00\
59FF0033FF0059FF0033FF0066FF0080FF008CFF0099FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF008CFF008CFF0080FF0073FF0066FF004CFF0000FFD93FFF0059FF0066FF0073FF00\
73FF0073FF0073FF0066FF0000FF5980FF0099FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF008CFF0080FF0073FF0066FF003FFF000CFF0000FF663FFF0066FF0073FF0080FF00\
80FF0080FF008CFF0080FF0073FF0073FF0099FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF008CFF008CFF0080FF0059FF0019FF0026FF0000FF0C0CFF003FFF0059FF0073FF0080FF00\
8CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
99FF008CFF008CFF0080FF0066FF0026FF0000FF4C00FF4C00FFBF00FF0059FF0073FF008CFF00\
8CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF00
8CFF008CFF0080FF0080FF0073FF0059FF0033FF0000FF0019FF004CFF0059FF0073FF008CFF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF0099FF0073FF008CFF008CFF008CFF008CFF00
8CFF0080FF0080FF0073FF0066FF0059FF0000FF000CFF003FFF0066FF0073FF0080FF008CFF00\
99FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF0099FF008CFF004CFF0000FF9973FF0080FF0080FF00
80FF0080FF0073FF0073FF0066FF0059FF0033FF0033FF0066FF0073FF0080FF008CFF008CFF00\
99FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
CCFF00C0FF0066FF0099FF00A6FF00A6FF0099FF0073FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF008CFF0073FF003FFF004CFF0073FF0073FF00
66FF0066FF0066FF0066FF0059FF004CFF0000FF0C4CFF0066FF0073FF0080FF008CFF008CFF00\
99FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00C0FF00B3FF008CFF0073FF0080FF0080FF0059FF008CFF0099FF0099FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF008CFF0080FF0066FF0000FF8C3FFF0059FF00
3FFF004CFF0059FF0059FF004CFF003FFF0000FF4033FF0059FF0073FF0080FF008CFF008CFF00\
99FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00C0FF00A6FF008CFF0026FF0000FF0000FF4C66FF0066FF0080FF008CFF0099FF00\
99FF0099FF0099FF008CFF008CFF0080FF0080FF0066FF003FFF0000FF3333FF00
26FF0026FF003FFF003FFF0000FF8C00FF4026FF0000FF0C3FFF0059FF0073FF0080FF008CFF00\
99FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00C0FF00B3FF008CFF0080FF0080FF0073FF003FFF003FFF004CFF0073FF008CFF00\
8CFF008CFF0073FF0080FF0080FF0080FF0073FF0066FF004CFF0000FF6600FF00
19FF0000FF260CFF000CFF000CFF0026FF004CFF0026FF000CFF0000FFBF66FF0080FF008CFF00\
8CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00C0FF00B3FF00A6FF00A6FF0099FF0080FF0080FF0073FF0066FF0000FF4066FF00\
73FF0073FF0000FF1973FF0073FF0073FF000CFF003FFF0019FF0033FF003FFF00
4CFF0026FF0026FF0000FF734CFF0059FF0066FF0059FF0059FF004CFF0026FF0059FF0073FF00\
80FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF008CFF0073FF0026FF00\
3FFF004CFF0000FF334CFF0066FF0059FF0000FF4000FF4000FF003FFF0059FF00
59FF0059FF0059FF0033FF0059FF0066FF0073FF0073FF0080FF0073FF0066FF0000FF2619FF00\
66FF0073FF0080FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0066FF00\
19FF0000FF0C26FF000CFF004CFF004CFF0000FF6600FF7300FF004CFF0066FF00
66FF0073FF0066FF0059FF003FFF0073FF0080FF0080FF008CFF008CFF0080FF004CFF0059FF00\
00FF003FFF0059FF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0059FF00\
66FF0066FF004CFF0000FF2600FF260CFF0026FF003FFF004CFF004CFF0073FF00
73FF0080FF0080FF0073FF003FFF0080FF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00\
59FF0080FF0080FF0000FF73A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF00\
80FF0073FF0000FF264CFF0033FF0000FF194CFF0059FF0066FF0073FF0073FF00
80FF0080FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF00\
8CFF0080FF0073FF0066FF0000FF8000FF334CFF0066FF0073FF0073FF0080FF00
80FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF00\
8CFF0080FF0080FF0073FF0059FF0000FF0C59FF0066FF0073FF0080FF0080FF00
8CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF00\
8CFF008CFF0080FF0073FF004CFF0033FF0066FF0073FF0080FF0080FF008CFF00
8CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF00\
8CFF0080FF0073FF0059FF0026FF0033FF0066FF0073FF0080FF0080FF008CFF00
8CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF00\
8CFF0080FF0073FF0059FF0026FF0026FF004CFF0073FF0080FF0080FF008CFF00
8CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF00\
80FF004CFF003FFF003FFF0000FFBF26FF004CFF0066FF0073FF0080FF008CFF00
8CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00C0FF00A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF0080FF00\
73FF0066FF003FFF0000FFD919FF003FFF0059FF0066FF0073FF0080FF008CFF00
8CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00CCFF0099FF0000FF0C99FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0033FF0059FF00\
59FF0059FF003FFF0019FF0000FF0019FF0033FF004CFF003FFF0066FF008CFF00
8CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00B3FF004CFF0080FF00B3FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF0080FF003FFF00\
0CFF0033FF0000FF0000FF2600FF4000FFB300FF9919FF004CFF0073FF0080FF00
8CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00E6FF00D9FF00D9FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00C0FF00B3FF0099FF0080FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0066FF00\
00FF5900FF0C00FFCC00FF4C00FF6600FF2600FF0026FF0026FF0033FF0080FF00
8CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00CCFF008CFF0099FF00A6FF0099FF00B3FF00CCFF00CCFF00CCFF00C0FF00C0FF00\
CCFF00C0FF00C0FF00C0FF00B3FF008CFF0066FF0099FF00A6FF00B3FF00B3FF00
C0FF00B3FF00B3FF0080FF0059FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF0099FF0080FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0000FF0C\
4CFF003FFF0000FF3300FF7300FF0026FF003FFF004CFF0026FF0033FF004CFF00
80FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00E6FF00D9FF00B3FF0099FF0080FF0066FF00A6FF00B3FF00B3FF00A6FF0099FF00\
B3FF00C0FF00B3FF00B3FF00A6FF008CFF0026FF0080FF008CFF0000FF4CA6FF00
B3FF00B3FF00A6FF008CFF0080FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF008CFF0000FF5933FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF0080FF0073FF00\
66FF004CFF0033FF0019FF000CFF003FFF0059FF0066FF0073FF0073FF0073FF00
80FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00E6FF00E6FF00CCFF00CCFF00C0FF00C0FF0099FF0000FFA68CFF008CFF0080FF00\
A6FF00A6FF0099FF008CFF008CFF0080FF0000FF1926FF0066FF0073FF0099FF00
99FF0099FF0099FF004CFF0080FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF0073FF0033FF00
80FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF00\
66FF004CFF0026FF0000FF260CFF0019FF0059FF0073FF0080FF0080FF008CFF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF0080FF0073FF0033FF00\
8CFF0099FF0073FF000CFF0000FF2659FF0073FF0000FF3359FF0000FF8C80FF00
8CFF004CFF0073FF004CFF0059FF0066FF0099FF0099FF0073FF0099FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF004CFF00
73FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF00\
66FF0026FF0000FF8C26FF004CFF004CFF0000FF1973FF0080FF008CFF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF0080FF00B3FF00A6FF0019FF00\
0CFF004CFF0000FF0C4CFF003FFF008CFF0099FF008CFF0073FF0019FF0059FF00
59FF0000E6FF26FF0066FF003FFF0026FF0073FF0080FF0000FF008CFF0099FF00A6FF00A6FF00\
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0080FF0059FF00
59FF0073FF0080FF0080FF0073FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF00\
66FF004CFF0000FF333FFF0066FF0073FF0073FF0080FF008CFF008CFF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00CCFF00B3FF00A6FF00\
73FF0066FF008CFF008CFF0080FF00A6FF00A6FF0099FF004CFF0073FF0019FF00
66FF0066FF0066FF0080FF0073FF0033FF0033FF0000FF8C3FFF0059FF0059FF0099FF0099FF00\
A6FF00A6FF0099FF008CFF0099FF0099FF0099FF0099FF008CFF0080FF0059FF00
00FF2659FF0073FF0066FF0019FF0073FF0080FF0080FF0080FF0080FF0080FF0073FF0066FF00\
59FF0033FF0026FF004CFF0073FF0080FF0080FF008CFF008CFF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF00\
80FF0080FF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF008CFF0019FF00
8CFF0099FF0099FF0099FF008CFF0073FF0073FF0080FF0080FF004CFF004CFF0059FF008CFF00\
8CFF008CFF0080FF0059FF008CFF008CFF008CFF008CFF0080FF0073FF0059FF00
00FFD93FFF004CFF003FFF004CFF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF00\
4CFF000CFF0059FF0066FF0073FF0080FF008CFF008CFF008CFF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00A6FF00\
59FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF008CFF0073FF00
99FF00A6FF00A6FF00A6FF00A6FF0066FF008CFF0099FF0099FF008CFF008CFF0080FF0026FF00\
33FF0073FF0066FF0000FF2673FF0080FF0080FF0059FF0059FF0059FF003FFF00
19FF000CFF0000FF1900FFBF3FFF0059FF0066FF0066FF0066FF0066FF0066FF0066FF004CFF00\
00FF803FFF0066FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF004CFF00\
8CFF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF0073FF0080FF00
A6FF00B3FF00B3FF00B3FF00B3FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0080FF00\
4CFF0000FF003FFF000CFF0059FF0073FF0066FF0033FF0000FF0000FF003FFF00
59FF0059FF004CFF0033FF000CFF004CFF0059FF0059FF0033FF004CFF004CFF004CFF0026FF00\
00FF0000FF6666FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF0059FF00\
99FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00A6FF0099FF00
B3FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF00\
4CFF0080FF0073FF004CFF0019FF004CFF003FFF0000FF400CFF0026FF0066FF00
73FF0066FF0066FF003FFF0000FF0C19FF003FFF003FFF0000FF190CFF0019FF0026FF0000FF00\
19FF003FFF0059FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00CCFF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00\
99FF0099FF008CFF003FFF0059FF000CFF0059FF0066FF0066FF0059FF0073FF00
80FF0073FF0066FF0033FF003FFF0000FF0000FF1900FF0C00FF1900BFFF19FF0033FF0026FF00\
00FF2633FF004CFF0066FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
A6FF00A6FF0099FF008CFF0073FF0000FFA673FF0080FF0080FF0080FF008CFF00
8CFF0080FF0080FF0073FF0059FF0000FF403FFF004CFF003FFF0019FF004CFF004CFF003FFF00\
0CFF0000FF0C00FF0059FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00A6FF0099FF0080FF0059FF0080FF008CFF008CFF008CFF008CFF00
8CFF008CFF0080FF0073FF0066FF000CFF0059FF0066FF0066FF0066FF0066FF0066FF004CFF00\
33FF0000FF593FFF0059FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00A6FF0099FF0066FF0073FF008CFF0099FF0099FF0099FF0099FF00
99FF0099FF008CFF0080FF0033FF0059FF0073FF0073FF0073FF0073FF0073FF0066FF0059FF00\
19FF0000FF003FFF0059FF0066FF0073FF0073FF0080FF008CFF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF0000FF00C0FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00B3FF00B3FF0099FF0000FF7380FF0099FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF008CFF0073FF000CFF0073FF0080FF0080FF0080FF0080FF0080FF0073FF0066FF00\
33FF0000FF330CFF0000FF0C59FF0059FF0033FF004CFF008CFF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00
C0FF00B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00B3FF00\
4CFF0099FF00CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00B3FF0099FF0066FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0080FF004CFF0080FF008CFF008CFF008CFF008CFF0080FF0073FF0059FF00\
26FF003FFF0026FF0000FF1919FF0026FF0059FF0080FF008CFF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00
8CFF0000FF00A6FF00C0FF00CCFF00CCFF00CCFF00B3FF00CCFF00CCFF00C0FF0099FF008CFF00\
99FF00CCFF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00B3FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF008CFF008CFF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0026FF00\
59FF0066FF0059FF003FFF0000FF994CFF0073FF0080FF008CFF008CFF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
B3FF0073FF004CFF00B3FF00C0FF00C0FF00B3FF008CFF00A6FF0080FF008CFF000CFF00A6FF00\
59FF00D9FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF00\
73FF0073FF0066FF004CFF0000FF0C4CFF0073FF0080FF008CFF008CFF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
C0FF00A6FF0066FF0099FF00A6FF0080FF00A6FF0073FF0066FF008CFF00B3FF00C0FF00CCFF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF00\
80FF0080FF0073FF0033FF0033FF0019FF004CFF0080FF008CFF008CFF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00
C0FF00B3FF0000FF9900FF4C73FF000CFF0073FF003FFF00A6FF00B3FF00CCFF00CCFF00D9FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF00\
8CFF008CFF0080FF0073FF004CFF0026FF0066FF0080FF008CFF008CFF0099FF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00
C0FF00B3FF0099FF0066FF0059FF0080FF0066FF004CFF00A6FF00C0FF00CCFF00D9FF00D9FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
8CFF008CFF0080FF0073FF0066FF000CFF0066FF0080FF0080FF008CFF008CFF00
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
B3FF00A6FF008CFF0000FF198CFF0099FF00A6FF00A6FF0099FF00CCFF00D9FF00D9FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00\
99FF008CFF008CFF0080FF0066FF0000FF0C59FF0073FF0080FF008CFF008CFF00
8CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00
B3FF003FFF003FFF004CFF0080FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF008CFF008CFF0080FF0066FF0019FF003FFF0066FF0073FF0080FF008CFF00
8CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
A6FF008CFF0059FF000CFF0000FF73A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF008CFF008CFF0073FF003FFF0000FF593FFF0059FF0066FF0073FF0080FF00
8CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00C0FF0099FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF008CFF0066FF0066FF0099FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00\
99FF0099FF008CFF0080FF0066FF003FFF0000FF660CFF0026FF0073FF0080FF00
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00C0FF00A6FF004CFF0099FF00A6FF00A6FF0099FF00
99FF008CFF0059FF0080FF0099FF00B3FF00C0FF00CCFF00CCFF00D9FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00\
99FF0099FF008CFF0080FF0073FF004CFF0019FF0026FF0059FF0073FF0080FF00
80FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00A6FF008CFF0000FF008CFF008CFF0059FF00
80FF0019FF0000FF0C00FF7380FF00A6FF00B3FF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF008CFF0080FF0066FF0026FF0000FF003FFF0059FF0066FF0073FF00
80FF0080FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF0099FF0059FF00A6FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0080FF0026FF004CFF000CFF00
4CFF0000FF0C73FF0066FF0066FF0080FF0099FF00B3FF00CCFF00D9FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00\
99FF008CFF0080FF0073FF0066FF003FFF0000FF263FFF0059FF0066FF0073FF00
73FF0073FF0073FF0073FF0066FF003FFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF0066FF00
99FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF0099FF0080FF003FFF008CFF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF008CFF0066FF0059FF0073FF00
66FF0026FF0099FF00A6FF00A6FF0099FF0066FF0059FF00A6FF00CCFF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00\
99FF008CFF0066FF0033FF0000FFD919FF0019FF0019FF000CFF0000FF8066FF00
66FF0066FF0066FF0059FF000CFF0066FF0080FF008CFF0099FF0099FF0099FF0099FF0099FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0073FF0073FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
99FF008CFF0059FF0073FF0099FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF0080FF0000FF0C66FF008CFF00
99FF008CFF00A6FF00B3FF00C0FF00C0FF00B3FF00C0FF00C0FF00D9FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00\
99FF008CFF0066FF0066FF0066FF0059FF004CFF0000FF9900FFCC26FF004CFF00
59FF0059FF004CFF0000FF0C33FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF0033FF003FFF0066FF00
8CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00\
8CFF0073FF004CFF0066FF0099FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00B3FF00A6FF00A6FF0099FF0073FF0026FF0000FF0099FF00
A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00\
99FF008CFF0080FF0080FF0073FF0066FF0059FF0000FF2600FF0000FF0C3FFF00
3FFF0019FF0000FF0C3FFF0066FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0073FF004CFF003FFF00
33FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF00\
80FF004CFF0059FF0080FF0099FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00B3FF008CFF0099FF0099FF008CFF0073FF000CFF0080FF0099FF00
B3FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00\
99FF0099FF008CFF0080FF0080FF0073FF0066FF004CFF003FFF0026FF0000FF80
00E6FF19FF004CFF0066FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0073FF004CFF000CFF00
73FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF00\
66FF0033FF0066FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF0099FF003FFF0066FF0059FF0000FF1900FF5973FF0099FF00
B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF008CFF008CFF0080FF0073FF0066FF0059FF004CFF0033FF0000FF0C
19FF003FFF0059FF0066FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0073FF0059FF0000FF4C
3FFF0080FF008CFF008CFF008CFF0099FF008CFF008CFF0073FF004CFF0073FF0066FF0000FFA6\
66FF0080FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00A6FF0099FF0080FF0000FF8C4CFF0033FF0080FF0073FF0066FF00
A6FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00\
99FF0099FF008CFF008CFF0080FF0073FF0066FF0059FF004CFF0033FF0000FF19
26FF004CFF0059FF0066FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0073FF0059FF0000FF59
66FF0080FF0080FF008CFF008CFF008CFF008CFF0080FF0073FF004CFF0033FF0019FF004CFF00\
80FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00A6FF0099FF008CFF0066FF0000FF3380FF008CFF0099FF00A6FF003FFF00
4CFF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00\
99FF0099FF008CFF0080FF0073FF0066FF0059FF004CFF0000FFB300FF1900FF26
00FF2626FF004CFF0066FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0066FF0026FF00
59FF0073FF0080FF0080FF0080FF0073FF0080FF0073FF0066FF004CFF0026FF0059FF0066FF00\
80FF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
A6FF00A6FF008CFF004CFF003FFF0059FF008CFF00A6FF00B3FF00B3FF00B3FF00
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF00\
99FF008CFF008CFF0080FF0033FF0026FF003FFF0033FF000CFF0000FF0C00FF59
33FF003FFF0059FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0059FF000CFF00
3FFF0059FF0066FF0073FF0066FF000CFF0066FF0066FF0059FF0000FF3300FF7366FF0080FF00\
8CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
99FF0099FF0066FF0000FF3373FF0080FF0073FF00B3FF00C0FF00C0FF00C0FF00
CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF00\
8CFF008CFF008CFF0080FF0073FF0059FF003FFF0000FF0000FF5919FF0033FF00
4CFF0059FF0059FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0066FF0026FF0000FF33
0CFF0000FF0C59FF0059FF0059FF0026FF004CFF004CFF004CFF0019FF003FFF0066FF0080FF00\
8CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0000FF008CFF00\
73FF0026FF0059FF0080FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF0099FF008CFF00\
8CFF008CFF0080FF0080FF0073FF0066FF004CFF0033FF0000FF4026FF003FFF00
4CFF0059FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0059FF003FFF00
19FF000CFF003FFF004CFF003FFF000CFF000CFF0019FF0026FF0000FF3333FF0059FF0073FF00\
80FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00A6FF008CFF0099FF00A6FF00A6FF00A6FF0099FF0080FF0000FF0C\
26FF0073FF0099FF00A6FF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF008CFF008CFF00\
80FF0080FF0080FF0073FF0066FF0059FF004CFF0026FF0000FFD900FF2633FF00
4CFF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0059FF003FFF00
00FF000CFF0026FF0019FF0000FF2600FF0019FF0000D9FF00FF0033FF0026FF0000FF0000FF0C\
00FF0C80FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00A6FF0026FF003FFF008CFF0099FF008CFF008CFF0073FF0000FF0C\
73FF008CFF00A6FF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF008CFF0080FF0080FF004CFF0073FF0073FF00\
73FF0073FF0073FF0066FF0059FF0059FF003FFF0000FF0C00FF4C0CFF0033FF00
4CFF0059FF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF003FFF00
26FF0000FF2600FF3300FF4000FF2626FF003FFF003FFF0000FF4C4CFF0066FF0066FF0066FF00\
80FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00A6FF008CFF0059FF0000FF2680FF0073FF003FFF0059FF0033FF00\
80FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF008CFF0059FF003FFF0026FF0019FF0033FF00\
59FF0066FF0066FF004CFF0000FF263FFF0033FF0026FF0000FF6626FF003FFF00
4CFF0059FF0059FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0066FF00\
66FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF004CFF00
26FF0000FF400CFF0033FF0033FF003FFF004CFF0059FF0059FF0066FF0073FF0073FF0080FF00\
8CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF0066FF0000FF0C3FFF0026FF0026FF0059FF00\
00FF198CFF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF003FFF0059FF0026FF003FFF00\
26FF000CFF0026FF0033FF0000FF0C00FF5919FF0000FF0000FF1926FF003FFF00
4CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF003FFF00\
4CFF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF004CFF003FFF00
33FF0000FF2626FF003FFF004CFF0059FF0059FF0066FF0066FF0073FF0073FF0080FF0080FF00\
8CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0059FF000CFF0059FF0073FF0080FF00\
8CFF0099FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0080FF0066FF0066FF00\
66FF0059FF0033FF0000FF0026FF0000FF0000FF1900FF0C00FF8C19FF0033FF00
4CFF004CFF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0059FF0059FF0033FF00\
33FF0059FF0059FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF00
19FF000CFF0033FF004CFF004CFF0059FF0066FF0066FF0073FF0073FF0080FF0080FF008CFF00\
8CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0066FF0026FF0066FF0080FF008CFF00\
99FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0080FF00\
73FF0066FF004CFF003FFF004CFF0033FF0026FF0026FF0000FF1900FF6626FF00
3FFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF004CFF0059FF004CFF003FFF0019FF00\
33FF004CFF0059FF0059FF0059FF003FFF004CFF004CFF004CFF0026FF0019FF00
00FF9926FF003FFF004CFF0059FF0059FF0066FF0066FF0073FF0073FF0080FF0080FF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF0073FF003FFF0019FF000CFF0080FF008CFF00\
99FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF00\
80FF0073FF0066FF0059FF0059FF004CFF004CFF003FFF0033FF000CFF0019FF00
33FF003FFF004CFF004CFF004CFF004CFF004CFF004CFF000CFF003FFF003FFF0033FF0000FF40\
19FF0033FF004CFF004CFF003FFF0000FF6626FF003FFF0033FF0026FF0000FF19
0CFF0033FF003FFF004CFF0059FF0059FF0066FF0066FF0073FF0073FF0080FF0080FF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0073FF0000FF8C00FF003FFF0073FF008CFF00\
99FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF00\
80FF0073FF0073FF0066FF0066FF0059FF0059FF004CFF003FFF0026FF0000FF0C
19FF0033FF003FFF003FFF004CFF004CFF004CFF003FFF000CFF000CFF0026FF0000FF6600FF19\
00FF0C26FF003FFF003FFF0033FF0026FF0000FF2626FF0019FF000CFF0000FF19
00FF0026FF003FFF004CFF0059FF0059FF0066FF0066FF0073FF0073FF0080FF0080FF0080FF00\
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00
80FF0000FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0073FF0066FF0000FF0059FF0080FF008CFF00\
99FF00A6FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF00\
80FF0080FF0073FF0073FF0066FF0066FF0059FF004CFF003FFF0026FF0000FFA6
0CFF0019FF0000FFB333FF003FFF003FFF003FFF0033FF0026FF0000FF5900FF3300FF4C00FF19\
0CFF0026FF0033FF0033FF0033FF0026FF0000FF2600FF3300FF0C00FFA600FF59
00FF000CFF003FFF004CFF004CFF0059FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0000FFB3
26FF0080FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF0099FF0099FF008CFF008CFF008CFF0080FF0073FF0066FF003FFF004CFF0066FF0080FF00\
8CFF008CFF0099FF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF00\
80FF0080FF0073FF0073FF0066FF0066FF0059FF0059FF003FFF0000FF3300FF00
00E6FF00FF1900FF0026FF0033FF0033FF0033FF0033FF0026FF000CFF0000FF4C00FF4000FF0C\
0CFF0019FF0026FF0026FF0026FF0019FF0000FF0000FF8C00FF6600FF1900FF00
19FF0026FF003FFF003FFF004CFF004CFF0059FF0066FF0066FF0073FF0073FF0080FF0080FF00\
80FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0073FF0059FF00
0CFF0080FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
99FF004CFF0073FF0080FF0080FF0080FF0073FF0066FF0059FF0033FF0000FFBF26FF0033FF00\
59FF003FFF0033FF003FFF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF00\
80FF0080FF0073FF0073FF0066FF0066FF0059FF0059FF004CFF0033FF0019FF00
00FF0C00FF590CFF0026FF0026FF0033FF0026FF0026FF0019FF000CFF0000FF0C00FF4C00FF0C\
00FF000CFF000CFF000CFF0019FF000CFF0000FF0000FF3300FF1900FF000CFF00
19FF0026FF0033FF003FFF003FFF003FFF0033FF0059FF0066FF0066FF0073FF0073FF0080FF00\
80FF0080FF0080FF008CFF008CFF008CFF008CFF0080FF0080FF0019FF0026FF00
33FF0026FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00
99FF0059FF0026FF004CFF0073FF0066FF000CFF0059FF003FFF0000FFF34CFF0033FF0073FF00\
73FF0080FF0080FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00C0FF00A6FF00A6FF00A6FF00A6FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF00\
80FF0080FF0073FF0073FF0066FF0066FF0059FF004CFF003FFF0033FF0000FF19
00FF4000FF2600FF0019FF0026FF0026FF0019FF0019FF000CFF0000FF0000FF1900FFE600FF33\
00FF0C00FF4C00FF3300FF1900FF0000FF0C00FF1900FF9900FF1900FF000CFF00
19FF0026FF0033FF0033FF0033FF0000FF5933FF004CFF0059FF0059FF004CFF0066FF0073FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0059FF00000CFF
66FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
8CFF0080FF0066FF003FFF003FFF004CFF0026FF0000FFA60CFF003FFF0066FF0080FF008CFF00\
8CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00A6FF0073FF0000FF1980FF0080FF0099FF0099FF0099FF00A6FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF00\
80FF0080FF0073FF0073FF0066FF0066FF004CFF003FFF0033FF0026FF000CFF00
00FF4000FF3300FF000CFF0019FF0019FF0000FF0000FF0C00FF0000FF7300FF4000FF8000FF33\
00FF2600FF4C00FF8C00FF3300FF2600FF7300FFA600D9FF00FF2600FF0C00FF00
0CFF0019FF0026FF0026FF0019FF0000FF3326FF0033FF0019FF0033FF000CFF0066FF0073FF00\
73FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0066FF003FFF0026FF00
66FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
8CFF0080FF0073FF0066FF0033FF0000FF0000FF3333FF003FFF0033FF0059FF0080FF008CFF00\
99FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00B3FF0099FF0059FF000CFF000CFF0059FF008CFF0099FF0099FF00
99FF0099FF008CFF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00\
80FF0073FF0073FF0066FF0066FF0059FF004CFF0000FF8C00FFB300FF0000FF66
00FF4000FF2600FF0000FF0000FF0000FF0000FF1900FF5900FF2600FF2600FF5900FF7300FF59\
00FF9900FF8C00FF8000FF6600FF4C00FF6600FF6600FF4000FF2600FF1900FF73
00FF0C00FF590CFF0019FF000CFF0000FF4000FF0C00FF0000FF8026FF004CFF0066FF0066FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0059FF0019FF0059FF00
73FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00
8CFF0080FF0073FF0066FF004CFF0000FF594CFF0059FF0066FF0066FF0073FF008CFF0099FF00\
99FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00B3FF00A6FF008CFF008CFF004CFF003FFF0066FF0080FF008CFF00
8CFF008CFF0073FF004CFF0080FF0080FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00\
73FF0066FF0066FF0066FF0059FF0059FF004CFF0033FF0026FF000CFF0000FF0C
00FF2600FF7300FF1900FF0C00FF0C00FF3300FF4C00FF7300FF4000FF5900FF8000FFE600FF8C\
00FFF300FFF300D9FF00FFCC00FFB300FFD900FF6600FF4C00FF4000FF3300FF66
00FFCC00FF4000FF0C00FF0C00FF0C00FF9900FF2600FF2600FF1933FF004CFF0059FF0066FF00\
66FF0073FF0073FF0073FF0073FF0073FF0066FF0033FF0026FF0033FF0066FF00
73FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF00
8CFF0080FF0073FF0059FF0000FF2600FF004CFF0066FF0073FF0080FF008CFF008CFF0099FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0080FF0033FF0059FF0000FF19
80FF0073FF0066FF0000FF1973FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF00\
66FF0026FF004CFF0059FF004CFF004CFF003FFF003FFF0026FF0019FF000CFF00
00FF0000FF3300FF4000FF3300FF2600FF3300FF4C00FFCC00FF7300FFE600FFA600CCFF00E6FF\
000CFF0000000000000099FF00E6FF00FF9900FF8000FF8C00FF8000FF5900FF80
00FF5900FF4000FF3300FF5900FF7300FF1900FF0019FF0026FF003FFF004CFF0059FF0059FF00\
66FF0066FF0066FF0066FF0066FF0066FF0059FF003FFF0000FF193FFF0059FF00
73FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF008CFF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF00
80FF0073FF0073FF003FFF0000FF9900FF263FFF0066FF0073FF0080FF008CFF0099FF0099FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0000FF0C4CFF0033FF00
66FF0066FF004CFF003FFF0066FF0073FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF00\
66FF004CFF0000FF193FFF003FFF003FFF003FFF0033FF0026FF0019FF000CFF00
00FF0000FF2600FF7300FF4C00FF3300FF4C00FF6600FFD900FFB300BFFF000CFF00BFFF0099FF\
0000000000006600FF008CFF00FFFF00FFFF00FFA600CCFF00FF9900FF8C00FFD9
00FF8C00FFD900FF7300FF7300FF4000FF1900FF0019FF0026FF003FFF003FFF004CFF004CFF00\
59FF0066FF0066FF0066FF0066FF0059FF004CFF003FFF0000FF0019FF0000FF33
66FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF0080FF0059FF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF004CFF0073FF00
73FF0073FF0066FF004CFF0026FF0000FF264CFF0066FF0080FF0080FF008CFF0099FF0099FF00\
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0066FF0000FF26
00FF0019FF0019FF0033FF0059FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
66FF0059FF0033FF000CFF0000FF0026FF0033FF0026FF0026FF0019FF000CFF00
00FF2600FF4000FFA600FF5900FF4C00FF8000FF8C00FFCC00CCFF000000C000FF0C00FF5900FF\
0000000000000000000026FF0099FF00E6FF00FFFF00FFF300F3FF00FFD900FFF3
0073FF00000000FFCC00FF8000FF5900FF3300FF190CFF0026FF0033FF0033FF0026FF0026FF00\
4CFF0059FF0059FF0059FF0059FF004CFF0019FF0019FF0000FF2626FF004CFF00
66FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0073FF0000FF8073FF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0059FF003FFF00
59FF0059FF0059FF004CFF0019FF003FFF0059FF0073FF0080FF0080FF008CFF008CFF0099FF00\
99FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF003FFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF0080FF0000FF0059FF00
33FF003FFF0026FF0000FF0026FF004CFF0066FF0073FF0073FF0073FF0073FF0066FF0066FF00\
59FF004CFF0033FF0000FF0000FFCC19FF0026FF0019FF000CFF0000FF0C00FF0C
00FF1900FF4000FF6600FF8000FF7300FF9900FFF30080FF0000FF000000000000000000000000\
000000000000000000C000FF9900FF4C00FF008CFF00B3FF0080FF0000000073FF
4C00FFB300FF0080FF00FFFF0080FF00FFD900FFD900FF0C19FF0026FF0026FF0000FF0C26FF00\
4CFF004CFF004CFF004CFF004CFF004CFF0033FF0000FF000CFF0033FF004CFF00
59FF0059FF0059FF0000FF4C66FF0073FF0080FF0080FF0073FF0066FF0026FF0066FF0080FF00\
80FF0080FF0080FF008CFF008CFF0080FF0080FF0080FF0073FF0059FF0000FF59
33FF0026FF003FFF0033FF0000FF403FFF0059FF0073FF0073FF0080FF008CFF008CFF0099FF00\
99FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00B3FF0000FF0CCCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF0080FF0073FF00
66FF0059FF003FFF0000FF0C33FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
59FF004CFF0033FF0000FF4C00FF260CFF000CFF000CFF0000FF0000FFA600FF33
00FF2600FF4000FF6600FFFF00FF9900E6FF00CCFF000000000000000000000000000000000000\
000000000000000000000000000000F300FF0019FF3F00FF000000000000B300FF
D900FF0000000000008000FFA600FF00FFCC00FF3300FF190CFF000CFF0000FF0C00FF0026FF00\
3FFF003FFF003FFF003FFF003FFF0033FF0019FF0000FF0C00FF0026FF0033FF00
3FFF004CFF003FFF0019FF0066FF0073FF0073FF0073FF0066FF0059FF0000FF0C59FF0066FF00\
73FF0066FF0066FF0073FF0080FF0080FF0073FF0066FF0066FF004CFF0019FF00
0CFF0000FFD90CFF0000FF3319FF0019FF0033FF0066FF0073FF0080FF0080FF008CFF008CFF00\
8CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF008CFF008CFF0000FF19A6FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF0066FF00B3FF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF00
73FF0066FF0033FF0000FF0C33FF004CFF0059FF0066FF0066FF0066FF0066FF0059FF0059FF00\
00FF000CFF0019FF0000FF0C00FF4C00FF0C00FF0000FF0000FF4000FF6600FF4C
00FF4000FF7300FF7300FFB300FFF300F3FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000009900FF0C00FF0066FF0080FF00D9FF00FF5900FF4000FF0C00FF0C00FF4C00FF190CFF00\
26FF0026FF0000FF0026FF0026FF0019FF0000FF5900FF4000FF1900FF0C00FF19
0CFF0026FF0000FF0C3FFF0059FF0066FF0066FF0066FF0059FF004CFF0000FF0C26FF0000FF73\
59FF004CFF003FFF004CFF0066FF0066FF0059FF0026FF003FFF0019FF0000FF0C
4CFF003FFF0000FF0C4CFF003FFF0033FF000CFF0059FF0066FF0073FF0073FF0073FF0073FF00\
80FF0080FF0080FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0080FF0066FF0099FF00B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00C0FF0059FF0073FF00
B3FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF00
73FF0033FF0000FF3300FF4026FF003FFF004CFF0059FF0059FF0059FF0059FF0059FF004CFF00\
3FFF0019FF0000FF0000FF1900FFB300FF2600FF1900FF1900FF3300FF6600FF73
00FF8000FFF300FFA600FFCC004CFF008CFF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000002600FF0059FF00D9FF00FFB300FF8000FF6600FF9900FFB300FF7300FF6600FF8C00FF8C\
00FF0000FF8000FF6600FF4000FF1900FF0C00FF0C26FF0026FF0000FF0000FFBF
00FF0C00FF0C00FF2626FF0033FF0059FF0059FF004CFF0019FF000CFF0019FF0000FF1900FF26\
26FF0000FF4026FF0019FF0033FF0000FF000CFF0026FF0000FF6619FF004CFF00
66FF0066FF0000FF0066FF0066FF0059FF003FFF0026FF004CFF0000FF4066FF0066FF0019FF00\
59FF0026FF0080FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
59FF004CFF0033FF0099FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF008CFF0073FF00
99FF00A6FF0073FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF00
73FF0059FF004CFF0026FF0000FFD926FF004CFF004CFF0059FF0059FF0059FF004CFF004CFF00\
3FFF0033FF0026FF000CFF0000FF0C00FF6600FF5900FF3300FF4000FFB300FFBF
00FFD900CCFF00FFFF00BFFF0099FF000CFF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000099FF00FFE600E6FF00FF8000FF4000FF4000FF4000FF1900FF0C00FF0C00FF26\
00FF5900FF990CFF000CFF0033FF0033FF0033FF003FFF003FFF0033FF0000FF0C
26FF0026FF000CFF0000FF4C33FF003FFF003FFF0033FF0000FFBF0CFF003FFF004CFF0019FF00\
00FF8C4CFF0059FF0066FF0066FF0066FF0000FF0C66FF0059FF0019FF0066FF00
73FF0073FF0073FF0073FF0073FF0073FF0059FF000CFF0000FF1933FF004CFF004CFF0033FF00\
19FF0059FF0080FF008CFF0099FF0099FF0099FF0099FF0099FF008CFF0080FF00
59FF0073FF0099FF00A6FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF0073FF008CFF0066FF00
3FFF0000FF4CA6FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF008CFF00
80FF0066FF0059FF003FFF0000FF0C26FF003FFF003FFF004CFF004CFF004CFF004CFF003FFF00\
3FFF0033FF0026FF0019FF0000FF0000FF3300FF8000FF4C00FF9900FF9900B3FF
00A6FF0000FF000000000000000000F300FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000E600FF008CFF00FFBF00FF9900FFF300FF3300FF2600FF0C00FF0000FF000CFF0000FF00\
00FF0C00FF2619FF0033FF003FFF003FFF004CFF004CFF004CFF004CFF003FFF00
3FFF003FFF0019FF0000FF4019FF0019FF0026FF0000FF2600FF8000FF1959FF0066FF0066FF00\
3FFF0059FF0073FF0080FF0080FF0080FF0080FF0080FF0073FF0000FF0073FF00
80FF0080FF0080FF0080FF0080FF0080FF0073FF0059FF0026FF0019FF003FFF0019FF0000FF00\
00FF194CFF003FFF0080FF008CFF008CFF008CFF008CFF0080FF0073FF003FFF00
73FF0080FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF00
80FF003FFF0099FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF00
73FF0066FF004CFF0033FF0019FF0000FF1919FF0026FF003FFF003FFF0033FF0033FF0033FF00\
33FF0026FF0019FF000CFF0000FF0C00FF4000FF6600FF9900FFB300B3FF0059FF
C000FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0C00FF0066FF00FFF300FFA600FF8000FF4C00FF3300FF2600FF0C00FF000CFF0019FF0019FF00\
19FF0000FF0019FF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF00
4CFF004CFF0033FF0000FF8C00FF0000FF0C00FF3333FF004CFF0059FF0066FF0073FF0073FF00\
73FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF0080FF0073FF0080FF00
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0066FF003FFF0000FF4C0CFF0000F3FF00FF73\
00FF0000FFBF4CFF0073FF0080FF0080FF0080FF0073FF0033FF0000FFB380FF00
8CFF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00A6FF00
80FF0059FF008CFF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF0099FF008CFF0080FF0080FF00
73FF0059FF0000FF3300FF40008CFF0CFF0000FF0000FF3319FF0026FF0019FF000CFF0026FF00\
26FF0026FF000CFF0000FF1900FF2600FF3300FF7300FFCC008CFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000D900FF
0019FF00CCFF00E6FF00FFCC00FFA600FF5900FF4C00FF4C00FF400CFF0019FF0026FF0026FF00\
26FF0033FF0033FF003FFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF003FFF0019FF003FFF0033FF0000FF403FFF0059FF0066FF0073FF0080FF0080FF00\
80FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0066FF003FFF003FFF0000FF5900FF4C00FF66\
3FFF0026FF0026FF0000FF0C66FF0073FF0059FF0059FF0000FF5966FF008CFF00
99FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00B3FF00B3FF004CFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF00
8CFF003FFF0000FF0C8CFF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0080FF0066FF0059FF0059FF00
59FF0026FF000099FF26FF0000FF263FFF003FFF0033FF000CFF0000FF1900FF2600FF0C0CFF00\
19FF0019FF0000FF0000FF4000FF4C00FF6600FF9900FFF300B3FF7300FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000000000009900FF
0059FF00B3FF00FFD900FFB300BFFF4C00FF00FFE600FF4000FF0C0CFF0019FF0026FF0033FF00\
33FF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF00
66FF0059FF004CFF004CFF0059FF004CFF0033FF0033FF0059FF0073FF0073FF0080FF0080FF00\
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0059FF0033FF0019FF004CFF00\
59FF004CFF003FFF000CFF004CFF0000FF3333FF000CFF0033FF0019FF008CFF00
99FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF0073FF0080FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00
A6FF0080FF004CFF0099FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00A6FF000CFF0059FF004CFF0019FF0000FF4000FF00
4CFF003FFF0026FF004CFF004CFF004CFF004CFF004CFF0026FF0019FF0000FF0000FF8000FF00\
0CFF0000FF0000FF1900FF5900FFB300FF8C00D9FF008CFF0040FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0033FF008CFF00E6FF00FF9900FF8000FF6600FF5900FF8000FF4000FF0C19FF0026FF0033FF00\
33FF003FFF004CFF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF004CFF000CFF0059FF0073FF0080FF0080FF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF003FFF0000FF0C26FF0059FF00\
66FF0066FF0066FF0066FF003FFF0026FF0000FF264CFF0066FF0080FF008CFF00
99FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00A6FF0080FF0099FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00
A6FF0099FF000CFF008CFF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00A6FF0099FF0080FF003FFF0066FF004CFF0066FF00
73FF0066FF0059FF0066FF0066FF0059FF0059FF004CFF003FFF0033FF0000FF0C00FF2600FF33\
00FF0C00FF0C00FF1900FF3300FF7300BFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000CFF0099FF00FFE600FFA600FF8000FF4C00FF4000FF4000FF1900FF0019FF0026FF0033FF00\
33FF003FFF004CFF004CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0066FF0026FF0033FF0066FF0080FF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF0080FF003FFF0059FF0073FF0066FF00\
80FF0080FF0073FF0073FF0066FF0059FF0019FF003FFF0066FF0080FF008CFF00
99FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0066FF0000FF4C99FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00
B3FF0099FF0066FF008CFF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00A6FF0099FF0099FF0080FF0080FF0080FF0080FF00
80FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF004CFF003FFF0026FF0000FF0C00FF80\
00D9FF00FF4000FF4000FF4C00FFCC000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000BFFF00FFE600FFCC00FF4C00FF3300FF1900FF0C0CFF0019FF0026FF0033FF00\
33FF003FFF004CFF004CFF0059FF0066FF0066FF0066FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0059FF0033FF004CFF0080FF008CFF0099FF00\
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0080FF0000FF0080FF008CFF008CFF00\
8CFF0080FF0080FF0080FF0073FF0066FF0019FF0000FF734CFF0073FF0080FF00
8CFF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0080FF0080FF00B3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00
A6FF0099FF0033FF0073FF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF008CFF008CFF00
80FF0080FF0080FF0073FF0073FF0066FF0066FF0059FF004CFF0033FF000CFF0000FFCC00FF0C\
00FF0C00FF260059FF00FF8000FFA60059FF0059FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000004C00FF00FFBF00FF8000FF4C00FF3300FF2600FF0C0CFF0019FF0019FF0026FF00\
26FF0033FF0033FF004CFF0059FF0066FF0066FF0073FF0073FF0073FF0073FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0000FF0080FF008CFF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0099FF008CFF008CFF00\
8CFF008CFF008CFF0080FF0080FF0066FF003FFF0026FF003FFF0059FF0066FF00
3FFF0080FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF0000FF80A6FF00C0FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00
A6FF008CFF0026FF0073FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF00
8CFF0080FF0080FF0080FF0073FF0073FF0066FF0066FF004CFF0000FF1919FF0019FF0019FF00\
0CFF0000FF1900FF6600FF5900FF9900FFE6008CFF0019FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
E600FF3300FF00B3FF00FFBF00FFA600FF5900FF4000FF4C00FF5900FF000CFF000CFF0019FF00\
19FF0000FF1900FF0C3FFF0059FF0066FF0066FF0073FF0073FF0073FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF0099FF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF0080FF0073FF0066FF004CFF0000FF0C00FFA659FF00
73FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF0019FF0099FF00B3FF00C0FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00
A6FF0080FF0066FF0033FF0066FF0000FF8099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF00
8CFF008CFF0080FF0080FF0073FF0073FF0066FF0066FF0059FF003FFF0033FF0033FF0026FF00\
0CFF0000FF0C00FF2600FF4000FF8C00FFB300E6FF0066FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000B300FF
0033FF0080FF00FFE600FFBF00CCFF00FF8C00FF8000FF6600FF2600FF0C00FF0000FF0000FF19\
00FF2619FF0033FF004CFF0059FF0066FF0066FF0073FF0073FF0073FF0080FF00
80FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF0099FF008CFF008CFF0080FF0073FF0066FF004CFF0000FF0C4CFF0073FF00
80FF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF0099FF00\
A6FF00B3FF00B3FF00B3FF00A6FF0099FF004CFF0066FF0099FF00B3FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00A6FF0099FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
A6FF008CFF0073FF004CFF004CFF0080FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00\
00FF0CA6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF00
8CFF008CFF0080FF0080FF0080FF0073FF0066FF0066FF0059FF004CFF003FFF0033FF0026FF00\
0CFF0000FF0C00FF3300FF4000FF8C00FFE600D9FF0059FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
004CFF00E6FF00BFFF00FF9900FF8C00FF7300FF7300FFBF00FF4C00FF4C00FF1900FF3300FF73\
00FF0026FF003FFF004CFF0059FF0066FF0066FF0073FF0073FF0080FF0080FF00
80FF0080FF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF0099FF008CFF0080FF0073FF0059FF0000FF6600FF0C33FF0073FF00
8CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF0080FF00\
99FF00A6FF00A6FF00A6FF0099FF008CFF0066FF0059FF0080FF00B3FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00A6FF0000FF40B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00
99FF008CFF0059FF0000FF8C4CFF0080FF008CFF0099FF0099FF0099FF0099FF008CFF0066FF00\
80FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF00
8CFF008CFF0080FF0080FF0080FF0073FF0066FF0059FF0059FF004CFF003FFF0033FF0026FF00\
00FF0000FF4C00FF6600FF5900FF8000FFB300FFFF0073FF3F00FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0026FF00FFF300FFBF00FF8C00FF7300FF5900FF4C00FF6600FF8000FF4000FF4000FF4000FF4C\
00FF0000FF0033FF004CFF0059FF0066FF0066FF0073FF0073FF0080FF0080FF00
80FF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF008CFF0080FF0000FF5900FF0C00FF333FFF0066FF0073FF00
80FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF0099FF0080FF0059FF0059FF00\
80FF0066FF0099FF0099FF008CFF0066FF0000FFBF66FF0099FF00A6FF00B3FF00
B3FF00B3FF00C0FF00B3FF00B3FF00C0FF00C0FF00B3FF00A6FF0000FF4CA6FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
99FF008CFF0066FF0000FF2666FF0073FF0080FF008CFF008CFF0099FF008CFF0080FF0000FF40\
73FF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF00
8CFF008CFF0080FF0080FF0080FF0073FF0066FF004CFF004CFF0026FF0026FF0026FF0019FF00\
0CFF0000FF2600FFBF008CFF00FFA600D9FF00CCFF0019FFCC00FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000E600FF0000FF
00A6FF00CCFF00FFCC00FFA600F3FF00FF4C00FF4000FF3300FF4000FF1900FF0C00FF0C00FF33\
00FF8C0CFF0019FF0033FF004CFF0059FF0066FF0073FF0073FF0080FF0080FF00
80FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF008CFF0073FF0059FF0000FF0000FF0C66FF0073FF00
80FF0080FF008CFF0099FF0099FF0099FF0099FF0099FF0099FF008CFF0066FF0000FF803FFF00\
4CFF004CFF0073FF0073FF0073FF004CFF003FFF0073FF008CFF0099FF00A6FF00
33FF008CFF0099FF008CFF00A6FF00B3FF00A6FF00A6FF008CFF0059FF0099FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF000CFF0099FF0099FF0099FF0099FF0099FF00
8CFF0080FF0059FF0019FF004CFF0066FF0066FF0066FF0080FF0080FF0080FF0066FF0059FF00\
8CFF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF00
8CFF008CFF0080FF0080FF0073FF0066FF000CFF0000FF2619FF000CFF0000FF0C0CFF000CFF00\
00FF0000FF1900FF4000FF8000FFBF00FFFF0019FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000003300FF004CFF
00BFFF00FFF300FFF300FFD900FF9900FF5900FF3300FF2600FF1900FF0C00FF0000FF0000FF00\
00FF5900FF5900FF1900FF6626FF0019FF0059FF0073FF0073FF0080FF0080FF00
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF00A6FF0099FF0099FF008CFF0080FF0066FF003FFF0019FF004CFF0066FF00
66FF0073FF0073FF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0073FF004CFF0000FF33\
33FF0033FF0000FF1933FF004CFF0059FF003FFF004CFF0066FF008CFF0073FF00
A6FF0073FF0033FF0019FF0059FF0099FF0080FF008CFF0073FF003FFF0080FF0080FF00A6FF00\
B3FF00B3FF00B3FF00A6FF0099FF0066FF0073FF008CFF0033FF0080FF0080FF00
73FF0066FF0000FFD93FFF003FFF0000FF0000FF194CFF0073FF0073FF003FFF003FFF0080FF00\
8CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF00
8CFF008CFF0080FF0080FF0073FF0073FF0059FF004CFF0033FF000CFF0000FF4C00FF1900FF0C\
00FF0C00FF2600FF4000FF9900F3FF00BFFF8C00FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000009900FF9900FF0073FF
0099FF00FFF300FFBF00FF9900FF8C00FF5900FF3300FF2600FF1900FF000CFF000CFF0019FF00\
0CFF0000FF8026FF0033FF003FFF0033FF0059FF0073FF0073FF0080FF0080FF00
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF0099FF008CFF0080FF0000FF4000FF1926FF0000FF330CFF00
3FFF0000FF2666FF0080FF0080FF008CFF008CFF0080FF0066FF0066FF0066FF0033FF0000FF8C\
4CFF0066FF004CFF0080FF0080FF0080FF0073FF0000FF0019FF000CFF0080FF00
C0FF0099FF0099FF0080FF0033FF0073FF0000FF0C00FF2666FF0059FF003FFF0066FF0099FF00\
A6FF00A6FF00A6FF0099FF0066FF003FFF0059FF0066FF0059FF003FFF0033FF00
00FF0066FF0059FF0073FF0073FF003FFF0000FF660CFF0033FF004CFF0000FF2600FF3380FF00\
8CFF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF00
8CFF008CFF0080FF0080FF0073FF0073FF0066FF0059FF004CFF0033FF000CFF0000FF4000FFD9\
00FF4C00FFCC00FF5900FF9900BFFF0066FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000CC00FF2600FF0033FF
00B3FF00CCFF00F3FF00FF9900FF7300FF5900FF4000FF4000FF5900FF000CFF0019FF0026FF00\
26FF0026FF003FFF004CFF0059FF0059FF0066FF0073FF0080FF0080FF0080FF00
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF0099FF008CFF0073FF003FFF004CFF0066FF0059FF0000FF00
00FF3300FF193FFF0066FF0073FF0066FF0073FF0066FF004CFF0019FF004CFF0019FF0019FF00\
66FF0080FF008CFF0099FF0099FF0099FF008CFF0080FF0066FF0000FF0C66FF00
CCFF00C0FF00C0FF00A6FF0073FF0073FF008CFF0080FF008CFF0080FF0033FF0066FF008CFF00\
99FF0099FF0099FF008CFF0080FF004CFF0000FF0019FF000CFF004CFF003FFF00
73FF0080FF008CFF008CFF0080FF0066FF004CFF0059FF0059FF0033FF003FFF0066FF0080FF00\
8CFF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF00
8CFF0080FF0080FF0080FF0073FF0073FF0066FF0059FF004CFF0033FF000CFF0000FF2600FF00\
00FF1900FF5900FF8000FFF32600FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0059FF00BFFF00FFE600FFB300FFCC00FF7300FF664C00FF00FF2600FF0019FF0026FF0026FF00\
33FF003FFF004CFF0059FF0059FF0066FF0073FF0073FF0080FF0080FF0080FF00
8CFF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF0099FF0073FF0033FF0066FF0073FF0080FF0073FF0059FF00
00BFFF3FFF0019FF004CFF0033FF0000FF1900FF2633FF003FFF0033FF000066FF33FF0033FF00\
00FF3373FF0099FF0099FF00A6FF0099FF0099FF008CFF0073FF0000FF2673FF00
D9FF00CCFF00CCFF00B3FF0059FF0099FF00A6FF00A6FF00A6FF008CFF0059FF004CFF004CFF00\
80FF008CFF008CFF0073FF0059FF0026FF0033FF0019FF0000FF2666FF0080FF00
8CFF008CFF0099FF008CFF008CFF0080FF0080FF0073FF0066FF003FFF0000FF2659FF0066FF00\
80FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00
80FF0080FF0080FF0080FF0073FF0073FF0066FF0059FF004CFF0000FF2619FF0019FF0019FF00\
00FF0000FF2600FF4000FF8C00F3FF5900FFE600FF000000000000000000000000
4C00FF8000FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000A600FF00B3FF00FFBF00FFF300FF7300FFA600FF4C00FF190CFF0026FF0033FF00\
33FF003FFF004CFF0059FF0059FF0066FF0073FF0073FF0073FF0080FF0080FF00
8CFF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00A6FF0080FF0033FF0059FF0080FF008CFF008CFF008CFF0066FF00
73FF0066FF0059FF0026FF0033FF0000FF1973FF0080FF0080FF0080FF0019FF0080FF003FFF00\
73FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0073FF0026FF0026FF00
D9FF00D9FF00CCFF00C0FF0073FF00B3FF00C0FF00B3FF00B3FF0099FF0019FF0073FF0026FF00\
3FFF0066FF0033FF0019FF0059FF0000FF2666FF0059FF0019FF0059FF008CFF00
99FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0059FF0026FF0019FF0059FF00\
80FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00
80FF0080FF0080FF0073FF0073FF0073FF0066FF0059FF004CFF003FFF0033FF0026FF0026FF00\
0CFF0000FF1900FF4000FF8C00BFFF0000000040FF000CFF2600FFF300FF0033FF
0026FF0026FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000003F00FF0066FF00FFE600FFA600FF8000FF5900FF4000FF5900FF0C0CFF0026FF0033FF00\
33FF003FFF004CFF0059FF0059FF0066FF0073FF0073FF0073FF0080FF0080FF00
80FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00A6FF008CFF0000FF7380FF008CFF0099FF0099FF0099FF008CFF00
80FF0073FF0066FF0000FF6626FF0073FF008CFF008CFF0099FF0099FF0099FF0099FF008CFF00\
8CFF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF0080FF0080FF004CFF00
E6FF00D9FF00D9FF00CCFF00C0FF00C0FF00CCFF00C0FF00C0FF008CFF008CFF0099FF0080FF00\
66FF003FFF0073FF008CFF008CFF0066FF008CFF0066FF004CFF008CFF0099FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0066FF0019FF000CFF004CFF0073FF00\
80FF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF008CFF0000FF0073FF0073FF0080FF0080FF0080FF00
80FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF004CFF003FFF0033FF0026FF00\
00FF0000FF8C00FFCC00E6FF0033FF0059FF0080FF00FFF300E6FF00BFFF00D9FF
00D9FF0080FF0073FF7300FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000009900FF0066FF0066FF00FFD900FFA600FF6600FF3300FF1900FF000CFF0019FF0026FF00\
33FF0033FF003FFF004CFF0059FF0066FF0066FF0073FF0073FF0080FF0080FF00
80FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00A6FF0080FF0080FF008CFF00A6FF00A6FF00A6FF0099FF0099FF00
8CFF0080FF0059FF0033FF0000FF5966FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF008CFF0000FF19
E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00B3FF00A6FF008CFF00\
33FF000CFF008CFF0099FF00A6FF00A6FF00A6FF008CFF0080FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0080FF0073FF003FFF0033FF0059FF0073FF00\
80FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF0099FF008CFF0080FF0059FF0000FF1959FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF004CFF003FFF0033FF0026FF00\
19FF0000FF0000FF3300FF5900FFF300D9FF00F3FF00FFA600FFA600FFF300FFE6
00B3FF00FFF30099FF0000000000000000008C00FF7300FF000000000000A600FF6600FF8000FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000F300FF004CFF004CFF00FFCC00FF6600FF4000FF2600FF330CFF0019FF0019FF00\
19FF0019FF0000FF733FFF0059FF0066FF0066FF0073FF0073FF0073FF0080FF00
80FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF008CFF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
8CFF0080FF004CFF003FFF0066FF0080FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF0099FF003FFF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00B3FF0066FF00\
59FF0080FF0099FF00A6FF00B3FF00B3FF00B3FF00A6FF0099FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0073FF0033FF0033FF0000FF333FFF0066FF00\
73FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00\
99FF0099FF008CFF008CFF0080FF0073FF0019FF0000FF0C59FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF004CFF003FFF0033FF0026FF00\
19FF0000FF0000FF1900FF4000FF8C00FF6600FF8000FF7300FF9900FFCC00FF8C
00FF9900FFBF00BFFF00B3FFB300FFF300FF0059FF0033FF004CFF0000FF0040FF004CFF0000FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000004CFF00FFF300FFA600FF5900FF7300FF1900FF000CFF0000FF00\
00FF1900FF2626FF004CFF0059FF0059FF0066FF0066FF0073FF0073FF0073FF00
73FF0080FF0080FF0080FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
8CFF0026FF003FFF0026FF0066FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF0099FF0066FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF00\
59FF004CFF00A6FF00B3FF00B3FF00B3FF00C0FF00B3FF00B3FF00C0FF00C0FF00
C0FF00B3FF00B3FF00B3FF00B3FF00A6FF008CFF0026FF0073FF0073FF003FFF0000FF664CFF00\
73FF0080FF0080FF0080FF0080FF0080FF0080FF0066FF0066FF008CFF0099FF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF0080FF0073FF0066FF0033FF003FFF0059FF0059FF00
26FF0059FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF003FFF0000FF0019FF000CFF00\
0CFF0000FF0000FF2600FF5900FF8000FF3300FF3300FF5900FFB300FF6600FF66
00F3FF00FFE600FFA600D9FF0066FF0073FF00F3FF00F3FF0073FF00D9FF008CFF0099FF004CFF\
A600FF000000000000000000000000000000000000000000000000000000000000
0000006600FF3300FF008CFF00FFFF00FFD900FF8000FF6600FFFF00FF4000FF1900FF1900FF73\
00FF4019FF0033FF004CFF004CFF0059FF0066FF0066FF0066FF0066FF0073FF00
73FF0073FF0073FF0073FF0073FF0080FF0073FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00
8CFF0080FF0080FF004CFF004CFF0073FF0099FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF0099FF0066FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF00\
73FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF0080FF0066FF0033FF003FFF00\
59FF0066FF0073FF0073FF0073FF0000FF2659FF0026FF0073FF008CFF008CFF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
8CFF008CFF008CFF0080FF0080FF0073FF0066FF0033FF0000FF3333FF003FFF00
00FF804CFF0059FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF0019FF0000FF4C00FF8C\
00FF1900FF2600FF4000FF0C00FF0C00FF0C00FF3300FF8C00FFCC00FF4000FF40
00FF5900FF7300FF7300FF9900FFE600FFB300FFBF00E6FF00F3FF00FFD900F3FF0040FF0073FF\
9900FF000000000000000000000000000000000000000000000000000000000000
0000009900FF0099FF00E6FF0080FF00FFB300FF6600FF4C00FF6600FF5900FF4000FF8C00FF80\
00FF0C19FF0033FF003FFF004CFF0059FF0059FF0059FF0059FF0066FF0059FF00
59FF0066FF0066FF0066FF003FFF0059FF003FFF0066FF008CFF0099FF00A6FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
A6FF0099FF008CFF0059FF0026FF008CFF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF0000FF33
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF0066FF00\
8CFF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF0066FF004CFF0000FF19\
00FF403FFF004CFF003FFF0059FF003FFF000CFF003FFF0073FF0080FF008CFF00
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00\
8CFF0080FF0080FF0080FF0073FF0066FF0059FF003FFF0000FF0C00FF1900FF0C
0CFF003FFF004CFF004CFF004CFF004CFF004CFF003FFF003FFF0026FF000CFF0000FF7300FF0C\
00FF1900FF2600FF800CFF000CFF000CFF0000FF2600FF2600FF5900FF2600FF26
00FF3300FF4C00FF6600FFF300FF9900FF8000FFA60080FF00FFA600FFBF00FFFF00FFFF00B3FF\
000CFF000000000000000000000000000000000000000000000000000000000000
C000FF0033FF0099FF00E6FF00FFA600E6FF00FF5900FF3300FF2600FF2600FF0C00FF0C00FF33\
00FFB300FF1926FF0026FF003FFF004CFF004CFF004CFF004CFF004CFF003FFF00
19FF000CFF003FFF0000FF1900FF4000FFE659FF0066FF0059FF0099FF00A6FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00A6FF0099FF0073FF0000FF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00A6FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00CCFF00C0FF00A6FF0000FF59\
99FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0066FF003FFF0000FF004CFF00\
59FF0059FF0019FF0000FFCC26FF0000FF4019FF004CFF0059FF004CFF0080FF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF008CFF008CFF008CFF008CFF0080FF00\
80FF0066FF0059FF0066FF0066FF004CFF0033FF000CFF0026FF0033FF0026FF00
00FF5926FF0033FF0026FF0033FF003FFF0033FF000CFF000CFF0000FF4000FF4C0CFF0026FF00\
19FF000CFF0000FF2619FF0026FF0019FF000CFF000CFF0000FF0C00FF0C00FF19
00FF3300FF4C00FF7300FF6600FF4C00FF5900FFB300FF9900FF8000FF8C00FFB300FFD900E6FF\
000000B300FF000000000000000000000000000000000000000000000000000000
0000000C00FF0080FF00FFD900FF9900FF7300FF4C00FF3300FF1900FF0C00FF0000FF0000FF00\
00FF2600FF2600FF0C00FF2626FF003FFF003FFF003FFF0033FF0026FF0026FF00
19FF0019FF0059FF0059FF0059FF0073FF0066FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00A6FF0099FF0073FF0080FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF008CFF003FFF0080FF00\
A6FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0080FF0026FF0059FF0066FF00\
80FF0073FF0066FF0033FF0033FF0000FF1900FF9926FF0033FF003FFF0073FF00
80FF0080FF008CFF008CFF008CFF0080FF0073FF004CFF0073FF0080FF0080FF0080FF0073FF00\
73FF0059FF0019FF004CFF0059FF003FFF0000FFFF0CFF003FFF004CFF003FFF00
00FF0000FF260CFF0000FF3300FF1919FF0019FF0000FF260CFF0033FF0033FF0033FF003FFF00\
3FFF0019FF000CFF0026FF0033FF0026FF0026FF0019FF000CFF0000FF0000FF19
00FF7300FF9900FF6600FF7300FF3300FF3300FF4000FF5900FF6600FF8C00FFB300CCFF00E6FF\
00D9FF0073FF8C00FF000000000000000000000000000000000000000000000000
0000007300FF00A6FF00F3FF00FFB300FF9900FF4C00FF3300FF2600FF000CFF000CFF000CFF00\
00FF1900FF4000FF0C00FF0000FF8019FF0026FF0019FF000CFF0000FF4000FF80
33FF0059FF0073FF0080FF0080FF008CFF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
B3FF00B3FF0099FF004CFF0080FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00C0FF0099FF008CFF00\
B3FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF008CFF0066FF0033FF0073FF008CFF00\
8CFF008CFF0080FF004CFF0059FF0033FF0000FF3300FF590CFF0000FF2659FF00
73FF0080FF0080FF0080FF0080FF0073FF0066FF0026FF0059FF0059FF004CFF0066FF0059FF00\
3FFF0033FF0000FF1900FF2626FF000CFF0000FF0C00FF2659FF0059FF0059FF00
3FFF0000FF2626FF000CFF0000FF000CFF0000FF7300FF0026FF003FFF004CFF004CFF004CFF00\
4CFF0026FF0026FF003FFF003FFF0033FF0026FF0019FF000CFF0000FF0000FF19
00FF5900FF4000FF2600FFA600FF2600FF2600FF3300FF4C00FF6600FFA600FFB300FFA600FFA6\
00A6FF00A6FF000CFF000000CC00FF3300FFB300FF8000FF000000000000000000
0000000040FF0080FF00FFD900FFBF00FFB300FF7300FF9900FF2600FF0019FF0019FF0026FF00\
19FF0000FF1919FF0026FF0026FF0019FF0000FF8000FF8000FF3319FF0033FF00
4CFF0066FF0080FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00B3FF0099FF0073FF003FFF0099FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0000FF4CA6FF00\
C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF0080FF0059FF0073FF008CFF008CFF0099FF00\
99FF0099FF008CFF0080FF0059FF0026FF0019FF003FFF003FFF0000FF3300FF0C
59FF0066FF0073FF0066FF0066FF0066FF0059FF0033FF0000FF2619FF0033FF003FFF0019FF00\
26FF0019FF004CFF0026FF0026FF0000FF8059FF0066FF0066FF0066FF0066FF00
4CFF0033FF004CFF004CFF003FFF0026FF0000BFFF19FF003FFF004CFF0059FF0059FF0059FF00\
59FF004CFF004CFF004CFF003FFF003FFF0026FF0019FF0000FF0000FF0C00FF4C
00FF2600FF0C00FF0C00FF2600FF0C00FF1900FF4000FF6600FF8C00FF6600FF5900FF7300FF8C\
00FFB300FFFF000000000000004CFF008CFF008CFF0019FF0000006600FF000000
0000000040FF00BFFF00FFD900FF8C00FF8000FF6600FFA600FF3300FF0019FF0026FF0026FF00\
33FF0026FF0033FF003FFF003FFF003FFF0033FF0026FF0000FF2626FF003FFF00
59FF0073FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00B3FF0099FF0026FF0066FF008CFF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF008CFF00C0FF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00C0FF00B3FF0099FF0073FF0066FF008CFF0099FF0099FF00A6FF00\
A6FF0099FF0099FF008CFF004CFF0059FF0000FF4066FF0066FF0059FF003FFF00
26FF004CFF0059FF004CFF0033FF004CFF0026FF0000FF264CFF003FFF0066FF0073FF0073FF00\
73FF0026FF0073FF0066FF0059FF0000FF3366FF0073FF0073FF0073FF0073FF00
3FFF0059FF0066FF0059FF004CFF0000FF0000FF4C0CFF003FFF0059FF0059FF0066FF0066FF00\
66FF0059FF0059FF0059FF004CFF003FFF0000FF0000FF0C00FF2600FFB300FF80
00FF1900FF000CFF000CFF000CFF0000FF0C00FF4C00FF4C00FF6600FF4C00FF4000FF4C00FFE6\
00FFD900FFD90000000040FF0026FF00BFFF00F3FF00BFFF0066FF0073FF1900FF
0000000019FF0099FF00FFCC00FF9900FF7300FF4000FF4000FF2600FF1919FF0026FF0033FF00\
3FFF003FFF004CFF004CFF004CFF004CFF003FFF003FFF0000FF4C00FF4033FF00
59FF0066FF0080FF008CFF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00B3FF0099FF008CFF004CFF0000FF1980FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0080FF0066FF0059FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF0099FF008CFF0080FF0080FF0080FF0080FF0073FF0073FF0066FF00
3FFF0000FF0C26FF0000FF0C00FF000CFF0000FF804CFF0066FF0073FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0073FF0000FF0C73FF0080FF0080FF0080FF0080FF00
73FF0073FF0073FF0066FF004CFF0000FF330CFF003FFF0059FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0059FF0059FF003FFF0019FF0000FF3300FF0C00FF0000FF26
00FF190CFF0019FF0019FF0019FF0000FF1900FF1900FF0C00FF3300FF3300FF2600FF3300FF4C\
00FF7300FF9900FFF300FFD900FFCC00FFBF00FFCC0066FF00FFE6008CFF00CCFF
D900FF0000000066FF00BFFF00FFFF00FF9900FF4000FF1900FF000CFF0026FF0033FF003FFF00\
3FFF004CFF004CFF0059FF0059FF0059FF004CFF004CFF0000FF0C00FF0019FF00
26FF0000FF0073FF008CFF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00B3FF0099FF004CFF0059FF0099FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00C0FF00A6FF0066FF0080FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF00
66FF003FFF0000FF4C33FF003FFF0019FF0026FF004CFF0073FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF0080FF003FFF0073FF008CFF008CFF008CFF008CFF00
80FF0080FF0080FF0073FF0059FF004CFF0000FF0033FF0059FF0066FF0073FF0073FF0073FF00\
73FF0073FF0066FF0066FF0059FF003FFF0000FF3300FF0026FF0026FF000CFF00
00FF0019FF0026FF0026FF0019FF000CFF000CFF0000FF0000FF0C00FF1900FF1900FF3300FF40\
00FF6600FF9900FF7300D9FF00FF8C00FF8C00FFBF00FFB300FFA600E6FF00FFE6
00A6FF0C00FF0C00FF00A6FF00FFBF00FF7300FF4000FF3300FF190CFF0019FF0026FF0033FF00\
4CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF003FFF0033FF0000FF19
33FF0059FF0073FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00C0FF00B3FF0099FF0059FF0073FF008CFF00A6FF00B3FF00CCFF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00CCFF00C0FF0000FFB399FF0099FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0073FF00
66FF004CFF0000FF994CFF0059FF0066FF0066FF000CFF0073FF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF0080FF008CFF008CFF0099FF008CFF008CFF00
8CFF008CFF0080FF0080FF0066FF004CFF000CFF004CFF0066FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0066FF0059FF0000FF663FFF003FFF003FFF003FFF0000FF00
0CFF0026FF0033FF0033FF0026FF0026FF0019FF000CFF000CFF0000FF0000FF1900FF4000FF80\
00CCFF00FF5900FF4000FF4C00FF5900FF7300FF8C00FFCC00FF8000FFA600FFE6
00FFD900CCFF6600FF3F00FF00CCFF00FFF300FF7300FF7300FF1900FF000CFF0019FF0026FF00\
3FFF0059FF0059FF0066FF0066FF0066FF0066FF0059FF004CFF0033FF0000FF33
26FF0059FF0073FF0080FF0080FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00C0FF00B3FF0066FF008CFF0066FF0026FF0073FF0066FF00CCFF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0073FF00
66FF0033FF0000FF004CFF0066FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF008CFF008CFF0080FF0073FF003FFF004CFF0066FF0073FF0073FF0080FF0080FF0080FF00\
80FF0080FF0073FF0073FF004CFF004CFF0059FF0059FF0059FF004CFF0019FF00
26FF0033FF0033FF0033FF0033FF0026FF0026FF0019FF000CFF0000FF0000FF0C00FF3300FF59\
00FF3300FF5900FF2600FF2600FF4C00FF8000FF5900FF4C00FF6600FF8000FF8C
00FFB300FFF35900FF0000000080FF00FF8C00FF5900FF7300FF8C00FF2600FF4000FF000CFF00\
33FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0019FF0000FF33
33FF004CFF004CFF0066FF0059FF0073FF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00B3FF0099FF00B3FF00A6FF0066FF0099FF00C0FF00CCFF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0073FF00
59FF0000FF7300FF260CFF0073FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF0099FF008CFF0080FF0066FF0000FF0059FF0073FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF003FFF00
3FFF003FFF003FFF003FFF0033FF0026FF0026FF0019FF000CFF0000FF0000FF1900FF6600FF26\
00FF0C00FF2600FF0C00FF2600FF8000FF4C00FF4C00FF3300FF3300FF4C00FF66
00FF9900FFCC00E6FF0099FF0066FF00E6FF00FF4C00FF2600FF0C00FF1900FF4026FF003FFF00\
59FF0066FF0066FF0073FF0073FF0073FF0073FF0066FF0059FF004CFF0033FF00
00FF4C00FF3300FFD933FF0059FF0080FF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00C0FF00C0FF00B3FF008CFF0000FF8CC0FF00CCFF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0073FF00
59FF003FFF0033FF0066FF0073FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF008CFF0080FF0059FF0000FF5966FF0073FF0080FF0080FF008CFF008CFF008CFF00\
80FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF00
59FF004CFF004CFF003FFF0033FF0026FF0019FF000CFF0000FF0000FF0C00FF2600FF4C00FF0C\
0CFF000CFF000CFF0000FF0C00FF1900FF0C00FF3300FF1900FF2600FF4000FF66
00FF8000FF7300FFB300FFF30066FF00FFCC00FF5900FF260CFF000CFF0000FF6619FF003FFF00\
59FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0033FF00
33FF004CFF004CFF003FFF003FFF0073FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF00CCFF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0073FF0066FF0059FF00
4CFF0033FF0033FF0066FF0073FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF008CFF0073FF0033FF003FFF0066FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF00
59FF0059FF004CFF003FFF0033FF0019FF000CFF0000FF4000FF1900FF6600FF4000FF7300FF00\
19FF0019FF0019FF000CFF000CFF000CFF0000FF0000FF0C00FF3300FF8000FF80
00FF7300FF3300FF4C00FF7300FFB33F00FF00FF4C00FF1919FF0026FF0000FF000CFF0033FF00\
59FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0073FF0073FF003FFF00
59FF0073FF0073FF0059FF0033FF004CFF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF0059FF00CCFF00D9FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0066FF0000FF0C19FF00
19FF0000FF4C19FF0026FF0066FF0080FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF0099FF0099FF0080FF003FFF0059FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF00
59FF0059FF004CFF003FFF0026FF0000FF0C00FF7300FF8000FF7300FF2600FF0000FF4000FF8C\
19FF0026FF0026FF0026FF0026FF0019FF000CFF0000FF0000FF1900FF9900FF19
00FF6600FF1900FF4000FF8C00FF4000FF5900FF4C0CFF0026FF0033FF003FFF003FFF0033FF00\
33FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0033FF00
66FF0080FF0080FF0080FF0080FF0066FF0059FF0080FF008CFF0099FF00A6FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00CCFF00D9FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0080FF0066FF0033FF0033FF00
3FFF004CFF0066FF0066FF0019FF0026FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF0099FF008CFF0000FF004CFF0080FF008CFF0099FF0099FF0099FF0099FF008CFF00\
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF0066FF00
59FF0059FF004CFF004CFF003FFF0026FF0000FF0000FF330CFF0000FF0C26FF0019FF0000FF00\
26FF0033FF0033FF0033FF0026FF0019FF000CFF0000FF0000FF4000FF1900FF00
0CFF000CFF0000CCFF00FF0C00FF0C00FF3300FF0C19FF0033FF003FFF004CFF0059FF0059FF00\
66FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF0073FF00
80FF008CFF008CFF008CFF008CFF0080FF003FFF0019FF0073FF0066FF0099FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
C0FF00C0FF00B3FF00A6FF0059FF0066FF0066FF004CFF0033FF0000FF334CFF00
66FF0073FF0080FF0080FF0080FF0080FF008CFF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF0099FF0080FF0080FF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF0066FF00
59FF0059FF004CFF004CFF003FFF0019FF0000FF0C00FF0C26FF0033FF0033FF0026FF0000FF8C\
33FF003FFF003FFF003FFF0033FF0019FF0000FF0000FF2600FF5900FF400CFF00
19FF0019FF0019FF0019FF000CFF0000FF0C00FF7300FF7319FF003FFF0059FF0066FF0066FF00\
73FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
99FF0099FF0099FF0099FF0099FF0099FF008CFF0073FF0066FF0033FF0080FF00A6FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00C0FF00B3FF0080FF004CFF003FFF0073FF003FFF003FFF0000FF0C66FF00
73FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF0099FF0099FF0099FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF0066FF00
59FF0059FF004CFF003FFF0033FF0019FF0000FF0C19FF0026FF003FFF004CFF003FFF0019FF00\
3FFF004CFF004CFF003FFF0026FF0000FF0C00FF6600FFB300FF0000FF400CFF00
26FF0033FF0026FF0026FF0019FF0000FF0C00FF2619FF0033FF004CFF0059FF0066FF0073FF00\
73FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF0099FF008CFF0080FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00C0FF00C0FF00B3FF00A6FF0099FF008CFF0080FF0073FF0000FF7359FF00
73FF008CFF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00\
99FF0099FF008CFF008CFF0080FF0080FF0073FF0073FF0066FF0066FF0059FF00
59FF004CFF004CFF003FFF0026FF0000FF1926FF003FFF004CFF004CFF004CFF0059FF004CFF00\
4CFF0059FF0059FF004CFF003FFF0019FF0000FF8026FF0026FF000CFF0019FF00
33FF003FFF0033FF0033FF0019FF0000FF4000FF0033FF004CFF0059FF0066FF0066FF0073FF00\
80FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0073FF0019FF0000FF59
73FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF0099FF008CFF008CFF0080FF0080FF0073FF0066FF0066FF0059FF0059FF00
4CFF004CFF003FFF0033FF0000FF1919FF003FFF004CFF004CFF0059FF0059FF0059FF0059FF00\
59FF0059FF0059FF0059FF004CFF0019FF0019FF003FFF003FFF0033FF0000FF00
3FFF003FFF003FFF0033FF0000FF4C00FF0000FF730CFF004CFF0059FF0066FF0073FF0073FF00\
80FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0066FF000CFF003FFF00
73FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF008CFF0080FF0080FF0073FF0066FF004CFF004CFF0059FF004CFF00
3FFF0033FF0033FF0019FF0000FF6600FF0C3FFF004CFF0059FF0059FF0066FF0066FF0066FF00\
66FF0066FF0066FF0059FF004CFF000CFF004CFF004CFF0059FF004CFF004CFF00
4CFF004CFF004CFF003FFF0033FF0026FF0000FFB333FF004CFF0059FF0066FF0066FF0073FF00\
80FF0080FF008CFF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF008CFF0073FF0059FF0059FF00
80FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00\
99FF0099FF008CFF0073FF0066FF0066FF0059FF003FFF0026FF003FFF003FFF00
26FF0000FF1900FF3300D9FF00FF2626FF003FFF004CFF0059FF0066FF0066FF0066FF0073FF00\
73FF0073FF0066FF0066FF004CFF0000FF0059FF0066FF0066FF0059FF0059FF00
59FF0059FF0059FF004CFF003FFF0033FF0019FF0026FF003FFF004CFF0059FF0066FF0073FF00\
73FF0080FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00C0FF00C0FF00B3FF00B3FF00A6FF008CFF0080FF0066FF004CFF0026FF00
66FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00\
99FF0099FF0000FF3300FF0C00FF0C33FF0026FF0026FF0000FFA600FF0019FF00
00FF0C00FF4019FF0026FF0000FF0000FF260CFF0059FF0066FF0066FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0059FF0059FF0059FF004CFF003FFF0026FF0000FF0026FF003FFF004CFF0059FF0059FF00\
73FF0073FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00C0FF00C0FF00B3FF00B3FF0099FF0019FF003FFF0000FF733FFF0059FF00
4CFF0073FF008CFF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF0099FF008CFF0073FF0066FF004CFF0000FF0C0CFF0033FF0000FF0C00FF00
26FF003FFF003FFF003FFF0000FF330CFF003FFF0059FF0066FF0073FF0073FF0073FF0073FF00\
80FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF00
66FF0066FF0059FF0059FF004CFF003FFF0033FF0000FF0C0CFF000CFF0033FF003FFF0000FF00\
66FF0073FF0073FF0080FF008CFF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00C0FF00C0FF00B3FF00A6FF0099FF0080FF0019FF0066FF004CFF008CFF00
8CFF0066FF004CFF0099FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF0099FF008CFF0080FF0073FF0059FF0033FF0033FF004CFF004CFF003FFF00
3FFF0059FF0059FF004CFF000CFF0000FF4026FF004CFF0066FF0073FF0073FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00
66FF0066FF0066FF0059FF0059FF004CFF0033FF000CFF0000FF000CFF0000FF1900FF8C00FF19\
33FF0059FF0066FF004CFF0073FF0080FF0099FF00A6FF00A6FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
C0FF00C0FF00B3FF00B3FF00A6FF008CFF0066FF0026FF0080FF0099FF0099FF00
A6FF0099FF0099FF008CFF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF0099FF008CFF0080FF0073FF0059FF0000FF4033FF0066FF0066FF0059FF00
33FF0066FF0066FF0066FF004CFF003FFF0000FF0C4CFF0066FF0073FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF00
73FF0066FF0066FF0059FF0059FF003FFF0026FF0000FF4026FF0033FF0033FF003FFF0059FF00\
59FF0026FF0000FF0000FF1933FF0066FF008CFF00A6FF00A6FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
C0FF00B3FF00B3FF00A6FF0099FF0080FF003FFF0080FF0059FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00\
A6FF0099FF008CFF0080FF0066FF004CFF0000FF9959FF0073FF0073FF0073FF00
73FF0080FF0080FF0073FF0066FF004CFF0000FF0066FF0073FF0080FF0080FF0080FF0080FF00\
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF00
73FF0066FF0066FF0059FF0059FF003FFF0000FF3300FF8C26FF004CFF0059FF0059FF0073FF00\
73FF0073FF0066FF0059FF0066FF0059FF0059FF0099FF00A6FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00\
C0FF00A6FF0099FF008CFF0019FF0080FF0099FF0099FF00A6FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00\
A6FF0099FF008CFF0073FF0026FF0000CCFF00FF3366FF0080FF0080FF008CFF00
8CFF008CFF0080FF0080FF0073FF0059FF000CFF0066FF0073FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF00
73FF0073FF0066FF0059FF004CFF003FFF0026FF0000FF593FFF0059FF0066FF0073FF0080FF00\
80FF0080FF0080FF0080FF0080FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00\
B3FF0099FF0033FF000CFF0066FF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00\
99FF008CFF0080FF004CFF0000FF0073FF0073FF003FFF0080FF008CFF008CFF00
8CFF008CFF008CFF0080FF0073FF0059FF0019FF0066FF0073FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00
73FF0066FF0066FF0059FF004CFF0033FF0019FF0000FF1933FF0059FF0066FF0080FF0080FF00\
8CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00B3FF00B3FF00B3FF00\
A6FF008CFF0059FF0073FF008CFF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00\
99FF003FFF0000FF1973FF0080FF008CFF008CFF0080FF008CFF0099FF0099FF00
99FF0099FF0099FF008CFF0080FF0059FF0000FF264CFF0080FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00
73FF0066FF0000FF0019FF0026FF0000FF1900FF1919FF0026FF000CFF0066FF0080FF008CFF00\
8CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF0073FF0073FF0099FF00\
80FF0066FF003FFF0080FF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF00\
80FF004CFF0066FF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00
99FF0099FF0099FF008CFF0080FF0059FF0033FF0066FF0080FF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF00
73FF0066FF0059FF003FFF000CFF000CFF0019FF003FFF0059FF0059FF0073FF0080FF008CFF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF008CFF0026FF00\
26FF0059FF0066FF0033FF0099FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF008CFF00\
4CFF0059FF0073FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF008CFF0066FF0000FF0066FF0080FF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF00
73FF0066FF0059FF003FFF0000FF8019FF003FFF0059FF0066FF0073FF0080FF008CFF008CFF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0099FF0080FF00\
59FF0080FF008CFF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF00\
66FF0073FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0080FF0019FF0073FF008CFF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF00
73FF0059FF004CFF000CFF0000FF1926FF004CFF0059FF0066FF0073FF0080FF008CFF008CFF00\
99FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF0033FF00\
0CFF008CFF00A6FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0080FF00\
73FF003FFF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF0099FF0080FF0073FF008CFF0099FF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF00
59FF0033FF0000FF2626FF0033FF0000FF1933FF004CFF0066FF0073FF0080FF008CFF008CFF00\
99FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00C0FF00C0FF00B3FF008CFF0099FF008CFF0059FF00\
26FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00A6FF0080FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF0080FF0059FF00
00FF003FFF0059FF0059FF004CFF0000FF0000FF4000FF0059FF0073FF0073FF0080FF008CFF00\
99FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00D9FF004CFF0099FF0099FF00A6FF00A6FF00A6FF0073FF0066FF0066FF003FFF00\
73FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0073FF0000FF0C
4CFF0066FF0073FF0066FF0066FF0026FF0000FF0000FF264CFF0059FF0066FF004CFF0080FF00\
99FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00D9FF00CCFF0099FF0066FF0066FF0073FF0073FF003FFF0059FF0026FF0073FF00\
59FF008CFF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0080FF0080FF00
80FF0080FF0080FF0073FF0066FF0059FF004CFF0033FF0000FF4C19FF0026FF004CFF0080FF00\
99FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00D9FF00D9FF00CCFF00B3FF00A6FF008CFF003FFF0066FF008CFF008CFF0099FF00\
99FF0073FF0026FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF00
8CFF008CFF0080FF0080FF0073FF0066FF0059FF0033FF0019FF0059FF0073FF0080FF008CFF00\
99FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF0066FF0080FF0099FF00A6FF00A6FF00\
B3FF00B3FF00A6FF00B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
8CFF008CFF008CFF0080FF0073FF0066FF004CFF0000FF8033FF0066FF0080FF008CFF008CFF00\
99FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF0026FF0073FF00A6FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF008CFF008CFF008CFF0080FF003FFF0000FFBF00FF193FFF0066FF0080FF008CFF0099FF00\
99FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00B3FF0080FF0000FF4033FF00A6FF00B3FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF0099FF008CFF008CFF0080FF0066FF0059FF003FFF000CFF0026FF0073FF008CFF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00D9FF00CCFF00C0FF00B3FF00A6FF008CFF003FFF0099FF00B3FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0099FF008CFF008CFF0080FF0073FF004CFF0000FF2666FF0080FF008CFF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00
E6FF00D9FF00D9FF00C0FF0059FF008CFF0080FF0073FF0073FF00A6FF00B3FF00C0FF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF008CFF008CFF0080FF0073FF0059FF0000FF2666FF0080FF008CFF008CFF00\
99FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00
D9FF00D9FF00CCFF00C0FF0099FF0059FF004CFF0073FF0000FF268CFF00B3FF00C0FF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF0099FF008CFF0080FF0080FF0066FF0033FF0066FF0080FF008CFF008CFF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00
D9FF00CCFF00C0FF008CFF0066FF0099FF00A6FF00A6FF00A6FF0026FF00A6FF00C0FF00CCFF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF008CFF008CFF0080FF0066FF0000FF4066FF0073FF0080FF008CFF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00CCFF00
B3FF008CFF008CFF0099FF00A6FF00A6FF00C0FF00C0FF00C0FF0099FF0080FF00C0FF00CCFF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF008CFF008CFF0080FF003FFF0000FF4C3FFF0066FF0080FF008CFF00\
8CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00D9FF00C0FF00
33FF0099FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF0099FF00C0FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF008CFF008CFF0080FF0066FF0019FF0033FF0066FF0073FF0080FF00\
80FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00C0FF0059FF00
73FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF008CFF0080FF0073FF0059FF000CFF003FFF0059FF0066FF0066FF00\
19FF0080FF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00E6FF00CCFF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF008CFF0080FF003FFF0033FF003FFF0000FF660CFF004CFF0026FF00\
59FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF008CFF0080FF0073FF0066FF0066FF003FFF0026FF0000FF264CFF00\
66FF0073FF0080FF008CFF008CFF008CFF0080FF0066FF0080FF0099FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0073FF0066FF0059FF003FFF0000FF1900FF00\
66FF0073FF0080FF0080FF0080FF0080FF0073FF0026FF0073FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF004CFF00B3FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0059FF0026FF0019FF003FFF00\
59FF0066FF0066FF0073FF0073FF0073FF0059FF003FFF0080FF008CFF0099FF00
99FF0099FF00A6FF00A6FF0099FF008CFF0059FF008CFF00A6FF00B3FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0033FF0033FF0000FF1933FF00\
4CFF0059FF004CFF004CFF0059FF0059FF000CFF0066FF0080FF008CFF008CFF00
99FF0099FF0099FF0099FF008CFF0080FF0019FF008CFF00A6FF00B3FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF004CFF0019FF0019FF00\
33FF0033FF0000FF0C00FF0026FF0026FF0019FF0059FF0073FF0080FF008CFF00
8CFF008CFF008CFF008CFF0080FF0066FF0073FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF0033FF0000FF1926FF00\
33FF0000FF0000FF2619FF0033FF0033FF0000FF593FFF004CFF0073FF0080FF00
80FF0073FF0073FF0073FF0066FF0019FF0073FF008CFF00A6FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0066FF003FFF0000FF004CFF00\
59FF0059FF0026FF004CFF0059FF004CFF0033FF000CFF0059FF0066FF0073FF00
73FF0000FF1933FF0033FF003FFF0019FF0066FF0059FF0099FF0099FF00A6FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF004CFF0000FF334CFF0066FF00\
66FF0066FF0066FF0066FF0066FF0059FF0000FF330CFF003FFF004CFF0059FF00
59FF0033FF0000FF733FFF0059FF004CFF0019FF0066FF0080FF0080FF008CFF00A6FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF0000FF4000FF004CFF0066FF0073FF00\
73FF0073FF0080FF0073FF0073FF0066FF004CFF0000FF2600FF590073FF19FF00
19FF0026FF0019FF0066FF0073FF0073FF0000FF003FFF0000FF2600FF008CFF0099FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
99FF0099FF008CFF008CFF0080FF003FFF0059FF004CFF0033FF0033FF0059FF0073FF0073FF00\
80FF0080FF0080FF0080FF0080FF0073FF003FFF0059FF0059FF003FFF0019FF00
66FF0073FF0073FF0080FF008CFF0080FF0073FF004CFF0059FF003FFF004CFF008CFF0099FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00C0FF00B3FF00B3FF00A6FF00
A6FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00
99FF008CFF008CFF0080FF0073FF0066FF0033FF000CFF0000FF0C26FF0059FF0073FF0080FF00\
80FF008CFF008CFF008CFF008CFF0080FF004CFF0073FF0073FF0000FF000CFF00
73FF0080FF008CFF0099FF0099FF0099FF0080FF0073FF008CFF0073FF0073FF0059FF0080FF00\
80FF0099FF0099FF008CFF008CFF00A6FF00B3FF00B3FF00B3FF00A6FF0066FF00
99FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF0099FF00D9FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00
8CFF0073FF0066FF0073FF0066FF0059FF003FFF0000FF0C3FFF0059FF0066FF0073FF0080FF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0073FF000CFF00
80FF008CFF0099FF0099FF00A6FF00A6FF0099FF0099FF00A6FF0099FF0099FF0080FF0026FF00\
00FF3380FF0080FF0066FF0080FF0099FF00A6FF00A6FF00A6FF0099FF000CFF00
A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF004CFF00C0FF00D9FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00
8CFF0073FF0059FF0033FF0033FF003FFF0000FF0C00FF4026FF0059FF0066FF0073FF0080FF00\
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF008CFF0080FF0019FF00
80FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00A6FF00A6FF0099FF008CFF00\
0CFF003FFF0000FF8000FF1966FF008CFF008CFF008CFF008CFF0066FF0073FF00
99FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00B3FF0099FF0059FF00C0FF00D9FF00D9FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF00
8CFF008CFF0073FF004CFF0000FF4C19FF0000FF0C00FF4C26FF003FFF004CFF0066FF008CFF00\
8CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0066FF00
66FF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
80FF0073FF0080FF0059FF004CFF0073FF0073FF0019FF0059FF0033FF0066FF00
8CFF00A6FF00A6FF00B3FF00B3FF00B3FF00A6FF0099FF0000FF66B3FF00C0FF00D9FF00D9FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF008CFF0080FF0059FF0000FF0019FF0000FF4C00FFBF00FF5900FFBF4CFF0073FF008CFF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF004CFF00
3FFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
73FF0099FF0099FF0033FF004CFF0000FF4C26FF0000FF2666FF0066FF0019FF00
66FF0099FF0099FF0099FF008CFF008CFF0099FF0073FF004CFF00B3FF00C0FF00CCFF00D9FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF008CFF0073FF000CFF004CFF003FFF000CFF0000FF6619FF0019FF003FFF0073FF008CFF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00A6FF00A6FF00A6FF00
8CFF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00A6FF0099FF0073FF0059FF008CFF0073FF008CFF0080FF0000FF00
66FF0080FF008CFF0080FF004CFF0000FF1933FF0019FF0066FF008CFF00C0FF00CCFF00D9FF00\
D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
8CFF008CFF0080FF0073FF0066FF004CFF0026FF0000FFD933FF004CFF004CFF003FFF0080FF00\
99FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00A6FF0080FF008CFF0099FF00A6FF00A6FF008CFF003FFF00
33FF0000FF593FFF0026FF0000FFE633FF008CFF008CFF0066FF0080FF00A6FF00A6FF00C0FF00\
D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
8CFF008CFF0080FF0073FF0066FF004CFF0033FF0000FF004CFF0073FF0080FF0080FF008CFF00\
99FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00B3FF000CFF0099FF00B3FF00B3FF00B3FF0099FF0080FF00
8CFF0066FF0066FF008CFF0099FF008CFF00A6FF00A6FF0066FF004CFF0000FF7333FF00C0FF00\
CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00
8CFF008CFF0080FF0073FF0066FF0000FF2600FF0C3FFF0019FF0073FF008CFF008CFF0099FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF008CFF00B3FF00C0FF00C0FF00C0FF00B3FF00A6FF00
A6FF0066FF0073FF00A6FF00B3FF00B3FF00B3FF00B3FF0099FF008CFF0099FF0033FF008CFF00\
C0FF00CCFF00D9FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF00
8CFF008CFF0080FF0073FF0066FF003FFF0019FF0066FF0073FF0080FF008CFF0099FF00A6FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00CCFF00CCFF00C0FF00C0FF00C0FF00
B3FF008CFF008CFF00B3FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00C0FF00B3FF0099FF00\
8CFF008CFF00C0FF00C0FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF00
8CFF0080FF0080FF0073FF0066FF0033FF004CFF0073FF0080FF008CFF0099FF0099FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
B3FF0080FF008CFF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
A6FF000CFF0026FF00B3FF00D9FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF003FFF008CFF008CFF0080FF00\
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00
80FF0080FF0073FF0066FF004CFF0000FF1959FF0073FF0080FF008CFF0099FF0099FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
C0FF0099FF008CFF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF0000FF0CC0FF00B3FF00A6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF008CFF0019FF0059FF0066FF00\
80FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF00
80FF0073FF0073FF0066FF004CFF0000FF8059FF0073FF0080FF008CFF0099FF0099FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00B3FF003FFF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF000CFF0066FF0000FF33\
19FF0073FF0080FF0080FF0080FF0080FF0066FF0033FF0073FF0073FF0073FF00
73FF0059FF0059FF004CFF0033FF000CFF003FFF000CFF0073FF008CFF008CFF0099FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF0026FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF008CFF0080FF0066FF00\
00FF4033FF0073FF0073FF0073FF0073FF0066FF0000FF2659FF0066FF0066FF00
66FF004CFF000CFF0000FF1933FF0033FF000CFF003FFF0066FF0073FF0080FF0099FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF008CFF00\
73FF0033FF0033FF0026FF0059FF0059FF004CFF000CFF003FFF003FFF0059FF00
4CFF0033FF0000FF730CFF0059FF0059FF0019FF0026FF0000FF330CFF0080FF008CFF0099FF00\
A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF00\
80FF0059FF003FFF0000FF003FFF0033FF0000FF1919FF0000FF0026FF0033FF00
33FF0000FF6626FF0019FF0066FF0073FF0059FF0019FF0059FF0000FFBF4CFF008CFF0099FF00\
99FF00A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF00\
8CFF0073FF0066FF0033FF0000FF5900FF0000FF004CFF0033FF0000FF2600FF26
00FF0C3FFF0066FF0073FF0080FF0080FF0073FF0059FF0080FF0073FF003FFF0073FF0080FF00\
8CFF0099FF00A6FF00B3FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF00\
8CFF0080FF0066FF004CFF0000FF004CFF0059FF0059FF0059FF000CFF004CFF00
19FF0019FF0073FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF0080FF004CFF0059FF00\
59FF0080FF0099FF0099FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF00\
80FF0073FF0066FF0026FF003FFF0059FF0066FF0073FF0073FF0066FF0073FF00
66FF0000FF4C66FF0080FF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0080FF0066FF00\
33FF0066FF0073FF0059FF00A6FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF00\
73FF0066FF0019FF0000FF264CFF0066FF0073FF0073FF0080FF0080FF0080FF00
80FF0059FF004CFF0080FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF00\
80FF0059FF0073FF004CFF00A6FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF0080FF00\
59FF0000FF2600FF0000FF734CFF0066FF0073FF0080FF008CFF008CFF008CFF00
8CFF0080FF0066FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00A6FF00A6FF00A6FF00\
99FF008CFF0099FF0099FF0059FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0073FF008CFF008CFF008CFF008CFF008CFF0080FF00\
66FF0000FF5900FF4C00FF9933FF0066FF0080FF008CFF008CFF008CFF0099FF00
99FF0099FF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF0099FF0066FF003FFF0080FF0080FF0080FF0080FF0073FF00\
66FF004CFF0000FF3326FF0026FF0066FF0080FF008CFF008CFF0099FF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
C0FF00B3FF00B3FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF008CFF0080FF004CFF0066FF0073FF0073FF0073FF0066FF00\
59FF0026FF0000FF003FFF0066FF0073FF008CFF008CFF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
C0FF0059FF0000FF40A6FF00B3FF00A6FF00A6FF0080FF0080FF0099FF0099FF00
99FF0099FF0099FF0099FF008CFF008CFF0073FF0059FF0026FF003FFF0059FF0059FF0059FF00\
4CFF0000FFFF59FF0066FF0080FF0080FF008CFF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
C0FF00A6FF0059FF008CFF0099FF0099FF0099FF0080FF003FFF0033FF0073FF00
73FF0080FF0080FF0080FF004CFF0073FF003FFF0000FF003FFF0026FF0026FF0033FF0019FF00\
0CFF0033FF0066FF0073FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00\
B3FF00A6FF008CFF0033FF0073FF0066FF0080FF004CFF003FFF0000FF5900FFB3
4CFF004CFF0000FF403FFF0026FF003FFF0000FF1933FF0066FF004CFF000CFF0033FF0026FF00\
26FF0000FF0C66FF0073FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00\
B3FF00A6FF008CFF003FFF0000FF0019FF004CFF0019FF0073FF0073FF0066FF00
8CFF008CFF008CFF003FFF0073FF004CFF0059FF0073FF0080FF0073FF0000FF3366FF0066FF00\
3FFF0019FF004CFF0073FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00C0FF00B3FF0073FF00\
99FF008CFF0033FF0059FF0080FF0059FF0000FF0080FF008CFF0099FF0099FF00
99FF0099FF0099FF0099FF008CFF0066FF0073FF008CFF008CFF0080FF0066FF0080FF0073FF00\
3FFF004CFF0000FF7373FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00A6FF00A6FF00A6FF008CFF0073FF00\
3FFF0073FF0000FF0C73FF0099FF0099FF0080FF0080FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0080FF008CFF0099FF0099FF0099FF008CFF008CFF0080FF00\
80FF0066FF0000FF7373FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF0099FF0073FF0080FF0099FF0080FF0080FF00\
26FF003FFF008CFF0099FF00A6FF00A6FF00A6FF008CFF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF00\
80FF0073FF0000FF4C59FF0073FF0080FF008CFF0099FF0099FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF00C0FF00C0FF00B3FF00B3FF00\
A6FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00\
8CFF0073FF0033FF004CFF0066FF0073FF008CFF008CFF0099FF0099FF00A6FF00
A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF0059FF0099FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00\
8CFF0073FF0059FF0000FF2600FF3366FF0080FF008CFF008CFF0099FF00A6FF00
A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
C0FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF00\
8CFF0080FF0059FF0000FF993FFF0066FF0080FF0080FF0080FF0080FF0099FF00
A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600\
FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600FFE600
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF003FFF0066FF0066FF00
4CFF003FFF0033FF004CFF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
80FF0080FF0073FF0066FF0059FF0000FF0000FF0000FF2600FF6600FFB319FF00
33FF0026FF0000FF1900FF6633FF0033FF0000FF1926FF0033FF004CFF0073FF0080FF008CFF00\
8CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF0080FF008CFF008CFF00
73FF0059FF0059FF000CFF0026FF0073FF0080FF0080FF0080FF0080FF0066FF0080FF0080FF00\
80FF0073FF0066FF0066FF004CFF0033FF000CFF0026FF0033FF0026FF0000FF33
00FF4C00FF3333FF0033FF004CFF0059FF003FFF0033FF0033FF0026FF0066FF0073FF0080FF00\
8CFF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF00
80FF0080FF0080FF004CFF0066FF0026FF0066FF0059FF0073FF0066FF0000FF0C66FF0073FF00\
73FF0066FF0000FF193FFF0026FF0000FF0C3FFF004CFF004CFF003FFF0026FF00
26FF0000FF004CFF0059FF0066FF0066FF0059FF0059FF0066FF004CFF0033FF003FFF0073FF00\
66FF008CFF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF00
99FF0099FF008CFF008CFF0080FF0073FF000CFF0026FF004CFF004CFF0000FF0059FF0066FF00\
66FF0059FF000CFF0000FF4000FF2626FF004CFF0059FF0059FF0059FF0059FF00
4CFF0026FF004CFF0066FF0073FF0073FF0073FF0073FF0073FF0073FF003FFF000CFF0033FF00\
59FF0073FF0066FF0080FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00
A6FF00A6FF0099FF0099FF008CFF0080FF0066FF0019FF0000FF4000FF6600FF190CFF004CFF00\
59FF004CFF0026FF0000FF2600FF7300FF004CFF0066FF0066FF0066FF0066FF00
66FF0000FF4033FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0033FF004CFF00\
00FF1900FF6600FF0C80FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF0099FF0099FF008CFF0073FF003FFF0059FF004CFF0033FF0000FF0026FF00\
3FFF0033FF0000FF3319FF0033FF0000FFB359FF0066FF0073FF0073FF0073FF00
73FF0059FF0000FF0073FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0073FF00\
4CFF0066FF0066FF000CFF0080FF0099FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF0099FF008CFF0073FF0073FF0073FF0066FF003FFF0019FF0000FF73\
00FF0C00FF0C3FFF004CFF0059FF0059FF0066FF0073FF0073FF0080FF0080FF00
80FF0080FF0073FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF008CFF008CFF00\
66FF008CFF008CFF008CFF0066FF0019FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0073FF003FFF004CFF003FFF00\
0CFF000CFF004CFF0059FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF00
80FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0080FF0073FF0066FF004CFF00\
00FF3326FF004CFF0066FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF00
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0073FF0073FF0059FF00\
33FF0019FF004CFF0066FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF00
8CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0059FF00\
3FFF003FFF0066FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF00
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0059FF00\
00FF8C4CFF0066FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF00
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF000CFF00\
00FF004CFF0066FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0080FF0073FF0059FF003FFF00\
00FFA63FFF0059FF0073FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0059FF0059FF004CFF0019FF00\
00FF7326FF004CFF0066FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
CCFF0073FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0073FF004CFF0000FF260CFF0000FFD9\
26FF003FFF0059FF0066FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00
C0FF0080FF00A6FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF0099FF008CFF0080FF0080FF0073FF0066FF0059FF003FFF000CFF0000FF0C\
26FF003FFF004CFF0059FF0066FF0073FF0080FF008CFF008CFF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00
C0FF008CFF0059FF00A6FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF0099FF0099FF0080FF0033FF0059FF0000FF1959FF004CFF003FFF0019FF0000FF26\
19FF0019FF003FFF004CFF004CFF0033FF0073FF008CFF008CFF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
C0FF00A6FF0000FF0C99FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF008CFF0073FF0000FF2600FF1933FF0026FF000CFF0000FF1900FF99\
00FF1900FFF300FF5926FF0026FF0066FF0073FF0080FF008CFF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00
C0FF00A6FF004CFF008CFF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF008CFF0080FF0066FF0033FF0000FF4000FF1900FF6600FF73004CFF\
00FFA600FFB300FF0C0CFF000CFF0059FF0073FF0080FF008CFF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00D9FF00C0FF00C0FF00CCFF00C0FF0080FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
B3FF00A6FF008CFF008CFF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
8CFF0099FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0066FF00\
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF008CFF0080FF0033FF0026FF0033FF000CFF0000FF5900FF2600FF73\
00FF260CFF0026FF003FFF0000FF0000FF8059FF0073FF0080FF008CFF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00CCFF00B3FF0033FF0099FF0066FF008CFF0033FF00\
C0FF00C0FF00CCFF00C0FF00C0FF00B3FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00A6FF004CFF0066FF0080FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
80FF0073FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0066FF00\
80FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF008CFF008CFF0080FF0066FF0059FF004CFF0033FF0019FF0000FF0000FF33\
26FF003FFF004CFF0059FF0033FF0059FF004CFF0019FF0066FF008CFF0099FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00E6FF00E6FF00D9FF00C0FF0099FF00A6FF004CFF0033FF00\
99FF00B3FF00B3FF00B3FF00A6FF008CFF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF0099FF0080FF0000FF5980FF008CFF0080FF0026FF00A6FF00A6FF00A6FF00A6FF0099FF00\
80FF0080FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0019FF00\
00FF0C66FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF0059FF004CFF0033FF0019FF0000FF40\
26FF004CFF0059FF0066FF0073FF0073FF0073FF0073FF0080FF008CFF0099FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00CCFF00C0FF00CCFF00C0FF00B3FF00\
99FF004CFF0080FF0099FF008CFF0073FF00A6FF00A6FF00A6FF0099FF008CFF00
99FF008CFF0073FF0000FF264CFF0066FF0000FF3380FF0099FF00A6FF00A6FF0099FF008CFF00\
66FF0080FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF00\
59FF004CFF0080FF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF008CFF008CFF008CFF0080FF0073FF0073FF0059FF004CFF0026FF0000FF0C00FF00\
00FFA63FFF0059FF0073FF0080FF0080FF0080FF008CFF008CFF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00\
C0FF00A6FF003FFF0000FFB359FF0000FF0080FF0099FF0099FF0059FF0059FF00
33FF003FFF004CFF0066FF004CFF003FFF0000FF193FFF008CFF008CFF0080FF008CFF0080FF00\
3FFF0066FF0080FF0080FF0099FF0099FF008CFF0099FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF00\
73FF0000FF0073FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00
8CFF008CFF008CFF008CFF0080FF0080FF0073FF0066FF0026FF000CFF0000FF6600FF0C33FF00\
4CFF0026FF0026FF0073FF0080FF008CFF008CFF008CFF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
CCFF00B3FF0080FF0099FF0099FF003FFF0066FF0080FF0080FF0059FF0000FF19
00FF4066FF0080FF008CFF0080FF0073FF0033FF0059FF0073FF0073FF0000FF004CFF0000FF00\
00FF0000FF193FFF0073FF008CFF008CFF0073FF008CFF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF00\
80FF0059FF0066FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF0080FF0080FF0073FF0066FF0059FF003FFF0000FF333FFF004CFF00\
66FF0066FF0066FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00C0FF00C0FF00B3FF00A6FF0066FF004CFF0033FF004CFF0066FF0059FF00
3FFF0059FF0099FF0099FF0099FF0080FF0033FF0000FF664CFF004CFF0000FF0000FF2659FF00\
73FF0066FF0033FF0059FF0066FF0066FF0019FF0073FF008CFF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF00\
80FF004CFF003FFF0059FF0073FF0080FF0073FF0000FF0080FF0080FF008CFF00
8CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF0059FF0033FF0000FF4C3FFF0059FF00\
73FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00CCFF00C0FF00B3FF00A6FF008CFF0000FF0C80FF0099FF0099FF00
73FF0099FF00A6FF00A6FF00A6FF008CFF0080FF0066FF0000FF3366FF0073FF0059FF0080FF00\
8CFF0080FF003FFF0000FF730CFF0019FF004CFF000CFF0066FF0066FF0099FF00
99FF0099FF00A6FF0099FF0099FF0080FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00\
73FF0059FF0019FF004CFF0066FF0066FF0066FF0000FF0073FF0080FF0080FF00
80FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF004CFF000CFF0033FF004CFF0066FF00\
73FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00CCFF00C0FF00B3FF0099FF0000FF0C99FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0073FF0026FF0080FF008CFF008CFF0099FF00\
99FF008CFF0080FF000CFF0073FF0080FF0080FF0019FF0033FF0019FF0073FF00
8CFF008CFF008CFF008CFF0080FF0033FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00\
73FF0059FF0000FF0C3FFF004CFF0059FF003FFF004CFF0066FF0073FF0073FF00
80FF0080FF0073FF0073FF0073FF0073FF0066FF0059FF0033FF0026FF0059FF0066FF0073FF00\
80FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00CCFF00C0FF00B3FF0066FF0099FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0080FF0073FF0099FF0099FF00A6FF00A6FF00\
A6FF0099FF008CFF004CFF008CFF0099FF008CFF0033FF008CFF0080FF0066FF00
33FF0059FF0073FF0080FF0066FF004CFF0073FF0080FF008CFF0080FF0066FF0066FF0066FF00\
66FF004CFF0000FFCC00FF4C00FFA619FF0000FF663FFF0059FF0066FF0073FF00
73FF0073FF0073FF0066FF0066FF0066FF0059FF000CFF0000FF804CFF0066FF0073FF0073FF00\
80FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00C0FF00A6FF0000FF19A6FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0073FF0080FF0099FF00A6FF00B3FF00B3FF00\
B3FF00A6FF0099FF0073FF0099FF00A6FF00A6FF0099FF0099FF0099FF008CFF00
33FF004CFF004CFF0000FF3333FF0026FF0033FF0073FF0073FF0073FF004CFF0033FF0000FF0C\
26FF0026FF003FFF004CFF0000FF3333FF0000FF0000FF003FFF0059FF0066FF00
66FF0059FF004CFF0059FF0059FF0059FF004CFF0026FF000CFF004CFF0066FF0073FF0073FF00\
80FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00C0FF0099FF008CFF00B3FF00C0FF00C0FF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00A6FF0073FF008CFF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00
8CFF0073FF0019FF004CFF0059FF003FFF0026FF0059FF0066FF0059FF003FFF0000FF6600FFCC\
33FF0059FF0066FF0066FF0059FF004CFF0026FF0000FF003FFF004CFF0059FF00
4CFF0026FF0026FF0026FF004CFF004CFF0033FF0000FF260CFF003FFF0066FF0073FF0073FF00\
80FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00CCFF0080FF0080FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0080FF00A6FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
99FF0080FF0073FF0080FF0073FF0059FF0000FF2600FF003FFF0033FF0000FF1919FF0000FF0C\
3FFF0066FF0073FF0073FF0066FF0059FF0033FF0000FFA600FF193FFF003FFF00
33FF0000FF0C00FF1900FF730CFF0026FF0000FF0C00FF0033FF004CFF0059FF0066FF0073FF00\
80FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00D9FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00A6FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
A6FF008CFF0099FF0099FF008CFF0000FF8C66FF003FFF000CFF0059FF0059FF0059FF003FFF00\
66FF0073FF0080FF0080FF0073FF0059FF0033FF003FFF0000FF0000FF1900FF99
00FF1900FF4C00FF660CFF000CFF0033FF0026FF0000FF4000FF003FFF0059FF0066FF0073FF00\
80FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0033FF003FFF0066FF0073FF0080FF0073FF00\
80FF0080FF0080FF0080FF0080FF0073FF0066FF0059FF0026FF0000FF003FFF00
4CFF0033FF0000FF0019FF004CFF004CFF003FFF0000FF0C00FF8026FF0019FF0033FF0073FF00\
80FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF0066FF003FFF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF0080FF0080FF0073FF0059FF0026FF003FFF0059FF00
66FF0059FF0000FF2659FF0059FF0059FF004CFF003FFF0019FF0000FF003FFF0059FF0073FF00\
73FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00B3FF00A6FF0099FF0080FF0000FF4C73FF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF0000FF1959FF0066FF00
73FF0073FF0066FF0066FF0066FF0066FF0059FF003FFF0000FF4C0CFF004CFF0059FF0066FF00\
73FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00A6FF0099FF0080FF0033FF0080FF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF0080FF0000FFA63FFF0066FF0073FF00
80FF0080FF0073FF0073FF0073FF0066FF0059FF0026FF0000FF0026FF003FFF0059FF0066FF00\
66FF0073FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00CCFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00A6FF0099FF0066FF0066FF008CFF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF0099FF008CFF0073FF0000FF194CFF0073FF0080FF00
80FF0080FF0080FF0080FF0073FF0073FF0066FF004CFF000CFF0000FF1926FF000CFF004CFF00\
59FF0059FF0000FF0C33FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00C0FF0099FF00C0FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF0099FF004CFF004CFF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF0099FF0099FF0080FF0026FF0066FF0080FF008CFF00
8CFF008CFF008CFF0080FF0080FF0073FF0066FF003FFF000CFF0033FF0000FF3300FF4033FF00\
00FF0C00FF2633FF0073FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00B3FF004CFF0099FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00B3FF0099FF008CFF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0080FF0073FF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF0080FF0073FF0033FF0033FF0059FF0059FF0000FFBF33FF0000FF00\
19FF0059FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00B3FF0099FF0033FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF008CFF008CFF008CFF0080FF0000FF2666FF0066FF0066FF0059FF004CFF0026FF00\
00FF0C59FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00A6FF0073FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0073FF0066FF004CFF0000FF19\
33FF0059FF0073FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF0099FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0000FF333FFF00\
00FF4033FF004CFF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0073FF0066FF0059FF00\
0CFF003FFF0066FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0073FF0066FF00\
3FFF003FFF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF00\
4CFF004CFF0066FF0073FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF008CFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0073FF00\
33FF0033FF0059FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF008CFF0000FF40
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF00\
4CFF0000FF263FFF0066FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF00
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF004CFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0066FF00\
3FFF000CFF004CFF0066FF0066FF0073FF0080FF008CFF008CFF008CFF0099FF00
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0073FF0019FF00\
3FFF000CFF000CFF004CFF004CFF000CFF0073FF0080FF008CFF008CFF008CFF00
99FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00\
B3FF0059FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0080FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF00\
59FF003FFF000CFF0000FF1933FF0059FF0073FF0080FF0080FF008CFF008CFF00
8CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
B3FF0066FF004CFF0080FF0099FF0099FF0099FF008CFF008CFF008CFF0073FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0073FF00\
66FF003FFF000CFF0026FF004CFF0066FF0073FF0080FF0080FF0080FF008CFF00
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
B3FF00A6FF008CFF004CFF0080FF0080FF0080FF0066FF0080FF0066FF0000FF33
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0073FF00\
4CFF0000FF3300FF0033FF0059FF0066FF0073FF0073FF0080FF0080FF0080FF00
80FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
8CFF008CFF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
B3FF00A6FF0099FF008CFF0026FF003FFF003FFF0000FF0C4CFF003FFF0033FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0080FF0073FF00\
59FF0033FF0000FF263FFF004CFF0059FF0066FF0073FF0073FF0080FF0080FF00
80FF0080FF0073FF0073FF0033FF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF008CFF0080FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0073FF008CFF0000FF40
66FF0099FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
B3FF00A6FF00A6FF008CFF0073FF0019FF003FFF0066FF0033FF0000FF5980FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0073FF0066FF0059FF00\
3FFF0000FF2600FF3333FF003FFF004CFF0059FF0066FF0073FF0073FF0073FF00
73FF0066FF003FFF0033FF0073FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
8CFF0080FF0073FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0080FF000CFF000CFF00
8CFF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00\
B3FF00A6FF0099FF008CFF0073FF0019FF0073FF0080FF0080FF0080FF0073FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF0073FF004CFF0000FF0C00FF73\
33FF003FFF0033FF0000FF4C19FF0000FF0C4CFF0059FF0066FF0066FF0066FF00
59FF004CFF0000FF2666FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF00
80FF0000FF0073FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0080FF0019FF0073FF00
99FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00A6FF0099FF0000FF0026FF003FFF0073FF008CFF0099FF0099FF0099FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF0080FF0066FF0066FF0066FF00\
66FF0059FF004CFF0000FF2600FF8C00FF0033FF004CFF0059FF0059FF0059FF00
3FFF0000FF193FFF0000FF4080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF0073FF00
00FF0C00FF3366FF0080FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0019FF0066FF0033FF0059FF00
80FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00\
A6FF0099FF0099FF0080FF003FFF0000FF1933FF0099FF00A6FF00B3FF00B3FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0080FF0073FF00\
73FF0066FF0059FF0000FF2600FF2600FF1919FF003FFF003FFF0000FF330CFF00
00FF1933FF0066FF0073FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF00
66FF0000FF194CFF000CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF0099FF008CFF0073FF0000FF194CFF0080FF00
8CFF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF0099FF0099FF00\
99FF008CFF008CFF0073FF004CFF0066FF008CFF00A6FF00A6FF00B3FF00C0FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0080FF00\
73FF0073FF0059FF004CFF0033FF0026FF0000FF0C0CFF0000FF0C00FF5933FF00
4CFF0066FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF00
66FF004CFF0019FF0066FF0080FF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF008CFF0099FF008CFF008CFF008CFF0080FF0000FF0000FF2673FF008CFF00
99FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF0099FF0026FF00\
80FF0073FF0073FF0066FF0000FF4C66FF008CFF00A6FF00B3FF00B3FF00C0FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF008CFF0080FF00\
73FF0073FF0066FF0059FF004CFF003FFF0026FF0000FF190CFF0019FF003FFF00
59FF0066FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF00
26FF0000FF0C33FF0066FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF008CFF00\
80FF0066FF0080FF0080FF0073FF0066FF003FFF004CFF0073FF008CFF0099FF00
A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0080FF00\
26FF0026FF0000FF2600FF2659FF0026FF0080FF0099FF00A6FF00C0FF00C0FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF00\
80FF0073FF0066FF0059FF004CFF003FFF0026FF0000FFA619FF003FFF004CFF00
66FF0066FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00
66FF004CFF0000FF4C59FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
80FF0019FF0066FF0066FF0059FF0026FF0059FF0080FF008CFF0099FF0099FF00
A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF0080FF00\
59FF004CFF0066FF0000FF4C80FF008CFF0073FF0059FF0059FF00C0FF00CCFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF00\
73FF0073FF0066FF0059FF004CFF003FFF0026FF0000FF2619FF003FFF004CFF00
66FF0066FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF00
73FF004CFF0000FF4059FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF0080FF00\
73FF0059FF0000FF190CFF000CFF003FFF0073FF008CFF0099FF0099FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF0080FF00\
26FF003FFF008CFF008CFF0099FF00A6FF00A6FF0066FF008CFF00B3FF00CCFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF00\
73FF0066FF0059FF0059FF0000FF2626FF000CFF0000FF2600FF0C26FF003FFF00
59FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF00
73FF0059FF0000FF0C59FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF00\
73FF0059FF0026FF003FFF004CFF0059FF0073FF008CFF0099FF0099FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF004CFF004CFF00\
00FF1973FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00CCFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF00\
59FF004CFF004CFF003FFF0026FF0000FF3300FF4C00FF0026FF0026FF0033FF00
59FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF00
66FF0059FF0000FF194CFF0066FF0066FF0073FF0073FF0073FF004CFF0066FF0073FF0073FF00\
66FF0000FF3300FF333FFF0066FF0073FF0080FF008CFF0099FF0099FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF0080FF0019FF0059FF00\
73FF0000FF0C8CFF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0073FF00\
4CFF0019FF0000FFD90CFF0000FF0000FF7319FF0026FF003FFF004CFF0059FF00
66FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF00
66FF004CFF0000FF4C33FF004CFF003FFF0066FF0066FF0066FF003FFF003FFF0059FF0059FF00\
59FF0033FF0000FF403FFF0066FF0080FF0080FF008CFF0099FF0099FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0026FF000CFF0080FF00\
99FF0099FF008CFF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF00\
66FF0059FF003FFF0026FF0000FF0C0CFF0026FF003FFF004CFF004CFF0059FF00
66FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF00
59FF0033FF0019FF0000FF5900FF263FFF0059FF0059FF0059FF003FFF0026FF003FFF003FFF00\
3FFF0033FF0026FF004CFF0066FF0073FF0080FF008CFF0099FF0099FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF00B3FF00
B3FF00B3FF00A6FF00A6FF0099FF0026FF0080FF0080FF0000FF2659FF0080FF008CFF0099FF00\
A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0073FF00\
66FF0059FF004CFF0033FF000CFF000CFF0033FF003FFF004CFF0059FF0059FF00
66FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF00
66FF004CFF003FFF0019FF0000FF3333FF003FFF003FFF003FFF0026FF0000FF6600FF0019FF00\
26FF0000FF0C00FF2633FF0059FF0066FF0073FF008CFF0099FF0099FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF004CFF0099FF0099FF00
A6FF00A6FF00A6FF0099FF0099FF0080FF0000FF1900FF0C3FFF0080FF0099FF00A6FF00A6FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF00\
66FF0059FF004CFF0033FF0000FF2600FF190CFF003FFF004CFF0059FF0059FF00
66FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF00
66FF0059FF003FFF0019FF0000FF0C26FF0033FF0000FF3300FF0C00B3FF19FF0019FF0000FF66\
00FF3300FF5926FF0033FF0000FF0000FF2600FF4C66FF008CFF0099FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0073FF0026FF0073FF00
8CFF0099FF0099FF008CFF008CFF0073FF0000FF0066FF0080FF008CFF00A6FF00A6FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00
99FF008CFF008CFF0080FF0059FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF00\
59FF0059FF003FFF0019FF0000FFB300FF6600FF1926FF004CFF0059FF0059FF00
66FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF00
59FF0059FF0033FF0019FF0000FF3300FF000CFF0000FF2600FFD90CFF0033FF0033FF0033FF00\
00FF8C3FFF0059FF0059FF0059FF0059FF0066FF0080FF008CFF0099FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0080FF0073FF0000FF8C
73FF008CFF0080FF004CFF0066FF0059FF0000FF6673FF008CFF0099FF00A6FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF00
59FF0059FF0033FF0066FF0000FF6659FF0059FF0066FF0073FF0073FF0066FF0059FF0033FF00\
4CFF004CFF003FFF0026FF0000FF0C00FF2626FF003FFF004CFF0059FF0059FF00
66FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00
59FF0059FF004CFF0033FF000CFF0000FFBF0CFF0019FF0019FF0026FF003FFF004CFF004CFF00\
33FF004CFF0066FF0066FF0073FF0073FF0080FF008CFF008CFF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF0073FF00
00FF7359FF0066FF004CFF0000FF2626FF0000FF0066FF0080FF0099FF00A6FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
8CFF0073FF000CFF0000FF1933FF000CFF0019FF0026FF003FFF0059FF0059FF004CFF0026FF00\
26FF0026FF0033FF0026FF0000FF0C19FF0033FF003FFF004CFF0059FF0059FF00
59FF0066FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0066FF0066FF0066FF00\
4CFF0066FF0066FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF00
59FF004CFF004CFF0033FF0000FF9900FF0C26FF0033FF003FFF004CFF004CFF0059FF0059FF00\
59FF0066FF0073FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF0080FF00
66FF0033FF0026FF0000FF264CFF003FFF0066FF0066FF0059FF0099FF00A6FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
99FF008CFF0033FF0066FF0059FF0000FF594CFF000CFF000CFF0026FF0000FF0033FF000CFF00\
00FFA600FF190CFF0000FF0000FFE619FF0033FF003FFF004CFF004CFF0059FF00
59FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF003FFF00\
26FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF00
59FF004CFF003FFF0033FF0000FF0000FF1933FF003FFF004CFF004CFF0059FF0059FF0066FF00\
66FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF00
80FF0066FF0000FF804CFF0066FF0073FF0080FF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
99FF008CFF0080FF0080FF0073FF0066FF0066FF0066FF0059FF003FFF0019FF0000FF4000FF26\
19FF0000FF1900FF3300FF1900FF3300FF0026FF003FFF003FFF004CFF004CFF00
59FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF003FFF00\
00FF004CFF0059FF0059FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF00
4CFF004CFF003FFF0026FF0000FFE626FF003FFF004CFF004CFF0059FF0059FF0066FF0066FF00\
73FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF00
80FF0066FF0019FF0059FF0073FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
99FF0099FF008CFF008CFF0080FF0080FF0073FF0073FF0066FF0066FF004CFF0033FF003FFF00\
3FFF0000FF1926FF0026FF0000FF0000FF6600FF4033FF003FFF004CFF004CFF00
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF0033FF00\
26FF003FFF004CFF0059FF0059FF0059FF0059FF004CFF004CFF004CFF004CFF00
3FFF0033FF0026FF0000FF4019FF0033FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF00\
73FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF00
73FF003FFF0000FFA63FFF0066FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF008CFF008CFF0080FF0080FF0080FF0073FF0066FF0059FF004CFF0059FF00\
4CFF0033FF003FFF0033FF0019FF000CFF0000FF4026FF003FFF003FFF004CFF00
4CFF004CFF0059FF0059FF0059FF0059FF004CFF0033FF004CFF004CFF004CFF0026FF0000FF19\
19FF003FFF004CFF004CFF004CFF004CFF003FFF0019FF003FFF003FFF003FFF00
33FF0019FF0000FF4C00FF4019FF003FFF003FFF004CFF0059FF0059FF0066FF0066FF0066FF00\
73FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF00
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF00
00FF0C00FF0000CCFF00FF3300FF0C66FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF0066FF0059FF00\
59FF0059FF004CFF003FFF003FFF0033FF0000FF0019FF0033FF003FFF003FFF00
4CFF004CFF004CFF004CFF004CFF004CFF003FFF0000FF5919FF003FFF0033FF0026FF0000FF19\
00FF0000FF0C33FF003FFF004CFF003FFF0033FF0000FF0019FF0033FF0033FF00
26FF0019FF0000FF4C00FF0026FF0033FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF00\
73FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF00
73FF0019FF0033FF0000FF6659FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF0066FF00\
66FF0059FF0059FF004CFF003FFF0033FF0000FF0000FF0C0CFF0033FF0033FF00
3FFF003FFF004CFF004CFF004CFF003FFF0033FF0019FF0000FF6626FF0026FF0000FF5900FF26\
00FF1919FF0033FF003FFF003FFF003FFF0033FF0019FF0000FF2619FF0019FF00
00FF2600FF0000FF2600FF0C19FF0033FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF00\
73FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF003FFF008CFF0099FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF00
73FF0066FF003FFF000CFF0066FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF00\
66FF0059FF0059FF004CFF004CFF003FFF0019FF0000FF730CFF0019FF0019FF00
00FF0C33FF003FFF003FFF003FFF003FFF0033FF0026FF0000FF0000FF0C00FF0000FF3300FF26\
00FF0019FF0026FF0033FF0033FF0033FF0026FF0019FF0000FF8000FF4C00FF00
00FF3300FF8C00FF5900FF1900FF0026FF003FFF004CFF004CFF0059FF0059FF0066FF0066FF00\
73FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00
8CFF008CFF0099FF0099FF008CFF008CFF008CFF0080FF003FFF003FFF0073FF008CFF0099FF00\
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF00
73FF0066FF0059FF0026FF0059FF0073FF0080FF008CFF008CFF0099FF0099FF00A6FF00B3FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0073FF00\
66FF0066FF0059FF0059FF004CFF0033FF0000FF3300FF2600FF9900FF0000FF19
0CFF0033FF0033FF0033FF0033FF0033FF0033FF0026FF000CFF0000FF1900FF6600FF5900FF0C\
0CFF0019FF0026FF0026FF0026FF0026FF0026FF0019FF0000FF0C00FFB300FF33
00FF8C00FF1900FF190CFF0026FF0033FF003FFF004CFF004CFF0059FF0059FF0059FF0066FF00\
66FF0073FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0073FF0059FF003FFF0073FF008CFF0099FF00\
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF00A6FF0099FF0073FF008CFF008CFF008CFF008CFF0080FF0080FF0073FF00
73FF0066FF004CFF0000FFA626FF004CFF0059FF0073FF0073FF0073FF004CFF008CFF00A6FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0073FF00\
66FF0066FF0059FF0059FF004CFF003FFF0026FF000CFF0000FF1900FFD900FF19
19FF0026FF0033FF0033FF0033FF0033FF0026FF0026FF0019FF0000FF0000FF2600FF7300FF0C\
0CFF000CFF0019FF0019FF0019FF0019FF0019FF000CFF0000FF0000FF3300FF40
00FF1900FF000CFF0019FF0026FF0033FF003FFF003FFF004CFF004CFF004CFF0059FF0059FF00\
66FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0066FF004CFF0026FF0059FF0080FF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF0099FF0099FF0080FF003FFF004CFF0073FF0080FF0073FF0073FF0066FF00
66FF0059FF0019FF0019FF0033FF0019FF0033FF003FFF000CFF0033FF0080FF0099FF00A6FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
99FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0073FF00\
66FF0066FF0059FF0059FF004CFF003FFF0033FF0019FF0000FF0C00FF4C00FF26
0CFF0026FF0026FF0026FF0026FF0026FF0026FF0019FF000CFF0000FF0000FF1900FF4000FF0C\
00FF0000FF000CFF0000FF0000FF0C0CFF000CFF0000FF0000FF0C00FF3300FF26
00FF0C00FF000CFF0019FF0026FF0033FF0033FF003FFF003FFF0033FF0000FF004CFF0059FF00\
59FF0066FF0066FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00
8CFF008CFF008CFF0080FF0080FF0080FF0073FF0019FF0000FF4C33FF0066FF0080FF008CFF00\
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0080FF0066FF0000FF0C4CFF0066FF0066FF0059FF0033FF00
4CFF003FFF0000FF0C19FF0059FF0066FF0080FF0080FF0080FF008CFF0099FF00A6FF00B3FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF0099FF0099FF00A6FF00A6FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF0066FF00\
66FF0066FF0059FF004CFF004CFF003FFF0026FF000026FF00FF7300FF3300FF0C
0CFF0019FF0019FF0026FF0019FF0019FF0019FF000CFF0000FF0000FF0C00FF2600CCFF00FF4C\
00FF1900FF1900FF2600FF4000FF2600FF0C00FF2600FF0C00FF2600FF8000FF26
00FF0C00FF000CFF0019FF0026FF0026FF0033FF0033FF0033FF0026FF0000FF193FFF004CFF00\
4CFF0059FF004CFF003FFF0066FF0073FF0073FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0073FF0066FF004CFF0000FF6659FF0073FF008CFF008CFF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF0099FF008CFF0080FF0066FF003FFF0033FF003FFF003FFF0000FF26
00FF1900FF2619FF0059FF0073FF0080FF008CFF008CFF0099FF0099FF00A6FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00B3FF0099FF0066FF0080FF008CFF0073FF0080FF0099FF0099FF0099FF00\
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0073FF0066FF00\
66FF0059FF004CFF003FFF0033FF0033FF0026FF000CFF0000FF2600FFB300FF0C
0CFF000CFF0019FF0019FF000CFF0000FF4C00FF0000FF0000FF1900FF4000FF4C00FF8000FF33\
00FF2600FF3300FF8000FF7300FF3300FF2600FF3300FF4000FF6600FFB300FFFF
00FF0C00FF0000FF000CFF0019FF0019FF0026FF0026FF0026FF000CFF000CFF0033FF003FFF00\
26FF003FFF0000FF193FFF0066FF0073FF0073FF0073FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0073FF0073FF0066FF000CFF000CFF0059FF0080FF008CFF008CFF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF0099FF008CFF008CFF0080FF0073FF0059FF0033FF0000FF0C00FF4026FF00
26FF0033FF0033FF003FFF0073FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00B3FF0099FF0066FF004CFF0026FF0033FF0080FF008CFF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF00\
66FF0059FF003FFF0000FF2600FF0C0CFF000CFF0000FF1900FF3300FF3300FF0C
00FF000CFF000CFF000CFF0000FF0000FF2600FF3300FF1900FF1900FF4000FFA600FF6600FF4C\
00FF4C00FF4C00FF8000FF6600FF4C00FF4000FF4C00FFCC00FF9900FF4C00FF33
00FF1900FF1900FF5900FF0000FF0C00FF0019FF0019FF000CFF0000FF0C00FF400CFF0019FF00\
00FF0C00FF2633FF004CFF0066FF0066FF0073FF0073FF0073FF0073FF0080FF00
80FF0073FF0073FF0073FF0073FF0066FF0059FF0000FF4C3FFF0073FF0080FF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00\
99FF0099FF008CFF008CFF0080FF0073FF0066FF004CFF000CFF0033FF004CFF00
59FF0059FF0066FF0059FF0000FF598CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0073FF0073FF0073FF0000FF5900FF6673FF008CFF00\
8CFF008CFF008CFF008CFF008CFF0073FF0066FF0080FF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0066FF0066FF00\
59FF0059FF004CFF0026FF000CFF0000FF0000FFA600FF400099FF00FF4C00FF19
00FF0C00FF0000FF0000FF0C00FF2600FF5900FFA600FF3300FF3300FF4000FF6600FF9900FF73\
00FFB300FF8C00FFFF00FF994C00FF00FF6600FF6600FFB300FF5900FF4000FF33
00FF2600FF2600BFFF00FF3300FF4C00FF0C00FF000CFF0000FF0000FF1900FF4C00E6FF00FF59\
00FF2626FF003FFF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0066FF0059FF004CFF000CFF004CFF0066FF0073FF0080FF0080FF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
99FF008CFF008CFF0080FF0080FF0073FF0066FF004CFF0000FFB33FFF0059FF00
66FF0073FF0073FF0080FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00B3FF00B3FF0099FF0099FF008CFF0073FF0059FF0000FF0C73FF00\
80FF0080FF0080FF0080FF0080FF0059FF0019FF0073FF0080FF0080FF008CFF00
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0066FF0066FF0066FF0059FF0059FF00\
59FF004CFF004CFF003FFF0033FF0019FF000CFF0000FF0000FF1900FF3300FF33
00FF1900FF0C00FF0C00FF1900FF4C00FFA600FF6600FF4C00FF5900FF6600F3FF00FFB300FFA6\
00D9FF00BFFF00BFFF00000000CCFF00FFA60059FF00FF9900FF6600FF5900FF4C
00FF4000FF4000FF7300FFA600FF4000FF1900FF2600FF1900FF2600FF5900FF1900FF0C00FF0C\
0CFF0019FF003FFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF00
73FF0073FF0066FF0059FF0000FF1926FF0000FF4C4CFF0066FF0073FF0080FF0080FF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF00\
8CFF008CFF008CFF0080FF0073FF0066FF004CFF0019FF0000FF0033FF0059FF00
66FF0073FF0080FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0073FF0000FF26\
59FF0059FF0073FF0073FF0073FF0059FF0000FF3366FF0073FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0059FF003FFF004CFF004CFF004CFF00\
4CFF004CFF003FFF003FFF0033FF0026FF0019FF000CFF0000FF0000FF1900FF8C
00FF4C00FF3300FF2600FF2600FF4000FF5900FF9900FF7300FFE600FFA600FFBF00FFF300FFF3\
00A6FF0000000000000000000099FF00FFFF00FFB300FF8C00FF8000FFA600FFCC
00FF6600FF6600FFF300FF6600FF4000FF3300FF4000FF5900FF6600FF2600FF0C0CFF0019FF00\
26FF0033FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0059FF003FFF000CFF0026FF004CFF0059FF0073FF0073FF0080FF0080FF00\
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF008CFF008CFF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00\
80FF0080FF0080FF0080FF0073FF0066FF003FFF0000FF2600FFFF00FFBF4CFF00
66FF0073FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF004CFF00\
26FF004CFF0066FF0066FF0066FF003FFF003FFF0066FF0073FF0073FF0080FF00
80FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0059FF0033FF0000FF663FFF003FFF00\
3FFF003FFF003FFF0033FF0033FF0026FF0019FF000CFF0000FF0000FF1900FF40
00FFF300FF4000FF3300FF4000FF4C00FF8C00000000FFA600FFD900B3FF00CCFF00D9FF00A6FF\
0000FF0000000000003300FF004CFF00F3FF0099FF00FFE600FFA600FFE600FFA6
00FF8000FFA600FFD900FF8000FFBF00FF6600FF6600FF7300FF4C00FF2600FF000CFF0019FF00\
26FF0033FF003FFF004CFF004CFF004CFF0059FF0066FF0066FF0066FF0066FF00
66FF0066FF0059FF004CFF003FFF0019FF0000FF0033FF000CFF0066FF0073FF0080FF0080FF00\
80FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0066FF008CFF00
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0073FF00\
73FF0073FF0073FF0073FF0066FF0066FF004CFF0026FF0000FF1933FF004CFF00
73FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0073FF00\
33FF0026FF0033FF0033FF003FFF0019FF0000FF2659FF0066FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0059FF004CFF0026FF0000FF1926FF00\
0CFF0033FF0033FF0033FF0026FF0026FF0019FF000CFF0000FF0C00FF2600FF4C
00FFA600FF4C00FF4C00FF5900FF9900FF8000FFBF00FFF33300FF0000002600FF0040FF1900FF\
0000000000000000000000000040FF008CFF00CCFF00FFE600E6FF00D9FF00FFBF
0019FF00FFE600FFE600E6FF00D9FF00FFD900FFB300FF6600FF4C00FF2600FF2600FF0019FF00\
26FF0033FF0033FF003FFF0033FF0000FF664CFF0059FF0059FF0059FF0059FF00
59FF0059FF004CFF0033FF0026FF000CFF0000FF4033FF004CFF0066FF0066FF0073FF0073FF00\
73FF0080FF0080FF008CFF008CFF008CFF0080FF0080FF0033FF0059FF0080FF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0073FF00\
0CFF0059FF0066FF0066FF0066FF0059FF004CFF0026FF0019FF004CFF0066FF00
73FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0073FF00\
3FFF003FFF0000FF0000FF0C0CFF0000FFFF33FF004CFF0059FF0066FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF004CFF0000FF2600FF5900FF19\
0CFF0026FF0026FF0026FF0019FF000CFF000CFF0000FF0000FF1900FF5900FFA6
00FFB300FF6600FF6600FFB300FFD900FFFF00FFFF0066FF000000000000000000000000000000\
0000000000000000000000003F00FF3300FF0080FF00BFFF00B3FF00F3FF00F3FF
00D9FF0066FF00D9FF0099FF000000008CFF00FFF300FFA600FFB300FF4C00FFB300FF4000FF33\
19FF0026FF0033FF0026FF0000FF0000FF264CFF004CFF0059FF0059FF0059FF00
59FF004CFF004CFF0033FF0000FF3300FF400CFF003FFF004CFF0059FF0066FF0066FF0066FF00\
4CFF0073FF0080FF0080FF0080FF0080FF0080FF0073FF0059FF000CFF0073FF00
80FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF00\
59FF0026FF004CFF0026FF004CFF004CFF003FFF000CFF0033FF0059FF0066FF00
73FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF003FFF00\
66FF0066FF0059FF004CFF003FFF0000FF6600FF0C00FF003FFF0066FF0066FF00
73FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF004CFF0033FF0019FF0000FF33\
00FF4C19FF0019FF0019FF0019FF0000FF2600FF0C00FF0C00FF1900FF3300FF4C
00FF7300FFA600FF8000FF8C00FFD900E6FF0000008000FF000000000000000000000000000000\
0000000000000000000000000000000000000000000C00FF008CFF0099FF0059FF
5900FF0C00FF0059FF000CFF0000000040FF00B3FF0066FF0099FF00FFB300FF5900FF3300FF00\
19FF0019FF0019FF000CFF0000FF8026FF003FFF004CFF004CFF004CFF004CFF00
4CFF004CFF003FFF0033FF0000FF0000FF4C26FF0033FF004CFF004CFF0059FF0059FF004CFF00\
00FF5966FF0073FF0073FF0080FF0073FF0073FF0073FF0059FF0000FF0066FF00
73FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF00\
59FF0019FF0019FF0000FF3333FF0026FF000CFF0000FF7326FF004CFF0066FF00
73FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
3FFF00B3FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF00\
80FF0073FF0073FF0066FF004CFF0033FF0000FF2633FF004CFF0059FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF004CFF003FFF0033FF0000FF0C00FF66\
00FF0C0CFF000CFF000CFF0000FF0000FF1900FF6600FF3300FF2600FF3300FF4C
00FF7300E6FF00FFA600FFBF00FFF30066FF000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000006600FF1900FF1900FFE600FF
000000F300FF000000000000000000000000000000CC00FF0000000099FF00FFA600FF2600FF19\
00FF000CFF000CFF0000FF3300FF0026FF0033FF003FFF003FFF003FFF003FFF00
3FFF003FFF0026FF0019FF0000FF0000FF1919FF0026FF0033FF0033FF004CFF003FFF0026FF00\
33FF0059FF0066FF0073FF0073FF0073FF0066FF0066FF003FFF0026FF0059FF00
66FF0066FF0073FF0033FF0066FF0073FF0073FF0080FF0073FF0073FF0066FF0066FF0059FF00\
3FFF0000FF0C19FF0019FF0000FF8C00FF4000FF5919FF0000FF1933FF003FFF00
66FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF004CFF00
B3FF0099FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF00\
8CFF0080FF0073FF0066FF004CFF0019FF000CFF0033FF004CFF0059FF0059FF00
66FF0066FF0066FF0066FF0066FF0059FF0059FF003FFF0026FF0026FF0019FF0000FF0000FF4C\
00FF1900FF0000FF0000FF0000FF3300FF3300FFA600FF4C00FF4000FF8C00FF66
00FF8C00FFBF008CFF00FFE60073FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000C000FF000000000000
0000000000000000000000000000007300FF0C00FF0066FF0C00FF00FFFF00FF8000FF4C00FF33\
00FF0C00FF0000FF0C00B3FF00FF0C0CFF0019FF0026FF0026FF0019FF0033FF00
33FF0026FF0019FF0000FF9900FFB300FF4000FF0C00FF0000FF260CFF0033FF0026FF0000FF33\
3FFF0059FF0066FF0066FF0066FF0066FF0059FF0059FF003FFF0000FF2633FF00
19FF0059FF0059FF0033FF004CFF0059FF0066FF0066FF0066FF0059FF000CFF004CFF003FFF00\
00FF190CFF003FFF003FFF0026FF0033FF004CFF003FFF000CFF000CFF0033FF00
59FF0066FF0073FF0073FF0080FF0080FF0073FF0080FF0080FF0080FF008CFF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF004CFF00
B3FF0059FF0099FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF00\
8CFF0080FF0073FF0059FF003FFF0000FF4000FF0033FF003FFF004CFF0059FF00
59FF0059FF0066FF0059FF0059FF0059FF0059FF003FFF0019FF0000FF0000FF6600FF4C00FF59\
00FF9900FF1900FF0C00FF0C00FF2600FF8C00FFF300FF6600FF6600FF9900FF99
00FFA600FFE600BFFF00BFFF0C00FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000040FF0099FF00E6FF00FFD900FF8C00FF9900FF8000FFFF\
00FF4000FF3300FF4C00FF9900FF5900FF1900FF0019FF000CFF0000FF2600FF00
00FF0C00FF0C00FFD900FF0019FF0026FF000CFF0000FF7300FFD900FF3300FF8C00FF330CFF00\
33FF003FFF0059FF0059FF0059FF004CFF0033FF0026FF0019FF0000FF0000FF59
00FFA633FF000CFF0000FF1900FF0000FF8000FF003FFF000CFF0026FF000CFF0000FF0019FF00\
26FF0033FF0059FF0059FF004CFF003FFF0059FF0059FF0059FF004CFF0000FFD9
3FFF0059FF0059FF0066FF0073FF0066FF0026FF0066FF004CFF0026FF0080FF0099FF0099FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0000FF1973FF003FFF00
B3FF0080FF0080FF00A6FF00B3FF00A6FF008CFF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF00\
8CFF008CFF0073FF0000FFA63FFF0033FF000CFF0000FF0C00FF193FFF004CFF00
59FF0059FF0059FF0059FF0059FF0059FF004CFF003FFF0033FF0026FF0019FF0000FF0000FF0C\
00FF3300FF4000FF5900FF2600FF3300FF4000FF7300FFA600FF8000FFB300FFCC
00E6FF00FFF300A6FF0080FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000008000FF0C00FF00CCFF00D9FF00FFB300FF8000FF5900FF4C00FF8C\
00FF4C00FF3300FF2600FF1900FF8000FF4000FF4000FF0C0099FF00FF0C00FF33
19FF0026FF0026FF000CFF0033FF0033FF0033FF0019FF000C00FF0CFF0019FF000CFF0000FFB3\
00FF2626FF004CFF004CFF004CFF0026FF0000FF6600FF260CFF003FFF003FFF00
19FF0000FF4019FF003FFF004CFF003FFF0059FF0059FF004CFF0000FF194CFF000CFF0019FF00\
3FFF0059FF0066FF0066FF0066FF0066FF0073FF0073FF0066FF0066FF0026FF00
00FF6633FF000CFF0059FF0059FF0059FF003FFF0019FF0000FF4066FF0080FF008CFF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF0073FF003FFF0059FF00
A6FF0066FF0073FF0080FF0099FF0066FF00A6FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF00\
8CFF008CFF0080FF0066FF0059FF004CFF0019FF0000A6FF00FF003FFF004CFF00
4CFF004CFF004CFF004CFF004CFF004CFF004CFF003FFF0033FF0033FF0026FF0019FF0000FF00\
00FF1900FF4C00FF8000FF4000FF4C00FF5900FF9900FFBF00FFD900FFF300D9FF
0099FF0080FF0000FF3F00FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000066FF00FFFF00FFCC00FFCC00FF8000FF4C00FF3300FF33\
00FF4000FF0C00FF0C00FF0000FF0C00FF1900FF5900FFA600FF0C19FF0026FF00
33FF0033FF003FFF003FFF003FFF003FFF003FFF0033FF0026FF0033FF0033FF0026FF000CFF00\
00FF7326FF0033FF003FFF003FFF0019FF0000FF1900FF4033FF004CFF0059FF00
4CFF0033FF003FFF0059FF0066FF0066FF0073FF0073FF0073FF0019FF0066FF0066FF0059FF00\
3FFF0066FF0073FF0073FF0080FF0080FF0080FF0073FF0073FF0073FF0059FF00
19FF0000FF000CFF003FFF004CFF004CFF0033FF0000FF003FFF0066FF0073FF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF0073FF0019FF0059FF008CFF00
80FF008CFF0066FF0000FF1900FF668CFF00A6FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF00\
8CFF008CFF0080FF0073FF0066FF004CFF0033FF000CFF0000FF0C33FF003FFF00
3FFF004CFF004CFF004CFF004CFF003FFF003FFF003FFF0033FF0033FF0026FF0019FF0000FF00\
00FF1900FF4C00FF7300FF5900FF8C00FFA600FFBF00B3FF008CFF3F00FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000C00FF00D9FF00FFB300FF8C00FF8000FF6600FF3300FF26\
00FF0C00FF0000FF000CFF000CFF0000FF0000FF0000FF1900FF0026FF0033FF00
3FFF003FFF004CFF004CFF004CFF004CFF004CFF004CFF003FFF003FFF003FFF0033FF0000BFFF\
00FF4C0CFF0000FF0C26FF0019FF0000FF990CFF0026FF004CFF0059FF0066FF00
66FF0059FF0026FF0066FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0066FF00\
00FF1973FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0066FF00
59FF0033FF0000FF0033FF0033FF000CFF0000FF0000FF5919FF004CFF0000FF0C80FF008CFF00\
8CFF008CFF008CFF008CFF0066FF0073FF0066FF0000FF3366FF008CFF0099FF00
B3FF00A6FF0099FF0080FF0000FF0C73FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF00\
8CFF0080FF0080FF0073FF0059FF004CFF0033FF0019FF0000F3FF00FF1919FF00
33FF003FFF003FFF003FFF0033FF0033FF0033FF0033FF0033FF0026FF0019FF000CFF0000FF00\
00FF3300FF5900FF8000FFA600FF9900D9FF0099FF0059FFCC00FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000004C00FF0033FF00BFFF00FFD900FFA600FF8000FF5900FF4000FF3300FF19\
00FF0C00FF000CFF000CFF0019FF0019FF0019FF0019FF0000FF6626FF003FFF00
3FFF004CFF004CFF004CFF004CFF0059FF0059FF0059FF004CFF004CFF004CFF003FFF0026FF00\
00FF8C00FF0000FF7300FF8000FF0C33FF004CFF0059FF0059FF0066FF0073FF00
73FF0073FF0059FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF0080FF0080FF00\
00FF6680FF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF00
66FF003FFF0000FF190CFF000CFF0000FF4000FFB300FF0C00FF2600FF994CFF0073FF0080FF00\
80FF0080FF0080FF0073FF0059FF0000FF004CFF0080FF008CFF0099FF00A6FF00
C0FF00B3FF00A6FF0080FF0026FF0080FF0099FF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF008CFF00\
80FF0080FF0073FF0066FF000CFF0026FF000CFF0000FF4000FF0C00FF7300FF26
00FF1926FF0026FF0026FF000CFF0019FF0026FF0026FF0026FF0026FF0000FF2600FF0C00FF19\
00FF2600FF4000FF7300FFFF00FFD9000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000004C00FF0040FF0099FF00BFFF00F3FF00FFB300FFCC00FF6600FF4C00FF4000FF33\
00FF2600FF000CFF0019FF0019FF0026FF0026FF0026FF0026FF0033FF003FFF00
4CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF0033FF00\
19FF0033FF0026FF0019FF0000FFA63FFF0059FF0066FF0066FF0073FF0073FF00
80FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00
66FF0000FF5933FF0000FF0000FF8000FF4000FF3326FF0033FF0000FF0033FF004CFF0073FF00\
73FF0073FF0066FF0066FF003FFF0033FF0073FF008CFF0099FF00A6FF00A6FF00
C0FF00B3FF0099FF0000FF1959FF004CFF0080FF0059FF00B3FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0080FF00\
73FF0073FF0066FF0059FF003FFF0000FF3300FF0000FF1926FF0019FF0026FF00
19FF0000FF2600FF000CFF0000FF0C0CFF0019FF0026FF0019FF0019FF0000FF0000FFBF00FF4C\
00FF3300FFBF00FF8000FFB300D9FF1900FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000003F00FF0059FF0C00FF00FFFF00FFE600FFCC00FFD900FF8C00FF6600FF8000FF40\
00FF1900FF000CFF0019FF0026FF0026FF0033FF0033FF003FFF003FFF004CFF00
4CFF0059FF0059FF0059FF0059FF0059FF0059FF0066FF0066FF0059FF0059FF0059FF0026FF00\
33FF004CFF003FFF0019FF0000FF730CFF0059FF0066FF0073FF0073FF0080FF00
80FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF00
66FF0066FF0059FF0033FF000CFF0000FF0C33FF003FFF004CFF0026FF0000FF5900FF0059FF00\
66FF0066FF004CFF0026FF0000FF0C33FF0073FF008CFF0099FF00A6FF00A6FF00
C0FF00C0FF00A6FF0099FF008CFF0059FF0066FF0099FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF008CFF0073FF0026FF0059FF00\
19FF003FFF003FFF0026FF000CFF000CFF0033FF000CFF003FFF003FFF003FFF00
33FF0026FF0000FF4C00FFE600FF4C00FF260CFF0019FF0019FF000CFF0000FF0C00FF3300FF80\
00FF5900FFD900FFB300BFFF0059FF0033FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000033FF00CCFF00FFF300FFCC00FFA600FFA600FF8C00FFA600FF9900FF4C\
00FF1900FF000CFF0019FF0026FF0033FF0033FF003FFF003FFF004CFF004CFF00
4CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF004CFF00\
59FF0059FF0059FF004CFF0019FF0033FF0059FF0066FF0073FF0080FF0080FF00
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00
80FF0073FF0066FF003FFF0019FF0019FF004CFF0059FF0059FF0033FF004CFF0033FF0000FF00\
33FF0026FF0000FF1926FF000CFF0059FF0073FF008CFF0099FF00A6FF00A6FF00
C0FF00C0FF00B3FF00A6FF008CFF000CFF0073FF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF008CFF003FFF004CFF004CFF000CFF0000FF26\
26FF0000FF004CFF003FFF003FFF003FFF004CFF004CFF004CFF004CFF004CFF00
4CFF0033FF0019FF0019FF0000FF0C00FF4000FF0C00FF000CFF0000FF0000FF1900FF4000FF66\
00FFBF00FFCC00B3FF00A6FF0040FFA600FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000006600FF0059FF0073FF00FFE600FF9900FF8000FF6600FF5900FF6600FF73\
00FF7300FF190CFF0019FF0026FF0033FF0033FF003FFF003FFF004CFF004CFF00
59FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0059FF004CFF0019FF0059FF0066FF0073FF0080FF008CFF00
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00
8CFF0080FF0066FF0019FF0000FF2633FF004CFF0066FF0073FF0066FF0066FF0066FF0059FF00\
33FF0000FF4000FF264CFF0059FF0073FF0080FF008CFF0099FF00A6FF00A6FF00
C0FF00C0FF00B3FF00A6FF0099FF0080FF0026FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF0080FF0019FF0066FF0059FF00\
66FF0066FF0066FF0066FF0059FF0059FF0066FF0066FF0059FF0059FF0059FF00
4CFF003FFF0033FF0026FF0000FF8C00FF4000FF3300FF0C00FF0C00FF0C00FF1900FF3300FF59\
00FFA6004CFF9900FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000CC00FF0000FF0019FF0080FF00FFCC00FF9900FF8000FF5900FF4000FF4000FF59\
00FF1900FF0C0CFF0019FF0026FF0033FF0033FF003FFF003FFF004CFF004CFF00
59FF0059FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0066FF0059FF000CFF000CFF0066FF0073FF0080FF008CFF00
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF00
8CFF0080FF0066FF0033FF0066FF0066FF004CFF0073FF0080FF0073FF0073FF0073FF0066FF00\
59FF004CFF0000FF8C3FFF0059FF0073FF0080FF008CFF0099FF00A6FF00A6FF00
C0FF00C0FF00B3FF00B3FF00A6FF008CFF003FFF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0073FF0080FF0080FF00\
80FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0059FF00
59FF004CFF003FFF0033FF0019FF0000FF0C00FFD900FF8C00FF2600FF4C00FF3300FF4000FFA6\
00FFE60000FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000080FF0080FF00FFCC00FFA600FF5900FF4000FF2600FF19\
00FF0C00FF000CFF0019FF0026FF0033FF0033FF003FFF003FFF004CFF004CFF00
59FF0059FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0066FF004CFF0000FFCC26FF0073FF0080FF008CFF00
8CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
99FF0080FF0019FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF00\
66FF0059FF0000FF2619FF000CFF0066FF0080FF008CFF008CFF0099FF00A6FF00
C0FF00C0FF00B3FF00B3FF00A6FF008CFF0026FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF008CFF008CFF00\
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00
59FF004CFF003FFF0033FF0019FF0000FF7300FF4000FF1900FF4000FF6600FF6600FF5900FF80\
00D9FF6600FF4C00FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000004CFF00F3FF00FFB300FFA600FF8000FF4000FF2600FF19\
00FF0C00FF000CFF0019FF0026FF0026FF0033FF0033FF003FFF003FFF004CFF00
59FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF00\
80FF0080FF0080FF0080FF0073FF0059FF0059FF0019FF0073FF008CFF008CFF00
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF008CFF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00\
73FF0059FF0000FF1900FF0C00FF8C66FF0073FF0073FF0073FF0073FF0099FF00
C0FF00C0FF00B3FF00A6FF0099FF0080FF0000FF0066FF0099FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF00\
8CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF00
59FF004CFF0033FF0000FF0000FF2600FF4000FF0000FF0000FF0C00FF3300FF8000FFD900FFCC\
00D9FF0080FF0059FFCC00FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000D9FF00FFF300FF8000FF5900FF4000FF3300FF26\
00FF2600FF000CFF0019FF0019FF0026FF0026FF0026FF0026FF0026FF003FFF00
59FF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF008CFF0099FF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF00\
73FF0066FF004CFF003FFF0000FFBF3FFF0000FF194CFF0000FF0C73FF0099FF00
C0FF00B3FF00B3FF00A6FF008CFF0066FF0033FF0073FF008CFF008CFF0099FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF00\
8CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF00
59FF004CFF0026FF0019FF0026FF0019FF0019FF000CFF0000FF0000FF6600FF4C00FF4C00FFA6\
00FFA600F3FF5900FF004CFF6600FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000B300FF0000000026FF00BFFF00FFBF00FFB300FF6600FF4C00FF4C00FF59\
00FF3300FF0C0CFF000CFF000CFF000CFF000CFF000CFF0000FF400CFF003FFF00
59FF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF00\
80FF0073FF0066FF004CFF0033FF0000FF0C19FF0066FF0073FF008CFF0099FF00
C0FF00B3FF00B3FF00A6FF0080FF0073FF0026FF004CFF0073FF003FFF0080FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0073FF0066FF00
66FF0059FF004CFF003FFF0033FF0026FF0026FF0019FF0000FF0000FF1900FF2600FF4000FF73\
00FF9900FFD900E6FF0073FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000008C00FF2600FF1900FF00E6FF00FFD900FFBF0099FF00FF8C00FF6600FFF300FF73\
00FF2600FF0C00FF0000FF0000FF0000FF0C00FF8C00FF0C19FF0033FF004CFF00
59FF0066FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF00\
80FF0073FF0066FF004CFF0026FF0000FF0059FF0073FF0080FF008CFF0099FF00
B3FF00B3FF00B3FF00A6FF0099FF0080FF0066FF0033FF0000FF4073FF008CFF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF008CFF0099FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF0066FF00
66FF0059FF004CFF003FFF003FFF0033FF0026FF0019FF0000FF0000FF1900FF2600FF4000FF73\
00FFE60099FF00F3FF0059FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000066FF00BFFF0073FF00FFF300FF9900FF9900FF8C00FF8000FF9900FF73\
00FF4000FF3300FF1900FF0C00FF2600FF7300FF2619FF0033FF003FFF004CFF00
59FF0059FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF00\
80FF0073FF0059FF0026FF000CFF0000FFCC26FF0073FF0080FF008CFF0099FF00
B3FF00B3FF00A6FF00A6FF0099FF0080FF0066FF0033FF003FFF0073FF008CFF0099FF0099FF00\
A6FF00A6FF00A6FF00A6FF0099FF004CFF000CFF0099FF00A6FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF00
66FF0059FF004CFF003FFF003FFF0033FF0026FF0000FF0000FF8C00FF4C00FF4000FF4C00FF80\
00FF9900FFF300F3FF0080FF3F00FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000073FF00D9FF00FFE600FFE600FF8C00FF8000FF6600FF5900FF5900FF8C\
00FF7300FF8000FF9900FF4C00FF7300FF3300FF0C19FF0033FF003FFF004CFF00
59FF0059FF0066FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF00\
73FF0059FF004CFF0000FF0C26FF004CFF0066FF0073FF0080FF008CFF0099FF00
B3FF00A6FF00A6FF0099FF008CFF0000FF1926FF0019FF0059FF0073FF008CFF008CFF0099FF00\
99FF0099FF0099FF0099FF008CFF0066FF0066FF008CFF00A6FF00B3FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF00
59FF0059FF004CFF003FFF0033FF0026FF0026FF000CFF0000FF0C00FF4000FFA600FF6600FF73\
00FF9900FFF300E6FF008CFF1900FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000003F00FF008CFF00F3FF00FFD900FFA600FF8C00FF7300FF5900FF4C00FF4000FF4C\
00FF8C00FF3300FF2600FF2600FF2600FFA600FF2600FF2626FF0033FF003FFF00
4CFF0059FF0066FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF00\
00FF4C00FF8033FF000CFF0033FF0059FF0066FF0073FF0080FF008CFF008CFF00
A6FF00A6FF0099FF0099FF008CFF0073FF0059FF0000FF6659FF0073FF0080FF0080FF008CFF00\
8CFF008CFF008CFF008CFF0073FF0000FFA666FF008CFF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0066FF0059FF00
4CFF004CFF0033FF0000FF9926FF0026FF0019FF000CFF0000FF0C00FF4C00FFD900FF9900FFCC\
00FFB300F3FF00BFFF0033FF7300FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000003F00FF0019FF00B3FF0059FF00F3FF00FFBF00FFB300D9FF00FF5900FF4000FF3300FF33\
00FF3300FF1900FF0C00FF0C00FF0C00FF2600FF3300FF330CFF000CFF0026FF00
3FFF004CFF0059FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF00\
80FF0073FF0059FF0026FF0000FF404CFF0066FF0073FF0080FF0080FF008CFF00
99FF0099FF0099FF008CFF0080FF0073FF004CFF0000FF0C4CFF0066FF0066FF0066FF0073FF00\
80FF008CFF0080FF0080FF0066FF0033FF0080FF0099FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF004CFF0026FF00
00FF0026FF0019FF0000FF4C00FF000CFF000CFF000CFF0000FF0C00FF2600FF4000FF6600FFD9\
00A6FF00D9FF3300FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
E600FF0000000073FF00BFFF00FFFF00FFFF00FFE600FFF300FF9900FF6600FF4000FF3300FF26\
00FF1900FF0C00FF0000FF0000FF0000FF0000FF1900FF7300FF5900FF1900FF19
26FF0033FF0033FF0059FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF00\
80FF0073FF0066FF003FFF0000FF0C3FFF0059FF0066FF0073FF0073FF0073FF00
80FF008CFF008CFF0080FF0073FF0059FF0000FF0033FF0026FF0026FF0033FF0000FF0066FF00\
73FF0073FF0073FF004CFF003FFF0073FF008CFF0099FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF004CFF00
3FFF0026FF0000FF1900FF0C00FF8000FF0000FF0000FF0000FF0C00FF2600FF4000FF6600FF99\
00FFD90099FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
5900FF0026FF0033FF0033FF00F3FF00FFD900FFB300FFA600FFD900FF7300FF4000FF3300FF26\
00FF1900FF0C00FF000CFF000CFF000CFF0000FF0000FF0C00FF0026FF0026FF00
26FF0019FF003FFF0059FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF00\
8CFF0073FF0059FF0033FF0000E6FF00FFBF3FFF004CFF004CFF0033FF003FFF00
4CFF0073FF0059FF004CFF0019FF0026FF0059FF0066FF0066FF003FFF0000FF0C00FF3300FF19\
59FF0066FF004CFF0000FF9966FF0080FF008CFF0099FF0099FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00\
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF0066FF00
59FF003FFF0033FF000CFF0000FF2600FF8C00FF1900FF1900FFA600FF3300FF4C00FFBF00FFCC\
00D9FF000CFF4C00FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
3F00FF0026FF004CFF00BFFF00F3FF00FFFF00FFB300FF8C00FF7300FF5900FF4000FF3300FF26\
00FF1900FF0C0CFF000CFF0019FF0019FF0019FF0019FF0000FF5933FF003FFF00
4CFF004CFF0059FF0066FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF00\
80FF0073FF004CFF0026FF0026FF004CFF0026FF0000FF1926FF0000FF663FFF00
00FF1900FFF300FFD959FF0073FF0073FF0073FF0080FF0073FF0066FF003FFF0000FF0C26FF00\
00FF2626FF0000FF2619FF0066FF0080FF008CFF0099FF0099FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF00\
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0073FF0066FF00
59FF004CFF003FFF0026FF0000FF0000FF8000FF4000FF4C00FF6600FF6600FF6600FF990000FF\
3300FF0C00FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
CC00FF6600FF4C00FF0080FF0033FF00E6FF00FFE600FF9900FF8000FFF300FF4C00FF4C00FF4C\
00FFA600FF0C0CFF0019FF0019FF0026FF0026FF0033FF0033FF003FFF004CFF00
59FF0059FF0066FF0066FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF00\
80FF0066FF0000FF0C4CFF0066FF0073FF0059FF0000FF0000F3FF00FF0000FF33
26FF0059FF003FFF0073FF0080FF008CFF008CFF008CFF0080FF0073FF0033FF003FFF0059FF00\
59FF003FFF0000FF334CFF0066FF0080FF008CFF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00\
8CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF00
59FF004CFF003FFF0026FF0000FF1900FF1900FF0000FF0C00FF2600A6FF00FF8C00FFD90080FF\
A600FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000033FF008CFF00D9FF00FFD900FFB300FFBF00FF8C00FF7300FF7300FF8C\
00FF2600FF0C0CFF0019FF0026FF0026FF0033FF003FFF003FFF004CFF004CFF00
59FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF00\
59FF0033FF0073FF0073FF0080FF0080FF0073FF0059FF0000FF003FFF0000FF66
19FF0066FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0073FF0073FF00\
66FF0059FF0000FF0C33FF0059FF0066FF0080FF008CFF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00\
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF00
59FF004CFF0026FF0000FFD919FF0019FF0019FF000CFF0000FF8C00FF3300FF4C00FF8C00FFF3\
0019FF000000B300FF0000000000000000000000000000008000FF6600FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000008C00FF0059FF0080FF00CCFF00FFCC00FFFF00FF9900FF8000FFBF\
00FF4C00FF2600FF0C19FF0026FF0033FF0033FF003FFF003FFF004CFF0059FF00
59FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF008CFF0073FF00\
26FF0066FF0080FF008CFF008CFF008CFF0080FF0026FF0066FF0066FF0066FF00
4CFF0073FF008CFF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF00\
73FF0059FF003FFF0000FF6600FF8C26FF0073FF008CFF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF00\
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF00
59FF004CFF003FFF0033FF0033FF0026FF0019FF000CFF0000FF0000FF1900FF40004CFF0099FF\
004CFF0000005900FF004CFF0019FF0000000000000C00FF0033FF0033FF7300FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000059FF00BFFF00FFD900FFB300FF8C00FF7300FF5900FF4C\
00FF8C00FF2600FF0C19FF0026FF0033FF0033FF003FFF003FFF004CFF0059FF00
59FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF008CFF004CFF00\
59FF0080FF008CFF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF00
59FF0000FF338CFF0099FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF00\
73FF0059FF0000FF0000FF0C4CFF0066FF0080FF008CFF008CFF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF00
59FF0059FF004CFF003FFF0033FF0033FF0026FF0019FF0000FF0C00FFA600FF5900FF8000E6FF\
3F00FF3F00FF00A6FF0040FF00BFFF0099FF0040FF00A6FF0099FF00A6FF004CFF
3F00FFC000FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000008000FF004CFF00BFFF00F3FF00FFF300FF8C00FF8000FF4C00FF33\
00FF2600FF0C0CFF0019FF0026FF0026FF0033FF0033FF003FFF004CFF004CFF00
59FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF008CFF0033FF00\
66FF008CFF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF00
80FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF00\
73FF003FFF0000FF993FFF0059FF0073FF0080FF008CFF008CFF0099FF0099FF00
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF0099FF0099FF008CFF0080FF0019FF0066FF0066FF0073FF0080FF00\
80FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00
59FF0059FF004CFF003FFF003FFF0033FF0026FF0019FF0000FF0000FF2600FFCC00FF8000FFE6\
0000000073FF0073FF00FFD90099FF00FFE600E6FF00FFF300FFFF0080FF00BFFF
2600FF4C00FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000009900FF0040FF00BFFF00FFF300FFCC00FFCC00FF7300FF33\
00FF1900FF0C0CFF0019FF0019FF0026FF0026FF0033FF0033FF0033FF003FFF00
59FF0066FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0073FF0080FF00\
8CFF0099FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0066FF00
99FF00A6FF00A6FF00A6FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF0080FF00\
73FF004CFF0000FF334CFF0059FF0073FF0080FF0080FF008CFF008CFF008CFF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0000FF0000FFA659FF0066FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF00
59FF0059FF004CFF003FFF003FFF0033FF0026FF0019FF000CFF0000FF3300FF2600FF4C00FFCC\
00BFFF00FFBF00FFFF00FF9900FFA600FFB300FFFF00FFBF00E6FF00D9FF00F3FF
00A6FF000000000000000000E600FF2600FF8C00FF0000000000006600FFE600FF4C00FF5900FF\
C000FF000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000008C00FF0026FF00000000F3FF00FF8C00FF5900FF40\
00FF3300FF8C00FF000CFF0019FF0019FF0019FF0019FF0000FF3300FF1933FF00
59FF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF00\
8CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0080FF0066FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0073FF00\
4CFF0000FF5926FF0033FF004CFF0066FF0073FF0080FF0080FF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0066FF0000FF0C00FFBF59FF0066FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF00
59FF0059FF004CFF003FFF0033FF0033FF0026FF0019FF000CFF0000FF0000FF1900FF3300FF66\
00FF8C00FF7300FF8000FF7300FF8C00FFCC00FFD900FF8C00FF9900FFB300FFF3
00BFFF0099FF0000000000003300FF0040FF0000FF0000003F00FF0059FF0026FF0033FF0000FF\
7300FF000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000C00FF00A6FF00FFCC00FF7300FF59\
00FF9900FF2600FF0C00FF000CFF000CFF0000FF2600FF1900FF2626FF003FFF00
4CFF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF00\
80FF008CFF008CFF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0073FF0033FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF0080FF000CFF00\
66FF0066FF0059FF0000FF2600FF264CFF0073FF0073FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF003FFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0059FF0033FF003FFF0059FF00\
59FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF00
59FF004CFF004CFF0033FF0026FF0026FF0019FF000CFF000CFF0000FF0000FF2600FFD900FF99\
00FF4C00FF4000FF4000FF5900FF7300FF9900FF8000FF7300FF8C00FFBF00FFBF
00FFBF00F3FF0040FF0040FF0099FF00E6FF0080FF00A6FF00BFFF0099FF00A6FF0019FF0040FF\
B300FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000B300FF000CFF000CFF00CCFF00B3FF00FF9900FF9900FFCC\
00FF8C00FF4000FF2600FF0C00FF0C00FF3300FF8000FF0026FF0033FF003FFF00
4CFF0059FF0059FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF00\
80FF0080FF0080FF0080FF0080FF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF008CFF000CFF0073FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF008CFF008CFF00\
80FF0080FF0066FF0000FF4000FF263FFF0066FF0073FF0073FF0080FF0080FF00
80FF0073FF0066FF0066FF004CFF0066FF0080FF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF008CFF008CFF008CFF008CFF0080FF0073FF0073FF0066FF003FFF000CFF0000FF0C\
4CFF004CFF0000FF194CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
4CFF004CFF003FFF0033FF0000FF4000FF0000FF4000FF0000FF0C00FF1900FF4C00FF4C00FF26\
00FF3300FF1900FF3300FF5900FF8C00FF6600FF4C00FF4C00FF8C00FF8000FF99
00FF8C00FFB300FFF300FFD90C00FF00FFD900FFF3008CFF00FFF300F3FF00D9FF00B3FF0066FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000A600FF0000FF008CFF00BFFF008CFF00FFA600FF8000FF5900FF59\
00FF6600FF7300FFD900FF3300FF5900FFE600FF260CFF0026FF0033FF003FFF00
4CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF00\
73FF0066FF0073FF0073FF0019FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF00\
8CFF0080FF0073FF0059FF003FFF0033FF004CFF0059FF0066FF0066FF0066FF00
66FF0059FF0019FF0000FF4019FF0066FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0066FF0059FF004CFF000CFF0019FF00\
33FF0033FF0000FF193FFF004CFF0059FF0059FF0059FF0059FF004CFF004CFF00
4CFF003FFF003FFF0026FF000CFF0000FF4000FF4C00FF3300FF7300FF5900FF2600FF0000FF00\
00FF0000FF0C00FF4C00FF7300FF5900FF6600FF3300FF3300FF4C00FF5900FF66
00FF8000FFA600FFFF00FF9900FF9900FFB300FFF300FFD900FFCC00FFF300D9FF00A6FF00A6FF\
0040FFE600FF000000000000000000000000000000000000000000000000000000
0000000000000000000000008000FF0040FF00CCFF00FFF300FFD90073FF00FF8C00FF4C00FF40\
00FF4000FF8C00FF3300FF2600FF4000FF4C00FF4000FF0000FF0033FF003FFF00
3FFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF004CFF003FFF0059FF0066FF0059FF00\
59FF003FFF003FFF0033FF000CFF0033FF0080FF0099FF00A6FF00A6FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF00\
99FF008CFF0073FF0066FF003FFF0000FF1900FF1900FF193FFF004CFF0026FF00
59FF004CFF0026FF0019FF003FFF0066FF0073FF0080FF008CFF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0059FF003FFF0019FF0000FF59\
00F3FF00FF1900FF0033FF003FFF004CFF004CFF004CFF004CFF004CFF003FFF00
3FFF0033FF0033FF000CFF0000FF0C00FFB300FF0000FFE600FF0C00FF4000FF260CFF000CFF00\
0CFF0000FF0000FF7300FF1900FF2600FF4000FF2600FF2600FF3300FF4000FF59
00FF7300FFE600FF8C00FF7300FF8000FFBF00FFF300FFA600FFA600D9FF00CCFF00FFF300B3FF\
0066FFCC00FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000CFF0080FF0019FF004CFF00FFA600FFA600FFE600FF4C00FF33\
00FF2600FF2600FF1900FF0C00FF0C00FF2600FF4C00FFE600FF0019FF0026FF00
0CFF003FFF004CFF004CFF004CFF004CFF004CFF004CFF003FFF0000FF1926FF0019FF0019FF00\
00FF4C00FF0C00FF3326FF0066FF0073FF0073FF008CFF00A6FF00B3FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF00\
99FF0080FF0059FF0033FF000CFF003FFF0059FF0059FF004CFF0000FF0000FF59
33FF0000FF6600FF4026FF004CFF0059FF0066FF0059FF0080FF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
80FF0080FF0080FF004CFF0066FF0066FF0066FF0066FF0019FF003FFF0019FF000CFF0026FF00\
0CFF0019FF0000FF2619FF0033FF0033FF0033FF0026FF003FFF003FFF0033FF00
26FF0019FF000CFF0000FF8C00FF260CFF0026FF000CFF0019FF0000FF0C00FF9919FF0019FF00\
19FF0019FF0000FF000CFF0000FF0000FF0C00FF1900FF1900FF3300FF4000FF59
00FFFF00FF6600FF5900FF5900FF7300FF8C00FFB300FF8C00FF8C00FFA600FFBF00FFD900F3FF\
1900FF000000CC00FF000000000000000000000000000000000000000000000000
0000000000000000000000006600FF0066FF00CCFF00FFE600FFA600FF8000FF5900FF4000FF26\
00FF1900FF0C00FF0000FF0000FF0000FF0000FF1900FFB300FF0C00FF0C00FF0C
19FF0033FF003FFF003FFF003FFF003FFF0000FF2633FF0019FF0000FF0026FF004CFF0059FF00\
59FF0026FF0073FF004CFF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF00\
99FF0080FF0066FF0000FF004CFF0019FF0073FF0073FF0073FF0059FF0033FF00
00FF0000FF1900FF3300FF3326FF003FFF003FFF004CFF0073FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF0080FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00
80FF0073FF0073FF004CFF003FFF0059FF0059FF0059FF0019FF0000FF2600FF0C33FF003FFF00\
3FFF0033FF0000FF8C00FF4C19FF0019FF0000FF3300FF0019FF0026FF0026FF00
00FF0C00FF9919FF0026FF0026FF0019FF0033FF0033FF0033FF0000FF000CFF0026FF0026FF00\
26FF0026FF0019FF0019FF000CFF0000FF0000FF0C00FF1900FF4C00FF8C00FF99
00FF8C00FF6600FF4000FF4000FFBF00FF4C00FF6600FF7300FF8000FF9900FFB300F3FF0080FF\
00E6FF0080FF4C00FF000000000000000000000000000000000000000000000000
000000000000000000000000000000CC00FF00B3FF00E6FF00FFA600FF8C00FF5900FF4000FF33\
00FF1900FF0C00FF000CFF000CFF000CFF0000FF0C00FF2600FF8000FF7300FF19
00FF190CFF0033FF0033FF0026FF0026FF0000FF0000FFFF00FF1926FF004CFF0066FF0073FF00\
73FF0080FF0080FF008CFF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF00\
99FF0080FF0059FF0026FF0066FF0080FF0080FF0080FF0080FF0073FF000CFF00
4CFF0033FF0000FF0C00FF4C00FF0C0CFF0000FF0059FF0066FF0073FF0080FF0080FF0080FF00\
80FF0080FF0080FF0073FF0066FF0033FF0066FF0073FF0066FF0073FF0073FF00
73FF0066FF0059FF004CFF0000FF590CFF003FFF003FFF000CFF0000FF2600FF594CFF0059FF00\
59FF003FFF0033FF000CFF0000FFCC00FF0C00FF4C00FF8C00FFCC00FF0000FF33
00FF7319FF0033FF003FFF003FFF003FFF004CFF003FFF003FFF0000FF3319FF0033FF0033FF00\
33FF0033FF0026FF0019FF000CFF000CFF0000FF0000FF1900FF4000FF8000FF66
00FF4000FF5900FF3300FF2600FF3300FF4000FF4C00FF6600FFD900E6FF00B3FF00FFB300FFBF\
00FFE600BFFF000CFF000000000000000000000000000000000000000000000000
0000000000000000000000000000FF004CFF00F3FF00BFFF00E6FF00FFA600FF6600FF5900FF59\
00FF8000FF0C0CFF0019FF0019FF0019FF0019FF0000FF0000FF400CFF0019FF00
00FF0000FF0000FF1900FF0000FF2600FF0000FF590CFF0019FF0000FF0C4CFF0073FF0073FF00\
80FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF00\
8CFF0066FF0026FF0066FF0073FF008CFF008CFF008CFF008CFF0080FF0073FF00
66FF004CFF0026FF0000FF3300FF6626FF0000FF003FFF003FFF0066FF0073FF0073FF0080FF00\
73FF0073FF0073FF0073FF0059FF0000FF734CFF004CFF0033FF003FFF004CFF00
4CFF0019FF003FFF0000FF4026FF0000FF3300FF000CFF0026FF003FFF003FFF0059FF0066FF00\
66FF0059FF004CFF000CFF0026FF0033FF0019FF0000FF0026FF000CFF0000FF19
19FF0033FF003FFF004CFF004CFF004CFF004CFF004CFF004CFF000CFF0033FF003FFF003FFF00\
3FFF0033FF0026FF0019FF000CFF0000FF0000FF0C00FF1900FF5900FF6600FF19
00FF1900FF6600FF1900FF1900FF2600FF4000FF4C00FF6600FF9900FF8C00FF8C00FF8C00FF99\
00FFCC00FFF300BFFF000CFF0000007300FF1900FF000CFF1900FF5900FFE600FF
000000000000000000F300FF0019FF00B3FF00FFF300FFBF00FFA600FFD900FFF300F3FF00FF59\
00FF1900FF000CFF0019FF0026FF0026FF0026FF0019FF0000FF6626FF0033FF00
33FF0033FF0026FF0000FF0000FF0C00FF400CFF0033FF003FFF0059FF0066FF0073FF0080FF00\
8CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF0066FF00\
59FF0059FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF008CFF0080FF00
73FF0033FF0000FF4C26FF004CFF004CFF0026FF0000FF0C00FF0059FF0066FF0066FF0066FF00\
66FF0059FF0066FF0066FF004CFF0026FF0000FFA600FF0000FF0026FF004CFF00
3FFF003FFF0019FF003FFF004CFF0033FF003FFF0000FF003FFF0059FF0066FF0066FF0073FF00\
66FF0066FF004CFF000CFF004CFF004CFF004CFF003FFF0033FF0019FF0000FFE6
26FF003FFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF004CFF00\
3FFF0033FF0026FF0019FF000CFF0000FF0000FF1900FF5900FF3300FF0C00FF0C
00FF0000FF0C00FF0C00FF0C00FF2600FF4C00FF7300FF9900FF8000FF5900FF5900FF6600FF80\
00FFA600FFE600CCFF4C00FF0000004C00FF0073FF004CFF0080FF0059FFA600FF
8000FF6600FF0000000000000C00FF0080FF00BFFF00FFCC00FF9900FF8000FF6600FF6600FFF3\
00FF4000FF0C0CFF0019FF0026FF0033FF0033FF0033FF0026FF0033FF003FFF00
3FFF003FFF003FFF0033FF0026FF000CFF000CFF0033FF004CFF0059FF0066FF0073FF0080FF00\
8CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF00A6FF0099FF0073FF00\
59FF0080FF0099FF0099FF0099FF00A6FF00A6FF0099FF0099FF0099FF008CFF00
73FF0000FF7359FF0026FF0066FF0066FF0026FF004CFF0033FF0026FF004CFF004CFF0059FF00\
4CFF0033FF004CFF004CFF0000FF6600FF004CFF004CFF004CFF0066FF0073FF00
73FF0073FF0059FF0059FF0066FF0066FF0066FF003FFF003FFF0066FF0073FF0073FF0073FF00\
73FF0073FF003FFF003FFF0059FF0059FF0059FF004CFF0033FF0000FF0000FF4C
00FFBF3FFF0059FF0059FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF004CFF00\
3FFF0033FF000CFF0000FF0000FF2600FF2600FF8C00FFA600FF2600FF000CFF00
0CFF000CFF0000FF0000FF0000FF1900FFB300FF6600FF5900FF7300FF4000FF4000FF5900E6FF\
00FFF300FFBF00F3FF0000000033FF00B3FF00E6FF00CCFF00E6FF00B3FF000000
0073FF0066FF3300FFE600FF9900FF0099FF00F3FF00FFCC00FF9900FF7300FF4C00FF4000FF4C\
00FF3300FF400CFF0026FF0026FF0033FF0033FF003FFF003FFF003FFF004CFF00
4CFF004CFF004CFF003FFF003FFF0019FF0000FF3300FF6633FF0059FF0066FF0073FF0080FF00\
8CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00A6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00B3FF0000FF1933FF0026FF00\
59FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF00
00FF1980FF0080FF0000FF0C73FF0073FF0073FF0066FF0059FF003FFF0000FF000CFF003FFF00\
26FF0000FF2619FF0026FF0000FF193FFF0066FF0066FF0073FF0080FF0080FF00
80FF0080FF0080FF0073FF0080FF0080FF0073FF0059FF004CFF0073FF0080FF0080FF0080FF00\
80FF0073FF0059FF0066FF0066FF0066FF0066FF0059FF0033FF0000FF2619FF00
3FFF004CFF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF00\
4CFF0033FF0019FF0000FF7300FF2600FF4C00FF1900FF4C00FF2600FF000CFF00
19FF0019FF000CFF0000FF0000FF4C00FF2600FF1900FF3300FF4C00FF3300FF3300FF4000FF59\
00FFB300FF8C00F3FF0066FF00FFFF00D9FF00FFF300F3FF00FFD900F3FF00FFFF
00E6FF0059FF0099FF004CFF0000000026FF00CCFF004CFF00FFBF00FF8C00FF4C00FF3300FF26\
00FF0C0CFF0019FF0026FF0033FF0033FF003FFF003FFF004CFF004CFF004CFF00
59FF0059FF004CFF004CFF003FFF0026FF0000FF7300FF3333FF003FFF004CFF004CFF0080FF00\
8CFF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF0099FF003FFF0080FF00\
99FF00A6FF00A6FF00A6FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0066FF0059FF003FFF0000FF8C00FF00\
00FF2626FF0000FF000CFF0019FF0059FF0066FF0073FF0080FF0080FF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0059FF0033FF0073FF0080FF008CFF008CFF00\
8CFF0080FF0080FF0080FF0073FF0073FF0066FF003FFF0033FF0019FF0000FF73
3FFF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0059FF00\
4CFF0033FF000CFF0000FF4019FF0000FF3319FF0000FF1900FF660CFF0019FF00
19FF0019FF0019FF000CFF0000FF0C00FF0000FF0000FF2600FF2600FF2600FF2600FF3300FF40\
00FF5900FF8C00F3FF00FF9900FFB300FFB300FF9900FFA600FFBF00FFD900FFBF
00CCFF00FFF300D9FF00B3FF3F00FF000000008CFF00FFFF00FFBF00FF9900FF5900FF3300FF19\
00FF0C0CFF0019FF0026FF0033FF0033FF003FFF004CFF004CFF0059FF0059FF00
59FF0059FF0059FF0059FF004CFF003FFF0033FF0019FF0000FF4000FF193FFF0066FF0080FF00\
8CFF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF008CFF003FFF0080FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0066FF0059FF0033FF000CFF00\
3FFF004CFF003FFF004CFF003FFF004CFF0073FF0080FF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0059FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF0080FF0080FF0080FF0073FF0066FF0059FF0033FF0000FF59
26FF0059FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF00\
4CFF0019FF0000FF0C00FF2633FF0033FF0026FF000CFF0000FF0019FF0026FF00
26FF0026FF0026FF0019FF0019FF000CFF000CFF0000FF0000FF0C00FF0C00FF1900FF3300FF40\
00FF5900FF9900FF6600FF5900FFE600D9FF00FF7300FF9900BFFF00FFB300FF8C
00FF9900FFBF00FFFF0073FF0099FF6600FF0026FF00CCFF008CFF00FF8C00FF7300FF4000FF4C\
00FF260CFF0019FF0026FF0026FF0033FF003FFF004CFF0059FF0059FF0059FF00
59FF0066FF0059FF0059FF0059FF004CFF003FFF0026FF0000FF6633FF0059FF0066FF0073FF00\
80FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF0099FF0099FF00A6FF0099FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0066FF0059FF0019FF0033FF00\
4CFF0059FF0066FF0066FF0066FF003FFF0073FF008CFF008CFF008CFF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF008CFF0080FF0073FF0073FF0059FF0026FF0033FF00
4CFF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0059FF00\
0CFF0000FF4C3FFF004CFF004CFF003FFF0033FF0000FF000CFF0026FF0033FF00
33FF0033FF0026FF0026FF0019FF0019FF000CFF000CFF0000FF0000FF0C00FF1900FF4C00FFA6\
00FFB30080FF00FF4C00FF4000FF4000FF4C00FF5900FF8C00FF8000FFFF00FF73
00FF8C00FFBF00FFCC00FFD900F3FF004CFF0000008000FF00A6FF00FFFF00FF9900FF8C00FF59\
00FF1900FF000CFF000CFF0019FF0026FF0033FF004CFF0059FF0059FF0066FF00
66FF0066FF0066FF0066FF0059FF0059FF004CFF0000FF1900F3FF33FF0059FF0066FF0073FF00\
80FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF004CFF0000FF3326FF00\
4CFF0066FF0073FF0073FF0080FF0080FF0080FF008CFF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0059FF0000FF3359FF00
66FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF00\
26FF004CFF0059FF0059FF0059FF004CFF003FFF0000FF0026FF0033FF0033FF00
33FF0033FF0033FF0026FF0026FF0019FF0019FF000CFF0000FF0000FF0C00FF1900FF4000FF73\
00FFBF00FF4000FF3300FF2600FF2600FF4000FF5900BFFF00FF5900FF4C00FF59
00CCFF00FF8C00FF8C00FFB30099FF00BFFF00000000000000B3FF00FFA600FF7300FF5900CCFF\
00FF7300FF2600FF2600FF6600FF0C00FF0C19FF004CFF0059FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0059FF003FFF0000FF0C00FF0033FF004CFF0059FF0066FF00\
66FF0066FF0000FF8C8CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00C0FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0073FF0059FF0000FF3300FFD900FF0C\
3FFF0066FF0073FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF0080FF0066FF003FFF003FFF0066FF00
73FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00\
66FF0066FF0066FF0066FF0059FF0059FF004CFF0026FF003FFF003FFF003FFF00
3FFF003FFF0033FF0033FF0026FF0019FF0019FF000CFF0000FF0000FF0C00FF1900FF5900FF66\
00FF1900FF1900FF3300FF0C00FF1900FF6600F3FF00FF8C00FF4C00FF3300FF40
00FF4C00FF5900FF7300FF8C00FFBF00F3FF0073FFF300FF0099FF00FFF300FFFF00FF4000FF33\
00FF2600FF2600FF6600FF0C26FF003FFF004CFF0059FF0066FF0066FF0066FF00
73FF0073FF0073FF0073FF0066FF0066FF0000FF193FFF0000FF400CFF0026FF0019FF0026FF00\
4CFF0033FF0073FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0080FF0073FF0066FF003FFF0000FF0026FF00\
59FF0073FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF008CFF008CFF0080FF0000FF1900FF8C3FFF0066FF00
73FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF00\
73FF0073FF0066FF0066FF0066FF0059FF0059FF004CFF004CFF004CFF004CFF00
3FFF003FFF0033FF0033FF0026FF0019FF000CFF000CFF0000FF0000FF0C00FF4000FF4000FF0C\
00FF0000FF0000FF0000FF0000FF0C00FF6600FF2600FF3300FF3300FF2600FF26
00FF3300FF4C00FF6600FFB300FFA600FF8C00FFBF0019FF00000000FFE600FF8000FF3300FF19\
00FF0000FF0000FF2600FF4C26FF003FFF0059FF0059FF0066FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF0033FF0000FF1933FF000CFF0026FF00\
19FF004CFF0073FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0073FF0066FF0059FF004CFF0000FF4C4CFF00\
66FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0059FF000CFF004CFF0073FF00
80FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF00\
73FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF004CFF004CFF00
4CFF003FFF0033FF0033FF0026FF0019FF0000FF0000FF0000FF1900FF2600FF6600FF3300FF0C\
0CFF000CFF000CFF000CFF0000FF0000FF1900FF0000FF0C00FF1900FF1900FF19
00FF3300FF4C00FF7300FF7300FF4C00FF6600FFA600FFA600FFFF0059FF00F3FF00FF8000FF33\
0CFF0019FF0000FF0000FF400CFF0033FF0059FF0066FF0066FF0073FF0073FF00
73FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF003FFF0000FF7359FF0059FF0059FF00\
3FFF0033FF0059FF0080FF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00A6FF00A6FF0099FF008CFF0059FF0059FF0066FF0059FF004CFF003FFF0000FF593FFF00\
66FF0073FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF008CFF0066FF0033FF0033FF0059FF0073FF00
80FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00\
80FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF0059FF004CFF00
4CFF003FFF0033FF0019FF000CFF0000FF0000FF4000FF2600FF3300FF9900FF3300FFD900FF0C\
0CFF0019FF0019FF0019FF0019FF000CFF000CFF000CFF0000FF0000FF0C00FF19
00FFE600FF9900FF6600FFBF00FF3300FF3300FF4C00FFB300FFB300FFF300FFE600FF4000FF0C\
19FF0026FF0026FF0000FF000CFF0026FF004CFF0066FF0073FF0073FF0073FF00
80FF0080FF0080FF0080FF0080FF0080FF0073FF0066FF0026FF0059FF0073FF0073FF0073FF00\
59FF004CFF0000FF2673FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00
A6FF00A6FF0099FF0099FF008CFF0073FF004CFF0026FF0019FF0026FF0000FF6626FF0000FF66\
3FFF0066FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF00A6FF00A6FF00A6FF0099FF008CFF0073FF004CFF0000FF0073FF0080FF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00\
80FF0080FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF0059FF00
4CFF003FFF0026FF0000FF2600FF1900B3FF00FFCC00FF7300FF8C00FF0C00FF0C00FF5900FF26\
19FF0026FF0026FF0026FF0026FF0026FF0019FF0019FF000CFF0000FF0000FF0C
00FF3300FF5900FF2600FF4C00FF1900FF2600FF5900FFBF00FF4000FF4C00FF7300FF0C0CFF00\
26FF0033FF0033FF0033FF003FFF0000FF5900FF2666FF0073FF0073FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0019FF0066FF0080FF0080FF0080FF00\
73FF0073FF0066FF004CFF0073FF0080FF008CFF0099FF00A6FF00B3FF00B3FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00
A6FF0099FF0099FF008CFF0080FF0073FF0059FF0026FF0026FF0019FF0026FF0059FF0059FF00\
4CFF0033FF0066FF0080FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF0099FF0099FF0080FF004CFF0000FF8C66FF008CFF00
8CFF008CFF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00\
80FF0080FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF0059FF00
4CFF003FFF003FFF0026FF0019FF0000FF1900FF1900FF0000FF0C0CFF0019FF0000FF0000FF0C\
19FF0026FF0033FF0033FF0033FF0026FF0026FF0019FF000CFF0000FF0000FF19
00FF7300FF1900FF0000FF0000FF0000FF0C00BFFF00FF2600FF1900FF2600FF4C00FF0019FF00\
33FF003FFF004CFF004CFF0059FF0059FF0059FF0066FF0073FF0080FF0080FF00
80FF0080FF008CFF008CFF008CFF008CFF008CFF0080FF0066FF0073FF008CFF008CFF008CFF00\
8CFF008CFF0080FF0066FF0033FF0019FF0073FF0080FF004CFF00A6FF00B3FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00
99FF008CFF0080FF0080FF0073FF0059FF003FFF0000FF804CFF0059FF004CFF0073FF0073FF00\
73FF0066FF004CFF0080FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF0099FF0080FF0033FF0080FF0080FF008CFF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF00\
80FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF0059FF00
4CFF004CFF003FFF0033FF0019FF0000FFCC00FF1919FF0026FF0026FF0026FF0019FF0000FF33\
26FF0033FF0033FF0033FF0033FF0033FF0026FF0019FF000CFF0000FF0C00FF26
00FF7300FF0C0CFF000CFF0019FF000CFF0000FF000CFF0000FF0000FF0C00FF4C00FF0C0CFF00\
26FF003FFF004CFF0059FF0066FF0066FF0073FF0073FF0080FF0080FF0080FF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF008CFF008CFF0099FF0099FF00\
99FF0099FF008CFF0080FF0073FF0026FF003FFF0000FF0C80FF00A6FF00B3FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF0099FF00
80FF0033FF0000FF0C33FF0033FF0000FF1919FF003FFF0059FF0073FF0073FF0080FF0080FF00\
8CFF008CFF008CFF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF0099FF0073FF0080FF008CFF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF00\
80FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF0059FF00
4CFF003FFF003FFF0026FF0000FF0C00FF5900FF3326FF0033FF003FFF003FFF0033FF0000FF4C\
26FF003FFF003FFF003FFF003FFF0033FF0026FF000CFF0000FF1900FF2600FF59
00FF4C00FF0C0CFF0019FF0026FF0026FF0019FF0019FF000CFF0000FF0000FF2600FF3300FF19\
00FF2600FF004CFF0059FF0066FF0073FF0073FF0073FF0080FF0080FF008CFF00
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
A6FF0099FF0099FF0099FF008CFF0080FF0073FF0080FF0059FF008CFF00A6FF00
B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF008CFF00
73FF0073FF0080FF0073FF0033FF0059FF0000FF0C3FFF0066FF0073FF0080FF008CFF008CFF00\
8CFF0099FF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF00\
80FF0080FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF004CFF00
4CFF003FFF0033FF0026FF0000FF190CFF0026FF0026FF003FFF004CFF004CFF003FFF0033FF00\
33FF004CFF004CFF004CFF003FFF0033FF0000FF0C00FF4C00FF3300FF4000FF00
00FF4C00FF8C19FF0026FF0033FF0033FF0026FF0026FF0019FF0000FF0000FF3300FF0026FF00\
33FF003FFF0059FF0066FF0066FF0073FF0073FF0080FF0080FF0080FF008CFF00
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0073FF0080FF00
B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00
A6FF0099FF0099FF008CFF0080FF0073FF0059FF0033FF0066FF0073FF0080FF008CFF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF00\
80FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF0059FF004CFF00
4CFF003FFF0026FF0000FF0C0CFF0033FF003FFF003FFF004CFF004CFF004CFF004CFF004CFF00\
4CFF0059FF0059FF004CFF004CFF003FFF0026FF0000FF0000FF1919FF0026FF00
26FF0000FF4C19FF0033FF0033FF0033FF0033FF0033FF0019FF0000FF1900FF330CFF0033FF00\
3FFF004CFF0059FF0066FF0073FF0073FF0073FF0080FF0080FF008CFF008CFF00
8CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00
B3FF00A6FF0099FF0099FF008CFF0080FF0000FF730CFF0026FF0073FF0080FF008CFF0099FF00\
99FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF00\
80FF0080FF0073FF0073FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF00
3FFF0033FF0000FF1900FF2626FF003FFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF00\
59FF0059FF0059FF0059FF0059FF004CFF0033FF0000FF1900FF8C33FF003FFF00
33FF0000FF0019FF003FFF003FFF003FFF003FFF0033FF000CFF0000FF8C00FF800CFF0033FF00\
4CFF0059FF0059FF0066FF0073FF0073FF0073FF0080FF0080FF008CFF008CFF00
8CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00
B3FF00A6FF00A6FF0099FF008CFF0073FF0019FF0000FFCC26FF0033FF008CFF0099FF0099FF00\
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF00\
80FF0073FF0073FF0066FF0059FF0059FF0059FF0059FF004CFF003FFF003FFF00
33FF0026FF0000FF0C00FF0033FF003FFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0059FF004CFF0033FF0019FF003FFF004CFF004CFF00
4CFF003FFF0033FF004CFF004CFF004CFF003FFF003FFF0019FF0019FF0000FF0000FF3326FF00\
4CFF0059FF0059FF0066FF0073FF0073FF0073FF0080FF0080FF008CFF008CFF00
8CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
B3FF00B3FF00A6FF0099FF008CFF0080FF0000FF4C26FF0000FF0C73FF008CFF0099FF0099FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0080FF00\
73FF0073FF0066FF004CFF0033FF004CFF004CFF004CFF003FFF0019FF0026FF00
26FF000CFF0000FF400CFF0033FF004CFF004CFF0059FF0059FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0066FF004CFF000CFF0033FF004CFF0059FF0059FF00
59FF0059FF004CFF0059FF0059FF004CFF004CFF004CFF003FFF0033FF0000FF0C00FF4033FF00\
4CFF0059FF0059FF0066FF0066FF0073FF0073FF0080FF0080FF008CFF008CFF00
8CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
B3FF00B3FF00A6FF0099FF008CFF0080FF0066FF003FFF0059FF0080FF008CFF0099FF0099FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0073FF0066FF00\
66FF0066FF0059FF004CFF0000FF0033FF003FFF003FFF0026FF0000FF5900FF40
00FF3300FF8C00FF990CFF0033FF003FFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF00\
73FF0073FF0073FF0066FF0066FF0059FF0019FF004CFF0059FF0066FF0066FF00
66FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF0000FF0C26FF00\
3FFF004CFF0059FF0059FF0066FF0066FF0073FF0080FF0080FF0080FF008CFF00
8CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
B3FF00A6FF0099FF008CFF0080FF0073FF0066FF0033FF003FFF0066FF0080FF008CFF0099FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF0033FF0033FF000CFF00\
0CFF003FFF0033FF0033FF0000FF0000FF1919FF0026FF000CFF0000FFA600FF33
26FF0026FF0000FF0C00FF2600FF0C00FF8C59FF0059FF0066FF0066FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0066FF0059FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF004CFF003FFF0033FF0000FF000CFF00\
26FF003FFF003FFF0059FF0059FF0066FF0066FF0073FF0080FF0080FF008CFF00
8CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00
B3FF00A6FF004CFF0059FF0066FF0026FF003FFF0019FF0033FF0000FF0C73FF008CFF0099FF00\
A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF0080FF0066FF0066FF00\
59FF0000FF0000FF3300FF5900FF000CFF0000FF73008CFF0CFF0026FF0000FF0C
3FFF0033FF0019FF0000FF8026FF003FFF0059FF0066FF0066FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF004CFF003FFF000CFF0000FF26\
0CFF0026FF0000FF403FFF004CFF0019FF0059FF0073FF0073FF0080FF0080FF00
8CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00
B3FF00A6FF0099FF0073FF0033FF003FFF003FFF0066FF0080FF0080FF0000FF8059FF008CFF00\
A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0073FF00\
66FF004CFF0026FF0026FF003FFF003FFF0033FF0000FF0019FF004CFF004CFF00
4CFF004CFF0026FF0000FF1926FF003FFF0059FF0066FF0066FF0073FF0073FF0073FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF003FFF0026FF0000FF0C\
00FF2600FFE600FF4026FF000CFF0000FF004CFF0059FF0066FF0073FF0073FF00
80FF008CFF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00
B3FF00A6FF0099FF0080FF000CFF0066FF0080FF0080FF0099FF0099FF008CFF003FFF0026FF00\
A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0080FF00\
66FF004CFF0000FF0033FF004CFF0059FF0059FF004CFF0033FF0059FF0066FF00
59FF004CFF0000FF3326FF0000FF4019FF0000FF1966FF0073FF0073FF0073FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF00
73FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF004CFF003FFF0026FF0000FF00\
0CFF0019FF0000FF0000FF4019FF0026FF0019FF0033FF0033FF0059FF0000FF00
73FF0073FF0080FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00
A6FF0099FF0073FF0059FF0000FF2673FF008CFF0099FF00A6FF00A6FF00A6FF0099FF008CFF00\
99FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0080FF00\
66FF003FFF0000FF8019FF0059FF0066FF0066FF0059FF0000FF1966FF0073FF00
73FF0066FF0059FF004CFF0000FF0026FF0059FF0066FF0073FF0073FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
73FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF004CFF0033FF0000FF6600FF59\
26FF0033FF003FFF0026FF003FFF0059FF0059FF004CFF0026FF0000FFE600FFBF
3FFF0000FF0073FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF00
99FF008CFF0066FF004CFF0073FF0026FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0073FF00\
59FF003FFF0000FF0C4CFF0066FF0073FF0073FF0073FF0059FF0073FF0080FF00
73FF0073FF0066FF0059FF0033FF0019FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF00\
80FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF004CFF000CFF0000FF2600FF59\
19FF003FFF004CFF0059FF0059FF0066FF0073FF0073FF0066FF0059FF004CFF00
4CFF0059FF0000FF4073FF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF00A6FF0099FF00
73FF0000FF3373FF0080FF0099FF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0073FF0033FF00\
0CFF0000FFBF00FF1959FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0073FF0066FF0026FF004CFF0066FF0073FF0080FF0080FF0080FF0080FF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00
80FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF004CFF004CFF0033FF000CFF0000FF33\
26FF004CFF0059FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0073FF00
59FF0080FF008CFF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00A6FF0059FF008CFF0073FF00
00FF1973FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0073FF003FFF00\
3FFF0033FF004CFF0059FF0073FF0080FF008CFF008CFF008CFF008CFF008CFF00
8CFF0080FF0073FF0066FF0019FF003FFF0066FF0073FF0080FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00
80FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF004CFF003FFF0033FF0019FF000CFF00\
3FFF004CFF0066FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF00
8CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00A6FF008CFF003FFF0033FF00
3FFF0080FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF0080FF0073FF0033FF004CFF00\
66FF0080FF0073FF0033FF0080FF008CFF008CFF0099FF0099FF0099FF008CFF00
8CFF008CFF0080FF0059FF0000FF0C4CFF0066FF0073FF0080FF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0080FF0073FF0073FF0066FF0059FF004CFF003FFF0033FF0026FF0000FF0000FF40\
00FF004CFF0059FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF003FFF0066FF00
8CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF004CFF0000FF1973FF0080FF00\
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00
8CFF008CFF0080FF0066FF003FFF0019FF004CFF0073FF0080FF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
80FF0080FF0080FF0073FF0073FF0066FF0000FF0C00FF0026FF0000FF0000FF0C00FF2626FF00\
33FF0000FF2600FF0C73FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00B3FF0066FF0080FF0099FF008CFF0059FF0073FF0026FF0073FF00
99FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0073FF0000FF7366FF0080FF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF0099FF0099FF0099FF00
99FF008CFF0080FF0066FF0019FF003FFF0066FF0080FF008CFF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00
80FF0080FF0080FF0073FF0073FF0066FF004CFF0033FF000CFF0000FF1900FF0000FF0C3FFF00\
4CFF0059FF0066FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00C0FF00B3FF0099FF0080FF004CFF0066FF0000FF2600FFCC3FFF0066FF00
8CFF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0080FF0033FF0000FF804CFF0059FF008CFF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0080FF003FFF004CFF003300FF66FF0080FF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00
80FF0080FF0080FF0073FF0073FF0066FF0059FF003FFF000CFF0000FF0C33FF003FFF0059FF00\
66FF0066FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00C0FF00B3FF00A6FF0099FF0080FF0000FF1966FF0073FF0080FF0080FF00
33FF00A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF0080FF0000FF0080FF008CFF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF008CFF0080FF0066FF0000FF3300FFA680FF008CFF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF00
8CFF0080FF0080FF0073FF0066FF0059FF003FFF0033FF000CFF0000FF003FFF004CFF0059FF00\
66FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
C0FF00C0FF00B3FF00A6FF0099FF0080FF0000FF5973FF008CFF0099FF00A6FF00
A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF0059FF0000FF0080FF0099FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF008CFF0066FF0059FF0080FF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00
8CFF0080FF0073FF0066FF0059FF004CFF0033FF0000CCFF00FF6600FF0033FF004CFF0059FF00\
66FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00CCFF00C0FF00\
C0FF00B3FF00B3FF00A6FF008CFF000CFF0000FF1973FF0099FF00A6FF00A6FF00
B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00B3FF00A6FF008CFF0000FF198CFF0059FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF0099FF008CFF0000FF1980FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00
8CFF0080FF0066FF0059FF0026FF0000FF260CFF0033FF0033FF0019FF000CFF0033FF004CFF00\
66FF0073FF0073FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00C0FF00C0FF00\
B3FF0099FF0099FF0099FF008CFF0066FF0000FF0C80FF0099FF00A6FF00B3FF00
B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00B3FF0099FF0073FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF0099FF0080FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF00
8CFF0080FF004CFF0000FF6626FF004CFF0059FF0059FF004CFF0033FF0000FF3300FF190CFF00\
59FF0066FF0073FF0080FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00B3FF00B3FF0080FF00B3FF00B3FF00B3FF00\
A6FF008CFF0073FF0073FF0073FF0059FF0066FF008CFF0099FF00A6FF00B3FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF00
8CFF0073FF0019FF003FFF0059FF0066FF0066FF0066FF0059FF004CFF0000FF0C00FF6600FF0C\
4CFF0059FF0066FF0073FF0073FF0080FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00C0FF0026FF0066FF000CFF0099FF0099FF00\
8CFF0080FF0033FF0019FF003FFF0033FF0033FF0080FF0099FF00A6FF00B3FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00
8CFF0033FF0066FF0033FF0073FF0073FF0073FF0073FF0066FF0059FF003FFF0033FF0000FF40\
33FF0026FF004CFF0000FF000CFF003FFF008CFF0099FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00B3FF00A6FF0099FF0073FF0000FF0C\
59FF0033FF0026FF0073FF003FFF0080FF0080FF0000FF4C80FF00A6FF00B3FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0059FF004CFF0033FF00\
00FF0C00FF194CFF0059FF0066FF0080FF0099FF0099FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF008CFF00\
59FF0059FF0080FF008CFF008CFF0099FF0099FF008CFF0033FF0066FF00B3FF00
C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0066FF0059FF004CFF0026FF00\
00FF004CFF0066FF0073FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00C0FF00B3FF0099FF00\
73FF0073FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00A6FF0099FF00B3FF00
C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0059FF0033FF0000FF73\
26FF003FFF0073FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00C0FF00B3FF0099FF00\
4CFF0066FF008CFF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0066FF004CFF0000FF000CFF00\
3FFF0066FF0073FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00C0FF00A6FF0066FF00\
33FF0000FF008CFF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0033FF003FFF004CFF0000FF0C\
19FF0059FF0066FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00CCFF00C0FF00B3FF00A6FF003FFF00\
00FF7373FF0073FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF0066FF004CFF00\
00FF0033FF0059FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00B3FF00B3FF00A6FF0099FF008CFF00\
0CFF008CFF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0073FF0066FF003FFF00\
0CFF0059FF0073FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF0066FF008CFF0033FF008CFF0073FF00\
66FF0099FF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0059FF00\
0CFF0033FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00E6FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF004CFF004CFF003FFF003FFF00\
00D9FF80FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0073FF0066FF00\
00FF2666FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00E6FF00E6FF00D9FF00D9FF00CCFF00C0FF00A6FF008CFF0000FF338CFF0059FF0099FF00\
8CFF0000FF00A6FF00B3FF00C0FF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0059FF00\
00FF0C66FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
E6FF00E6FF00D9FF00CCFF00C0FF00B3FF00A6FF0059FF0026FF008CFF00B3FF00B3FF00B3FF00\
B3FF008CFF0080FF00B3FF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0059FF00\
00FF2659FF0066FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
E6FF00E6FF00C0FF00A6FF0099FF0059FF00A6FF0099FF00B3FF0066FF00C0FF00C0FF00CCFF00\
C0FF00B3FF0026FF008CFF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF004CFF00\
00FF0C33FF0000FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
E6FF00D9FF00C0FF008CFF008CFF00A6FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00B3FF0026FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0059FF00\
33FF000CFF0059FF0066FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
D9FF00CCFF0080FF004CFF00C0FF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00A6FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0059FF00\
19FF0033FF004CFF0066FF0066FF0073FF0066FF0066FF008CFF008CFF0099FF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
CCFF00A6FF00C0FF00C0FF00CCFF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0073FF0059FF003FFF00\
00FF260CFF0000FF004CFF0059FF0059FF0000FF0C73FF0080FF008CFF008CFF00
99FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
E6FF00E6FF00E6FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0019FF003FFF0059FF00\
4CFF0026FF0000FF6619FF0033FF0019FF0059FF0073FF0080FF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF0080FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF00\
66FF004CFF003FFF0026FF0000FF003FFF0066FF0073FF0080FF0080FF008CFF00
8CFF008CFF008CFF0080FF0059FF0066FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF00\
66FF0059FF004CFF0033FF0000FF4026FF0059FF0073FF0073FF0080FF0080FF00
80FF0080FF0080FF0073FF003FFF0059FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF0019FF00B3FF00B3FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF00\
73FF0066FF004CFF0000FF0C00FF0C3FFF0059FF0066FF0073FF0073FF0073FF00
73FF0073FF0073FF0059FF0019FF0073FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF0099FF008CFF0000FF0C8CFF00A6FF00B3FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF00\
73FF004CFF0000FF0C00FF4C19FF003FFF004CFF0059FF0066FF0059FF0066FF00
66FF0066FF0059FF0019FF0059FF0073FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF008CFF0066FF0000FF0073FF00A6FF00B3FF00B3FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF00\
73FF0059FF004CFF0033FF0000D9FF26FF003FFF004CFF004CFF0033FF003FFF00
59FF0059FF003FFF0026FF0066FF0073FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00\
99FF008CFF0080FF0059FF0059FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF00\
73FF0066FF0059FF003FFF0019FF0000FF0026FF0026FF0026FF0000FF1900FF26
19FF0033FF0000FF1933FF0059FF0066FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF0080FF0066FF003FFF0080FF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF00\
73FF0066FF0059FF0033FF0000FF0019FF0033FF000CFF0000FF4C00FF4019FF00
19FF0033FF0019FF0000FF663FFF0000FF2673FF0080FF0080FF0080FF0080FF0059FF0073FF00\
73FF0073FF004CFF004CFF0080FF0099FF0099FF00A6FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF00\
73FF0066FF0059FF0026FF0019FF003FFF004CFF004CFF003FFF0000FF4026FF00
4CFF004CFF003FFF0026FF0000FF0C4CFF0066FF0073FF0073FF0073FF0066FF0026FF004CFF00\
59FF0059FF0000FF194CFF0073FF0080FF0099FF00A6FF00A6FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0073FF00\
73FF0066FF004CFF0000FF330CFF0059FF0066FF0066FF0059FF0000FF0059FF00
66FF0059FF004CFF0026FF0000FF4C4CFF0059FF0066FF0066FF0066FF004CFF000CFF0000FFA6\
00FF0C3FFF003FFF0000FFB333FF0066FF008CFF008CFF008CFF00A6FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF00\
66FF004CFF0000FF003FFF0059FF0066FF0066FF0073FF0073FF0073FF0073FF00
73FF0066FF0059FF0033FF0000FF7333FF0026FF004CFF0059FF004CFF0026FF0000FFBF0CFF00\
59FF0066FF0066FF004CFF0000FF4066FF0073FF0073FF0019FF0099FF00A6FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0073FF0066FF00\
33FF0000FF0C26FF0059FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF00
73FF0073FF0066FF004CFF000CFF0026FF0000FF330CFF0000FF0C33FF004CFF004CFF0019FF00\
73FF0073FF0073FF0059FF000CFF003FFF0000FF6633FF0066FF008CFF0099FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0059FF0059FF004CFF00\
33FF0000FF594CFF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0073FF0000FF0059FF0059FF004CFF0033FF0033FF0066FF0073FF0073FF0073FF00\
80FF008CFF0080FF0073FF003FFF004CFF0000FF3359FF0033FF0059FF008CFF00
99FF00A6FF00A6FF00A6FF00B3FF00B3FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00B3FF00\
B3FF00A6FF00A6FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0080FF0066FF003FFF0026FF0026FF00\
00FF4C00FF593FFF0066FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF00
8CFF0080FF0073FF0000FF4073FF0073FF0066FF0026FF003FFF0066FF0080FF008CFF008CFF00\
8CFF0099FF008CFF008CFF0000FF5973FF0080FF0080FF0066FF0000FF0C73FF00
8CFF0099FF0099FF0099FF00A6FF0099FF0000FF19A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF0026FF00A6FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF008CFF0080FF0080FF0073FF0073FF0066FF0059FF0033FF0000FF0C\
26FF003FFF0059FF0066FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF0080FF0080FF0080FF0073FF0059FF0000FF4C73FF008CFF008CFF0099FF00\
99FF0099FF0099FF0099FF0073FF008CFF0099FF0099FF008CFF008CFF003FFF00
4CFF0073FF0066FF008CFF008CFF0080FF004CFF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
8CFF0026FF0099FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF0080FF0073FF00C0FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF0099FF008CFF0066FF0019FF0066FF0066FF0059FF0059FF004CFF000CFF0000FF00\
33FF004CFF0066FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF00
99FF0099FF0099FF008CFF008CFF008CFF0080FF0073FF0033FF0080FF008CFF0099FF0099FF00\
A6FF00A6FF00A6FF00A6FF0099FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF00
19FF003FFF0000FF3373FF0073FF0059FF0073FF008CFF0099FF0099FF00A6FF0099FF0099FF00\
80FF0066FF0099FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF008CFF0099FF00CCFF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF0099FF008CFF0080FF0073FF003FFF0019FF0019FF003FFF0033FF0000FF6600FF66\
0CFF004CFF0059FF0066FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF008CFF0080FF0000FF0073FF008CFF0099FF00A6FF00\
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF00
8CFF0066FF0000FF000CFF0019FF0026FF004CFF0080FF008CFF008CFF0080FF008CFF0080FF00\
33FF0080FF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00B3FF00
B3FF0099FF0059FF00A6FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF008CFF0080FF0066FF004CFF0000FF8019FF0019FF0000FF1900FF33\
19FF003FFF004CFF0059FF0073FF0080FF008CFF0099FF0099FF0099FF0099FF00
99FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0080FF0059FF0059FF008CFF0099FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF008CFF000CFF0073FF0073FF0066FF0019FF0066FF0080FF0073FF0000FF663FFF0066FF00\
19FF0073FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
99FF0073FF0099FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF008CFF0080FF0073FF0059FF0026FF0000FF2600FF5900FF7300FF73\
0CFF0026FF0000FFBF4CFF0073FF008CFF008CFF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF0033FF0000FF9926FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
A6FF0099FF0073FF0099FF008CFF0073FF003FFF0000FF0C59FF0033FF0000FF594CFF0059FF00\
0CFF003FFF0000FF338CFF0099FF00A6FF00A6FF0099FF008CFF0099FF0099FF00
80FF0073FF00A6FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF008CFF0080FF0073FF003FFF0026FF0033FF0026FF0000FF9900FF33\
00FF0C00FF0026FF0059FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0066FF008CFF00A6FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00A6FF00A6FF00A6FF00A6FF008CFF0080FF003FFF0066FF0073FF004CFF0080FF0080FF00\
73FF0033FF0066FF008CFF008CFF0099FF008CFF0066FF0059FF0066FF0080FF00
00FF0073FF00A6FF00B3FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF008CFF0080FF0073FF0059FF0059FF004CFF0033FF0000FF1900FF40\
26FF0033FF0000FF2626FF0073FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00A6FF008CFF004CFF0080FF008CFF0099FF0099FF008CFF00\
73FF0026FF0059FF0066FF0080FF0080FF0073FF0059FF000CFF0059FF0073FF00
66FF0000FF2673FF00A6FF00C0FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0066FF0059FF003FFF0000FF0000FF26\
19FF004CFF0019FF0059FF0019FF0080FF0099FF0099FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF0033FF0099FF00A6FF00A6FF00A6FF0099FF00\
8CFF0026FF004CFF0000FF0C59FF0026FF0000FF0C26FF000099FF80FF008CFF00
8CFF0073FF003FFF0099FF00A6FF0099FF00C0FF00D9FF00D9FF00E6FF00E6FF00E6FF00F3FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0099FF008CFF008CFF008CFF0080FF0073FF0066FF0059FF003FFF0026FF0019FF00\
4CFF0066FF0073FF0080FF0080FF0080FF0099FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00B3FF008CFF0073FF00A6FF00B3FF00B3FF00B3FF00A6FF00\
73FF0080FF008CFF0073FF0000FF9973FF008CFF008CFF0000FF1999FF00A6FF00
99FF0000FF0000FF4C66FF0073FF0080FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0066FF003FFF0026FF0000FF1926FF00\
19FF0066FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00A6FF008CFF00B3FF00B3FF00C0FF00C0FF00B3FF00\
A6FF00A6FF0099FF0073FF003FFF008CFF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF0099FF0019FF008CFF008CFF004CFF0066FF00C0FF00CCFF00D9FF00D9FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
99FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0066FF004CFF000CFF0033FF0059FF00\
66FF0073FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00A6FF0099FF0019FF008CFF00A6FF00B3FF00C0FF00C0FF00C0FF00
C0FF00A6FF0073FF00B3FF00A6FF0099FF0066FF00A6FF00C0FF00CCFF00CCFF00D9FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00
99FF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0066FF004CFF0000FF0000FF1966FF00\
80FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00B3FF00A6FF004CFF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00
C0FF00C0FF00B3FF00C0FF00C0FF00C0FF00B3FF0059FF0080FF00A6FF00B3FF00B3FF00D9FF00\
E6FF00F3FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00
8CFF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF004CFF0019FF0066FF0073FF00\
80FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF0099FF004CFF00A6FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF008CFF008CFF003FFF0073FF00A6FF00CCFF00\
E6FF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0080FF008CFF0099FF008CFF0080FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF00
8CFF008CFF008CFF0080FF0080FF0080FF0073FF0066FF0059FF0026FF004CFF0066FF0073FF00\
80FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00C0FF00A6FF0019FF0099FF00C0FF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00C0FF00A6FF00C0FF00B3FF0099FF00\
CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF008CFF0000FF1959FF0073FF0059FF00\
80FF008CFF008CFF008CFF0099FF008CFF008CFF008CFF008CFF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF004CFF0000FF4033FF0066FF0073FF00\
80FF008CFF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00A6FF0099FF0059FF00C0FF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00D9FF00D9FF00CCFF00\
CCFF00E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300
FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300FFF300\
FFF300FFF300FFF300FFF300FFF300FFF300FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00\
FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0080FF0000FF190CFF0019FF00\
66FF0066FF0080FF008CFF008CFF008CFF008CFF0080FF0073FF0066FF0073FF00
80FF0080FF0080FF0073FF0073FF0066FF0066FF0059FF003FFF0000FF733FFF0059FF0066FF00\
80FF008CFF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00B3FF00A6FF00CCFF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFF300FFF300
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
C0FF00B3FF00B3FF00B3FF00A6FF008CFF0066FF0000FFFF80FF0099FF0099FF008CFF0099FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00A6FF008CFF0000FF2699FF00A6FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF00
80FF004CFF0073FF0080FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0073FF00
66FF0059FF004CFF003FFF0026FF0019FF0000FF2626FF0033FF004CFF0059FF0059FF0066FF00\
66FF0066FF0066FF0026FF0066FF0073FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
B3FF00B3FF00A6FF00A6FF0099FF008CFF0000FFBF3FFF0073FF0080FF008CFF0059FF008CFF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF0000FF008CFF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF00
73FF0026FF0000FF0073FF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF00
66FF0059FF004CFF003FFF0033FF0019FF0000FFA600FF4033FF004CFF0059FF0066FF0073FF00\
73FF0080FF0080FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
A6FF008CFF008CFF008CFF008CFF0080FF003FFF0000FF403FFF004CFF0066FF004CFF0080FF00\
99FF0099FF0099FF0099FF0099FF008CFF0066FF003FFF008CFF0099FF00A6FF00
A6FF00A6FF00B3FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF00
8CFF0073FF0000FF1959FF0080FF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0073FF00
66FF0059FF004CFF0033FF0019FF0000FF3300FF0000FF5900FF803FFF0059FF0073FF0073FF00\
80FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
99FF0066FF0066FF004CFF0066FF0026FF004CFF0066FF003FFF0026FF000CFF003FFF0066FF00\
8CFF008CFF008CFF0080FF008CFF0080FF0066FF0000FF4C73FF008CFF0080FF00
99FF00A6FF0099FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00
8CFF0080FF0059FF0026FF0073FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF00
66FF003FFF000CFF000CFF0000FF3300FF1926FF003FFF003FFF0000FF7333FF0073FF0080FF00\
80FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
80FF0059FF000CFF0019FF003FFF0066FF0080FF0080FF0080FF0073FF0059FF000CFF0066FF00\
80FF0080FF0073FF0000FFB359FF0066FF004CFF000CFF0019FF0059FF0073FF00
8CFF0099FF008CFF0026FF0080FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF00
8CFF0080FF0073FF0000FF2673FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF00
66FF0059FF003FFF0019FF000CFF0033FF003FFF0059FF0059FF0059FF0059FF0073FF0080FF00\
8CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
4CFF0000FF0C3FFF0000FFD959FF0080FF008CFF008CFF008CFF0080FF0066FF0000FF4C4CFF00\
66FF0066FF0059FF0000FF800CFF0000FF9959FF0059FF0026FF0000FF5966FF00
80FF0080FF0080FF0026FF0080FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
8CFF0080FF0073FF0000FF0C59FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF00
66FF0059FF004CFF0019FF0000FF003FFF0059FF0066FF0066FF0073FF0073FF0080FF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
73FF0080FF0073FF003FFF0073FF0099FF0099FF0099FF0099FF008CFF0059FF0059FF000CFF00\
33FF0000FF2626FF0019FF000CFF0059FF0073FF0073FF0066FF0000FF004CFF00
59FF0000FF194CFF000CFF0059FF0080FF008CFF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF0099FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF00
8CFF0080FF0059FF0000FF2633FF0019FF0073FF0073FF0073FF0073FF0000FF2673FF0080FF00\
80FF0080FF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00
66FF0059FF000CFF0000FF0C00FF8026FF0059FF0073FF0073FF0080FF0080FF0080FF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
8CFF0099FF0099FF0080FF0099FF00A6FF00A6FF00A6FF00A6FF0099FF0080FF0080FF0066FF00\
19FF0066FF0073FF0073FF004CFF0080FF008CFF008CFF0073FF0059FF0019FF00
33FF0026FF004CFF0059FF0000FFF359FF004CFF0080FF008CFF0099FF0099FF0099FF0099FF00\
99FF0099FF0000FF598CFF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00
8CFF0080FF0066FF004CFF000CFF003FFF0066FF0066FF0066FF0059FF0000CCFF66FF0073FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF00
66FF004CFF0033FF000CFF004CFF0059FF0066FF0073FF0080FF0080FF0080FF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0066FF00\
00FF4C73FF008CFF008CFF008CFF0099FF0099FF0099FF008CFF0080FF0026FF00
66FF0073FF0080FF0073FF003FFF003FFF004CFF004CFF0080FF008CFF008CFF008CFF008CFF00\
8CFF0080FF003FFF0080FF008CFF008CFF0099FF008CFF008CFF008CFF0080FF00
80FF0073FF0066FF0019FF0000FF4033FF004CFF0059FF0059FF003FFF003FFF0066FF0073FF00\
73FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF00
59FF003FFF0000FF4C3FFF0059FF0066FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF0080FF00\
26FF008CFF0099FF0099FF0099FF00A6FF00A6FF0099FF0099FF0080FF0026FF00
80FF008CFF008CFF008CFF0019FF0080FF0073FF0066FF0026FF0066FF0073FF0000FF0C80FF00\
80FF0073FF003FFF0073FF0080FF008CFF008CFF008CFF0080FF0073FF0073FF00
73FF0066FF0059FF003FFF0000FF000CFF000CFF0019FF0033FF0000FF003FFF0059FF0066FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF004CFF00
3FFF0000FF0033FF0059FF0066FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0066FF00\
73FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0080FF004CFF00
8CFF0099FF0099FF0099FF008CFF0099FF008CFF008CFF0080FF0019FF0000FF263FFF0066FF00\
59FF0059FF000CFF0059FF0073FF0080FF0080FF0080FF0073FF003FFF0059FF00
00FF334CFF003FFF000CFF0026FF0033FF0000FF0000FF0C00FF0000FF2633FF003FFF0059FF00\
66FF0066FF0066FF0066FF0059FF0066FF0066FF0066FF0066FF0059FF004CFF00
19FF000CFF003FFF0059FF0066FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF0099FF004CFF00\
00FF4099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF0099FF0080FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0059FF0066FF0000FF0C3FFF00\
00FF9900FF1919FF0026FF004CFF0073FF0073FF0073FF0059FF0000FF4C19FF00
0CFF0000FF4C19FF004CFF004CFF004CFF0033FF003FFF0033FF0019FF0000FF5933FF0059FF00\
59FF0066FF0059FF0059FF000CFF004CFF0059FF0059FF0059FF004CFF003FFF00
19FF0000FF0033FF0059FF0066FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF0099FF0066FF00\
80FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0080FF0059FF004CFF00\
59FF0059FF004CFF0000FF334CFF0059FF0066FF0066FF004CFF0026FF0000FF73
00FF5926FF003FFF0059FF0066FF0066FF0059FF0059FF004CFF000CFF0000FF0033FF004CFF00\
4CFF0059FF004CFF0000FFB300F3FF33FF000CFF004CFF004CFF003FFF000CFF00
00FF800CFF0033FF0059FF0066FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF0066FF00\
99FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0000FF0073FF00\
80FF0073FF0066FF0026FF000CFF0019FF004CFF003FFF000CFF0000FFBF19FF00
00FF2633FF0059FF0066FF0073FF0073FF0066FF0066FF004CFF0026FF0000FF590CFF0033FF00\
3FFF003FFF0033FF0019FF0000FF7300FF0000FF3319FF0026FF0019FF0000FF00
00FF0033FF004CFF0059FF0066FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00B3FF008CFF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF008CFF00\
8CFF008CFF0066FF004CFF004CFF0026FF0000FF8C33FF004CFF004CFF004CFF00
26FF004CFF0066FF0073FF0073FF0073FF0073FF0066FF004CFF0019FF0033FF0000FF4000FF00\
19FF0026FF0000FF0C00FF0C00FFD900FF6600FF0000FF0C19FF0000FF0000FF00
00FF0C19FF003FFF004CFF0059FF0066FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF00\
99FF008CFF0080FF0073FF0066FF003FFF0000FF6659FF0066FF0073FF0073FF00
66FF0066FF0080FF0080FF0080FF0080FF0080FF0073FF004CFF0059FF004CFF0033FF0000FF00\
00FF0033FF0026FF0000FF000CFF0000FFBF26FF0033FF003FFF003FFF0033FF00
00FF2600FF3333FF003FFF003FFF004CFF0073FF0073FF0080FF0080FF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF0099FF0099FF008CFF0073FF003FFF0033FF0066FF0073FF0080FF0080FF00
80FF0080FF0080FF008CFF008CFF0080FF0080FF0080FF0073FF0066FF0059FF0033FF0000FF26\
19FF004CFF004CFF003FFF0033FF0000FF0019FF004CFF004CFF004CFF003FFF00
19FF0000FF0C00FF0000FF4000FF004CFF0066FF0073FF0080FF0080FF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF00A6FF0099FF008CFF0080FF0059FF004CFF0073FF0080FF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0066FF003FFF0000FF0C\
4CFF0059FF0066FF0066FF004CFF004CFF0059FF0059FF0059FF0059FF004CFF00
33FF0019FF0000FF8C33FF004CFF0059FF0066FF0073FF0080FF0080FF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
A6FF00A6FF0099FF008CFF0080FF0000FF1973FF0080FF008CFF008CFF008CFF00
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0073FF0066FF003FFF003FFF00\
59FF0066FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF0059FF004CFF00
33FF0000FF8000FF1919FF004CFF0059FF0066FF0073FF0073FF0080FF0080FF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00A6FF0099FF008CFF0059FF004CFF0080FF008CFF008CFF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0059FF0000FF0C59FF00\
66FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF004CFF00
00FF5900FF2619FF0033FF004CFF0059FF0066FF0066FF0073FF0073FF0080FF0080FF008CFF00\
8CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00A6FF00A6FF0080FF003FFF004CFF0080FF008CFF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0073FF004CFF0033FF0066FF00\
73FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0059FF00
3FFF000CFF0000FF0033FF003FFF004CFF0059FF0066FF0066FF0066FF0066FF0073FF0080FF00\
8CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00A6FF008CFF0000FF1973FF008CFF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0059FF0026FF0059FF0073FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0066FF0059FF00
3FFF0000FF1900FF0C00FFA60CFF0000FF4C4CFF0059FF0059FF003FFF0000FF594CFF0080FF00\
8CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00A6FF008CFF004CFF0019FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF000CFF0000FF0080FF00\
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0066FF0059FF00
33FF0000FFD93FFF0026FF0000FF4000FF6633FF0033FF0000FF0C00FF003FFF0073FF0080FF00\
8CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00A6FF004CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0080FF0073FF0080FF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0066FF0026FF00
33FF004CFF0059FF004CFF0019FF0026FF0000FF2600FF0C33FF0059FF0073FF0080FF0080FF00\
8CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF008CFF008CFF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0066FF0000FF19
59FF0066FF0066FF0059FF0059FF003FFF0026FF0000FF003FFF0066FF0073FF0080FF0080FF00\
8CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0059FF0073FF00
73FF0073FF0073FF0066FF0059FF004CFF0000FF0000FF194CFF0066FF0073FF0080FF0080FF00\
8CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF00
80FF0080FF0073FF0073FF0066FF004CFF0000FF3319FF003FFF0059FF0073FF0080FF0080FF00\
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF00
8CFF0080FF0080FF0073FF0066FF0026FF003FFF0000FF8C19FF0000FF7366FF0080FF0080FF00\
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00
8CFF008CFF0080FF0080FF0073FF0066FF0059FF003FFF0000FF4059FF0073FF0080FF0080FF00\
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF00
8CFF008CFF008CFF0080FF0080FF0073FF0066FF003FFF0000FF334CFF0073FF0080FF0080FF00\
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00
8CFF008CFF008CFF0080FF0080FF0073FF0066FF0059FF0000FF4059FF0073FF0073FF0080FF00\
80FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00
99FF008CFF008CFF008CFF0080FF0080FF0073FF0059FF0000FF0C59FF0066FF0073FF0080FF00\
80FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
99FF008CFF008CFF008CFF0080FF0080FF0073FF003FFF0000FF193FFF0059FF0073FF0073FF00\
80FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF0099FF008CFF008CFF0080FF0080FF0073FF0059FF0026FF0000FF4C4CFF0066FF0073FF00\
80FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF0099FF008CFF008CFF0080FF0080FF0073FF0059FF0000FF0C26FF004CFF0066FF0066FF00\
73FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF008CFF008CFF0080FF0073FF003FFF0026FF0000FF4019FF003FFF0059FF0059FF00\
59FF0066FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF008CFF008CFF0080FF0073FF0059FF004CFF003FFF0000FF2600FF333FFF003FFF00\
00FF0059FF0073FF0080FF008CFF008CFF008CFF008CFF008CFF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF004CFF0033FF000CFF000040FF33FF00\
4CFF0066FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00
99FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF0059FF003FFF000CFF0019FF004CFF00\
59FF0066FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00B3FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF0019FF000CFF0000FF0C26FF004CFF00\
59FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF004CFF00A6FF00B3FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF008CFF008CFF0080FF0080FF0073FF0066FF004CFF0019FF000CFF003FFF004CFF00\
59FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF0073FF0066FF00A6FF00B3FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF008CFF008CFF0080FF0073FF0066FF0059FF003FFF0019FF0000FF003FFF004CFF00\
59FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0066FF0059FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF008CFF0066FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF008CFF0059FF0080FF003FFF0073FF0099FF00A6FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF008CFF0080FF0066FF0066FF0059FF003FFF0000FF0C00FF4000FF1933FF003FFF00\
4CFF004CFF0059FF0066FF0073FF0073FF0073FF0073FF0073FF0066FF003FFF00
19FF004CFF0073FF0080FF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF008CFF0080FF0033FF0080FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF0099FF008CFF0066FF0019FF003FFF0080FF00A6FF00A6FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0080FF0066FF004CFF0000FF2600FF0033FF0026FF0033FF0026FF0000FF1919FF00\
00FF1900FF664CFF0059FF0066FF0066FF0066FF0066FF0066FF004CFF0033FF00
33FF0066FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
99FF0099FF008CFF0080FF0059FF0000FF7380FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF008CFF0073FF0000FF0073FF008CFF00A6FF00A6FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0080FF0066FF0000FF2659FF0059FF0059FF0059FF004CFF003FFF000CFF0000FF33\
00FFCC19FF003FFF0059FF0059FF0059FF0059FF0059FF004CFF0019FF0000FF33
00FF0066FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF008CFF0066FF0066FF0033FF003FFF0073FF008CFF0099FF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF008CFF0073FF0066FF0000FF3373FF008CFF0099FF00A6FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF008CFF0080FF0073FF0073FF0073FF0066FF0066FF0059FF004CFF0026FF0000FF80\
00FF5900FF8C33FF004CFF004CFF004CFF004CFF003FFF0026FF0000FF733FFF00
59FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
8CFF008CFF0080FF0059FF0033FF003FFF0066FF0073FF008CFF0099FF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF008CFF0073FF0000FF1900B3FF3FFF0059FF003FFF0099FF00A6FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF008CFF008CFF0080FF0080FF0073FF0073FF0073FF0066FF0059FF0000FF0C00FF73\
0CFF0000FFA60CFF0033FF0033FF0033FF0000FF2600FF0C33FF004CFF0059FF00
66FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00
8CFF008CFF0080FF0073FF004CFF0000FF0C00FF194CFF0080FF008CFF0099FF0099FF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF008CFF0080FF0073FF000CFF004CFF0073FF008CFF0099FF00A6FF00A6FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0073FF0066FF0059FF004CFF003FFF00\
33FF0026FF0000FF0C00FF8000FF0000FF0000FF003FFF004CFF0059FF0066FF00
73FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00
8CFF0080FF0080FF0073FF0059FF0019FF003FFF0073FF0080FF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00
8CFF008CFF0080FF0073FF003FFF0000FFBF4CFF0080FF0099FF0099FF00A6FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF0059FF004CFF00\
3FFF0033FF0026FF0000FF2600FF1900FF1900FF193FFF0059FF0066FF0073FF00
73FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF00
8CFF0080FF0080FF004CFF0000FF3300FF004CFF0066FF0080FF008CFF008CFF008CFF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF0059FF0073FF0080FF0080FF00
80FF0066FF0066FF0059FF0000FF7373FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF0059FF0059FF00\
4CFF003FFF0026FF0000FF0C0CFF0033FF003FFF004CFF0059FF0066FF0073FF00
73FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00
8CFF0080FF0073FF0066FF0059FF0026FF0000FF004CFF0073FF0080FF008CFF008CFF008CFF00\
8CFF008CFF0099FF008CFF008CFF008CFF0080FF0059FF0033FF0073FF0073FF00
66FF0033FF0000FF1959FF0073FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF0059FF0059FF00\
4CFF003FFF0019FF0000FFB300FF2633FF004CFF0059FF0066FF0066FF0073FF00
73FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
80FF0080FF0073FF0073FF0059FF0019FF0033FF0066FF0073FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF003FFF004CFF004CFF00
3FFF0000FF0C59FF0073FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0066FF0066FF0059FF004CFF00\
3FFF0033FF0026FF0000FF0C0CFF0033FF003FFF004CFF0059FF0066FF0073FF00
73FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
80FF0080FF0073FF0073FF0059FF003FFF0019FF0066FF0073FF0080FF0080FF0080FF0080FF00\
8CFF0080FF0080FF0080FF0080FF0080FF0073FF0066FF0059FF0000FFB300FF73
00FF660CFF004CFF0073FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0073FF0066FF0059FF0059FF003FFF00\
0CFF0019FF000CFF0000FF2600FF590CFF0026FF0033FF0059FF0066FF0073FF00
73FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0073FF0073FF0066FF004CFF0033FF0059FF0066FF0073FF0073FF0080FF0080FF00\
80FF0080FF0073FF0080FF0080FF0073FF0073FF0066FF004CFF0019FF0033FF00
4CFF0059FF0066FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF0099FF008CFF008CFF008CFF0080FF0073FF0066FF0059FF004CFF004CFF004CFF0033FF00\
19FF0000FF4C00FFD900FF0C19FF0026FF0019FF0033FF004CFF0066FF0073FF00
73FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00
80FF0080FF0073FF0066FF0059FF0026FF0026FF004CFF0066FF0066FF0073FF0073FF0073FF00\
73FF0066FF0059FF0073FF0073FF0073FF0066FF004CFF0019FF0000FF0C33FF00
59FF0073FF0080FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
99FF0099FF008CFF008CFF008CFF0080FF0073FF004CFF0000FFBF00FF0C26FF0026FF0019FF00\
00FF6600FF190CFF0000FF3333FF003FFF004CFF004CFF0059FF0066FF0073FF00
73FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF00
80FF0073FF0073FF0066FF0059FF0033FF0000FF333FFF004CFF004CFF0066FF0066FF0066FF00\
66FF0059FF0000FF4059FF0066FF0066FF0059FF004CFF0019FF0000BFFF19FF00
66FF0073FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00
99FF008CFF008CFF008CFF0080FF0080FF0073FF0066FF004CFF003FFF0033FF0000FF1900FF4C\
00FF330CFF0026FF0033FF003FFF004CFF004CFF0059FF0066FF0066FF0073FF00
73FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
73FF0073FF0073FF0059FF0000FF0000FF0000FF0C00FF2633FF0000FF4C59FF0059FF0066FF00\
59FF004CFF0000FF004CFF0059FF0059FF004CFF003FFF0026FF0019FF004CFF00
66FF0073FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00
8CFF008CFF008CFF008CFF0080FF0080FF0073FF0066FF0066FF0059FF003FFF0033FF0019FF00\
00FF6619FF0033FF003FFF004CFF004CFF0059FF0059FF0066FF0066FF0066FF00
73FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
73FF0073FF0066FF0059FF004CFF003FFF000CFF0000FF5900FF8033FF004CFF0059FF0059FF00\
4CFF003FFF0000FF0C19FF0033FF0033FF003FFF0033FF0000FF1926FF004CFF00
66FF0073FF0073FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF00
8CFF008CFF008CFF0080FF0080FF0080FF0073FF0066FF0066FF0059FF004CFF003FFF0026FF00\
00FF4019FF0033FF003FFF004CFF004CFF0059FF0059FF0066FF0066FF0066FF00
73FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF00
73FF0073FF0066FF0066FF0059FF004CFF0033FF0019FF0000FF4C00FF0C3FFF003FFF003FFF00\
33FF0033FF0000FF0000FF0C00FF0C0CFF0026FF0000FF3300FF3300FF7326FF00
4CFF0066FF0066FF0073FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00A6FF0073FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00
8CFF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0066FF0059FF004CFF0033FF0000FF0C\
00FF4000FF0019FF003FFF004CFF004CFF0059FF0059FF0066FF0066FF0066FF00
73FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF00
73FF0073FF0066FF0066FF0059FF004CFF0033FF000CFF0000FF2619FF0033FF0033FF000CFF00\
00FF0000FF2600FF000CFF000CFF0000FFBF00FF1900FF1926FF0019FF0026FF00
00FF0C33FF003FFF0000FF0073FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00A6FF008CFF0026FF0066FF0080FF0099FF0099FF0099FF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0073FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0073FF0073FF0066FF0066FF0059FF0059FF003FFF000CFF0000FF26\
00CCFF00FF4C00FF4C26FF004CFF004CFF0059FF0059FF0066FF0066FF0066FF00
66FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF00
73FF0066FF0066FF0066FF0059FF004CFF0000FF3300FF0000FF3300FF3319FF0019FF0000FF00\
00FFFF00FF0C26FF0033FF0033FF0019FF0000FF3326FF003FFF004CFF0059FF00
59FF0000FF593FFF0059FF0073FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00A6FF0073FF0073FF004CFF0059FF0080FF008CFF008CFF00
F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF0099FF0080FF0080FF0080FF0080FF0073FF0000FF5966FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0066FF0059FF0059FF0059FF004CFF003FFF0026FF0000FF00\
00FF4000FF0C26FF0033FF004CFF004CFF0059FF0059FF0066FF0066FF0066FF00
66FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0066FF0066FF0059FF0059FF004CFF003FFF0026FF000CFF0000FF3300FF3300FFCC00FF40\
00FF0C00FF5933FF003FFF003FFF003FFF0033FF0019FF004CFF0059FF0066FF00
66FF0066FF0073FF0073FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00A6FF0099FF008CFF0026FF004CFF003FFF0073FF0073FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF0099FF0080FF0066FF004CFF0059FF0059FF0019FF003FFF0059FF0019FF00
59FF0066FF0066FF0066FF0066FF0059FF0000FF193FFF003FFF003FFF0033FF0026FF000CFF00\
00FF400CFF0033FF003FFF004CFF004CFF0059FF0059FF0059FF0066FF0066FF00
66FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF00\
66FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF00
66FF0066FF0066FF0059FF0059FF004CFF003FFF0033FF000CFF0000FF2600FF0019FF0026FF00\
26FF000CFF003FFF004CFF004CFF004CFF004CFF003FFF0059FF0066FF0073FF00
73FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0059FF003FFF0033FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF0099FF0099FF0080FF0066FF0000FF4C00FF2633FF0000FF660CFF0000FF59
33FF0026FF0059FF0059FF0059FF004CFF0033FF000CFF0026FF0026FF0026FF0026FF000CFF00\
00FF0C26FF0033FF003FFF004CFF004CFF0059FF0059FF0059FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF00\
26FF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00
66FF0066FF0059FF0059FF0059FF004CFF003FFF0026FF0000FF0C00FF1919FF0033FF0033FF00\
3FFF003FFF004CFF0059FF0059FF0059FF0059FF0066FF0066FF0073FF0073FF00
80FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF0080FF0066FF004CFF0000FF33
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF00A6FF0099FF008CFF0073FF0033FF0066FF0059FF003FFF003FFF003FFF00
19FF0000FF0C19FF0033FF0026FF0033FF0019FF0000FFF300FF330CFF000CFF000CFF0000FF26\
00FF0026FF0033FF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF004CFF00\
00FF334CFF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF000CFF0000FF4019FF0033FF003FFF00\
4CFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF00
80FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF008CFF0080FF0066FF004CFF00
F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF00A6FF0099FF0099FF0080FF0073FF0073FF0073FF004CFF0059FF0066FF00
59FF0059FF004CFF000CFF0000FF5900FF0000FF990CFF0000FF0000FF4C00FF4C00FF4C00FF33\
00FF1919FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0059FF00
59FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF003FFF00\
00FF003FFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF00
59FF0059FF0059FF004CFF004CFF003FFF0033FF0026FF0000FF0C0CFF0033FF003FFF004CFF00\
4CFF0059FF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0080FF00
80FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0073FF0059FF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0073FF0073FF00
66FF0066FF0059FF004CFF0033FF0019FF0033FF0033FF0026FF0000FF330CFF000CFF0000FF00\
00FF4000FF0019FF0033FF003FFF004CFF004CFF004CFF0059FF0059FF0059FF00
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF003FFF00\
00FF263FFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF004CFF004CFF003FFF003FFF0026FF0000FF000CFF0026FF003FFF003FFF004CFF00\
4CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0073FF004CFF00
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0080FF0073FF00
73FF0073FF0066FF0059FF0000FFA63FFF004CFF003FFF0033FF0000FF0026FF0026FF000CFF00\
00FF1900FF4000FF0026FF003FFF003FFF004CFF004CFF004CFF0059FF0059FF00
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF0026FF00\
00FF0C33FF004CFF004CFF0059FF0059FF0059FF0059FF004CFF003FFF004CFF00
4CFF004CFF004CFF003FFF000CFF0019FF000CFF0000FFE619FF0033FF003FFF004CFF004CFF00\
59FF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0073FF0059FF0026FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0080FF00
80FF0073FF0073FF0066FF004CFF0059FF0059FF004CFF004CFF003FFF003FFF003FFF0026FF00\
26FF0000FF0C00FF3326FF0033FF003FFF003FFF004CFF004CFF004CFF004CFF00
59FF0059FF0059FF0059FF004CFF004CFF0033FF004CFF004CFF004CFF003FFF0026FF0000FF40\
00FF0033FF003FFF004CFF004CFF004CFF004CFF004CFF003FFF0000FF3333FF00
3FFF003FFF003FFF0033FF0026FF0000FF0C00FFA600FF0C19FF0033FF003FFF004CFF004CFF00\
59FF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0033FF0000FF4C00FF40
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF00
80FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF00\
33FF0026FF0000FF0C19FF0033FF0033FF003FFF003FFF004CFF004CFF004CFF00
4CFF004CFF004CFF004CFF004CFF003FFF0000FFF30CFF003FFF003FFF0033FF0026FF0000FF26\
00FF2619FF0000FFA63FFF003FFF004CFF004CFF003FFF0033FF0000FF000CFF00
33FF0033FF0033FF0033FF0026FF0000FF0000FF590CFF0026FF0033FF003FFF004CFF004CFF00\
59FF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF0099FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF0099FF0099FF008CFF0080FF0073FF004CFF0033FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF004CFF004CFF003FFF00\
3FFF0033FF0000FF0000FF0019FF0033FF0033FF003FFF003FFF003FFF004CFF00
4CFF004CFF004CFF004CFF003FFF0033FF000CFF0000FF0C26FF0026FF0026FF000CFF0000FF0C\
00FFFF00FF0C19FF0033FF003FFF003FFF003FFF003FFF0033FF000CFF0000FF80
19FF0026FF0026FF000CFF000CFF0000FF0000FF9900FF0019FF0033FF003FFF004CFF004CFF00\
59FF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0000FF198CFF00
99FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF0059FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF004CFF004CFF00\
3FFF0033FF000CFF0000FF4000FF0026FF0026FF0026FF0026FF0033FF003FFF00
3FFF003FFF003FFF003FFF003FFF0033FF0019FF0000FF260CFF0019FF000CFF0000FF3300FF59\
00FF8C0CFF0026FF0033FF0033FF0033FF0033FF0033FF0026FF0019FF0000FF0C
00FF000CFF000CFF0000FF2600FF1900FF2600FFA600FFE600FF1900FF3333FF003FFF004CFF00\
59FF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF00
80FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF008CFF008CFF0080FF0073FF0073FF0033FF0073FF008CFF00
99FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0073FF0073FF0059FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00
80FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF00\
3FFF0033FF0019FF0000FF8000FF0C0CFF0019FF000CFF0000FF0C33FF0033FF00
3FFF003FFF003FFF003FFF0033FF0033FF0026FF000CFF0000FF7300FF8C00FF1900FFF300FF19\
00FF000CFF0026FF0026FF0033FF0033FF0033FF0033FF0026FF0019FF0000FF33
00FFB300FF1900FF0C00FF3300FF4C00FF6600FF1900FF000CFF0026FF0033FF003FFF004CFF00\
4CFF0059FF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0080FF00
80FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF0080FF0073FF0033FF0026FF0000FF4080FF008CFF00
99FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00\
99FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0066FF0059FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00
80FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF004CFF00\
3FFF0026FF0000FF4C00FF1900FF6600FF1900FF0000FF400CFF0026FF0033FF00
33FF0033FF0033FF0033FF0033FF0026FF0026FF000CFF0000FF0C00FF4C00FF6600FF3300FF0C\
00FF000CFF0019FF0026FF0026FF0026FF0026FF0026FF0026FF0019FF0000FF00
00FF3300FF5900FF4C00FF9900FF1900FF0C00FF0C19FF0026FF0033FF003FFF003FFF004CFF00\
4CFF004CFF0059FF0059FF0059FF0066FF0066FF0073FF0073FF0073FF0073FF00
80FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF0080FF0073FF0059FF0000FF0C59FF0080FF008CFF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0019FF0080FF00\
80FF0080FF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF0059FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00
80FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF004CFF00\
3FFF0033FF0026FF000CFF0000FF1900FF3300FF8000FF0C19FF0026FF0026FF00
33FF0033FF0033FF0033FF0033FF0026FF0026FF0019FF0000FF0000FF0C00FFE600FF3300FF0C\
00FF000CFF0019FF0019FF0019FF0019FF0019FF0019FF0019FF000CFF0000FF00
00FF1900FF5900FF3300FF1900FF0C00FF000CFF0019FF0026FF0033FF0033FF003FFF003FFF00\
4CFF004CFF004CFF004CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF00
73FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF0080FF0080FF0073FF0066FF0059FF000CFF004CFF0066FF0080FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0080FF000CFF00\
59FF0066FF0080FF0080FF0080FF0073FF0066FF0066FF0066FF0059FF0026FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF004CFF00\
3FFF003FFF0033FF0019FF0000FF0000FF1900FFF300FF0C0CFF0019FF0026FF00
26FF0026FF0026FF0026FF0026FF0026FF0019FF0019FF000CFF0000FF0C00FF2600FF3300FF0C\
00FF0000FF000CFF000CFF000CFF0000FF190CFF000CFF000CFF000CFF0000FF00
00FF1900FF7300FF3300FF0C00FF000CFF0019FF0019FF0026FF0033FF0033FF003FFF003FFF00\
3FFF003FFF0033FF000CFF004CFF0059FF0059FF0066FF0066FF0066FF0073FF00
73FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF0080FF0080FF0080FF0066FF0033FF0026FF0000FF594CFF0059FF0080FF00
8CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0080FF003FFF00\
3FFF0033FF0066FF0073FF0073FF0066FF0019FF004CFF0059FF004CFF0026FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF004CFF00\
3FFF003FFF0026FF000CFF0000FF0C00FFBF00FF4C00FF190CFF0019FF0026FF00
26FF0026FF0026FF0026FF0019FF0019FF0019FF000CFF0000FF0000FF0C00FF4C00FF4000FF26\
00FF0C00FF0C00FF0C00FF0C00FF1900FF2600FF0000FF0000FF0000FF0000FF0C
00FF2600FF6600FF1900FF0C00FF000CFF0019FF0019FF0026FF0026FF0033FF0033FF0033FF00\
33FF0033FF0019FF0019FF003FFF004CFF0059FF0059FF0059FF0059FF0059FF00
66FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0073FF0066FF004CFF0000FF264CFF0066FF0080FF008CFF00
8CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0073FF00\
59FF004CFF0019FF0059FF0059FF0059FF003FFF0000FF0000FF4033FF0019FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
B3FF0059FF0080FF0099FF0099FF0099FF0099FF008CFF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF004CFF004CFF00\
3FFF0033FF0026FF0000FF0000FF3300FF6600FF1900FF000CFF0019FF0019FF00
19FF0019FF0019FF000CFF000CFF000CFF000CFF0000FF0000FF0C00FF1900FF4000F3FF00FF40\
00FF1900FF1900FF3300FF3300FF4C00FF5900FF1900FF0C00FFBF00FF1900FF26
00FF5900FF4C00FF1900FF0C00FF000CFF000CFF0019FF0019FF0026FF0026FF0033FF0033FF00\
26FF0026FF0000FF0C19FF003FFF004CFF004CFF004CFF004CFF003FFF0000FF4C
59FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0073FF0073FF0066FF003FFF0000FF0C4CFF0073FF0080FF008CFF00
8CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF00\
73FF0066FF004CFF000CFF000CFF0033FF000CFF0000FF0C00FF1900FF0C00FF0C
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
B3FF00A6FF0080FF0059FF0066FF008CFF0080FF0066FF008CFF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00
80FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF004CFF003FFF0033FF00\
33FF0026FF0026FF000CFF0000FF0C00FFE600FF3300FF000CFF000CFF0019FF00
19FF0019FF000CFF0000FF0000FF3300FF0000FF0000FF0C00FF9900FF4000FF6600FF6600FF40\
00FF3300FF2600FF4000FFA600FFCC00FF4000FF2600FF2600FF4000FF4C00FF66
00FF7300FFB300FF4C00FF0C00FF0C00FF000CFF000CFF000CFF0019FF0019FF0026FF0026FF00\
26FF0019FF0000FF7319FF0033FF0033FF0033FF0033FF0033FF0000FFB300FF0C
59FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
73FF0073FF0073FF0066FF0059FF000CFF0019FF0059FF0073FF0080FF008CFF00
8CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF00\
80FF0073FF0059FF003FFF0000FFCC00FF0000FF3333FF0033FF000CFF003FFF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
B3FF00B3FF00A6FF0059FF0000FF0C4CFF003FFF004CFF0073FF0080FF008CFF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00
80FF0080FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF003FFF000CFF0000FFE6\
00FF0019FF000CFF0000FF0C00FF1900F3FF00FF2600FF0C00FF000CFF000CFF00
0CFF000CFF0000FF0000FF0C00FFBF00FF2600FF1900FF1900FF3300FF7300D9FF00FF6600FF4C\
00FF4000FF4C00FF4C00FF8000FF6600FF4C00FF4000FF3300FF4C00FFE600F3FF
00FF6600FF4000FF2600FF1900FF1900FF1900FF0C00FF0000FF0000FF1919FF0019FF0019FF00\
19FF0000FF0000FF9900FF000CFF0019FF000CFF0000FF8C0CFF0033FF004CFF00
59FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0073FF0073FF00\
73FF0073FF0066FF0059FF004CFF0000FF6626FF0066FF0073FF0080FF008CFF00
8CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF00\
80FF0073FF0066FF004CFF0033FF0000FF0033FF004CFF004CFF004CFF0059FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00B3FF00A6FF0099FF0066FF0066FF0066FF0000FF0C33FF0033FF0080FF00
8CFF008CFF0099FF0099FF0099FF008CFF008CFF008CFF0073FF0073FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF00
80FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0059FF0059FF003FFF0000FF000CFF00\
00FF0C00FF4000FF2600FF8000FF5900FF9900FF2600FF0C00FF0C00FF0000FF00
00FF0000FF0C00FF0C00FF1900FF5900FF4C00FF2600FF2600FF3300FF4C00FF8000FF7300FF66\
00FF8000BFFF00FF80008CFF00FF80008CFF00FF8C00FF5900FF5900FF8C00FF66
00FF4C00FF4000FF3300FF2600FF2600FF3300FF3300FF2600FF8C00FF0C0CFF000CFF000CFF00\
0CFF0000FF0C00FF7300FF2600FF2600FF4C00FF260CFF0033FF004CFF0059FF00
59FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
66FF0066FF0059FF004CFF0000FF003FFF0059FF0073FF0073FF0080FF008CFF00
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF00\
80FF0073FF0066FF004CFF0033FF0026FF003FFF0059FF0059FF0066FF0073FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00B3FF00B3FF0099FF0066FF008CFF0080FF0000FF5959FF0000FF5933FF00
80FF0080FF008CFF008CFF008CFF008CFF008CFF0080FF003FFF0059FF0073FF0080FF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF00
73FF0073FF0073FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF004CFF003FFF0026FF00\
19FF000CFF0000F3FF00FF1900FF3300FF5900FF9900FF1900FF0C00FF0C00FF0C
00FF0C00FF2600FFE600FF40008CFF00FF4C00FF4000FF4000FF4C00FF6600FF8C00FFB300FF80\
00FF9900FFBF00FFE600FFFF00D9FF00B3FF00FF9900FF9900FFB300FFA600FF66
00FF5900FF4000FF4000FF3300FF3300FF4C0099FF00FFA600FFB300FF1900FF0C00FF0C00FF00\
00FF0C00FF1900FF8C00FF3300FF2600FF3300FF2600FF0C33FF004CFF0059FF00
59FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF00\
59FF004CFF004CFF0033FF0019FF004CFF0066FF0073FF0073FF0080FF0080FF00
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF00\
73FF0066FF0059FF000CFF0000FF1900FF334CFF0059FF0066FF0073FF0073FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF0080FF0080FF0073FF004CFF00
66FF0073FF0073FF0080FF0080FF0080FF0080FF0073FF004CFF0033FF0073FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF00
73FF0066FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF00\
26FF0019FF000CFF0000FF0000FF0C00FF1900FF4000FF4000FF2600FF2600FF19
00FF1900FF2600FF4000FF7300FFB300FF5900FF5900FF6600FFD900FF8000FFD900FFB300FFB3\
00FFD900A6FF000000004CFF00000000000000FFE600FFCC00FFBF00FF9900FF73
00FF6600FF5900FF5900FF4C00FF4000FF4C00FFBF00FF6600FF4000FF2600FF1900FFB300FF26\
00FF3300FFA600FF2600FF0C00FF000CFF0019FF0026FF0033FF004CFF004CFF00
59FF0059FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00\
59FF0033FF0000FF3300FF4C26FF004CFF0066FF0073FF0073FF0080FF0080FF00
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00\
73FF0059FF0033FF0019FF0000FF1919FF0033FF0059FF0066FF0073FF0080FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0073FF00
00FF004CFF0019FF0066FF0073FF0073FF0073FF0066FF004CFF0026FF0066FF0073FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF00
73FF0059FF0000FF0033FF004CFF004CFF004CFF004CFF004CFF004CFF003FFF003FFF0033FF00\
26FF0026FF0019FF000CFF0000FF0000FF0C00FF3300FF7300FF4C00FF4C00FF26
00FF2600FF2600FF3300FF4C00FF8000FFB300FF7300FFB300FFB300FFD900FFD900FFE600FFF3\
00BFFF0000000000000000000000000019FF00E6FF00FFE600FFB300FF9900FF80
00FF8C00FF8C00D9FF00FF6600FF6600FF7300FFB300FF6600FF4C00FF4000FF3300FF6600FF59\
00FF7300FF4000FF0C00FF000CFF0019FF0026FF0033FF003FFF003FFF004CFF00
59FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF00\
59FF003FFF0026FF0000FF1933FF004CFF0059FF0066FF0073FF0080FF0080FF00
80FF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF00\
73FF0059FF003FFF0000FF0C00FFA600FFBF00FF194CFF0066FF0073FF0080FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF00
3FFF0026FF0019FF0059FF0066FF0066FF0066FF0059FF0033FF004CFF0066FF0073FF0073FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00
66FF0059FF0026FF0000FF2626FF003FFF003FFF003FFF003FFF003FFF003FFF0033FF0033FF00\
26FF0026FF0019FF000CFF0000FF0000FF0C00FF2600FF4C00FFFF00FF4C00FF33
00FF3300FF4000FF4000FF5900FF8C00FFB300FFA600FFCC00F3FF00CCFF00CCFF00D9FF00A6FF\
0066FFB300FF0000000000004C00FF0019FF004CFF00FFF300E6FF00BFFF00FFA6
00FFA600FFFF00FFA600FF8000FF8C00FFE600FFB300FF8000FFBF00FF8000FF5900FF7300FF73\
00FF4C00FF3300FF0C00FF000CFF0019FF0026FF0033FF003FFF003FFF004CFF00
4CFF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF00\
4CFF003FFF0026FF0000FF2626FF0033FF0033FF0066FF0073FF0073FF0080FF00
80FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0073FF00\
80FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF008CFF008CFF008CFF0080FF0066FF0073FF0073FF0073FF0073FF0073FF00\
66FF0059FF004CFF0026FF0000FF0000FF0033FF004CFF0066FF0073FF0080FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF00
73FF003FFF000CFF003FFF004CFF003FFF004CFF003FFF0000FF733FFF0059FF0066FF0073FF00\
73FF0073FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF00
66FF0059FF004CFF003FFF0000FF3326FF0033FF0000FF0033FF0033FF0033FF0033FF0033FF00\
26FF0019FF0019FF000CFF0000FF0000FF0C00FF2600FF9900FF8C00FF5900FF40
00FF4000FF5900FF7300FF7300FF9900A6FF00FFE60080FF6600FFF300FF0066FF4C00FF0026FF\
0000000000000000000000000000002600FF0099FF00B3FF00D9FF00FFE600FFD9
00FFD900FFD900FFB300FFB300FFA600FFF300FFBF00FFF300D9FF00FFB300FFD900FFD900FF66\
00FF4000FF2600FF1900FF0C0CFF0019FF0026FF0033FF0033FF003FFF003FFF00
3FFF003FFF0033FF0059FF0059FF0059FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF00\
3FFF0033FF0026FF0000FF0000FF4C19FF003FFF0059FF0066FF0073FF0073FF00
73FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF0080FF0073FF0033FF00\
73FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00
99FF008CFF008CFF008CFF008CFF0080FF0073FF0000FF8C3FFF0066FF0066FF0066FF0066FF00\
66FF0059FF004CFF0026FF0000FF2626FF004CFF0066FF0073FF0073FF0080FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF00
80FF0066FF0019FF0000FF4C00FF0C00FF0C19FF0019FF0000FF003FFF0059FF0059FF0066FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF00
66FF0059FF0059FF003FFF000CFF0000FF000CFF0000FF7326FF0033FF0033FF0026FF0026FF00\
26FF0019FF000CFF000CFF0000FF0C00FF6600FF4000FF6600FFB300FF5900FF59
00FF5900FF7300B3FF00FF9900FFBF00FFFF00CCFFC000FF0000000000003F00FF4C00FF7300FF\
000000000000000000000000000000000000000CFF008CFF00CCFF00A6FF00FFFF
00D9FF00FFE600FFE600E6FF00FFE600CCFF00FFF300A6FFD900FF0080FF00FFD900FF9900FF80\
00FF6600FF4000FF3300FF3300FF0C0CFF0019FF0026FF0033FF0033FF0033FF00
26FF0000FFD933FF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF00\
00FF330CFF0000FF0C00FF590CFF003FFF004CFF0059FF0066FF0066FF0073FF00
73FF0066FF0066FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0066FF000CFF00\
00FF5973FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF0080FF0080FF0073FF0059FF0000FF0C4CFF0059FF0059FF0059FF00\
59FF004CFF003FFF0026FF000CFF003FFF0059FF0066FF0073FF0073FF0080FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF00
73FF0033FF0000FF194CFF0033FF000CFF0026FF0019FF0000FF3326FF003FFF0033FF0059FF00\
66FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF00
66FF0059FF004CFF003FFF000CFF0000FF3300FF7300FF0C19FF0026FF0026FF0026FF0019FF00\
0CFF0000FF0000FF0000FF0000FF0C00FF2600FF4C00FF7300FFB300FF7300FF66
00FF7300FF9900FFE600FFCC00D9FF0099FF0040FFC000FF000000000000000000000000000000\
000000000000000000000000000000D900FF2600FF3F00FF0026FF0099FF0000FF
00CCFF00B3FF00D9FF00B3FF0099FF00B3FF0099FF004CFF0000000040FF00D9FF00FFF300FFCC\
00FFA600FF8C00FF7300FFCC00FF8000FF0C19FF0026FF0026FF0026FF0026FF00
0CFF0000FF2633FF003FFF004CFF004CFF0059FF0059FF0059FF0059FF004CFF004CFF003FFF00\
33FF000CFF0000FF8C0CFF0026FF003FFF004CFF0059FF0059FF0066FF0066FF00
59FF0026FF0059FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0073FF0066FF0026FF00\
4CFF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF0080FF0080FF0080FF0073FF0073FF0059FF003FFF0026FF003FFF0026FF003FFF00\
4CFF003FFF0033FF0000FF0026FF004CFF0059FF0066FF0073FF0073FF0080FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF00
0CFF0059FF0066FF0066FF0059FF004CFF004CFF003FFF0000FF1900FF0C00FF9933FF0059FF00\
66FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00
59FF0059FF004CFF003FFF0033FF000CFF0000FF2600FF400CFF0019FF0019FF0019FF0019FF00\
00FF0000FF7300FF1900FF0C00FF1900FF2600FF3300FF4C00FF6600F3FF00FF99
00FF8000FF9900BFFF00E6FF0059FF000000A600FF000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000003F00FF0066FF
0080FF004CFF0026FF8C00FF0000001900FF0040FF8000FF0000003300FF0040FF0099FF00A6FF\
0019FF00FFCC00FF7300FF4000FF2600FF000CFF0019FF0019FF0019FF000CFF00
00FF1919FF0033FF003FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF003FFF0033FF00\
26FF0000FF0C00FFCC0CFF0026FF003FFF003FFF004CFF0059FF0059FF0059FF00
4CFF0000FF0C33FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF003FFF00\
4CFF0066FF0073FF0073FF0080FF0080FF0073FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0073FF0073FF0066FF0059FF003FFF0000FF6600FF0000FF4019FF00\
33FF0000FF0000FF0000FF590CFF0033FF004CFF0066FF0066FF0073FF0080FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF00
80FF0080FF0080FF0073FF0073FF0066FF0059FF003FFF0019FF0000FF6626FF003FFF0059FF00\
59FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF00
59FF004CFF004CFF003FFF0026FF0000FF4000FFA600FF1900FF000CFF000CFF000CFF000CFF00\
00FF0000FF4000FF4C00FF3300FF2600FF3300FF4000FF4C00FF6600FFBF00FFB3
00FFA600F3FF00FFE600BFFF3300FF000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000009900FF0019FF
000CFF0000FF9900FF000000000000CC00FF0000000000000000000000000000000000009900FF\
000000004CFF00B3FF00FF4C00FF2600FF1900FF000CFF000CFF000CFF0000FF26
00FF1919FF0026FF0033FF003FFF003FFF003FFF003FFF003FFF003FFF003FFF0033FF0019FF00\
19FF0000FF0000FFFF0CFF0026FF0033FF0033FF0033FF003FFF004CFF004CFF00
33FF000CFF004CFF0066FF0066FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF0019FF00\
3FFF0059FF0066FF0066FF0073FF0073FF0033FF0066FF0073FF0073FF0080FF00
80FF0073FF0073FF0059FF0066FF0066FF0059FF004CFF0033FF0000FFCC19FF0019FF0000FF19\
0CFF0000FF4C00FF0019FF0000FF2626FF0033FF004CFF0066FF0073FF0073FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00
8CFF008CFF0080FF0080FF0073FF0066FF0059FF0000FF0000FF730CFF0033FF004CFF004CFF00\
59FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF00
4CFF003FFF0033FF0033FF0019FF0000FF0000FF8000FF3300FF0000FF000CFF0000FF0000FF0C\
00FF1900FF3300E6FF00FF4000FF3300FF4000FF5900FF5900FF8C00FFD900FFD9
00FFBF00FFF300A6FF7300FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000E600FF
6600FF0000000000000000000000000000000000000000000000000000007300FF0000002600FF\
0080FF0099FF00FF9900FF4C00FF4000F3FF00FF0C00FF0000FF0000FF0C00FF33
00FF400CFF0019FF0026FF0033FF0033FF0000FF0033FF0033FF0033FF0033FF0026FF000CFF00\
00FF3300FF3300FF4000FF590CFF0019FF0000FF3300FF1933FF0033FF0033FF00
00FF5933FF004CFF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF004CFF0026FF00\
0CFF003FFF003FFF0059FF0066FF0059FF0033FF0059FF0066FF0066FF0073FF00
73FF0066FF0066FF003FFF004CFF004CFF004CFF0000FF0000FF3326FF003FFF0033FF0026FF00\
00FF4033FF003FFF003FFF000CFF0000FF3300FF264CFF0059FF0066FF0073FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00
99FF008CFF008CFF0080FF0073FF0066FF0059FF003FFF0000FF0C0CFF0033FF003FFF004CFF00\
59FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF00
3FFF0000CCFF00FF3300FF0000FF0000FF3300FF4000FF3300FF0C00FF0C00FF0000FF0C00FF19\
00FF8000FFA600FFA600FF5900FF4C00FF5900FFD900FF8000FF8C00FFA600FFE6
00FFF300CCFF0073FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000002600FF0040FF0040FF00BFFF\
00FFFF00FFF300FFBF00FF9900FF9900FF4C00FF2600FF1900FF1900FF262600FF
00FF2600FF0000FF000CFF0026FF0019FF0000FF0C19FF0019FF0019FF0019FF0000FF4C00FF0C\
00FF2600FF0C0CFF000CFF0000CCFF00FF2600FF9900FF5900FF0019FF0000FF00
00FF3333FF004CFF0059FF0059FF0066FF0066FF0059FF004CFF004CFF004CFF003FFF0019FF00\
00FF0C00FF0C00FF333FFF004CFF003FFF0019FF0019FF003FFF0000FF004CFF00
59FF004CFF004CFF0033FF000CFF0033FF0033FF0000FF4000FF3333FF004CFF004CFF004CFF00\
00FF334CFF0059FF004CFF0000FF993FFF0019FF0033FF0059FF0059FF0066FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00
99FF008CFF008CFF0080FF0073FF003FFF0026FF0000FF0C00FF2600FF0C26FF0033FF003FFF00\
4CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF00
3FFF0033FF0019FF000CFF0000FF3300FF2600FF3300FF5900FF2600FF1900FF1900FF1900FF19\
00FF3300FF5900FF8C00FF7300FF6600FFB300BFFF00FFA600FFB300FFBF00FFFF
00BFFF00BFFF2600FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000003300FF0033FF00A6FF00FFFF\
00FFBF00FF9900FF8000FF6600FF6600FFB300FF5900FF8C00FF590000FF00FF4C
00FF6600FFCC00FF7300FF000CFF0000FF0C00FF2600FF7300FF260033FF00FF1900FF4C00FF0C\
0CFF0026FF0026FF0026FF0019FF0000FF400040FF00FF2600FF5900FF1900FF66
00FF0C26FF0026FF003FFF0059FF0059FF0059FF004CFF0033FF0019FF0000FF4C00FF260CFF00\
26FF000CFF0000FF0019FF0026FF0000FFCC19FF0026FF0000FF4C26FF0026FF00
00FF0C00D9FF19FF0000FFB326FF0000FF2600FF9926FF003FFF0059FF0059FF0066FF0059FF00\
26FF0059FF0066FF0066FF0059FF0059FF004CFF0000FF0033FF004CFF0059FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF008CFF0080FF0073FF0033FF003FFF003FFF0033FF0000FF0000FF1900FF2626FF00\
4CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF00
3FFF0033FF0033FF0026FF000CFF0000FF0000FF0C00FF1900FF8000FF4000FF4000FF2600FF26\
00FF3300FF4C00FF8000FFBF00FF8C00FF9900CCFF00FFCC0099FF00FFF300E6FF
008CFF0073FFC000FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000008C00FF0019FF008CFF00F3FF00D9FF\
00FFBF00FF9900FF7300FF4C00FF4C00FF9900FF9900FF3300FF2600FF1900FF19
00FF3300FF3300FF5900FF3300FF1900FF4C00FF3300FF0000FF7319FF0026FF0026FF0026FF00\
26FF0033FF0033FF0033FF0026FF0019FF0000FF6600FF0019FF0019FF000CFF00
00FF5900FF0C00FF003FFF004CFF004CFF004CFF003FFF000CFF0000FF8C00FF260CFF0033FF00\
3FFF003FFF0026FF0000FF0C00FF2633FF004CFF004CFF0000FF3359FF0059FF00
59FF004CFF0033FF004CFF004CFF0033FF0026FF000CFF0059FF0066FF0066FF0073FF0073FF00\
66FF0066FF0073FF0073FF0073FF0066FF0059FF003FFF0000FF4C33FF0033FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF008CFF0080FF0080FF0073FF0066FF0059FF003FFF000CFF0000CCFF00FF0C33FF00\
3FFF004CFF004CFF004CFF0059FF0059FF0059FF004CFF004CFF004CFF004CFF00
3FFF003FFF0033FF0026FF0019FF000CFF0000FF0000FF0C00FF4000FF7300FF5900FF3300FF40\
00FF5900FF6600FFD900FFCC00FFBF00FFE600F3FF00D9FF00A6FF00B3FF008CFF
0073FF1900FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000006600FF00CCFF00FFF300FFCC\
00FFCC00FFA600FF6600FF4000FF3300FF3300FF4000FF1900FF0C00FF0C00FF0C
00FF0C00FF0C00FF2600FF8000FF7300FF1900FF0019FF0019FF0026FF0033FF0033FF003FFF00\
3FFF003FFF003FFF003FFF003FFF0033FF0019FF0033FF0033FF0033FF0026FF00
0CFF0000FF4000FF0033FF003FFF003FFF003FFF0033FF0019FF0000FF4000FF5919FF003FFF00\
4CFF004CFF003FFF003FFF0000FF264CFF0059FF0066FF0066FF0073FF0073FF00
73FF0073FF0059FF0066FF0066FF0066FF0059FF0019FF0059FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0066FF0059FF0000FF6600FF3300FF73
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF008CFF008CFF0080FF0080FF0073FF0066FF0059FF004CFF0026FF0000FF0000FF2626FF00\
33FF003FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF003FFF00
3FFF0033FF0033FF0026FF0019FF0019FF000CFF0000FF0C00FF2600FF8000FF5900FF4C00FF59\
00FF9900FF8C00FFA600D9FF0099FF00A6FF0080FFB300FF000000000000000000
9900FFA600FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000026FF0073FF00BFFF00FFB3\
00FF9900FFF300FF7300FF4000FF3300FF2600FF1900FF0C00FF0000FF0000FF00
00FF0000FF0000FF1900FF0C00FF4C00FF2619FF0026FF0033FF0033FF003FFF003FFF003FFF00\
4CFF004CFF004CFF004CFF004CFF003FFF003FFF003FFF003FFF003FFF0033FF00
0CFF0000FF4C0CFF0019FF0019FF0033FF0026FF0019FF0000FF3300FF400CFF0033FF004CFF00\
59FF0059FF0059FF0059FF0000FF264CFF0066FF0073FF0073FF0073FF0080FF00
80FF0080FF0073FF0073FF0073FF0073FF0066FF0000F3FF59FF0073FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF004CFF003FFF0000FF73
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF008CFF008CFF0080FF0080FF0073FF0066FF0059FF004CFF0033FF0026FF0000FF2619FF00\
26FF0033FF003FFF003FFF003FFF003FFF003FFF003FFF003FFF003FFF003FFF00
33FF0033FF0033FF0026FF0019FF000CFF0000FF0000FF4C00FF5900FFBF00FF8C00FF6600FF73\
00FFBF00FFBF00FFFF00D9FF0000FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000F300FF0000002600FF00E6FF00FFF300FFBF\
00FF8000FF7300FF5900FF4000FF2600FF1900FF0C00FF0C00FF000CFF000CFF00
0CFF000CFF000CFF000CFF000CFF00008CFF0CFF0026FF0033FF003FFF003FFF004CFF004CFF00\
4CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF003FFF003FFF00
26FF0000FF0000FF3300FF4000FF990CFF0000FF0C0CFF0026FF0033FF003FFF003FFF0059FF00\
66FF0066FF0066FF0066FF004CFF003FFF0073FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0073FF0059FF0066FF0080FF0080FF0080FF008CFF00\
8CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF0066FF004CFF0019FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF00
8CFF008CFF008CFF0080FF0073FF0073FF0059FF004CFF003FFF0033FF0019FF0000FF1900FF26\
0CFF0000FF0C26FF0033FF003FFF003FFF0033FF0026FF0026FF0033FF0033FF00
33FF0033FF0026FF0026FF0019FF000CFF0000FF0000FF1900FF3300FF4C00FF8000FFCC00FF99\
00FFCC00B3FF4C00FF0026FF3300FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000002600FF0033FF0019FF00FFFF00FFD900FF99\
00FF8000FF6600FF4C00FF4000FF3300FF2600FF1900FF0000FF000CFF0019FF00
19FF0019FF0019FF0019FF0019FF000CFF0000FFA633FF003FFF003FFF004CFF004CFF004CFF00\
4CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF00
33FF0000FF000CFF000CFF0000FF5900FF0000FF2626FF003FFF004CFF0059FF0066FF0066FF00\
73FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0066FF004CFF0000FF00
CCFF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF00
8CFF0080FF0080FF0080FF0073FF0066FF003FFF0000FF8019FF000CFF0000FF1900FF2600FF00\
00FF4000FF1900FF6626FF0026FF0026FF0026FF000CFF0000FF0026FF0026FF00
26FF0026FF0026FF0019FF0000FF4000FF0C00FF1900FF2600FF3300FF4C00FFB300E6FF00FFD9\
00A6FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000002600FF004CFF00A6FF00CCFF00D9FF00FFE600FFB3\
00F3FF00FF8000FF5900FF4C00FF4000FF3300FF8C00FF0C0CFF000CFF0019FF00
19FF0026FF0026FF0026FF0026FF0026FF0033FF003FFF003FFF004CFF004CFF004CFF0059FF00\
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF00
33FF0000FF0C33FF0033FF0033FF0019FF0000FF5926FF004CFF0059FF0066FF0066FF0073FF00\
73FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0066FF000CFF003FFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF00
80FF0073FF0073FF0073FF0066FF0059FF004CFF0026FF0000FF0C00FF2600FF5919FF0026FF00\
00FF0026FF0019FF0000FF4C00FF190CFF0019FF0000FF0000FF0019FF0026FF00
26FF0026FF0019FF000CFF0000FF0C00FF8000FF4C00FF3300FF4000FF6600FF8000FFA600E6FF\
004CFFF300FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000008C00FF0000FF0059FF0C00FF00E6FF00FFF300FFF300FFE6\
00F3FF00FF8C00FF6600FF6600FF8C00FF4C00FF2600FF000CFF0019FF0019FF00
26FF0026FF0026FF0033FF0033FF0033FF003FFF003FFF004CFF004CFF004CFF0059FF0059FF00\
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF00
00FF0026FF003FFF004CFF003FFF0026FF0000FF2619FF003FFF0059FF0066FF0073FF0073FF00\
80FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF0099FF0099FF0099FF0099FF0099FF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF004CFF0059FF0059FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF008CFF0073FF0059FF00
66FF004CFF0059FF003FFF004CFF003FFF0026FF0000FF4019FF0033FF0000FF0033FF003FFF00\
3FFF003FFF0033FF000CFF0000FF1900FF2600FF4C00FF4000FF1900FF0019FF00
19FF0019FF0019FF000CFF0000FF0C00FF4000FF7300FF4C00FF6600FFE600FFA600D9FF00F3FF\
0099FF3F00FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000001900FF0C00FF00BFFF00F3FF00FFD900FFBF00FFA6\
00FFBF00FFE600FFD9008CFF00FF8000FF4000FF1900FF000CFF0019FF0019FF00
26FF0026FF0033FF0033FF0033FF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF00\
59FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF00
3FFF004CFF0059FF0059FF004CFF0033FF0033FF0000FF194CFF0059FF0066FF0073FF0073FF00\
80FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0073FF0066FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00A6FF008CFF0073FF0080FF0073FF0066FF0000FF59
19FF0000FF0000FF000CFF0026FF0000FF0C00FF4000FF003FFF004CFF003FFF004CFF004CFF00\
4CFF004CFF003FFF0033FF000CFF0000FF0000FF1900FF1900FF5900FF1900FF00
0CFF000CFF000CFF0000FF0000FF9900FF7300FFD900FF7300FF8000FFB300FFE600E6FF00BFFF\
0C00FF9900FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000066FF00B3FF00E6FF00CCFF00FFBF00FF99\
00FF8C00FFE600FF6600FF6600FFA600FF6600FF3300FF0C00FF000CFF0019FF00
26FF0026FF0033FF0033FF003FFF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0059FF00\
59FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0059FF0059FF004CFF0019FF003FFF0059FF0066FF0073FF0080FF00\
80FF0080FF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0073FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF0099FF0073FF004CFF0019FF0000FF0C3FFF00
33FF0033FF004CFF0059FF0059FF0059FF004CFF0000FF264CFF0059FF0059FF0059FF0059FF00\
59FF004CFF004CFF003FFF0019FF0026FF0019FF0000FF0000FFE600FF1900FF0C
00FF0000FF0000FF0000FF0C00FF1900FF3300FF5900CCFF00FFA600FFF30080FF0066FF0019FF\
3300FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000008C00FF0033FF008CFF008CFF00F3FF00E6FF00FF99\
00FF8000FF6600FF5900FF4C00FF5900FFA600FF5900FFA600FF6600FF0019FF00
26FF0026FF0033FF0033FF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0059FF0026FF0019FF004CFF0066FF0073FF0080FF00\
80FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF0080FF0066FF004CFF0066FF00
66FF0059FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0066FF0066FF0066FF0059FF00\
59FF0059FF004CFF004CFF003FFF0033FF0026FF0000FF8C00FF2600BFFF00FF19
00FF0C00FF0C00FF0C00FF1900FF2600FF3300FF5900FF8C00B3FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000009900FF000CFF0026FF00A6FF00FFF300FFBF00FF99\
00FF8C00FF6600FF4C00FF4000FF4000FF4000FF2600FF0C00FF000CFF0019FF00
26FF0026FF0033FF0033FF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0066FF00\
66FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0066FF0066FF0019FF0000FF1926FF0059FF0073FF0080FF00\
80FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0073FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF0080FF0073FF0080FF00
80FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF00\
66FF0059FF0059FF004CFF004CFF003FFF0033FF0019FF0000FF0000FF3300FF4C
00FF4C00FF2600FF2600FF3300FF3300FF4000FF9900FFA600CCFF3300FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000C000FF0000000019FF00D9FF00FFFF00FFBF\
00FFE600FF6600FF4C00FF3300FF2600FF2600FF0C00FF000CFF0019FF0019FF00
26FF0026FF0033FF0033FF003FFF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0066FF00\
66FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0066FF0059FF0033FF000CFF0033FF003FFF0080FF00\
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF0073FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF008CFF00
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF00\
66FF0059FF0059FF0059FF004CFF003FFF0033FF0019FF0000FF4000FF6600FF40
00FF3300FF8000BFFF00FF8000FF4C00FF4C00FF8000FFFFC000FF000000E600FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FF00CCFF00FFE600FFBF\
00FFD900FFD900FF6600FF3300FF2600FF1900FF0C00FF000CFF0019FF0019FF00
26FF0026FF0033FF0033FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF0066FF0066FF00\
66FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
80FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0000FF0C4CFF0000FF2666FF0080FF00\
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0073FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF00
8CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF00\
66FF0066FF0059FF0059FF004CFF0033FF0026FF000CFF0000FF4000FF1900FF0C
00FF0C00FF1900FF3300FFB300FF7300FF7300FF8C00FFD9A600FF0059FF1900FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000001900FF00FFFF00FFA6\
00FF8000FF6600FF4C00FF3300FF2600FF1900FF1900FF000CFF000CFF0019FF00
19FF0026FF0026FF0026FF0033FF0033FF0033FF003FFF004CFF0059FF0059FF0066FF0066FF00\
66FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0059FF0059FF0080FF00\
8CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00\
66FF0066FF0059FF0059FF003FFF0019FF0000FF4000FF000CFF000CFF000CFF00
00FF0000FF0000FF1900FF4C00FF9900FF7300FFB300FFCC00FFE600B3FF008CFF3300FFC000FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000F300FF00000000FFF300FFA6\
00FF8000FF6600FF4C00FF4000FF3300FF3300FF4000FF2600FF000CFF0019FF00
19FF0019FF0019FF0026FF0026FF0019FF000CFF0026FF003FFF0059FF0059FF0066FF0066FF00\
66FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0066FF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
99FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00\
66FF0066FF0066FF0059FF003FFF0019FF0026FF0026FF0026FF0019FF0019FF00
0CFF0000FF0000FF3300FF4C00FF4000FF4C00FF9900FF8C00FFE600CCFF0059FF0066FF3300FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000008C00FF0000000066FF00BFFF004CFF00FFB3\
00FFE600FF8000FF5900FF4C00FF5900FF6600FF4000FF1900FF000CFF000CFF00
0CFF000CFF000CFF000CFF0000FF0000FF3300FF4026FF003FFF0059FF0059FF0066FF0066FF00\
66FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
99FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00\
73FF0066FF0066FF0059FF004CFF003FFF003FFF0033FF0033FF0026FF0019FF00
19FF000CFF0000FF0C00FF2600FF3300FF4000FF6600FF8C00FFB300FFE600E6FF0033FF4C00FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000005900FF0019FF004CFF00BFFF00FFFF00FFD900FFCC\
00B3FF00FF8C00FF7300FF6600FF9900FF7300FF3300FF1900FF0C00FF0000FF00
00FF0000FF0000FF2600FF4C00FF1900FF0026FF003FFF004CFF0059FF0059FF0066FF0066FF00\
66FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
99FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF00\
73FF0066FF0066FF0059FF0059FF004CFF003FFF003FFF0033FF0026FF0026FF00
19FF000CFF0000FF0C00FF1900FF2600FF4C00FFA600FFCC00FFBF00FFE60059FF1900FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000003F00FF004CFF00B3FF0080FF00FFFF00FFBF00FFA6\
00FFB300FFCC00FFBF00FFF300FFBF00FF6600FF5900FF2600FF2600FF0C00FF0C
00FF0C00FF4000FF4000FF1919FF0026FF0033FF003FFF004CFF0059FF0059FF0066FF0066FF00\
66FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
99FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF00\
73FF0066FF0066FF0059FF0059FF004CFF003FFF003FFF0033FF0026FF0026FF00
0CFF0000FF0C00FF1900FF3300FF3300FF4000FF660033FF00FFBF00CCFF00A6FF0080FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000006600FF0033FF00BFFF00F3FF00BFFF00FFB300FF99\
00FF8C00FFA600FF7300FF6600FF8000FF9900FF6600FF4C00FF5900FF2600FF26
00FF3300FFB300FF4C00FF0C19FF0026FF0033FF003FFF004CFF0059FF0059FF0066FF0066FF00\
66FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
99FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF00\
73FF0066FF0066FF0059FF004CFF004CFF003FFF003FFF0033FF0026FF0026FF00
0CFF0000FF2600FF7300FF8000FF4C00FF4C00FF6600FF8C00FFA600FFD900F3FF00A6FF0026FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000073FF0099FF00FFE600FFCC00FFB300FF8C\
00FF7300FF6600FF5900FF5900FF5900FF7300B3FF00FFA600FF6600FFA600FF99
00FF6600FF8C00FF2600FF000CFF0026FF0033FF003FFF004CFF0059FF0059FF0066FF0066FF00\
66FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
99FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF00\
66FF0066FF0059FF0059FF004CFF003FFF003FFF0033FF0033FF0026FF0019FF00
0CFF0000FF0000FF2600FF7300FF7300FF6600FF8000FF8C00E6FF00FFE600D9FF0099FF0033FF\
6600FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000009900FF0000FF0099FF6600FF00FFE600FFCC00FFA600FF8C\
00FF8000FF6600FF4C00FF4C00FF4000FF4C00FF5900FF4C00FF2600FF2600FF26
00FF2600FF3300E6FF00FF2600FF3319FF0026FF0033FF003FFF004CFF0059FF0059FF0066FF00\
66FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
99FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF00\
66FF0059FF004CFF004CFF003FFF0033FF0019FF0026FF0026FF0026FF0019FF00
0CFF0000FF0000FF3300FF8000FF8000FFF300FFE600FFA600A6FF00B3FF00BFFF0026FF1900FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000F300FF0019FF3300FF00A6FF0059FF0073FF00FFD900FFB300FFB3\
00FFE600FF7300FF4C00FF4000FF3300FF3300FF3300FFFF00FF1900FF0C00FF0C
00FF0C00FF1900FF3300FF4000FF260CFF0019FF0000FF0033FF003FFF004CFF0059FF0059FF00\
66FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
99FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0066FF00\
59FF003FFF0033FF0033FF0033FF0019FF0000FF330CFF0019FF0019FF000CFF00
0CFF0000FF0C00FF2600FF4000FF4C00FF6600FFBF00FFD900FFE600D9FF0026FF5900FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000003300FF004CFF0099FF00CCFF00F3FF00F3FF0080FF00FFFF00FFF3\
00FF8C00FF6600FF4C00FF4000FF3300FF2600FF1900FF1900FF0C00FF0000FF00
00FF0000FF0000FF0C00FF3300FF4000FF1900FF6600FF5919FF0033FF003FFF003FFF0059FF00\
66FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00
99FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0066FF00\
4CFF0000FF0C0CFF000CFF0000FF8000FF9900FF9900FF4C00FF000CFF000CFF00
00FF0000FF0C00FF1900FF3300FF4000FF6600FF8C00FFBF00B3FF0059FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000006600FF0000FF0000FF0080FF0073FF00FFFF00FFE600FFD900FFBF00FFBF\
00FFCC00FFA600FF8000FF4000FF3300FF2600FF1900FF0C00FF0000FF000CFF00
0CFF000CFF0000FF0000FF5900FF2600FF4000FF000CFF0000FF0000FF8000FF262600FF00FF00\
4CFF0066FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00
99FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF00\
66FF0059FF004CFF003FFF000CFF000CFF0000FF0000FF5900FF1900FF0C00FF00
00FF0C00FF1900FF2600FF3300FFD900FF9900FF9900FFD900E6FF0033FFB300FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000E600FFC000FFB300FF0059FF008CFF0019FF00D9FF00FFE600FFCC00FFA600FF99\
00FF8C00FF6600FF4C00FF4000FF3300FF2600FF1900FF0C00FF000CFF000CFF00
0CFF0019FF0019FF000CFF000CFF0000FF3319FF0033FF0033FF0033FF0033FF0000FF004CFF00\
66FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00
99FF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF00\
66FF0066FF0059FF004CFF003FFF0033FF0000FF0000FF190019FF00FF2600FF19
00FF2600FF8C00FF4000FF4000FF5900FFD900FFCC0066FF00B3FF0040FF8C00FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000CC00FF4C00FF000CFF004CFF0080FF00BFFF00E6FF00FFFF00FFF300FFA600FF8C\
00FF7300FF6600FF4C00FF4000FF3300FF3300FF2600FF1900FF000CFF000CFF00
19FF0019FF0019FF0026FF0019FF0000FF0C19FF003FFF003FFF004CFF004CFF0059FF0059FF00\
66FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF00
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00\
66FF0066FF0059FF0059FF004CFF003FFF0026FF000CFF0000FF2600FF6600FF40
00FF7300FF8000FF7300FF5900FF6600FF990080FF004CFF0026FF1900FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000B300FF8000FF0000FF0066FF0099FF0080FF00BFFF00B3FF00FFCC00FF99\
00FF8000FF8000FF5900FF4C00FF4000FF4000FF6600FF3300FF000CFF0019FF00
19FF0026FF0026FF0026FF0033FF0033FF0033FF003FFF004CFF0059FF0059FF0059FF0066FF00\
66FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00\
66FF0066FF0059FF0059FF004CFF003FFF0026FF0000FF0000FF4000FF2600FF0C
00FF1900FF2600FF6600FFB300FFCC00FFBF0000009900FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000C000FF6600FF0059FF00A6FF00D9FF00FFE600FFBF00FFA6\
00FFA600FF9900FF6600FF5900FF6600FFCC00FF3300FF1900FF000CFF0019FF00
19FF0026FF0026FF0033FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF0066FF0066FF00\
73FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00\
66FF0066FF0059FF0059FF004CFF0026FF0000FF1900FF1900FF800CFF000CFF00
00FF0000FF1900FF7300FF4C00FF8000FF9900FFFF3300FF7300FF000000000000000000000000\
000000000000000000000000000000B300FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000B300FF000CFF004CFF0073FF00F3FF0099FF00FFD9\
00BFFF00FFD900FF9900FFCC00A6FF00FF8000FF5900FF2600FF0C0CFF0019FF00
26FF0026FF0033FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF0066FF0066FF0066FF00\
73FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00\
66FF0066FF0059FF0059FF0026FF0000FF3300FF2619FF0019FF0019FF0019FF00
0CFF0000FF0C00FF2600FF3300FF5900FF9900FFD900A6FF2600FF0000004C00FF8C00FF7300FF\
E600FF0000000000000000006600FF1900FF5900FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000B3FF00F3FF00F3FF\
00FFBF00FFB300FFD900FF7300FF6600FF7300FF8C00FF8000FF3300FF400CFF00
26FF0026FF0033FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF0066FF0066FF0066FF00\
73FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00\
66FF0066FF0059FF0059FF004CFF0033FF0033FF0033FF0026FF0026FF0019FF00
0CFF0000FF0000FF1900FF3300FF4C00FFD900F3FF00A6FF0000007300FF3300FF0059FF0059FF\
CC00FF0000000000000019FF0033FF0059FF3F00FF8000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000003F00FF0099FF00F3FF00FFD9\
00FFB300FF9900FF8000FF6600FF4C00FF4C00FF4C00FF3300FF1900FF000CFF00
26FF0026FF0033FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF0066FF0066FF0066FF00\
73FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF0099FF0099FF008CFF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF00\
66FF0066FF0059FF0059FF004CFF004CFF003FFF0033FF0033FF0026FF0026FF00
0CFF0000FF0C00FF4000FF4C00FF5900FF8000FFFF0040FF0000002600FF00A6FF008CFF00CCFF\
004CFF0066FF6600FF0073FF0019FF00A6FF0073FF0040FF0C00FF6600FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000009900FF0C00FF0080FF00D9FF00FFFF\
00FFD900FFA600FF8000FF6600FF4C00FF3300FF2600FF1900FF000CFF0019FF00
19FF0026FF0033FF0033FF0033FF003FFF003FFF004CFF0059FF0059FF0066FF0066FF0066FF00\
73FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
8CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF0099FF0099FF008CFF008CFF0073FF004CFF0073FF0073FF0073FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF00\
66FF0066FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0033FF0026FF00
0CFF0000FF0C00FF3300FF6600FF8C00FFBF00F3FF7300FF0033FF00BFFF00D9FF00FFF300FFFF\
00FFFF00F3FF0073FF00F3FF00F3FF00D9FF0080FF00A6FF0040FF9900FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000005900FF0026FF0000FF00A6FF\
00FFE600FFBF00FFB300FF7300FF4C00FF3300FF2600FF0C00FF000CFF0019FF00
19FF0026FF0026FF0033FF0033FF0033FF003FFF003FFF004CFF0059FF0059FF0066FF0066FF00\
73FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF00
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00\
99FF0099FF0099FF008CFF008CFF0073FF003FFF003FFF0000FFB366FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF00\
66FF0066FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0033FF0026FF00
19FF000CFF0000FF0C00CCFF00FF4000FF5900FFA60000000040FF00FFD900BFFF00FFBF00E6FF\
00E6FF00FFD900BFFF00FFE600FFE600D9FF00F3FF00D9FF008CFF3F00FF000000
000000000000000000000000D900FF000000000000000000000000000000000000C000FFB300FF\
CC00FF000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000008000FF004CFF0099FF\
00BFFF00E6FF00FFBF00FFA600FF5900FF3300FF2600FF1900FF0C00FF000CFF00
19FF0019FF0026FF0026FF0026FF0026FF0019FF0019FF000CFF0059FF0059FF0066FF0066FF00\
66FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
99FF0099FF008CFF008CFF0080FF0073FF003FFF0033FF0000FF194CFF0066FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF00\
66FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0033FF0026FF00
19FF000CFF0000FF0000FF1900FF2600FF4000FF9900FFB300FFA600FFA600FFE600FF8C00FF8C\
00FFA600FFBF00FFBF00FFA600FFBF00FFCC00FFD900FFF300CCFFD900FF000000
000000000000CC00FF2600FF2600FFC000FF0000000000003F00FF0C00FF3300FF3300FF3300FF\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000007300FF2600FF\
0000000073FF00A6FF00FF8000FF5900FF4000FF4000FF4C00FF2600FF000CFF00
0CFF0019FF0019FF0019FF0019FF0000FF0000FF4019FF003FFF004CFF0059FF0066FF0066FF00\
66FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00
80FF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF0080FF0080FF0066FF004CFF0026FF0026FF0059FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF0033FF0026FF0026FF00
19FF000CFF0000FF0000FF0C00FF2600FF4000FF5900FFB300FF8000FF8000FF7300FF7300FF80\
00FFB300B3FF00FFCC00FF8C00FF8C00FFA600FFBF00F3FF00CCFF00CCFF0040FF
000000C000FF1900FF0033FF0080FF0066FF0040FF0C00FF0059FF004CFF0059FF0040FF000CFF\
3F00FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000CFF0026FF00FFF300E6FF00FF7300FF5900FF8000FF4000FF1900FF0C00FF00
0CFF000CFF0000FF0000FF1900FF5900FF1919FF0033FF004CFF004CFF0059FF0059FF0066FF00\
66FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF00
80FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
80FF0080FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0000FF1980FF008CFF0099FF00\
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
8CFF008CFF008CFF008CFF0080FF0080FF0073FF0066FF004CFF0000FF194CFF00
59FF0059FF0066FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF00\
59FF0059FF0059FF004CFF004CFF003FFF0033FF0026FF0026FF0026FF0019FF00
0CFF000CFF0000FF0000FF0C00FF5900FF9900D9FF00FF6600FF4000FF4000FF4C00FF5900FF66\
00FFB300FF8000FF9900FF7300FF8000FFA600FFCC00FFCC00F3FF00FFE60080FF
8000FF0019FF00A6FF00CCFF008CFF00CCFF00A6FF00B3FF00B3FF0073FF0099FF9900FF0033FF\
0000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000A600FF2600FFC000FF8000FF\
00B3FF00FFFF00FFB300FF9900FF990033FF00FF9900FF4C00FF2600FF1900FF0C
00FF0C00FF0C00FF190C00FF00FF0019FF0033FF003FFF004CFF004CFF0059FF0059FF0066FF00\
66FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
80FF0080FF0080FF0080FF0080FF0066FF0073FF0073FF0066FF0000FF4073FF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00\
8CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF0059FF0026FF0026FF00
33FF004CFF0059FF004CFF0000FF334CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00\
59FF0059FF004CFF004CFF004CFF003FFF0026FF0000FF4000FF000CFF0000FF00
00FF0000FF0000FF0C00FF1900FF5900FF4000FF3300FF6600FF2600FF2600FF3300FF4C00FF66\
00FF8C00FF5900FF5900FF5900FF7300FFD900FFA600FF9900FF9900FFBF00FFD9
00E6FF00F3FF00E6FF00FFF300FFF300FFFF0099FF00F3FF00B3FF0026FF00BFFF00A6FF0073FF\
1900FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000E600FF1900FF0059FF0C00FF00CCFF\
00D9FF00FFCC00FF9900FF7300FF6600FF5900FF7300FFBF00FF4C00FF6600FF26
00FF2600FF3300FF8000FF3300FF0C26FF0033FF003FFF003FFF004CFF0059FF0059FF0059FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0066FF0073FF008CFF0099FF0099FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
73FF0073FF0073FF0073FF0066FF0026FF0059FF0059FF0000FF2659FF0073FF0080FF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF00\
8CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF0059FF0026FF0000FF26
19FF003FFF003FFF0033FF0000FF733FFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF00\
59FF004CFF004CFF004CFF003FFF003FFF0033FF0019FF0000FF8C00FF2600FF40
00FF1900FF2600FF2600FFA600FF2600FF1900FF0C00FF5900FF0C00FF1900FF4000FF8000E6FF\
00FFE600FF4C00FF4000FF4000FF7300FF5900FF7300FF8000FF8000FF9900FFB3
00FFE600FFB300FFD900FFCC00FFD90073FF004CFF00FFE600FFE600FFFF00B3FF008CFF0059FF\
0040FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000A600FF0066FF00BFFF00FFFF\
00F3FF00FFCC00FFA600FF8000FF5900FF4C00FF4C00FF7300FF6600FF5900FF59
00FF8000FFCC00FF4C00FF1900FF0019FF0026FF0033FF003FFF004CFF004CFF0059FF0059FF00\
59FF0059FF0059FF0066FF0066FF0066FF0059FF003FFF0066FF0066FF0066FF00
66FF0066FF0066FF0000FF0059FF0059FF003FFF0059FF0080FF008CFF0099FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0066FF0066FF0066FF0059FF003FFF0000FF4C00FF8000FF8C3FFF0073FF0080FF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00\
80FF0080FF0080FF0080FF0073FF0073FF0066FF0066FF0059FF003FFF0000FF26
0CFF0019FF0026FF0019FF000CFF003FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00\
4CFF004CFF004CFF003FFF003FFF0033FF0026FF000CFF0000FF1900FF2600FF4C
00FF4C00D9FF00FF5900FF4000FF0C00FF000CFF0000FF0000FF0000FF0C00FF3300FF4C00FF40\
00FF7300FF4000FF3300FF3300FF4000FF4000FF4C00FF6600FF7300FFA60073FF
00FFBF00FF8C00FF8C00FFA600FFBF00FFE600FFBF00FFBF00FFE600E6FF00BFFF00D9FF00BFFF\
0C00FF2600FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000F300FF7300FF0040FF008CFF00BFFF00FFE6\
00FFBF00FFBF00FFB300FF6600FF4C00FF4000FF3300FF4000FF4C00FF2600FF19
00FF2600FF2600FFA600FF8000FF0C00FF2619FF0033FF0033FF003FFF004CFF004CFF004CFF00\
59FF0059FF0059FF0059FF0059FF0059FF004CFF0000FF0C4CFF0059FF0059FF00
59FF0026FF004CFF000CFF0026FF0026FF0026FF0000FF3300FF3359FF008CFF0099FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
26FF003FFF003FFF004CFF004CFF0033FF0000FF0C26FF003FFF0059FF0073FF0073FF0080FF00\
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00\
80FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF004CFF003FFF0000FF00
00FF4000FF5900FF5900FF9900FF0026FF003FFF003FFF004CFF004CFF004CFF004CFF004CFF00\
4CFF003FFF003FFF003FFF0033FF0026FF0000FF0000FF0C00CCFF00FF0000FF00
00FF3300FF0C00FF1900FF4C00FF000CFF0019FF0019FF000CFF0000FF0000FF4C00FF1900FF19\
00FFBF00FF2600FF2600FF2600FF3300FF4000FF4C00FF5900FF7300FFBF00FF80
00FFB300FF7300FF8000FFCC00B3FF00FFBF00FF9900FFA600D9FF00FFD900FFFF00FFF30000FF\
0066FF3F00FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000D900FF0C00FF0059FF00B3FF0073FF00D9FF\
00FFB300FF9900F3FF00FF8000FF4000FF3300FF2600FF2600FF1900FF0C00FF0C
00FF0C00FF0C00FF5900FF4000FFE600FF0C19FF0026FF0026FF0000FF003FFF004CFF004CFF00\
4CFF004CFF004CFF004CFF004CFF004CFF003FFF000CFF000CFF000CFF0019FF00
00FFB300FF0C00FF0C33FF0000FF000CFF0066FF0073FF0080FF0080FF008CFF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
00FF0000FF4000FF8033FF0019FF0000FF0C00FF0C26FF003FFF0059FF0066FF0066FF0066FF00\
80FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF00\
19FF0066FF0073FF0073FF0066FF0066FF0033FF003FFF0026FF0000FF3300FF00
26FF0019FF0019FF000CFF0000FF4019FF0033FF0033FF0033FF0033FF0026FF003FFF003FFF00\
3FFF0033FF0026FF0026FF0019FF0000FF0000FF4000FF5900FF0019FF0019FF00
0CFF0019FF0000FF2600FFB300FF0019FF0019FF0019FF0019FF000CFF0000FF0000FF0000FF00\
00FF2600FF1900FF1900FF1900FF2600FF4000FF4C00FF5900FF8000FF8000FF59
00FF5900FF5900FF6600FFE600FF8C00FFA600FF8C00FF8C00FF9900FFB300FFCC00FFE600F3FF\
0099FF000000000000CC00FF000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000003F00FF0040FF00B3FF00FFFF2600FF\
00E6FF00FF8000FF7300FF5900FF4000FF3300FF2600FF1900FF0C00FF0000FF00
00FF0000FF0000FF0C00FF1900FF6600FF1900FF0000FF0000FF0C19FF0033FF003FFF003FFF00\
3FFF003FFF003FFF0033FF0026FF0033FF0026FF0000FF5919FF0019FF004CFF00
4CFF004CFF004CFF0059FF0066FF0059FF0073FF008CFF008CFF0099FF0099FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
33FF004CFF000CFF0000FF0C00FF4000FF5900FF4000FF0000FF334CFF004CFF0033FF004CFF00\
73FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
80FF0059FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF00\
3FFF003FFF0059FF0066FF0059FF0059FF003FFF0000FF0000FF0C00FF0C33FF00
3FFF003FFF0033FF0026FF0000FFA600FF0019FF0026FF0019FF0000FF0C0CFF0026FF0033FF00\
33FF0026FF0000FF0000FF2600FF660CFF000CFF0019FF0000FF1933FF0033FF00
33FF0026FF0019FF0000FF4019FF0026FF0026FF0026FF0026FF0019FF0019FF0019FF000CFF00\
00FF0000FF0000FF0C00FF1900FF3300FF4C00FF6600FF9900FFE600FF8000FF4C
00FF4000FF4000FF5900FF5900FF6600FF8C00FF7300FF8000FF8C00FFA600FFBF00F3FF00D9FF\
00BFFF0080FF004CFF0C00FF000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000059FF00FFFF00FFCC\
00FF9900FF8C00FF7300FF4C00FF4000FF3300FF2600FF1900FF0C00FF000CFF00
0CFF000CFF0000FF0000FF0C00FF8000FF4C00FF3300FFBF00FF4000FF400CFF0033FF0033FF00\
33FF0033FF0033FF0026FF0000FF1900FF000CFF000CFF003FFF0059FF0066FF00
66FF0073FF0073FF0073FF0080FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
73FF0066FF003FFF0026FF0033FF0000FF1900FFBF00FF4C0CFF0033FF0026FF0026FF0059FF00\
73FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF0080FF0080FF0080FF00
73FF0000FF1966FF0073FF0073FF0073FF0073FF0080FF0080FF0073FF0073FF0073FF0066FF00\
4CFF000CFF004CFF004CFF004CFF004CFF0026FF0000FF4C00FF8C19FF003FFF00
4CFF004CFF003FFF0019FF000CFF0000FF8000FF0C00FF0000FF1900FFA600FF4000FF1919FF00\
19FF0000FF0C00FF2600FF0026FF0033FF0033FF003FFF0033FF003FFF003FFF00
3FFF0033FF0019FF0000FF0C26FF0033FF0033FF0033FF0033FF0026FF0026FF0019FF0019FF00\
0CFF0000FF0000FF0C00FF1900FF4C00FF8C00FF8000FF9900FF5900FFFF00FF40
00FF3300FF3300FF4000FF4000FF4C00FF5900FF6600FF8000FF9900FFB300FFD900FFF300FFF3\
00FFE600D9FF00A6FF0059FF9900FF000000000000000000000000000000000000
0000000000000000000000000000000000000000000000008C00FF4C00FF00A6FF00CCFF00FFFF\
00FFB300D9FF00FF8000FF5900FF4000FF4000FF3300FF1900FF000CFF000CFF00
0CFF0019FF000CFF0000FF0C00FF0C00FF8C00FF0C00FF2600FF0000FFF300FF400CFF0019FF00\
19FF0000FF0C19FF0000FF0C00FF3300FF4000FF2600FFCC3FFF0059FF0066FF00
73FF0080FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
80FF0073FF0026FF0059FF004CFF0026FF0000FF3300FF9900FF4C00FFCC00FF7326FF004CFF00\
66FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF00
66FF003FFF004CFF0066FF0066FF0066FF0059FF0066FF0066FF0066FF0059FF0059FF0059FF00\
3FFF0000FF1900FF0033FF003FFF0033FF000CFF0000FF4C19FF0026FF004CFF00
59FF0059FF0059FF003FFF0033FF000CFF0000FF1919FF0000FF0000FF1900FF2600FF3300FF19\
00FF7300FF6600FF1900FF0C33FF003FFF003FFF004CFF004CFF004CFF004CFF00
4CFF003FFF0000FF6600FF0033FF0033FF0033FF0033FF0033FF0033FF0026FF0019FF0019FF00\
0CFF0000FF0000FF0C00FF1900FF3300FF7300FF4C00FF3300FF3300FF8C00FF33
00FF2600FF2600FF3300FF3300FF4000FF4C00FF6600FF8000FFFF00F3FF00F3FF00FFA600FFA6\
00FFE600E6FF0080FF0080FF1900FF000000000000E600FF7300FF000000000000
F300FF000000000000000000000000000000000000000000000CFF0073FF00A6FF00FFF300A6FF\
00FFCC00F3FF00FF8C00FF6600FF6600FFE600FF6600FF2600FF000CFF0019FF00
19FF0019FF0019FF0019FF000CFF0000FF260CFF0019FF0019FF000CFF0019FF000CFF0000FF40\
00FF4000FFE600FF0C0099FF00FF0C19FF0026FF003FFF003FFF0066FF0073FF00
80FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
8CFF0080FF0073FF0066FF0059FF003FFF0019FF0000FF9900FF3326FF0026FF0000FF593FFF00\
3FFF0059FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
66FF004CFF000CFF003FFF004CFF003FFF0019FF0033FF004CFF003FFF0033FF0019FF0033FF00\
00BFFF26FF0019FF0000FF0C00FF3300FF1926FF003FFF004CFF0033FF0059FF00
66FF0066FF0059FF0059FF004CFF0019FF0019FF0033FF0033FF0000FF0019FF0026FF0019FF00\
00FF0000FF0C19FF0033FF003FFF004CFF004CFF004CFF0059FF0059FF0059FF00
4CFF004CFF0033FF0026FF003FFF003FFF003FFF003FFF0033FF0033FF0026FF0019FF0019FF00\
0CFF0000FF0000FF0C00FF1900FF4000FF5900FF7300FF1900FF1900BFFF00FF26
00FF1900FF1900FF2600FF3300FF4000FF5900FF6600FF8C00FFBF00FF8000FFBF00FF8C00FF8C\
00FFB300CCFF00FFFF00B3FF004CFFF300FF0000002600FF0C00FF000CFF000CFF
0000FF3300FF000000000000000000000000000000000000000CFF0080FF00E6FF00FFE600FFBF\
00FFA600FFB300FFB300FF99008CFF00FF6600FF2600FF0C00FF000CFF0019FF00
19FF0026FF0026FF0026FF0019FF0000FF0C0CFF0026FF0033FF0033FF0033FF0033FF0019FF00\
0CFF0000FF0000FF1900FF1919FF0033FF003FFF004CFF0059FF0066FF0073FF00
80FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
8CFF008CFF0080FF0073FF004CFF0019FF0000FF0C33FF003FFF004CFF003FFF0000FF0C00FF8C\
00FF0C4CFF0066FF0066FF0073FF0073FF0066FF0000FF2666FF0066FF0066FF00
59FF003FFF0000FF2600FF3300FF0000FF4033FF0033FF004CFF0033FF0026FF0019FF0000FF40\
3FFF004CFF004CFF0019FF0033FF0000FF0C33FF0059FF0059FF0066FF0066FF00
66FF0066FF0066FF0059FF004CFF0000FF193FFF004CFF004CFF003FFF003FFF0033FF0026FF00\
00FF0C00FF4026FF0033FF004CFF004CFF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF004CFF004CFF004CFF004CFF004CFF003FFF003FFF0033FF0026FF0019FF000CFF00\
00FF0000FF0C00FF1900FF4C00FF6600FF1900FF0C00FF0C00FF0C00FF0C00FF0C
00FF0C00FF0C00FF2600FF4000FF7300FF7300FF8C00FF9900FF6600FF5900FF9900FF7300FF80\
00FF9900FFBF00FFF300B3FF1900FFC000FF0000000040FF0073FF0059FF008CFF
9900FF0019FF000000E600FF5900FFA600FF0000000000003F00FFA600FF0026FF00B3FF00FFBF\
00FF9900FF8000FF7300FF6600FF6600FFA600FF4000FF1900FF000CFF0019FF00
26FF0026FF0033FF0033FF0033FF0026FF0026FF0033FF003FFF003FFF003FFF003FFF0033FF00\
33FF0026FF0019FF0000FF8019FF0033FF004CFF0059FF0066FF0073FF0073FF00
80FF008CFF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
99FF008CFF008CFF0073FF004CFF0033FF003FFF003FFF0059FF0059FF0059FF0026FF003FFF00\
00FF4000FF194CFF0059FF0059FF0066FF0059FF000CFF004CFF0059FF0059FF00
33FF0000FF0C26FF003FFF0033FF0026FF0059FF0066FF0066FF0066FF0066FF0066FF0026FF00\
59FF0066FF0066FF0059FF004CFF0026FF0000FF0059FF0066FF0073FF0073FF00
73FF0073FF0073FF0066FF003FFF000CFF004CFF0059FF0059FF0059FF004CFF003FFF0026FF00\
00FF0000FF7300FF0033FF004CFF0059FF0059FF0059FF0059FF0066FF0066FF00
59FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF0026FF0019FF000CFF0000FF26\
00FF0C00FF3300FF3300FF7300FF4C00FF0C00FF0000FF000CFF0000FF0000FF00
00FF0000FF0C00FF2600FF5900FF7300FF8C00FF7300FF8C00FF4C00FF4C00FF4C00FF5900FFBF\
00FFCC00FFFF00F3FF0080FF000000C000FFA600FF0059FF00CCFF0066FF00D9FF
0099FF0059FF0000000026FF0026FF8C00FF0000000000006600FF0059FF00CCFF00FFFF00FFCC\
00FF9900FF8000FF6600FF4C00FF4C00FF6600FF5900FFA600FF260CFF0026FF00
26FF0033FF0033FF0033FF003FFF003FFF003FFF003FFF004CFF004CFF004CFF004CFF003FFF00\
3FFF0033FF0026FF0000FF1900FF0C00FF0033FF0059FF0066FF0066FF0073FF00
80FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
99FF0099FF008CFF0059FF0059FF0066FF0066FF0019FF0066FF0073FF0066FF0066FF0059FF00\
59FF003FFF0019FF003FFF0019FF004CFF004CFF000CFF0026FF0033FF003FFF00
26FF0000FF0C33FF0059FF0059FF003FFF0066FF0073FF0073FF0080FF0073FF0073FF0059FF00\
66FF0073FF0073FF0073FF0066FF004CFF003FFF0066FF0073FF0073FF0080FF00
80FF0080FF0073FF0073FF004CFF000CFF0066FF0066FF0066FF0059FF0059FF003FFF0019FF00\
00FF3300FF2626FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0059FF0059FF0059FF0059FF004CFF003FFF0000FF0C00FF2600FF4000FF66\
00FF4C00FFD900FF4000FF4C00FF4000FF0C00FF000CFF000CFF000CFF000CFF00
0CFF0000FF0000FF1900FFB300FF4000FF3300FF4000FF7300FF4000FF3300FF4000FF5900FF73\
00FF8C00FFA600FFB300F3FFB300FF0066FF000CFF00FFFF00FFFF00CCFF00FFF3
00FFFF00BFFF00BFFF00A6FF00A6FF0066FF0040FF1900FF0000000033FF0073FF00FFFF00FFD9\
00FFA600FFA600FF7300FF4C00FF3300FF3300FF2600FF0C00FF0019FF0026FF00
26FF0033FF0033FF003FFF003FFF003FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00\
4CFF003FFF0033FF0000FF0000A6FF00FF4033FF004CFF0059FF0059FF0066FF00
80FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
A6FF0099FF008CFF0066FF0080FF0080FF0080FF0073FF0080FF0080FF0073FF0073FF0073FF00\
66FF0059FF000CFF0000FF4000FF0C33FF0000FF1900FF3300FF8000FF000CFF00
00FF193FFF0059FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0073FF004CFF0026FF0066FF0073FF0080FF0080FF00
80FF0080FF0080FF0080FF0066FF0073FF0073FF0073FF0066FF0066FF0059FF0033FF0000FF19\
00FF2626FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF003FFF0033FF0019FF0000FF5900FF0C\
00FF1900FF0C00FF0000FF3300FF3300FF000CFF0019FF0019FF0019FF0019FF00
0CFF0000FF0000FF8000FF1900FF1900FF1900FF3300FF4C00FF3300FF2600FF3300FF4000FF4C\
00FF7300FF7300FF8C00FFCC00E6FF00FFE60066FF00FFFF00FFD900FFCC00FFCC
00FFF300B3FF00FFE600FFFF0080FF00CCFF00A6FF0026FFD900FF6600FF0059FF00B3FF008CFF\
00CCFF00CCFF00FF8C00FF4C00FF3300FF1900FF0C00FF000CFF0019FF0026FF00
33FF0033FF003FFF003FFF004CFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF004CFF00\
4CFF004CFF0033FF0000FF3300FF0C00FF4C26FF0033FF003FFF0019FF003FFF00
73FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
A6FF00A6FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF00\
73FF0066FF004CFF0033FF0000FF1900FF2600FF2626FF0033FF0000FF8019FF00
00FF593FFF0059FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF0080FF0080FF0026FF0000FF0C66FF0080FF0080FF008CFF00
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0059FF0033FF0033FF00\
00FF0C00FF003FFF004CFF0059FF0066FF0066FF0066FF0073FF0073FF0073FF00
73FF0073FF0066FF0066FF0066FF0066FF0059FF004CFF003FFF0033FF0000FF0000FF3319FF00\
19FF0019FF0019FF0000FF0C00FF5900FF9919FF0019FF0026FF0026FF0019FF00
19FF000CFF0000FF0C00FF0000FF0000FF0C00FF2600FF2600FF1900FF2600FF2600FF3300FF40\
00FF4C00FF6600FFB300FFF300FF8C00FF9900E6FF00FF9900FF8C00FF9900FFB3
00FFFF00FFBF00FFB30073FF0099FF00FFF300E6FF00A6FF2600FF0000000000FF00BFFF00FFF3\
00FFBF00FF9900FF7300FF4C00FF3300FF2600FF0C00FF000CFF0019FF0026FF00
33FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00\
59FF004CFF004CFF003FFF0033FF0019FF0000FF4C00FF6633FF004CFF0066FF00
73FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0080FF00\
73FF0066FF0059FF004CFF0026FF0000FF0033FF003FFF004CFF0033FF004CFF00
3FFF0026FF0059FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0080FF000CFF0080FF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF0059FF004CFF00\
26FF0000FF2626FF004CFF0066FF0066FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0066FF0066FF0059FF004CFF003FFF0019FF0000FF0000FF0C26FF00\
33FF0033FF0026FF000CFF0000FF330CFF0019FF0026FF0026FF0026FF0026FF00
26FF0019FF0019FF000CFF000CFF0000FF0000FF0000FF0C00FF0C00FF1900FF2600FF3300FF40\
00FF4C00FF6600FFB300FF6600FF6600FF8C00FF8000FF8000FF7300FF8C00FFBF
00CCFF00FFA600FF9900FFA600FFB300FFD900FFFF00A6FF008CFF000CFF0000000080FF00D9FF\
00F3FF00FF9900FF7300FF4C00FF4000FF4000FFB300FF000CFF0019FF0026FF00
26FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00\
59FF0059FF004CFF004CFF003FFF0026FF0000FF4C19FF004CFF0059FF0066FF00
73FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF00\
73FF0073FF0066FF004CFF0033FF0026FF004CFF0059FF0059FF0066FF0066FF00
66FF004CFF0019FF0073FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF0073FF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF003FFF00\
00FF8000FF803FFF003FFF0066FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0066FF0059FF003FFF000CFF0026FF003FFF003FFF003FFF00\
3FFF003FFF0033FF0000FF0000FF1919FF0026FF0033FF0033FF0033FF0026FF00
26FF0026FF0019FF0019FF0019FF000CFF0000FF0000FF0000FF0C00FF1900FF2600FF4000FF73\
00FF6600FF9900FF7300FF4C00FF4000FF6600FF4C00FF5900FF6600FF9900FFA6
00FF8C00FF8C00FF8000FF8C00FFA600FFE600FFE600FFE600D9FF0099FF7300FF4C00FF0059FF\
00B3FF00FFBF00FFD900FF7300FF6600FF8000FF2600FF0C00FF000CFF0019FF00
19FF0026FF0033FF003FFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF00\
66FF0059FF0059FF004CFF003FFF0019FF0000FF1900FF0C3FFF0059FF0066FF00
73FF0080FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF00\
73FF0073FF0059FF003FFF0000FF1900FF0C4CFF0059FF0066FF0073FF0073FF00
73FF0073FF0066FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0066FF004CFF00\
00FF4C3FFF0059FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF00
80FF0073FF0073FF0073FF0073FF0066FF0066FF003FFF0000FF003FFF004CFF004CFF004CFF00\
4CFF004CFF0033FF0000FF0000FF0026FF0033FF0033FF0033FF0033FF0033FF00
26FF0026FF0026FF0019FF0019FF000CFF000CFF0000FF0000FF0000FF0C00FF3300FF6600D9FF\
00FF9900FF5900D9FF00FF4000FF3300FF3300FF4000FF4C00FF5900FF8C00FF73
00FF6600FF6600FF6600FFBF0066FF00E6FF00FFA600FFBF00F3FFA600FF1900FF000000A600FF\
00B3FF00FFCC00FFA600FF8C00FF7300FFB300FF4000FF2600FF0C00FF0000FF0C
00FF0000FF0000FF0026FF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0066FF0059FF004CFF003FFF0019FF0000FF0C26FF004CFF0059FF0066FF00
66FF0073FF0073FF0073FF0073FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF00\
73FF0066FF0059FF0033FF0000FF190CFF000CFF0066FF0073FF0073FF0080FF00
80FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0059FF0019FF00\
3FFF0059FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0073FF0073FF0073FF0066FF0026FF004CFF0059FF0059FF0059FF0059FF00\
59FF004CFF003FFF0000FF0000FF0C33FF003FFF003FFF003FFF0033FF0033FF00
33FF0026FF0026FF0026FF0019FF0019FF000CFF0000FF0000FF0000FF0C00FF2600FF4000FF8C\
00FF3300FF3300FF5900FF3300FF1900FF2600FF3300FF4C00FF7300B3FF00FF66
00FF4C00FF4000FF4C00FF8000FF7300FFA600FF8000FF9900FFFF00BFFF3F00FFA600FF7300FF\
00B3FF00D9FF00FF8C00FF6600FF4C00FF8000FF8000FFBF00FF3300FF4000FF80
00FF0019FF0019FF003FFF004CFF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0066FF0059FF004CFF0019FF0000FF7300FF590CFF003FFF004CFF004CFF00
4CFF0066FF0066FF0026FF0066FF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0080FF00\
73FF0066FF003FFF0000FF2600FF7300FF0000FF0C59FF0073FF0080FF0080FF00
80FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF004CFF0000FF40\
4CFF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF0059FF00\
59FF0059FF004CFF0026FF003FFF003FFF003FFF003FFF003FFF003FFF0033FF00
33FF0033FF0026FF0026FF0019FF0019FF000CFF0000FF0000FF0000FF0C00FF2600FF8000FF40\
00FF1900FF0C00FF1900FF1900FF0C00FF1900FF5900FFD900FFB300FF6600FF73
00FF4000FF3300FF4000FF4000FF4C00FF6600FF7300FF8C00FFB300E6FF00F3FF00BFFF6600FF\
0073FF00FFFF00FFB300FF6600FF4000FF3300FF3300FF1900FF2600FFF300FF0C
19FF0033FF003FFF004CFF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF00\
73FF0066FF0066FF004CFF0033FF003FFF000CFF0000FF400CFF0026FF0000FF00
19FF003FFF000CFF0059FF0080FF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0080FF00\
73FF0066FF0059FF0026FF0000FF0C26FF004CFF0066FF0073FF0080FF0080FF00
8CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF003FFF0000FF590CFF00\
4CFF0066FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF00\
66FF0059FF0059FF004CFF004CFF004CFF004CFF004CFF003FFF003FFF003FFF00
33FF0033FF0026FF0026FF0019FF000CFF000CFF0000FF0000FF0C00FF1900FF4000FF3300FF19\
00FF0C00FF0000FF0000FF0000FF0000FF0C00FF2600FFA600FF2600FF3300FF59
00FF2600FF2600FF2600FF3300FF4000FF5900FF7300FFD900FFB300FF9900FFA600FFD90026FF\
6600FF00CCFF00FFA600FF6600FF3300FF1900FF0C00FF0000FF0000FF4000FF33
00FF4033FF004CFF0059FF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0066FF0059FF004CFF0033FF0000FF1926FF0026FF0000FF26
19FF0019FF0019FF0059FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0073FF00\
73FF0066FF0059FF003FFF0000FF733FFF0059FF0073FF0073FF0080FF008CFF00
8CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0066FF0033FF0026FF00\
59FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF00\
66FF0066FF0059FF0059FF0059FF004CFF004CFF004CFF004CFF003FFF003FFF00
33FF0033FF0026FF0019FF000CFF000CFF0000FF0000FF0C00FF1900FF2600FF6600FF3300FF0C\
00FF000CFF000CFF000CFF000CFF0000FF0000FF4000FF1900FF0C00FF1900FF73
00FF1900FF1900FF2600FF3300FF4000FF5900FF8000FF7300FF6600FF6600FFA600FFCC00FFBF\
004CFF0059FF00F3FF00FF8000FF4C00FF3300FF000CFF000CFF0000FF0C00FF59
0CFF0026FF004CFF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0066FF0059FF003FFF0000FF0C4CFF0059FF0033FF00
4CFF004CFF000CFF004CFF0073FF0080FF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF008CFF0080FF0073FF0073FF00\
66FF0059FF004CFF003FFF0000FF004CFF0059FF0073FF0080FF0080FF008CFF00
8CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0073FF0059FF0000FF4C00FF00\
00FF4073FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF00\
66FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF00
33FF0026FF0019FF0019FF0000FF0C00FF0C00FF0C00FF1900FF5900FFD900FFCC00FF3300FF0C\
0CFF000CFF0019FF0019FF0019FF000CFF0000FF2600FF000CFF0000FF0000FF00
00FF0C00FF0C00FF1900FF4000FFB300FF8000FF9900FF6600FF4000FF4000FF5900FF8000FF8C\
00F3FF0099FF00F3FF00FF7300F3FF00FF0C0CFF0019FF0019FF000CFF0000FFBF
00FFA600FF003FFF0059FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0073FF0073FF0066FF004CFF003FFF0059FF0066FF0066FF00
66FF0059FF0019FF0000FF1900FF3380FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0026FF004CFF0059FF00\
3FFF004CFF003FFF0019FF0000FF4C0CFF004CFF0066FF0073FF0080FF008CFF00
8CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0000FF4C00FF4C26FF0059FF00\
66FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00\
66FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF00
26FF0000FF0C00FF0000FF0000FF1900D9FF00FF4000FF4000FF6600FF2600FF3300FF5900FF0C\
0CFF0019FF0019FF0026FF0026FF0019FF0019FF0019FF0019FF000CFF000CFF00
00FF0000FF0C00FF1900FF4C00FFE600FF5900FF4000FF8000FF3300FF2600FF3300FF4C00FF99\
00FFB300FF9900E6FF00FF7300FF2600FFF319FF0026FF0026FF0026FF0000FF19
26FF000CFF0033FF004CFF0066FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0073FF0066FF0000FF004CFF0066FF0073FF0080FF00
73FF0066FF003FFF0059FF0000FF5966FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
C0FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0066FF003FFF0000FF26\
19FF0000FF0C19FF0000FF1933FF0000FF2600FF0C59FF0073FF0080FF008CFF00
8CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0073FF0059FF0000FF6659FF00\
73FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00\
73FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF00
26FF0000FF0C00FF0C00FF7300FF5900FF330080FF0C00FF00FF0C00FF0000FF1900FF5900FF40\
0CFF0019FF0026FF0026FF0026FF0026FF0026FF0026FF0019FF0019FF000CFF00
00FF0000FF0000FF1900FF3300FFB300FF2600FF1900FF8000FF1900FF1900FF3300FF7300FFBF\
00FF4000FF4000FF5900FF7300FF0C0CFF0026FF0033FF0033FF003FFF003FFF00
3FFF003FFF0019FF0000FF3359FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0073FF0033FF004CFF0073FF0080FF0080FF00
80FF0080FF0080FF0073FF0066FF0026FF0066FF0080FF0080FF008CFF0099FF0099FF00A6FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
C0FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0066FF004CFF0019FF00\
19FF0019FF0000FF0C3FFF0059FF0059FF0059FF0000FF800CFF0073FF0080FF00
8CFF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF0080FF0059FF0000FF594CFF00\
73FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00\
73FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF00
33FF0026FF0019FF0000FF0000FF8000FF0C00FF0000FF0C00FF0019FF000CFF0000FF0000FF40\
19FF0026FF0026FF0033FF0033FF0033FF0026FF0026FF0026FF0019FF000CFF00
0CFF0000FF0000FF1900FF4000FF2600FF0C00FF0000FF0000FF0000FF0000FF2600FF3300FF33\
00FF2600FF2600FF7300FF2600FF0019FF0026FF0033FF003FFF004CFF004CFF00
4CFF0059FF0059FF0059FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF0080FF0080FF0066FF004CFF0080FF008CFF008CFF00
8CFF008CFF008CFF008CFF0080FF0000FF0000FF263FFF003FFF0080FF008CFF0066FF0099FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
C0FF00B3FF00A6FF00A6FF0099FF008CFF008CFF0080FF0080FF0066FF0059FF000CFF0000FF19\
3FFF004CFF004CFF0019FF0066FF0073FF0073FF0059FF0019FF0000FF0080FF00
8CFF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0080FF003FFF0066FF0073FF00\
80FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00\
73FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF00
33FF0026FF0019FF0000FF3300E6FF00FF0019FF0019FF0019FF0026FF0026FF0019FF0000FF40\
19FF0026FF0033FF0033FF0033FF0033FF0033FF0026FF0026FF0019FF000CFF00
00FF0000FF0C00FF2600FFCC00FF1900FF000CFF000CFF000CFF000CFF0000FF9900FF0000FF00\
00FF0000FF0C00FF2600FF2600FF0019FF0026FF0033FF003FFF004CFF0059FF00
59FF0066FF0066FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0066FF008CFF008CFF0099FF00
99FF0099FF0099FF0099FF008CFF0080FF0026FF0059FF000CFF0059FF0059FF0066FF0099FF00\
A6FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00
C0FF00B3FF00A6FF0099FF0073FF0073FF0073FF0073FF0066FF0026FF003FFF0019FF0019FF00\
4CFF0066FF0066FF0073FF0073FF0080FF0080FF0080FF004CFF0073FF0019FF00
99FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0066FF0073FF0080FF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF00\
73FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF00
33FF0026FF0019FF0000FF0C00FF400CFF0026FF0033FF0033FF0033FF0033FF0026FF0000FF26\
00FF0033FF003FFF003FFF003FFF003FFF0033FF0033FF0026FF0019FF0000FF00
00FF0C00FFBF00F3FF00FF8C00FF2600FF000CFF0019FF0019FF0019FF0019FF0019FF0019FF00\
0CFF0000FF0000FF0C00FF5900E6FF00FF4C0CFF0026FF003FFF004CFF0059FF00
66FF0066FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF004CFF0059FF0059FF0026FF0059FF00\
A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
B3FF00A6FF008CFF0073FF0000FF8000FF3326FF004CFF0000FF5933FF0000FF5900FF0C4CFF00\
59FF0066FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF0099FF00
99FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0000E6FF8CFF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0073FF00\
73FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF00
33FF0026FF0000FF2600FF9900FF1900FF0C26FF0033FF003FFF003FFF003FFF0033FF0000FF00\
00FF0C33FF003FFF003FFF003FFF003FFF003FFF0033FF0019FF000CFF0000FF4C
00FF3300FF9900FF2600FF3300FF3300FF0019FF0026FF0026FF0026FF0026FF0026FF0019FF00\
19FF000CFF0000FF0C00FF9900FF1900FF000CFF0000FFFF19FF0059FF0059FF00
66FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0059FF0080FF008CFF0073FF0059FF00\
8CFF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
C0FF00A6FF0099FF0080FF0073FF0073FF0080FF0080FF003FFF0066FF004CFF0026FF004CFF00\
66FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0073FF00\
73FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF00
33FF0019FF0000FF1900FF0026FF0026FF0033FF003FFF004CFF004CFF004CFF003FFF0033FF00\
26FF003FFF004CFF004CFF004CFF004CFF003FFF0026FF0000FF3300FF4C00FFBF
00FF5900FF990CFF0000FF0C00FF2600FF0019FF0026FF0033FF0033FF0033FF0026FF0026FF00\
19FF000CFF0000FF0C00D9FF00FF0026FF0033FF003FFF004CFF0059FF0066FF00
66FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF0099FF0099FF00A6FF0099FF00\
80FF004CFF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
C0FF00B3FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF0033FF003FFF00\
66FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
99FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0073FF00\
66FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF00
26FF0000FF0000FF0C26FF0033FF003FFF003FFF004CFF004CFF004CFF004CFF004CFF004CFF00\
4CFF004CFF004CFF0059FF004CFF004CFF004CFF0033FF0026FF000CFF0000FF40
0CFF0019FF0026FF0026FF000CFF0000FF0026FF0033FF0033FF0033FF0033FF0033FF0026FF00\
19FF0000FF0000FF8C00FFCC0CFF0033FF003FFF004CFF0059FF0059FF0066FF00
66FF0073FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF0099FF00\
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
C0FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0066FF0033FF0026FF00\
4CFF0066FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0073FF0066FF00\
66FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF0019FF00
00FF0000FF1926FF0033FF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF00\
59FF0059FF0059FF0059FF0059FF0059FF004CFF003FFF0033FF000CFF0000FF4C
19FF0033FF0033FF0033FF0019FF0000FF4C26FF0033FF003FFF003FFF003FFF0033FF0033FF00\
19FF0000FF0C00FF8C00FF0C19FF0033FF003FFF004CFF0059FF0059FF0066FF00
66FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF0080FF0066FF003FFF0000FF73\
00FF8059FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF0066FF00\
66FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0019FF00
00FF400CFF0026FF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0066FF00\
66FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF0033FF0000FF1926FF00
00FF8C3FFF003FFF003FFF0033FF0000FF1926FF003FFF003FFF003FFF003FFF003FFF0033FF00\
00FF0C00FF0000FF0000FF7300FF0000FF403FFF004CFF0059FF0066FF0066FF00
66FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF003FFF0000FF0C00FF59\
3FFF0066FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0099FF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF0066FF0059FF00\
59FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0033FF0026FF0000FF00
00FF2600FF0C26FF003FFF004CFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF0019FF0026FF003FFF00
4CFF004CFF004CFF004CFF004CFF0000FF263FFF004CFF004CFF004CFF004CFF003FFF003FFF00\
33FF0026FF0019FF0000FF0000FF2626FF003FFF004CFF0059FF0059FF0066FF00
66FF0073FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0073FF004CFF0019FF00\
00FF4C73FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0073FF0066FF0066FF0059FF0019FF00\
3FFF004CFF004CFF004CFF003FFF0019FF0026FF000CFF0019FF000CFF0000FF19
00FF1919FF0033FF003FFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0066FF0066FF0059FF004CFF0000FF1933FF004CFF00
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF004CFF00\
3FFF0033FF0026FF0000FF0C00FF2633FF003FFF004CFF0059FF0059FF0066FF00
66FF0073FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF0080FF0073FF0066FF0033FF00\
59FF0073FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF008CFF0080FF0073FF0066FF0066FF0066FF0066FF0059FF004CFF0026FF00\
26FF003FFF003FFF003FFF0033FF0000FF0000FF1900FF590059FF00FF3300FF26
00FF1919FF0033FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0073FF00\
73FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0000FF1933FF0059FF00
59FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF00\
4CFF003FFF0033FF0026FF0000D9FF26FF003FFF004CFF004CFF0059FF0059FF00
66FF0066FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF0099FF008CFF0080FF0073FF0066FF000CFF00\
4CFF0066FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF008CFF0080FF0066FF004CFF0019FF0033FF004CFF004CFF004CFF003FFF0026FF00\
00FF3300FF0026FF0026FF0026FF0000FF0000D9FF00FF260CFF0019FF000CFF00
00FFB300FF0019FF0026FF004CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0066FF0059FF0026FF0059FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF004CFF00\
4CFF003FFF003FFF0026FF0000FF4C0CFF0033FF003FFF004CFF004CFF0059FF00
59FF0066FF0066FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
C0FF00C0FF00B3FF00B3FF00A6FF00A6FF008CFF0080FF0080FF0059FF0059FF0000FF0C00FF26\
00FF003FFF0066FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0080FF0066FF0033FF0026FF0026FF0000FF260CFF0019FF0019FF0000FF99\
00FF0000FF4000FF000CFF0000FF0C00FF0C0CFF0000FF0033FF0033FF0026FF00
0CFF0000FF5919FF0033FF004CFF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF00
73FF0073FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF00\
4CFF004CFF003FFF0033FF0000FF1900FFBF00FFFF33FF0033FF0019FF004CFF00
4CFF004CFF003FFF0066FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF0099FF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
C0FF00C0FF00B3FF00B3FF00A6FF0099FF004CFF0026FF003FFF0033FF000CFF0000FF594CFF00\
59FF0059FF0033FF0073FF0080FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF008CFF0080FF0073FF0066FF0066FF004CFF0033FF0000FF1900FF0C00FF19\
26FF0019FF0000FF0000FF0000FF0033FF003FFF003FFF003FFF003FFF0033FF00
00FF1900FF0C26FF003FFF004CFF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF00\
4CFF004CFF003FFF0033FF0019FF0000FF0C00FF1919FF0019FF0000FF0033FF00
3FFF0033FF0033FF0059FF0066FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
C0FF00C0FF00B3FF00B3FF00A6FF0099FF008CFF0073FF004CFF003FFF004CFF003FFF0073FF00\
80FF0080FF0073FF0000FF0C66FF0080FF0099FF00A6FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF008CFF008CFF0080FF0073FF0073FF0059FF004CFF0026FF0026FF003FFF00\
3FFF0033FF0033FF0019FF0000FF263FFF004CFF0059FF0059FF004CFF003FFF00
0CFF0000FF1919FF0033FF004CFF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0059FF0059FF00\
59FF004CFF004CFF003FFF0026FF0000FF0000FF7300FF4C00FF3300FF3319FF00
00FF0000FF0C0CFF003FFF0059FF0066FF0066FF0073FF0073FF0080FF0080FF008CFF008CFF00\
99FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
C0FF00B3FF00B3FF00B3FF00A6FF0099FF008CFF0073FF0033FF0026FF0073FF0080FF0080FF00\
8CFF008CFF008CFF0080FF004CFF000CFF0099FF00A6FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF008CFF0080FF0080FF0073FF0066FF004CFF0000FF0C33FF004CFF00\
59FF0059FF0059FF004CFF0000FF004CFF0059FF0059FF0059FF0059FF003FFF00
0CFF0019FF0000FFB326FF0033FF004CFF0066FF0073FF0073FF0073FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF00\
59FF004CFF004CFF003FFF0026FF000CFF0000B3FF0CFF0019FF0000FF1900FFB3
00FF0026FF0000FF4000FF263FFF004CFF004CFF0059FF003FFF0073FF0073FF0066FF008CFF00\
99FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
C0FF00B3FF00B3FF00A6FF00A6FF0099FF0080FF0066FF0033FF0066FF0080FF008CFF0099FF00\
99FF0099FF0099FF0099FF008CFF0080FF008CFF00A6FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF008CFF0080FF0080FF0073FF0059FF0000FF0000FFBF00FF004CFF00\
66FF0066FF0066FF0059FF0000FF334CFF0066FF0066FF0066FF0066FF0000FF33
4CFF003FFF0019FF0000FF003FFF0059FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0059FF00\
59FF004CFF003FFF0033FF0019FF0000FF8019FF0026FF0033FF0026FF0019FF00
33FF004CFF004CFF004CFF0033FF0000FF5919FF0000FF0033FF0059FF004CFF0059FF0080FF00\
99FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
B3FF00B3FF00A6FF00A6FF0099FF008CFF0066FF000CFF003FFF0059FF008CFF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF008CFF0080FF0073FF0066FF0059FF0033FF0000FF7326FF0059FF00\
66FF0073FF0073FF0066FF0059FF0066FF0073FF0073FF0073FF0073FF0066FF00
59FF004CFF0000FF0C26FF004CFF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF00\
59FF004CFF003FFF0026FF0000FF0C00FF2619FF0033FF003FFF004CFF003FFF00
6600FF59FF0066FF0066FF0066FF0059FF0000FF334CFF0000FF0C0080FF33FF0019FF0066FF00\
8CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
B3FF00A6FF00A6FF0099FF008CFF0073FF0000FF3366FF0080FF0080FF0080FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF0099FF0099FF008CFF008CFF0073FF0066FF0059FF004CFF0033FF0026FF0059FF0066FF00\
73FF0073FF0080FF0080FF0073FF0073FF0080FF0080FF0080FF0073FF0073FF00
66FF0059FF003FFF0026FF0059FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF00\
59FF004CFF003FFF0019FF0000FF5900FFA600FF403FFF004CFF0059FF0059FF00
66FF0066FF0073FF0073FF0073FF0073FF0059FF0066FF0059FF004CFF0073FF0066FF0066FF00\
26FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
A6FF0099FF008CFF0059FF004CFF0066FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF0099FF0099FF008CFF008CFF0073FF004CFF0019FF000CFF0000FF1919FF0059FF0073FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF00
73FF0066FF0026FF003FFF0059FF0066FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF00\
59FF004CFF003FFF0026FF000CFF0000FFD926FF003FFF0059FF0059FF0066FF00
73FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0073FF004CFF0080FF008CFF008CFF00\
8CFF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
80FF008CFF0080FF0033FF0066FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF0099FF0099FF008CFF0080FF0073FF004CFF0019FF003FFF004CFF003FFF004CFF0073FF00\
80FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00
73FF0066FF0019FF0033FF0059FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF00\
4CFF004CFF003FFF0033FF000CFF0000FF0033FF004CFF0059FF0066FF0073FF00
73FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF00\
99FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
66FF003FFF0000FFCC00FFFF73FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
99FF0099FF008CFF0080FF0073FF004CFF0000FF334CFF0073FF0073FF0073FF0000FF1966FF00\
80FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00
73FF0059FF000CFF0033FF0059FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF004CFF00\
4CFF003FFF0033FF0026FF000CFF0000FF0C26FF003FFF0059FF0066FF0073FF00
73FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
80FF0026FF0066FF0073FF0073FF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00A6FF00
99FF008CFF0080FF0066FF000CFF0059FF0073FF0066FF0080FF0080FF0080FF0073FF0073FF00\
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF00
73FF004CFF0033FF0000FF4059FF0066FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0059FF003FFF003FFF00\
33FF0026FF0019FF000CFF0000B3FF00FF0000FFBF26FF003FFF0059FF0073FF00
80FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
66FF0000FF4073FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF0099FF00
99FF0080FF004CFF000CFF004CFF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00
80FF0066FF003FFF0000FF7300FF0C66FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0059FF0000FFCC00FF0C\
0CFF0000FF0000FF7300FFCC0CFF0033FF003FFF003FFF0000FF6600FF8066FF00
80FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
59FF004CFF0080FF008CFF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00A6FF008CFF00
80FF0066FF004CFF004CFF0073FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF00
80FF0066FF0026FF0033FF0059FF0073FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF00
8CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0059FF004CFF0033FF00\
19FF0000FF4C0CFF0019FF0000FF193FFF004CFF0059FF0059FF0066FF0073FF00
80FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
00FF1900FF0073FF008CFF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF000CFF00
3FFF0026FF0000FF0C00FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF00
73FF0019FF003FFF000CFF0059FF0073FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF0059FF004CFF003FFF00\
19FF0000FF2626FF0033FF003FFF004CFF0059FF0066FF0066FF0073FF0080FF00
80FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
59FF0080FF003FFF0000FF59A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF008CFF00
73FF0000FF0C66FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
8CFF0080FF0066FF0033FF003FFF0066FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00
8CFF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF0066FF0059FF004CFF0033FF00\
0CFF0000FF8C19FF003FFF004CFF0059FF0066FF0066FF0073FF0080FF0080FF00
8CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
8CFF0099FF0099FF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF008CFF00
73FF0000FF3373FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
8CFF008CFF0019FF0019FF0066FF0066FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
8CFF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF0059FF004CFF0000FF4C00FF00\
00FF0000FF0033FF003FFF004CFF0059FF0066FF0073FF0073FF0080FF0080FF00
8CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
99FF00A6FF00A6FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0080FF00
00FF194CFF0066FF008CFF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF008CFF0073FF0059FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF008CFF008CFF008CFF0080FF0080FF0073FF0066FF0059FF004CFF0033FF0000FF0000FF00\
00FF0000FF3326FF003FFF004CFF0059FF0066FF0066FF0073FF0080FF0080FF00
8CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
99FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF0066FF00
00FF008CFF0080FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
99FF008CFF0000FF0080FF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF008CFF008CFF008CFF0080FF0073FF0066FF004CFF000CFF0000FF1919FF000CFF0033FF00\
33FF0026FF0000FF1926FF0026FF004CFF0059FF0066FF0073FF0080FF0080FF00
80FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0073FF0080FF00
99FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF0099FF0066FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00
99FF008CFF008CFF008CFF0080FF0073FF0026FF0000FF190CFF003FFF004CFF004CFF004CFF00\
4CFF003FFF0000FF0000FF1900FF1900FF194CFF0066FF0073FF0073FF0080FF00
80FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00A6FF008CFF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00
99FF0099FF008CFF008CFF0080FF0066FF0033FF0033FF004CFF0059FF0066FF0066FF0066FF00\
59FF004CFF0026FF0000FF3300B3FF0CFF004CFF0059FF0066FF0073FF0073FF00
73FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF0099FF008CFF008CFF0073FF0019FF003FFF004CFF0066FF0073FF0073FF0073FF0066FF00\
66FF0059FF0000FF7300FF0019FF0000FF193FFF004CFF0059FF0059FF0059FF00
59FF0073FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
A6FF00B3FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0099FF008CFF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
66FF0066FF0059FF004CFF003FFF0026FF0000FF1919FF0000FF330CFF0000FFA6
19FF0059FF0073FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
8CFF00A6FF00B3FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF00\
73FF0066FF0066FF0059FF004CFF0033FF0000FF2619FF0033FF0059FF0066FF00
66FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
00FF0099FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF00\
73FF0073FF0066FF0059FF004CFF0033FF0000FF4C3FFF0059FF0066FF0073FF00
80FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
99FF0059FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00\
73FF0073FF0066FF0059FF0026FF000CFF0000FF3300FF2659FF0073FF0080FF00
80FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
B3FF00B3FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF00\
80FF0073FF0066FF004CFF0033FF0000FF2626FF004CFF0066FF0073FF0080FF00
8CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF00\
80FF0073FF003FFF0019FF0000FF4000B3FF33FF004CFF0066FF0073FF0080FF00
8CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00\
80FF0066FF0033FF004CFF004CFF0026FF0000FF803FFF0059FF0066FF0080FF00
8CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF00\
80FF0080FF0073FF0066FF0059FF004CFF0026FF0000FF4C00FF0059FF0080FF00
8CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00\
8CFF0080FF0080FF0073FF0066FF004CFF0000FF0000FF0C59FF0073FF0080FF00
8CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00\
8CFF0080FF0080FF0073FF0066FF000CFF000CFF003FFF0066FF0073FF0080FF00
8CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF00\
8CFF008CFF0080FF0080FF0073FF0059FF0033FF0033FF0066FF0073FF0080FF00
8CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF00\
8CFF008CFF0080FF0080FF0073FF0066FF003FFF004CFF0066FF0073FF0080FF00
8CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF00\
8CFF008CFF0080FF0080FF0073FF0066FF000CFF004CFF0066FF0073FF0080FF00
8CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00\
8CFF008CFF0080FF0080FF0073FF0059FF0026FF0019FF0066FF0073FF0080FF00
80FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00\
8CFF008CFF008CFF0080FF0073FF0019FF0000FFCC33FF0059FF0066FF0073FF00
80FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
8CFF008CFF008CFF0080FF0073FF0059FF003FFF0000FF330CFF0000FF2673FF00
80FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
8CFF008CFF008CFF0080FF0073FF0066FF003FFF0000FF0033FF0059FF0066FF00
73FF0080FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
8CFF008CFF0080FF0080FF0073FF0059FF0033FF0000FF003FFF0059FF0066FF00
66FF0073FF0073FF0073FF0073FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
8CFF008CFF0080FF0073FF0066FF004CFF0000FF0000FF3333FF003FFF004CFF00
59FF0066FF0059FF0000FF3366FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
8CFF008CFF0080FF0066FF0000FF1926FF000CFF0033FF0000FF4000FF6633FF00
4CFF004CFF000CFF003FFF0073FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
8CFF008CFF0080FF0066FF0059FF0059FF0059FF004CFF000CFF0000FF000080FF
19FF0000FF803FFF0066FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF0080FF0073FF0080FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00F3FF00
E6FF00E6FF00E6FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF008CFF0080FF0080FF0073FF0073FF0066FF0059FF004CFF003FFF0026FF00
00FF8C26FF004CFF0066FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF0080FF00\
80FF0000FF333FFF0080FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF008CFF008CFF0080FF0080FF0073FF0073FF0066FF0059FF004CFF0033FF00
00FF0C26FF003FFF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
73FF004CFF004CFF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0080FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF0080FF0080FF0073FF0066FF0059FF004CFF0000FF00
00FF3326FF003FFF0059FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0073FF0073FF00\
59FF0000FF0C66FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF008CFF0066FF003FFF0099FF00A6FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF0080FF0080FF0073FF0066FF0059FF003FFF000CFF00
0CFF0033FF004CFF0059FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0066FF00\
4CFF003FFF0073FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0080FF0000FF0C73FF0099FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF0080FF0080FF0073FF0059FF0000FF5926FF000CFF00
00FF0C26FF003FFF004CFF0059FF0059FF0059FF004CFF0059FF0066FF0066FF0059FF0000FF00\
0CFF0059FF0073FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF008CFF0066FF0000FF0C66FF0099FF00A6FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF0080FF0080FF0073FF0066FF0059FF004CFF0033FF00
00FF3300FF0C33FF003FFF004CFF004CFF0000FF0000FF0C3FFF004CFF0059FF004CFF0026FF00\
26FF0059FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF00
99FF008CFF008CFF008CFF0080FF003FFF0019FF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF0059FF003FFF00
26FF0000FF1919FF0026FF0033FF0033FF0019FF0000FF3300FF0019FF0033FF0026FF0000FF19\
33FF0059FF0066FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF0080FF0073FF0000FF6673FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF0059FF003FFF00
26FF0000FF5900FF0C19FF0000FF6600FF1900FF7300FF9900FF0000FF0C19FF000CFF0000FF4C\
26FF004CFF004CFF0000FFFF73FF0080FF0080FF0080FF0080FF0080FF0073FF00
80FF0080FF0080FF0073FF003FFF004CFF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00
F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00F3FF00\
F3FF00F3FF00F3FF00F3FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF004CFF0000FF19
00FFA600FF0C33FF003FFF003FFF0000FF1919FF0000FF5926FF003FFF003FFF003FFF0019FF00\
00FF2619FF0019FF0059FF0073FF0073FF0080FF0080FF0073FF0073FF0026FF00
66FF0066FF0066FF0059FF0026FF0033FF0073FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF008CFF00
66FF0000FF0080FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0066FF0000FF1959FF00
73FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF00\
66FF0059FF003FFF0000FF000CFF0026FF0000FF0000FF3300FF3300FF403FFF00
4CFF004CFF0033FF0000FF194CFF0073FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF008CFF00
26FF0080FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0066FF003FFF004CFF00
80FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF00\
66FF004CFF0000FF0026FF003FFF003FFF0033FF0000FF0C00FF1900FF2626FF00
19FF0000FF263FFF0059FF0066FF0073FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0066FF00
8CFF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0026FF0080FF0080FF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF00\
4CFF0000FF4C33FF004CFF0059FF0059FF004CFF0026FF0026FF0026FF0000FF26
0CFF0033FF0059FF0066FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF008CFF008CFF008CFF00
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF0073FF00\
59FF000CFF0059FF0066FF0066FF0066FF0059FF004CFF004CFF0033FF0000FF59
0CFF003FFF0059FF0066FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0073FF00\
3FFF0066FF0066FF0073FF0073FF0066FF0066FF0059FF004CFF003FFF000CFF00
00FF0C26FF0059FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF00\
80FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF0033FF0000FFCC
26FF004CFF0059FF0066FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00\
8CFF0080FF0080FF0080FF0080FF0073FF0073FF0066FF004CFF0019FF0000FF00
00FF0033FF004CFF0059FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00\
8CFF008CFF008CFF0080FF0080FF0080FF0073FF0066FF0000FF003FFF003FFF00
00FF5900FF0000FF4C4CFF0073FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF00\
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0066FF0059FF004CFF00
33FF0000FF404CFF0066FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0066FF0059FF00
00FF2600FF333FFF0066FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF00\
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
99FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF00
4CFF0000FF264CFF0066FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0066FF00
59FF0019FF004CFF0066FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00\
99FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0066FF00
59FF0000FF403FFF0066FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0066FF00
4CFF0000FFCC3FFF0059FF0066FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0066FF00
4CFF0019FF000CFF000CFF0059FF0066FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0066FF00
59FF0026FF0000FF333FFF0059FF0066FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0073FF0066FF00
4CFF0019FF0019FF003FFF0059FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF008CFF00\
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0066FF0026FF00
00FF0000FF0C00FF0019FF003FFF0059FF0059FF0059FF0059FF0066FF0080FF0080FF008CFF00\
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0066FF004CFF00
4CFF003FFF0000FF0C00FF8033FF003FFF003FFF0019FF0033FF0066FF0073FF0080FF0080FF00\
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0073FF0066FF00
66FF004CFF0033FF000CFF0000FF000CFF000CFF0026FF0059FF0066FF0073FF0080FF0080FF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF00
66FF0059FF003FFF0033FF0000FF1919FF003FFF0059FF0066FF0073FF0073FF0080FF0080FF00\
80FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF00
66FF0059FF003FFF0019FF0000FF1919FF003FFF0059FF0066FF0073FF0073FF0080FF0080FF00\
80FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
99FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF00A6FF00
B3FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF00
59FF0000FF1919FF0000FFFF00FF0026FF004CFF0059FF0066FF0066FF0073FF0073FF0080FF00\
80FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF004CFF0073FF00A6FF00
B3FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0073FF00
66FF004CFF0026FF0000FF5926FF003FFF004CFF0059FF0066FF0066FF0073FF0073FF0073FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0000FF9966FF00A6FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0066FF00
59FF004CFF0026FF0000CCFF19FF003FFF004CFF0059FF0059FF0066FF0066FF0073FF0073FF00\
73FF0073FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF00
73FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0059FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF0099FF0073FF008CFF008CFF000CFF0026FF0080FF0099FF00A6FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0066FF0059FF00
4CFF0019FF0019FF0000FF5919FF0033FF003FFF004CFF0059FF0059FF0066FF0066FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0066FF0033FF0059FF004CFF003FFF00
73FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF0073FF0059FF008CFF0099FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF00A6FF0099FF0073FF004CFF0059FF0033FF0073FF0099FF00A6FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF008CFF008CFF0080FF0059FF0059FF0000FF003FFF00
26FF0000FF4000FF1900FF0000FF4C26FF0033FF0033FF003FFF003FFF0059FF0066FF0066FF00\
66FF0073FF0073FF0073FF0073FF0066FF0059FF003FFF0000FF333FFF0066FF00
80FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF0080FF0066FF0073FF008CFF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF008CFF0080FF0066FF0026FF0059FF0073FF0099FF00A6FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF008CFF0073FF0066FF004CFF0000FFD900FF0033FF00
33FF000CFF003FFF0033FF0026FF0000FF8C0CFF000CFF0000FF3326FF004CFF0059FF0066FF00\
66FF0066FF0066FF0066FF0066FF0059FF004CFF0026FF0000FF0C59FF0073FF00
80FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0066FF000CFF0073FF008CFF008CFF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF008CFF0080FF003FFF0000FF2673FF008CFF0099FF00A6FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF008CFF0073FF0059FF0026FF004CFF004CFF0059FF00
59FF0059FF004CFF004CFF0033FF0000FF0000FF2600FF9900FF0033FF004CFF0059FF0059FF00\
59FF0059FF0059FF0059FF0059FF003FFF0000FF4000FF3300FF004CFF0073FF00
80FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF008CFF008CFF0073FF0066FF004CFF0000FF8C59FF0080FF008CFF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF008CFF0080FF0073FF0059FF0019FF0073FF0080FF0099FF00A6FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF008CFF008CFF0080FF0066FF0073FF0073FF0066FF00
66FF0066FF0059FF0059FF003FFF0019FF0000FF2600FFBF00FF1900FF993FFF004CFF004CFF00\
59FF004CFF004CFF004CFF003FFF0026FF0000FF193FFF004CFF0059FF0073FF00
80FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF008CFF0080FF0066FF003FFF0000FF0C3FFF0066FF0073FF0080FF00\
8CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
8CFF0080FF0000FF004CFF0033FF0026FF0000FF5959FF008CFF00A6FF00A6FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0073FF00
73FF0066FF0066FF0059FF004CFF0019FF0000FF1900FF8000FF1900FF1933FF003FFF003FFF00\
3FFF0033FF0033FF0026FF0000FF0019FF0026FF0059FF0066FF0073FF0073FF00
80FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF004CFF0000FF804CFF0059FF0000FF66\
80FF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00\
8CFF0080FF0059FF0000FF193FFF0059FF0080FF0080FF008CFF00A6FF00A6FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF00
73FF0073FF0066FF0066FF003FFF0026FF000CFF0019FF000CFF0000FF190CFF0033FF0033FF00\
26FF0019FF0000FF260CFF003FFF004CFF0059FF0066FF0066FF0073FF0080FF00
80FF0080FF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF008CFF008CFF008CFF0080FF0080FF0066FF0059FF0033FF0000FF664CFF0066FF00\
80FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF00\
80FF0066FF004CFF0000FF1966FF0080FF008CFF0099FF0099FF00A6FF00B3FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0080FF00
73FF0073FF0073FF0066FF0059FF004CFF003FFF003FFF0033FF0026FF0000FF2600FF190CFF00\
00FF2600FF1919FF003FFF004CFF0059FF0066FF0066FF0073FF0073FF0080FF00
80FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF008CFF008CFF008CFF008CFF0080FF0073FF0066FF0059FF0026FF0000FF5959FF0073FF00\
80FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00\
73FF004CFF0000FF0C26FF0066FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF00
80FF0073FF0073FF0066FF0066FF0059FF004CFF004CFF003FFF0033FF0019FF0000FF8000FF40\
00FF000CFF0000BFFF3FFF0059FF0059FF0066FF0073FF0073FF0073FF0080FF00
80FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
8CFF008CFF008CFF008CFF0080FF0080FF0073FF004CFF000CFF0000FF4033FF0059FF0073FF00\
80FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF008CFF008CFF0066FF0073FF0080FF008CFF0080FF0080FF0073FF0073FF0066FF00\
59FF0000FF4059FF0073FF0080FF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF00
80FF0073FF0073FF0066FF0066FF0059FF0059FF004CFF003FFF0033FF0026FF0000FF0000FF0C\
19FF0033FF003FFF004CFF0059FF0066FF0066FF0073FF0073FF0073FF0080FF00
80FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00
8CFF008CFF008CFF008CFF0080FF0080FF0073FF0066FF004CFF0033FF0000FF263FFF004CFF00\
73FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00
8CFF008CFF008CFF0080FF0033FF0019FF0073FF0073FF0073FF0073FF004CFF003FFF0000FF33\
4CFF0066FF0080FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF00
80FF0073FF0073FF0066FF0066FF0059FF0059FF004CFF003FFF0033FF0019FF0000FF2600FF33\
19FF0033FF004CFF004CFF0059FF0066FF0066FF0073FF0073FF0073FF0080FF00
80FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF0080FF0080FF0073FF0066FF0059FF003FFF0000FF003FFF0066FF00\
73FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF0080FF0073FF003FFF004CFF0066FF0059FF0059FF003FFF0019FF004CFF00\
66FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF00
80FF0073FF0073FF0066FF0066FF0059FF0059FF004CFF003FFF0033FF0019FF0000FF2600FF40\
19FF003FFF004CFF0059FF0059FF0066FF0066FF0073FF0073FF0073FF0080FF00
80FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0059FF0000FF0C00FF263FFF0066FF00\
73FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF0080FF0080FF0073FF0059FF0000FF3333FF0033FF0019FF0019FF003FFF0066FF00\
73FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF00
73FF0073FF0073FF0066FF0066FF0059FF004CFF003FFF003FFF0033FF0019FF0000FF0000FF0C\
26FF0033FF003FFF004CFF0059FF0066FF0066FF0073FF0073FF0073FF0080FF00
80FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF0066FF004CFF0000FF003FFF0066FF00\
73FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0073FF0073FF0059FF003FFF0000FFA600FF7319FF0026FF0000FF0059FF00\
80FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF00
73FF0073FF0066FF0066FF0059FF0059FF003FFF000CFF0026FF0019FF000CFF0000FF0C00FFBF\
00FF0C26FF0033FF0033FF0059FF0066FF0066FF0073FF0073FF0073FF0080FF00
80FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF004CFF0019FF004CFF0059FF00\
66FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0073FF0073FF0066FF0059FF003FFF0000FF4C3FFF004CFF0059FF0059FF0066FF00\
80FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF00
73FF0066FF0059FF0059FF004CFF004CFF003FFF0019FF0000FF4000FF2600FF3300FF4C00FF00\
0CFF0000FF5900FF6600FF0000FF1959FF0066FF0073FF0073FF0073FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
80FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0066FF004CFF0000FF003FFF0059FF00\
66FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0073FF00
73FF0073FF0073FF0066FF0059FF003FFF0000FF4000FF003FFF0059FF0066FF0073FF0080FF00\
80FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0066FF00
3FFF003FFF0033FF003FFF003FFF003FFF0033FF0019FF0000FF1900FF0C00FF3300E6FF26FF00\
33FF0033FF003FFF003FFF0059FF0066FF0066FF0073FF0073FF0073FF0073FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0059FF003FFF0000FF0C0CFF004CFF00\
59FF0066FF0066FF0073FF0073FF0073FF0073FF0066FF0026FF003FFF0066FF00
66FF0066FF0066FF0066FF004CFF000CFF0000B3FF00FF4C33FF0059FF0073FF0073FF0080FF00\
8CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0073FF00
59FF0019FF0000FF0C00FF5919FF000CFF000CFF0000FF0000FFCC0CFF0019FF0026FF0033FF00\
3FFF003FFF004CFF0059FF0059FF0066FF0066FF0073FF0073FF0073FF0073FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0059FF003FFF0000FF4019FF003FFF00\
4CFF003FFF004CFF0066FF0066FF0066FF0066FF0059FF003FFF000CFF004CFF00
59FF0066FF0059FF0059FF004CFF0033FF0000FF0000FF003FFF0059FF0073FF0073FF0080FF00\
8CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF00
66FF0059FF004CFF003FFF0026FF0000FF0000FF6600FF8000FF0019FF0026FF0033FF003FFF00\
3FFF004CFF0059FF0059FF0059FF0066FF0066FF0073FF0073FF0073FF0073FF00
73FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0073FF0073FF0066FF0059FF0026FF0000FF6600FFB300FF0C19FF00\
33FF0000FF0C3FFF0059FF0059FF0066FF0059FF0059FF003FFF0000FF263FFF00
4CFF004CFF004CFF004CFF004CFF0033FF0000FF1933FF004CFF0066FF0073FF0073FF0080FF00\
8CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
99FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF00
66FF0066FF0059FF004CFF003FFF0033FF0019FF0000FF260CFF0026FF0033FF003FFF003FFF00\
4CFF004CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF00
73FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0073FF0073FF0073FF0066FF0059FF003FFF003FFF0033FF0000FF3300FFE6\
00FF4C26FF003FFF004CFF0059FF0059FF0059FF004CFF003FFF0000D9FF00FF4C
33FF0000FF0C3FFF003FFF003FFF0026FF0000FF263FFF004CFF0066FF0066FF0073FF0080FF00\
80FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00\
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF00
66FF0066FF0059FF004CFF004CFF0033FF0026FF0000FF190CFF0026FF0033FF003FFF003FFF00\
4CFF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF00
73FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF004CFF003FFF0026FF000CFF00\
0033FF0CFF0033FF003FFF004CFF004CFF003FFF003FFF0033FF0000FF8C00FF00
0CFF0000FF8026FF0033FF000CFF000CFF0000FF2600FF733FFF0059FF0066FF0066FF0073FF00\
80FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF00
66FF0066FF0059FF004CFF004CFF0033FF0019FF0000FF4000FF0C19FF0033FF003FFF003FFF00\
4CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF004CFF003FFF0033FF000CFF00\
00FF660CFF0033FF003FFF003FFF0033FF0019FF000CFF0019FF0000FF2600FF19
00FF3300FFE600FF000CFF0000FF4000FF0C19FF0000FF8000FF9933FF004CFF004CFF0059FF00\
4CFF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00\
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF00
66FF0066FF0059FF004CFF003FFF0026FF000CFF0000FF4000FF3300FF1919FF0033FF003FFF00\
4CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF00
73FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF004CFF003FFF0026FF0000FF0C\
00FF330CFF0026FF0026FF0026FF0000FF0000FF4000FF4000FF8C0CFF0019FF00
19FF000CFF0000FF3300FF9919FF0026FF0033FF0000FF193FFF0033FF0000FF2600FF4C19FF00\
00FF264CFF0073FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF008CFF0080FF0059FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF00
66FF0059FF0059FF004CFF003FFF000CFF0000FF3300FFD90080FF00FF2600FFA60CFF003FFF00\
4CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF004CFF0019FF0000FF000CFF00\
00FF1900E6FF0CFF0019FF000CFF0000FF0C00FF6600FFB300FF0026FF0033FF00
33FF0026FF0026FF0000FF0C26FF003FFF004CFF004CFF0059FF0059FF004CFF004CFF0000FF4C\
66FF0073FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF008CFF0080FF0080FF0080FF0080FF0080FF0073FF000CFF0066FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF00
59FF0059FF004CFF004CFF003FFF0019FF0000FF0C00FF4000FF3300FF0026FF0033FF003FFF00\
4CFF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF004CFF003FFF0033FF0026FF00\
00FF0000FF2600FF1900FF4C00FF6600FF2600FF2600FF2600FF0033FF003FFF00
3FFF003FFF003FFF0026FF0000FF0C4CFF0059FF0066FF0066FF0066FF0066FF0066FF0073FF00\
73FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF0099FF0066FF0000FF0066FF004CFF0066FF0066FF000CFF004CFF0059FF00\
66FF0000FF8066FF0066FF0073FF0073FF0066FF0066FF0066FF004CFF0033FF00
4CFF004CFF004CFF003FFF0033FF0026FF000CFF0000FF4000FF1900FF2633FF003FFF003FFF00\
4CFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF004CFF003FFF0033FF00\
19FF0000FF0C00FF6600FF0019FF0019FF000CFF0019FF0019FF003FFF004CFF00
4CFF004CFF004CFF003FFF0026FF004CFF0066FF0066FF0073FF0073FF0073FF0073FF0080FF00\
80FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF0099FF008CFF0080FF004CFF0019FF003FFF0000FF0000FF2600FF4C33FF00\
3FFF0000FF404CFF004CFF0059FF0066FF0066FF0059FF0059FF003FFF0000FF00
33FF0033FF0033FF0033FF0033FF0026FF000CFF0000FF3300FF0026FF0033FF003FFF004CFF00\
4CFF004CFF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF00\
66FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF0026FF00\
00FF0000FF6600FF2619FF0026FF0033FF0033FF003FFF003FFF004CFF004CFF00
4CFF0059FF0059FF0059FF0059FF0059FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF00\
8CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF0099FF0099FF008CFF0073FF0059FF0000FF0C26FF003FFF0026FF0000FF19\
00FF6619FF000CFF0000FF0C3FFF004CFF004CFF004CFF004CFF003FFF0019FF00
00FF5919FF0019FF0026FF0026FF0019FF0000FF0000FF1919FF0026FF0033FF003FFF003FFF00\
4CFF004CFF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF00\
4CFF004CFF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF0026FF00\
0CFF0000FF800CFF0026FF0033FF003FFF003FFF004CFF004CFF004CFF0059FF00
59FF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00\
8CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF004CFF0059FF0066FF0066FF004CFF0019FF00\
4CFF003FFF000CFF0033FF000CFF0026FF0033FF0019FF0033FF0019FF000CFF00
00FF6600FF5900FF0C0CFF0000FF2600FF0000FF2600FF8019FF0026FF0033FF003FFF003FFF00\
4CFF004CFF0059FF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF004CFF00\
19FF0033FF004CFF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF0026FF00\
0CFF0000FF3300FF0C26FF003FFF003FFF004CFF004CFF004CFF0059FF0059FF00
59FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF00\
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0066FF0073FF0073FF0073FF0066FF0033FF00\
59FF0059FF0059FF0059FF004CFF0033FF0000FF0000FF800CFF0000FF4C00FF19
0CFF0000FF0000FF4C00FF1900FFBF00FF9900FF4000FF4C00FF2626FF0033FF003FFF003FFF00\
4CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF00\
26FF0000FF0C4CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF0033FF0026FF00\
00FF0000FF0C19FF0033FF003FFF004CFF004CFF004CFF0059FF0059FF0059FF00
66FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF00\
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0080FF0080FF0073FF0073FF00\
73FF0066FF0066FF0066FF0059FF004CFF003FFF0026FF0000FF4C19FF0019FF00
26FF0019FF0000FF0C00FF1900FF0C00FF0000FF0000FF4C00FF0C19FF0026FF0033FF003FFF00\
3FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF004CFF003FFF00\
26FF0000FF403FFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF0033FF0026FF000CFF00\
00FF1919FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0059FF00
66FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0080FF00\
73FF0073FF0073FF0073FF0066FF0066FF0059FF003FFF0019FF0033FF003FFF00
3FFF0033FF0000FF0C19FF0026FF0019FF000CFF0000FF3300FF4000FF0C00FF8C26FF003FFF00\
3FFF004CFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF00\
19FF0026FF003FFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF004CFF004CFF004CFF004CFF004CFF004CFF003FFF003FFF0033FF0026FF000CFF0000FF73\
0CFF0026FF0033FF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0066FF00
66FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF00\
80FF0080FF0073FF0073FF0073FF0066FF0059FF0033FF0033FF004CFF004CFF00
4CFF003FFF0000FF2633FF0033FF0033FF0019FF0000FF0C00FF0000FF3300FF0026FF0033FF00\
3FFF003FFF004CFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF0059FF0059FF004CFF004CFF004CFF004CFF004CFF004CFF004CFF0033FF0026FF00\
00FFE619FF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF004CFF00
3FFF003FFF004CFF004CFF004CFF004CFF003FFF003FFF0026FF0000FF190CFF0000FF1900FF40\
0CFF0033FF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0059FF0066FF00
66FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF00\
80FF0080FF0080FF0073FF0073FF0073FF0066FF0059FF0059FF0059FF0059FF00
4CFF004CFF003FFF003FFF003FFF003FFF0033FF0026FF0019FF0000FF3300FF5926FF0033FF00\
3FFF003FFF003FFF004CFF004CFF004CFF004CFF004CFF0059FF0059FF0059FF00
59FF004CFF004CFF004CFF0033FF003FFF003FFF004CFF004CFF003FFF003FFF0019FF0000FFA6\
00FF1919FF0033FF003FFF003FFF004CFF004CFF004CFF004CFF004CFF003FFF00
33FF0019FF0033FF003FFF003FFF003FFF003FFF0033FF0026FF000CFF0000FF4000FF3300FF00\
19FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0059FF0066FF00
66FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00\
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00\
80FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF00
59FF0059FF004CFF004CFF004CFF003FFF003FFF0033FF0026FF0019FF0000FF3319FF0026FF00\
33FF003FFF003FFF003FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00
4CFF004CFF004CFF003FFF0026FF000CFF0026FF003FFF003FFF003FFF0033FF0026FF0000FF00\
00FFE60CFF0019FF000CFF003FFF003FFF004CFF004CFF004CFF003FFF003FFF00
19FF0000FF4C19FF0033FF0033FF0033FF0033FF0033FF0026FF000CFF0000FF3300FF260CFF00\
26FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0066FF0066FF00
66FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF00\
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
8CFF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00\
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00
59FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0026FF0000FF2600FF1919FF00\
26FF0033FF003FFF003FFF003FFF003FFF004CFF004CFF004CFF004CFF004CFF00
4CFF004CFF003FFF003FFF0019FF0000FF260CFF0026FF0033FF0033FF0026FF0019FF0000FF00\
00FF3300FF4000FF4019FF0033FF003FFF003FFF003FFF003FFF003FFF0033FF00
26FF0000FF4000FF3326FF0026FF0026FF0026FF0019FF0019FF000CFF0000FF4000FF4C0CFF00\
19FF0026FF0033FF003FFF004CFF004CFF0059FF0059FF0059FF0059FF0066FF00
66FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0073FF00\
0CFF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00\
8CFF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF00
66FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF0026FF0000FF400099FF00FF19\
19FF0026FF0033FF0033FF0033FF003FFF003FFF003FFF003FFF004CFF004CFF00
4CFF003FFF003FFF0033FF0026FF0000FF3300FF6619FF0026FF0019FF0000FF0000FF2600F3FF\
00FF6600FF0C0CFF0026FF0033FF0033FF003FFF003FFF003FFF0033FF0033FF00
26FF000CFF0000FF4C0CFF0019FF0019FF000CFF0000FF3300FF0000FF0C00FF2600FF3300FF0C\
0CFF0019FF0033FF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0066FF00
66FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0073FF004CFF00\
73FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00\
8CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF00
66FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF000CFF0000FF2600FF19\
0CFF0026FF0026FF0026FF0019FF0019FF0033FF003FFF003FFF003FFF003FFF00
3FFF003FFF003FFF0033FF0026FF0019FF0000FF0000FF0C00FF000CFF0000FF0000FF3300FF40\
00FF2600FF3319FF0026FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
26FF0019FF0000FFE600FF1900FF190CFF0000FF0000FF5900FF3300FF4000FF9900FF4000FF33\
0066FF00FF1919FF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0066FF00
66FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF00
99FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0059FF0066FF0066FF0026FF0059FF00\
80FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00\
8CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF00
66FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF0026FF000CFF0000FF4C00FF19\
00FF000CFF0019FF000CFF0000FF7319FF0033FF0033FF003FFF003FFF003FFF00
3FFF003FFF0033FF0033FF0026FF0019FF000CFF0000FF6600FF4000FF2600FF262600FF00FF26\
00FF0C0CFF0019FF0026FF0026FF0033FF0033FF0033FF0033FF0033FF0026FF00
26FF000CFF0000FF7300D9FF00FF4000FF0C00FF4000FF4C00FF4000FF6600FFCC00FF0C0CFF00\
19FF0026FF0033FF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF00
66FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00\
80FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0066FF003FFF0026FF000CFF0019FF00\
80FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00\
8CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF00
66FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF000CFF0000FF5900FF2600FFFF\
00FF6600FF0C00FF0000FF1900FF1919FF0026FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0033FF0026FF0019FF000CFF0000FF0C00FF2600FF6600FF6600FF3300FF19\
00FF000CFF0019FF0019FF0026FF0026FF0026FF0026FF0026FF0026FF0026FF00
19FF000CFF0000FF0000FF2600FF7300FF3300FF5900FFB300FF1900FF0C00FF0C00FF0019FF00\
26FF0026FF0033FF003FFF003FFF004CFF004CFF004CFF004CFF0059FF0059FF00
59FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00\
80FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0059FF0000FFD94CFF0073FF00\
80FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00\
8CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF00
66FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF0026FF0019FF000CFF0000FF26\
00FF4000FF3300FF4C00FF190CFF0019FF0026FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0026FF0026FF0019FF0019FF0000FF0000FF1900FF3300FFBF00FF2600FF0C\
00FF000CFF000CFF0019FF0019FF0019FF0026FF0026FF0026FF0026FF0019FF00
19FF000CFF0000FF0000FF1900FF4000FF9900FF3300FF2600FF0C00FF000CFF000CFF0019FF00\
26FF0033FF0033FF003FFF003FFF003FFF004CFF004CFF004CFF004CFF0059FF00
59FF0059FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF00\
80FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0066FF004CFF000CFF004CFF0066FF00\
80FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00\
8CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF00
66FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF0026FF0019FF000CFF00\
00FF0C00FF3300FF4000FF0C0CFF0019FF0026FF0026FF0033FF0033FF0033FF00
33FF0033FF0026FF0026FF0026FF0019FF0019FF000CFF0000FF0000FF1900FF7300FF2600FF0C\
00FF0000FF000CFF000CFF0019FF0019FF000CFF000CFF0019FF0019FF0019FF00
0CFF000CFF0000FF0000FF0C00FF4000FF6600FF2600FF0C00FF000CFF000CFF0019FF0019FF00\
26FF0033FF0033FF0033FF003FFF003FFF003FFF003FFF003FFF003FFF003FFF00
4CFF0059FF0059FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF00\
80FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF0080FF0080FF0080FF0073FF0066FF0059FF004CFF0019FF0000FF0C26FF00\
00FFA680FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00\
8CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF00
66FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF0026FF0019FF000CFF00\
00FF0C00FF3300FF5900FF2600FF0019FF0026FF0026FF0026FF0026FF0026FF00
26FF0026FF0026FF0026FF0019FF0019FF000CFF000CFF0000FF0000FF1900FF5900FF3300FF19\
00FF0C00FF0000FF0000FF000CFF0000FF0000FF0C00FF0C0CFF000CFF000CFF00
0CFF0000FF0000FF0000FF1900FF3300FF4000FF1900FF0C00FF000CFF000CFF0019FF0019FF00\
26FF0026FF0033FF0033FF0033FF003FFF003FFF003FFF0033FF0019FF0000FF26
3FFF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00
8CFF0080FF0080FF0080FF0080FF0073FF0073FF0026FF0000FF1900FF0C00FF264CFF0066FF00\
73FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF00
66FF0066FF0066FF0059FF0059FF004CFF004CFF004CFF003FFF0033FF0026FF000CFF0000FF00\
00FF2600FFA600FF4000FF1900FF0019FF0019FF0026FF0026FF0026FF0026FF00
26FF0026FF0019FF0019FF0019FF000CFF000CFF0000FF0000FF0C00FF3300FF8C00FF4000FF26\
00FF1900FF0C00FF0C00FF1900FF0C00FF0C00FF4C00FF1900FF0000FF0000FF00
00FF0000FF0C00FF0C00FF2600FF9900FF3300FF1900FF0C00FF000CFF000CFF0019FF0019FF00\
26FF0026FF0026FF0033FF0033FF0033FF0033FF0033FF0026FF000CFF0000FF00
3FFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0066FF0073FF0073FF0073FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0073FF0066FF0059FF003FFF0000FF193FFF0066FF0073FF00\
80FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00A6FF008CFF0080FF0099FF00
A6FF00A6FF0099FF0099FF0080FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF00
66FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0026FF0000FF0000FF26\
00FFA600FF4000FF1900FF0C0CFF000CFF0019FF0019FF0019FF0019FF0019FF00
19FF0019FF000CFF000CFF000CFF000CFF0000FF0000FF0C00FF0C00FF2600FF4C00FF8C00FF59\
00FF2600FF1900FF1900FF4000FF3300FF3300FFB300FF5900FF0C00FF0C00FF26
00FF3300FF1900FF2600FF4C00FF6600FF3300FF1900FF0C00FF0000FF000CFF0019FF0019FF00\
19FF0026FF0026FF0026FF0033FF0033FF0033FF0026FF0019FF0000FF0C19FF00
33FF003FFF004CFF004CFF004CFF004CFF004CFF0000FF4000FF0059FF0066FF0073FF0073FF00\
73FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0073FF0073FF0066FF0059FF003FFF0000FFCC3FFF0066FF0073FF00\
80FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF008CFF0059FF0073FF00
8CFF008CFF008CFF0080FF0059FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
80FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF00
66FF0066FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0026FF0026FF000CFF0000FF00\
00FF3300FF5900FF1900FF0C00FF000CFF000CFF0019FF0019FF0019FF0019FF00
0CFF0000FF0000FF2600FF0000FF0000FF0000FF0C00FF4000FF2600FF4000FF9900FF9900FF40\
00FF2600FF2600FF2600FF4000FFF300FFBF00FF7300FF3300FF2600FF1900FF33
00FF8C00FF3300FF7300FF5900FF7300FF4C00FF2600FF0C00FF0000FF000CFF000CFF000CFF00\
19FF0019FF0019FF0026FF0026FF0026FF0026FF0026FF000CFF0000FF4019FF00
33FF003FFF003FFF003FFF003FFF003FFF0033FF0000FF003FFF0059FF0066FF0073FF0073FF00\
73FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0073FF0073FF0073FF0066FF0059FF0000FF4C00FF0C0CFF0033FF003FFF0073FF00\
80FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00A6FF0099FF0073FF00
26FF0066FF0073FF0066FF0059FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF0099FF0099FF0099FF00
99FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00\
80FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF00
66FF0066FF0059FF004CFF003FFF0033FF00008CFF26FF0026FF0026FF0019FF000CFF0000FF0C\
00FF5900FFD900FF2600FF0C00FF000CFF000CFF000CFF000CFF000CFF000CFF00
0CFF0000FF0C00FF7300FF0C00FF0C00FF0C00FF1900FF3300FF8C00FF7300BFFF00FF5900FF40\
00FF3300FF3300FF3300FF4000FF6600FF8000FF4C00FF4000FF3300FF3300FF33
00FF8C00FF7300FF8C00FFA600FF6600FF4000FF2600FF1900FF0C00FF0C00FF0C00FF000CFF00\
0CFF0000FF000CFF0019FF0019FF0026FF0019FF0019FF0000FF4000FF330CFF00
26FF0026FF0026FF0019FF0019FF0000FF0000FF4C26FF004CFF0059FF0066FF0066FF0073FF00\
73FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
73FF0073FF0073FF0073FF0066FF0066FF0059FF003FFF0000FF594CFF0066FF0073FF0080FF00\
80FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF008CFF00
66FF0026FF0000F3FF19FF0000FF0066FF0073FF0059FF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00\
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00
66FF0059FF0059FF004CFF0033FF0000FF4C00FF4000FF0C00FF000CFF0000FF0000FF2600FF26\
00FF3300FF5900FF2600FF0C00FF0000FF000CFF000CFF000CFF000CFF0000FF00
00FF0000FF1900FFD900FF3300FF2600FF1900FF2600FF3300FF4C00FF8000FFA600FF6600FF4C\
00FF4C00FF5900FF5900FF6600FF8000FF8C00FF5900FF4C00FFD900FF4000FF40
00FF5900FFBF00FF8000FF5900FF4C00FF3300FF2600FF1900FF1900FF19000CFF00FF0C00FF0C\
00FF0C00FFCC0CFF000CFF0019FF0019FF0019FF000CFF0000FF0C00FF5900FF0C
0CFF0000FF730CFF0000FF0C00FF1900FF4033FF003FFF0059FF0059FF0066FF0066FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0066FF0066FF0059FF004CFF0026FF0033FF004CFF0066FF0073FF0080FF00\
80FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF0099FF00
80FF0059FF0066FF0066FF0000FF2633FF003FFF0066FF0080FF008CFF008CFF008CFF0099FF00\
99FF0099FF008CFF008CFF008CFF008CFF0073FF0066FF0080FF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00\
80FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF00
59FF0059FF0059FF004CFF003FFF0000FF000CFF0000FF0000FF0C00FFA600FF3300FF6600FF66\
00FFE600FF6600FF2600FF1900FF0C00FF0000FF0000FF0000FF0000FF0C00FF19
00FF1900FF2600FF4C00FF7300FF3300FF2600FF2600FF3300FF4000FF5900FFE600FF7300FF66\
00FFFF00FFA600FF8C00FF8C0080FF00FF9900FF8000FF9900FF8000FF5900FF59
00FF7300FFA600FF6600FF4C00FF4000FF3300FF3300FF2600FF2600FF3300FF8000FF2600FF26\
00FF9900FF1900FF000CFF000CFF000CFF000CFF0000FF0000FF1900CCFF00FF33
00FF3300FF6600FF1900FF3300FF0026FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0066FF0066FF0066FF0059FF004CFF0026FF0026FF004CFF0066FF0073FF0073FF0080FF00\
80FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF0099FF00
26FF0080FF008CFF0080FF004CFF0059FF004CFF0033FF004CFF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF0080FF0080FF0059FF004CFF0073FF0080FF0080FF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF00\
80FF0080FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF0059FF00
59FF0059FF0059FF004CFF003FFF0033FF0026FF0026FF0019FF0000FF0000FF3300FF1900FF8C\
00FF3300FF8000FF6600FF2600FF0C00FF0C00FF0C00FF0C00FF0C00FF1900FF4C
00FF4C00FF4000FF8C00FF5900FF4000FF4000FF4000FF4C00FF5900FF7300FFA600FF9900FF80\
00FF8C00FFD900FFB300FFBF0033FF00FFF300FFD900FFBF00FF8C00FF8C00FF8C
00FFA600FF8C00FF6600FF5900FF4C00FF4000FF3300FF3300FF3300FF4000FFF300FF5900FFA6\
0080FF00FFBF00FF0C00FF0000FF0C00FF0000FF0000FF0C00FF2600FF9900FF40
00FF7300FF2600FFBF00FF3300FF0C26FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF00\
66FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
66FF0066FF004CFF004CFF004CFF0033FF0000FF333FFF0059FF0066FF0073FF0073FF0080FF00\
80FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00
99FF0099FF0099FF008CFF0073FF0080FF0066FF0059FF0000FF6666FF0073FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0073FF004CFF0000FF0C4CFF0073FF0080FF00
80FF0080FF0080FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF00
59FF0059FF004CFF004CFF003FFF003FFF0033FF0026FF0026FF0019FF000CFF0000FF0000FF0C\
00FF1900FF2600FF4C00FF3300FF2600FF1900FF1900FF0C00FF1900FF1900FF33
00FF4C00FFA600FFBF00FF6600FF4C00FF4C00FF5900FF7300FF7300FFA600F3FF00FFA600FF99\
00FFB30099FF00D9FF3300FF00B3FF000CFFC000FF000CFF00FFBF00FFB300FFFF
00FFCC00FF8C00FF7300FF6600FF5900FF4C00FF5900FF4000FF4000FF4C00FF6600FFF300FF73\
00FF4C00FF2600FF1900FF1900FFB300FF1900FF1900FF2600FF7300FF3300FF0C
00FF0C00FF0000FF0C0CFF000CFF0019FF003FFF004CFF0059FF0059FF0059FF0066FF0066FF00\
66FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF00
66FF0059FF003FFF0000FF9926FF0000FF2600FF0C0CFF0059FF0066FF0073FF0073FF0080FF00\
80FF0080FF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0073FF0059FF0033FF0059FF0066FF0019FF00\
73FF0080FF0080FF0080FF0073FF0066FF003FFF000CFF0059FF0073FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
73FF0073FF0073FF0066FF0000FF734CFF004CFF0059FF0059FF0059FF0059FF00
4CFF004CFF004CFF004CFF003FFF003FFF0033FF0033FF0026FF0019FF0019FF000CFF0000FF00\
00FF0C00FF1900FF4000FF8C00FF3300FF4000FF2600FF1900FF1900FF2600FF33
00FF4000FF5900FF8000FF7300FF6600FF7300FF9900FFB300FF8C00FF9900FFE600FFCC00FFE6\
00F3FF0099FF0026FF0000004C00FF0000007300FF004CFF00CCFF00A6FF00FFBF
00FF9900FF8C00FF8000FF8000FF8C00FF7300FF9900FF5900FF4C00FF5900FF7300FF8C00FF59\
00FF4000FF3300FF2600FF3300FF5900FF3300FF4000FFCC00FF3300FF1900FF00
00FF000CFF0019FF0026FF0026FF0033FF003FFF004CFF004CFF0059FF0059FF0059FF0066FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0059FF004CFF0033FF000CFF0000FF0C26FF003FFF0059FF0066FF0066FF0073FF0073FF00\
80FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0073FF0019FF0026FF003FFF004CFF00\
66FF0073FF0073FF0073FF0073FF0066FF004CFF000CFF0059FF0066FF0073FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF00\
73FF0073FF0073FF0066FF004CFF0000FF3300D9FF3FFF004CFF004CFF004CFF00
4CFF004CFF004CFF003FFF003FFF003FFF0033FF0033FF0026FF0026FF0019FF000CFF000CFF00\
00FF0000FF0C00FF6600FF8000FF7300FF8000FF3300FF2600FF2600FF2600FF33
00FF4000FF5900FF8000FFE600FF8000FF8C00FFB300FFCC00FFD900FFCC00BFFF00FFF300FFFF\
008CFF000CFF0000000000000000000000001900FF0099FF00E6FF00FFE600FFCC
00FFA600FF9900FF8C00FF9900FFCC00FFCC00CCFF00FF7300FF7300FF8000FF9900FFA600FF66\
00FF5900FF4C00FF4000FF4000FF6600FF8000FFB300FFBF00FF4C00FF0C00FF00
0CFF0019FF0019FF0026FF0033FF0033FF003FFF004CFF004CFF004CFF0059FF0059FF0059FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
59FF0059FF004CFF003FFF0026FF0000FF5900FF733FFF004CFF0059FF0066FF0073FF0073FF00\
80FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0073FF004CFF003FFF0019FF000CFF00\
59FF0066FF0066FF0066FF0066FF0059FF0033FF003FFF0059FF0066FF0073FF00
73FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF00\
73FF0073FF0066FF0066FF0059FF0033FF0000FF9919FF003FFF003FFF003FFF00
3FFF003FFF003FFF003FFF003FFF0033FF0033FF0026FF0026FF0026FF0019FF000CFF000CFF00\
00FF0000FF0C00FF2600FF4000FF7300FF7300FF4000FF3300FF3300FF3300FF40
00FF4C00FF7300FF8C00A6FF00FFA600FFBF00FFD900E6FF0040FF00BFFF0033FF00D9FF008CFF\
004CFF6600FF0000000000000000000000000000FF3F00FF0026FF00FFFF00FFFF
00FFE600FFCC00FFA600FFA600A6FF00FFBF00FF9900FF8000FF8C00FFD900D9FF00FF9900FF80\
00FFB300FFE600FF6600FF6600FF8000FF7300FF5900FF4000FF2600FF0C00FF00
0CFF0019FF0019FF0026FF0033FF0033FF003FFF003FFF004CFF004CFF004CFF004CFF0059FF00\
59FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF00
59FF004CFF004CFF003FFF0026FF0000FF0C0CFF0026FF0033FF0000FF0059FF0066FF0073FF00\
73FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF0080FF0073FF0073FF008CFF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0073FF0059FF0000FF0026FF00\
4CFF004CFF0000FF004CFF0059FF003FFF0000FF0C33FF0059FF0066FF0066FF00
73FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00\
73FF0073FF0066FF0066FF0059FF004CFF0033FF0000FF5926FF0033FF0033FF00
00FF4033FF0033FF0033FF0033FF0033FF0033FF0026FF0026FF0019FF0019FF000CFF0000FF00\
00FF0000FF1900FF2600FFB300FFE600FF6600FF4C00FF4000FF4000FF4C00D9FF
00FF6600FF7300FF9900FFCC00FFD900FFF3008CFF3F00FF0000001900FF0080FF0080FF6600FF\
0000FF0000000000000000000000000000005900FF0040FF00B3FF0099FF0000FF
00FFFF00FFD900FFD900FFCC00FFFF00FFBF00FFA600FFB300FFA600FFBF00FFCC00FFB300FFF3\
00FFCC00FFB300FF9900FFBF00FFE600FF6600FF4C00FF3300FF2600FF1900FF0C
00FF000CFF0019FF0026FF0033FF0033FF003FFF003FFF003FFF003FFF003FFF003FFF004CFF00\
59FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF00
4CFF004CFF003FFF0033FF0026FF0000FF0000FF5900FF0C19FF003FFF0059FF0066FF0073FF00\
73FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF0080FF0073FF003FFF0066FF0080FF008CFF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0066FF003FFF0000FF80\
26FF0019FF0000FF0000FF0C3FFF0026FF0000FF8C26FF004CFF0059FF0066FF00
66FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0066FF0066FF0066FF0059FF004CFF003FFF000CFF0000FF1919FF0019FF00
00FF4C26FF0033FF0033FF0033FF0033FF0026FF0026FF0019FF0019FF000CFF000CFF0000FF00\
00FF1900FF2600FF3300FF4C0099FF00FF7300FF5900FF4C00FF4C00FF5900FF8C
00FFA600FF8C00FFA600BFFF00E6FF0066FF0000000000000000005900FF0C00FF000CFF0C00FF\
9900FF0000000000000000000000000000000000001900FF0000FF0080FF00CCFF
00E6FF00FFF300FFF300A6FF00FFFF00FFD900F3FF0080FF00FFCC00E6FF00FFF300FFE600CCFF\
004CFF7300FF00B3FF00FFBF00FF8C00FF7300FF6600FF4C00FF3300FF3300FFD9
00FF0C0CFF0019FF0026FF0026FF0033FF0033FF0033FF0033FF0033FF0000FFCC00FF003FFF00\
4CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
4CFF0000FF0C0CFF0019FF0000FF7300FF1900FF0C26FF003FFF004CFF0059FF0066FF0066FF00\
73FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00
8CFF0080FF0080FF0080FF0080FF0066FF0019FF004CFF0073FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0066FF0033FF0019FF00\
33FF0000FF2600F3FF00FF1900FF1900FF4000FF0033FF003FFF004CFF0059FF00
66FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
66FF0066FF0066FF0059FF0059FF004CFF003FFF000CFF0000FF4C00FF2600FF19
00FF0019FF0026FF0026FF0026FF0026FF0026FF0019FF0019FF000CFF000CFF0000FF0000FF0C\
00FF3300FF7300FFB300FFCC00FFF300FF8000FF6600FF5900FF6600FFB300FFCC
00FFBF00FFA600F3FF00FFFF0066FF004CFF000000000000000000000000C000FF000000000000\
0000000000000000000000000000000000000000003F00FF0026FF0066FF008CFF
0040FF00D9FF00D9FF00CCFF00FFFF00A6FF00F3FF00E6FF00D9FF00BFFF00E6FF0066FF008CFF\
000000F300FF00B3FF00FFE600FFE600FF9900FFF300FF7300FF4C00FF5900FF4C
00FF2600FF1900FF1919FF0026FF0026FF0033FF0033FF0026FF0019FF0000FF0C0CFF003FFF00\
4CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF00
3FFF0033FF000CFF0000FF7300FF9900FF2600FF0026FF003FFF004CFF0059FF0059FF0066FF00\
66FF0066FF0066FF0059FF004CFF0066FF0073FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0073FF0066FF003FFF0026FF0066FF0080FF0080FF0080FF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0073FF0033FF004CFF0059FF00\
59FF003FFF0019FF0033FF0033FF0026FF0000FF4C00FF0033FF0033FF0000FF26
59FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF00\
66FF0066FF0066FF0059FF0059FF004CFF003FFF0026FF000CFF0000FF1900FFCC
00FF0C0CFF0019FF0026FF0026FF0026FF0019FF0019FF0000FF7300FF0000FF0000FF0000FF0C\
00FF1900FF3300FF4000FF5900FF7300FFCC00FF8000FF7300FF7300FF8000FFA6
00BFFF00FFD900E6FF0066FF000CFF0000FF000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000009900FF0000005900FFF300FF
0033FF008CFF0073FF00BFFF00BFFF0099FF00A6FF004CFF2600FF0080FF008CFF0040FF0026FF\
0000003300FF0099FF0099FF00FFE600000000FFCC00FF9900FF8C00FFBF00FF8C
00FFE600FF1900FF0019FF0019FF0026FF0026FF0026FF0019FF000CFF0000FF6626FF003FFF00\
3FFF004CFF004CFF004CFF004CFF0059FF0059FF004CFF004CFF004CFF004CFF00
3FFF0033FF0026FF0000FF0000FF260CFF0026FF0033FF003FFF004CFF0059FF0059FF0059FF00\
59FF0059FF0059FF003FFF0026FF0059FF0073FF0073FF0080FF0080FF0080FF00
80FF0080FF0080FF0073FF0073FF0066FF003FFF0000FF5966FF0073FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0033FF0059FF0066FF0066FF00\
66FF0059FF0059FF004CFF004CFF0033FF0019FF0000FF2600FF190CFF003FFF00
59FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF00\
66FF0066FF0059FF0059FF004CFF004CFF003FFF0033FF0019FF0000FF0C00FF59
00FF260CFF0019FF0019FF0019FF0019FF0019FF000CFF0000FF0C00FF4000FF1900FF1900FF19\
00FF1900FF2600FF4000FF4C00FF5900FFCC00FFD900FF9900FF8C00FF8C00FFA6
00CCFF00D9FF0019FF000000000000F300FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000CFF0073FF0073FF0080FF004CFF000000CC00FF0000000C00FF0033FF3300FF7300FF\
0000009900FF0033FF3300FF00A6FF008CFF0040FF00D9FF00FFA600FF6600FF40
00FF3300FF0C00FF000CFF0019FF0019FF0019FF0019FF000CFF0000FF1900FF0026FF0033FF00\
3FFF003FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF003FFF00
33FF0033FF0019FF0000FF993F00FF00FF2626FF0033FF003FFF003FFF004CFF004CFF0059FF00\
59FF0059FF004CFF0000FF1919FF0059FF0066FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0066FF0059FF003FFF0033FF0059FF0066FF0073FF0073FF0080FF00\
80FF0080FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF0080FF0080FF0080FF0073FF00\
73FF0066FF0066FF0059FF004CFF003FFF0026FF0000FF0C0CFF0033FF004CFF00
59FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0059FF0059FF0059FF004CFF003FFF003FFF0026FF0000FF4000FF5900FF40
00FF0C00FF000CFF000CFF0019FF000CFF000CFF0000FF0000FF0C00FF8000FF4000FF3300FF26\
00FF2600FF3300FF4000FF4C00FF6600FF8000E6FF00FFA600FF9900FFB300E6FF
00FFF300B3FF0C00FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000026FF4C00FF3300FFF300FF0000000000000000009900FF8000FF000000000000\
000000000000E600FF0000000000007300FF0000000040FF00FFFF00FFE600FF4C
00FF2600FF1900FF0C00FF000CFF000CFF000CFF0000FF0000FF6600FF400CFF0026FF0033FF00\
33FF003FFF003FFF003FFF003FFF003FFF003FFF003FFF003FFF003FFF0033FF00
26FF0019FF000CFF0000FF0C00FF730CFF0019FF0026FF0033FF0033FF0033FF003FFF004CFF00\
4CFF004CFF003FFF0000FF6633FF0059FF0066FF0066FF0073FF0073FF0073FF00
73FF0073FF0073FF0066FF0066FF0059FF0033FF0026FF0059FF0066FF0066FF0073FF0073FF00\
73FF0066FF0033FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0073FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0080FF00\
80FF0073FF0066FF0066FF004CFF0026FF0000FF0000FF3300FF0033FF004CFF00
4CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
59FF0059FF004CFF004CFF003FFF003FFF0033FF0026FF000CFF0000FF0C00FF99
00FF3300FF0000FF000CFF000CFF000CFF0000FF0000FF0C00FF1900FF4000FFE600FF4000FF33\
00FF3300FF4000FF4C00FF5900FFA600FFBF00FFFF00FFBF00FFB300FFF30073FF
00CCFF0C00FFCC00FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000005900FF3F00FFC000FF000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000040FF0059FF2600FF00FF8C00FF4C
00FF3300FF3300FF6600FF0C00FF0000FF0000FF0000FF0C00FF3300FF3300FF0019FF0026FF00\
33FF0033FF0033FF0033FF0019FF0033FF003FFF003FFF003FFF0033FF0033FF00
0CFF0000FF1900FF4C00FF3300FF7300FF0C0CFF0019FF0019FF000CFF0000FF4C33FF003FFF00\
3FFF0033FF000CFF0026FF004CFF0059FF0066FF0066FF0066FF0066FF0073FF00
66FF0066FF0066FF0066FF0059FF004CFF0026FF0000FF193FFF004CFF004CFF0059FF0066FF00\
66FF0059FF0026FF0059FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF00\
80FF0073FF0073FF0066FF004CFF0033FF000CFF0000FF0C26FF0033FF004CFF00
4CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF00\
59FF0059FF003FFF0019FF000CFF0019FF0019FF0019FF0000FF0000FF1900FFBF
00FF2600FF0C00FF0000FF0000FF0000FF0000FF0C00FF5900FF3300FF5900FF8000FF4C00FF40\
00FF4000FF5900FF7300FF6600FF8000FF9900FFB300D9FF00FFE600FFE600BFFF
0026FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000D900FF000000000000000000000000000000000000000000000000000000\
000000000000A600FF6600FF0000FF0080FF00CCFF00F3FF00FFD900E6FF00FF66
00FF5900FF9900FF3300FF1900FF0C00FF0C00FF0C00FF2600FF9900FF3300FF000CFF000CFF00\
19FF0026FF0026FF0019FF0000FFCC26FF0026FF0026FF0033FF0026FF0019FF00
0CFF0000FF4000FF3300FF4000FF0C00FF1900FF1900FF1900FF0000FF2600FF1900FF0026FF00\
26FF0019FF0000FF6626FF003FFF004CFF0059FF0066FF0066FF0066FF0066FF00
66FF0059FF0059FF0059FF004CFF003FFF0000FF0C00FF0C26FF0033FF0019FF003FFF0059FF00\
59FF004CFF0000FF8C3FFF004CFF0059FF0059FF0066FF0066FF0066FF0059FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF008CFF00\
80FF0073FF0066FF0059FF004CFF0026FF0000FF0000FF0026FF0033FF003FFF00
4CFF004CFF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF00\
59FF004CFF003FFF0019FF0000FF0000FF8C00FF8000FF1900FF6600FF4C00FFF3
00FF3300FF1900FF0C00FF0C00FF0C00FF0C00FF1900FF3300FF9900FFB300FF8000FF5900FF59\
00FF5900FF7300FFCC00FF8C00FF8C00FF9900FFBF00FFFF00F3FF00E6FF0099FF
000CFF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000003F00FF2600FF0073FF0073FF00E6FF00FFF300F3FF00FFA600CCFF00FFBF
00FFD900FF8000FF5900FF3300FF4000FF1900FF2600FF4C00FF7300FF2600FF1900FF0C00FF40\
0CFF0019FF0019FF000CFF0000FF590CFF000CFF0000FF0C0CFF000CFF0000FF19
00FF2600FF260CFF0000FF0C19FF0019FF0000FF1900FF4C00FF3300FFF300FF7300FF5900FF33\
0CFF0000FF1900FF1926FF003FFF004CFF004CFF0059FF0059FF0059FF0059FF00
59FF004CFF003FFF003FFF003FFF0033FF000CFF0000FF3300FF3300FF2600FF1926FF003FFF00\
33FF0019FF0000FF1900FFCC26FF0026FF0019FF0033FF004CFF004CFF003FFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF00\
80FF0073FF0059FF0033FF0000FF4C00FF2600FF8C00FF330CFF0026FF0033FF00
3FFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00\
59FF004CFF003FFF0033FF0026FF0019FF000CFF0000FF1900FF1900FFB300FF33
00FF5900FF3300FF1900FF1900FF1900FF1900FF1900FF3300FF4000FF5900FF9900FF7300FF66\
00FF7300CCFF00FFE600FFA600FFA600FFCC00FFCC00FFFF008CFF00BFFF0073FF
D900FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000FF0066FF00A6FF00A6FF00F3FF00FFD900FFA600FF8C00FF7300FF66
00FF6600FF8000FFF300FF73004CFF00CCFF00E6FF00FF4C00FF4000FFBF00FF9900FF4000FF66\
00FF000CFF0000FF0000FF1900FFFF00FF6600FF2600FF2600FF1900FF0C00FF19
00FF0000FF0C19FF0026FF0026FF0026FF0019FF0000FF0C00FF2600FFBF00FF9900FF0C00FF0C\
00FF1900FF3300FF0C19FF0026FF0019FF003FFF004CFF0059FF0059FF0059FF00
4CFF0033FF0000FF5919FF000CFF0000FFB30CFF0026FF0019FF0019FF0000FF000CFF0026FF00\
0CFF0000FF8026FF0026FF0000FF0C19FF0026FF0033FF0000FF3300FF0C00FF33
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF00\
80FF0073FF003FFF003FFF003FFF003FFF0033FF0019FF0000FF5900FF0C00FF0C
19FF003FFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00\
4CFF004CFF003FFF003FFF0033FF0026FF0019FF000CFF0000FF0000FF0000FF0C
00FF1900FFD900FF4000FF5900FF2600FF2600FF2600FF3300FF4000FF5900FF8C00FFE600FF80\
00FF8C00FFA600B3FF00FFCC00FFFF00E6FF00FFF300F3FF0066FF008CFF0019FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
A600FF0C00FF0033FF00A6FF00F3FF00D9FF00FFCC00FFA600FF8C00FF6600FF59
00FF4C00FF4C00FF7300FF6600FF4000FF2600FF2600FF1900FF1900FF3300FF6600FF3300FFA6\
00FF2600FF0C00FF2600BFFF00FF1900FF0C00FF330CFF0019FF0026FF0026FF00
26FF000CFF0033FF0033FF0033FF0033FF0033FF0019FF000CFF0000FF7300FF0C19FF0019FF00\
19FF000CFF0000FF9900FF1900FF3319FF003FFF004CFF004CFF004CFF004CFF00
3FFF000CFF0000FF3300FFE600FF0C00FF0C33FF003FFF003FFF0033FF0019FF0000FF0C00FF59\
19FF0033FF004CFF004CFF0033FF004CFF0059FF0059FF0059FF003FFF003FFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF00\
80FF0080FF0073FF0066FF0059FF004CFF003FFF0026FF0000FF2600FFB300FF00
26FF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF00\
4CFF004CFF003FFF003FFF0033FF0033FF0026FF0019FF000CFF000CFF0000FF00
00FF1900FF7300FFB300FF8000FF4000FF3300FF3300FF4000FF4C00FF8C00FFA600FFCC00FFA6\
00FFCC00FFBF00BFFF00FFF300F3FF0080FF00B3FF00A6FF0099FF3300FF2600FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000007300FF004CFF0C00FF00FFF300FFE600FFE60059FF00FF9900FF6600FF4C
00FF4000FF4000FF4000FFD900FF2600FF1900FF0C00FF0C00FF0C00FF0C00FF0C00FF1900FF66\
00FF4C00FF4000FF6600FF1900FF0019FF0019FF0019FF0033FF0033FF0033FF00
33FF0033FF003FFF003FFF003FFF003FFF003FFF0033FF0019FF000CFF0026FF0026FF0033FF00\
26FF0019FF000CFF0000FF1900FF0C26FF0033FF003FFF003FFF003FFF003FFF00
33FF0026FF0000FF1900FFFF00FF1926FF003FFF004CFF004CFF004CFF0000FF6633FF0000FF8C\
33FF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF00\
80FF0080FF0073FF0066FF0066FF0059FF004CFF0000FFB300FF8C00FF4000FF26
26FF0033FF003FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00\
4CFF003FFF003FFF003FFF0033FF0033FF0026FF0019FF0019FF000CFF0000FF00
00FF0C00FF2600FF5900FF8C00FF4C00FF4000FF4000FF6600FF7300FF8000FF9900BFFF00FFCC\
00CCFF00F3FF008CFF00A6FF0040FF0059FF004CFF000CFF0026FF0000FFD900FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000008C00FF0066FF00BFFF00FFE600FFBF00FFB300FFCC00FF8C00FF5900FF40
00FF3300FF3300FF2600FF2600FF1900FF0C00FF0000FF0000FF0000FF0000FF0000FF0C00FF40\
00FF2600FF4000FF2600FF0019FF0026FF0026FF0033FF0033FF003FFF003FFF00
3FFF003FFF003FFF003FFF003FFF003FFF003FFF003FFF0033FF0033FF003FFF003FFF0033FF00\
33FF0026FF0019FF0000FF5900FF1919FF0026FF0033FF0033FF0033FF0033FF00
26FF0000FF0C00FF1900FF4C00FF4019FF004CFF0059FF0059FF0059FF0059FF004CFF0033FF00\
33FF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF00\
80FF0080FF0073FF0073FF0066FF0059FF004CFF003FFF0026FF0000FF0C00FF40
26FF0033FF003FFF003FFF003FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF003FFF00\
3FFF003FFF003FFF0033FF0033FF0033FF0026FF0019FF0019FF000CFF0000FF00
00FF0C00FF2600FF5900FFB300FF5900FF5900FF6600FF8000FFB300FF9900FFB300CCFF00E6FF\
0099FF2600FF0000FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000008C00FF0099FF00D9FF00F3FF00FFB300FF9900FF9900FF8C0059FF00FF40
00FF3300FF2600FF1900FF1900FF0C00FF0000FF0000FF000CFF000CFF000CFF0000FF0000FF4C\
00FF0000FF1900F3FF0CFF0019FF0026FF0033FF0033FF003FFF003FFF003FFF00
4CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF003FFF003FFF003FFF003FFF003FFF00\
3FFF0033FF0000FF0C00FF3300FFE60CFF0019FF0000FF0026FF0026FF0019FF00
00FF0000FF190CFF0019FF000CFF0033FF0059FF0059FF0066FF0066FF0066FF0059FF004CFF00\
0CFF0059FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF00\
80FF0080FF0073FF0066FF0066FF0059FF004CFF003FFF0033FF0019FF0000FFE6
0CFF0026FF0026FF0033FF003FFF003FFF003FFF003FFF003FFF003FFF003FFF003FFF003FFF00\
3FFF003FFF0033FF0033FF0033FF0026FF0026FF0019FF0019FF000CFF0000FF0C
00FF8C00FFCC00FFB300FFBF00FF7300FF7300FF7300FF9900FFF300FFE600FFFF00D9FF0059FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000C000FF\
7300FF0000000099FF00FFF300E6FF00FFD900FF8C00FF7300FF6600FF4C00FF40
00FF3300FF2600FF1900FF0C00FF0C00FF0000FF000CFF000CFF000CFF000CFF000CFF000CFF00\
0CFF000CFF0000FF1900FF6619FF0033FF0033FF003FFF003FFF004CFF004CFF00
4CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00\
3FFF003FFF0026FF000CFF0000FF3300FF4C00FF3300FFE600FF0C00FF00008CFF
19FF0033FF003FFF003FFF004CFF003FFF0059FF0066FF0066FF0066FF0066FF0066FF0066FF00\
3FFF0066FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF00\
80FF0080FF0073FF0066FF0059FF004CFF003FFF0033FF0026FF0019FF0000FF4C
00FF1900FF0C0CFF0000FF2626FF0033FF003FFF003FFF003FFF003FFF0033FF0026FF0033FF00\
33FF0033FF0033FF0033FF0026FF0026FF0019FF0019FF000CFF0000FF0000FF0C
00FF1900FF3300FF4C00FF5900FFF300FFB300FF8C00FFBF00F3FF0040FF0000FF0059FF8C00FF\
CC00FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000CC00FF0000FF\
0026FF0059FF0099FF00FFE600FFCC00FFA600FF8C00FF7300FF6600FF4C00FF40
00FF3300FF2600FF1900FF0C00FF0C00FF000CFF000CFF0019FF0019FF0019FF0019FF0019FF00\
19FF0019FF000CFF0000FF190CFF0033FF003FFF003FFF004CFF004CFF004CFF00
4CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF00\
4CFF003FFF0033FF000CFF0000FF260CFF0000FF2600FF6600FF0000FF3300FF00
26FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF00\
66FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF00\
80FF0073FF0073FF0059FF0000FF0C33FF0026FF0019FF0019FF0000FF4C00FF33
00FF1900FF4C00FFBF00FF5900FF1926FF0033FF0033FF0033FF0033FF0019FF0000FF1926FF00\
26FF0033FF0033FF0026FF0026FF0026FF0019FF0000FF0000FF0000FF0C00FF0C
00FF1900FF3300FF4000FF5900FF8000FFE600FFB300F3FF004CFF000000000000000000E600FF\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000007300FF2600FF004CFF\
0073FF00BFFF00B3FF0066FF00FFCC00FFA600FFA600FFB300FF7300FF4C00FF40
00FF4000FF3300FF3300FF2600FF0C00FF000CFF000CFF0019FF0019FF0019FF0026FF0026FF00\
26FF0026FF0026FF0026FF0026FF0033FF003FFF004CFF004CFF004CFF004CFF00
4CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00\
4CFF004CFF0033FF000CFF0019FF0026FF0026FF0026FF0019FF0000FF0000FF4C
00FF003FFF004CFF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF00\
73FF0073FF0066FF0059FF003FFF0000FF2600FF19008CFF00FF1900FF3300FF00
19FF0000FF190CFF0000FF4000FF1900FF000CFF0000FF0026FF0019FF000CFF0000FF9919FF00\
26FF0026FF0026FF0026FF0026FF0019FF000CFF0000FF0C00FF4000FF2600FF26
00FF2600FF3300FF4C00FF6600FF8C00FFB300BFFF00BFFF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000C000FFB300FF0019FF1900FF\
0099FF00CCFF00F3FF00F3FF0099FF00FFD900F3FF00FF8C00FF7300FF5900FF4C
00FF4C00FF5900FF8000FF4000FF0C00FF000CFF0019FF0019FF0019FF0026FF0026FF0026FF00\
33FF0033FF0033FF0033FF003FFF003FFF003FFF004CFF004CFF004CFF0059FF00
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00\
59FF004CFF0033FF0000FF4C33FF003FFF003FFF003FFF0033FF0000FF0C00FF00
26FF003FFF0059FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF0099FF0099FF0099FF008CFF0073FF0080FF0080FF0073FF0066FF0073FF00\
66FF0066FF0059FF004CFF003FFF000CFF0000FF000CFF0000FF0000FF0026FF00
33FF0026FF0033FF0026FF0026FF0000FF0C00FFCC00FF190CFF000CFF0000FF0C00FF330CFF00\
19FF0019FF0019FF0019FF0019FF0019FF000CFF0000FF0000FF8000FF9900FF4C
00FF4000FF4000FFA600FF8000FF8C00FFB300FFF300A6FF0033FF7300FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000019FF0073FF\
008CFF00CCFF00FFF300FFE600FFD900FFBF00CCFF00FFBF00FF9900FF7300FF73
00FF8C00FF6600FF3300FF1900FF0C00FF000CFF0019FF0019FF0026FF0026FF0026FF0033FF00\
33FF0033FF0033FF003FFF003FFF003FFF004CFF004CFF004CFF0059FF0059FF00
59FF0059FF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF00\
59FF004CFF003FFF0000FF403FFF004CFF004CFF004CFF0033FF0000FF0000FF33
00FF1926FF0059FF0066FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0059FF0059FF0066FF0059FF0000FF734CFF00\
3FFF004CFF003FFF0000FF2619FF0000FF4C19FF0033FF0033FF0000FF1933FF00
3FFF003FFF003FFF003FFF0033FF0019FF000CFF0000FFCC00FF3300FF6600FF4000FF4000FF0C\
00FF000CFF0019FF0019FF0019FF000CFF000CFF0000FF0C00FF2600FF8C00FF66
00FF4C00FF6600FF8C00FFB300FFB30099FF00FFFF00A6FF004CFF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000003300FF004CFF\
00BFFF00E6FF00FFF300FFD900FFB300FFA600FFA600FFD900FFA600FFA600FFD9
00FF9900FF5900FF3300FF1900FF0C00FF000CFF0019FF0019FF0026FF0026FF0033FF0033FF00\
33FF0033FF003FFF003FFF003FFF004CFF004CFF004CFF004CFF0059FF0059FF00
59FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0059FF004CFF003FFF0059FF0059FF0059FF0059FF004CFF003FFF0026FF00
00FF003FFF0059FF0066FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF0099FF008CFF0080FF0080FF0073FF0073FF0059FF0000FF6600FF0C33FF0000FF3300FF00\
0CFF0000FF4C00FF0C0CFF0000FF0C19FF0033FF003FFF003FFF0033FF004CFF00
4CFF004CFF004CFF003FFF003FFF0033FF0019FF0000FF8000FF0000FF1900FF1900FF4000FFCC\
00FF0C0CFF000CFF000CFF000CFF000CFF0000FF0000FF4000FF4C00FFCC00FFD9
00FF7300FF7300FF990066FF00FFD900D9FF00CCFF0073FF0026FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000008000FF0073FF\
00B3FF0066FF00FFFF00F3FF00FFB300FF9900FF8C00FF8C00FF8000FF6600FF73
00FFBF00FFB300FF4C00FF3300FF1900FF000CFF0019FF0019FF0026FF0026FF0033FF0033FF00\
33FF003FFF003FFF003FFF004CFF004CFF004CFF004CFF0059FF0059FF0059FF00
59FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0066FF0059FF0059FF0059FF0066FF0059FF0059FF0059FF004CFF003FFF00
00FF0C3FFF0059FF0066FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF0099FF0080FF0059FF0000FF0033FF003FFF0000FF2633FF000CFF0000FF003FFF003FFF00\
4CFF0059FF004CFF004CFF003FFF000CFF004CFF004CFF0059FF0059FF0059FF00
59FF004CFF004CFF004CFF004CFF003FFF0019FF0019FF0019FF000CFF0000FF000C00FF00FF33\
00FF0C00FF0000FF000CFF0000FF0000FF0000FF0C00FF2600FF3300FF4C00FF66
00FFD900FF9900FFD900F3FF0099FF0099FF0066FF0019FF5900FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000004C00FF0026FF\
0059FF0059FF00BFFF00BFFF00FFBF00FF9900FF8000FF7300FF6600FF5900FF59
00FF5900FFA600FF7300FF9900FF4000FF2600FF0C0CFF0019FF0026FF0026FF0033FF0033FF00\
33FF003FFF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF00
59FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF004CFF00
00FF0C0CFF004CFF0059FF0066FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF0099FF008CFF0080FF0066FF0026FF004CFF0059FF0059FF0000FF0059FF0066FF00\
66FF0066FF0066FF0066FF0059FF0000FF3359FF0059FF0059FF0059FF0059FF00
59FF0059FF0059FF004CFF004CFF004CFF003FFF0033FF0026FF0019FF0000FF0000FFBF00FF4C\
00FF3300FF0C00FF0000FF0000FF0000FF0C00FF0C00FF1900FF3300FF4000FF66
00FFF300F3FF00B3FF0026FF0000003F00FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000008C00FF0C00FF\
0073FF00BFFF00F3FF00FFE600FFBF00FF9900FF8000FF7300FF5900FF4C00FF4C
00FF4C00FF4C00FF9900FF3300FF2600FF2600FF0C0CFF0019FF0026FF0026FF0033FF0033FF00\
33FF003FFF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF00
33FF0000FF0033FF004CFF0066FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF0099FF0099FF008CFF0080FF0026FF0066FF0073FF0073FF004CFF0073FF0073FF00\
73FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
59FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0026FF0000FF4C00FF0C00FF40\
00FF9900FF2600FF1900FF0C00FF0C00FF1900FF1900FF2600FF3300FF4C00FF66
00FF9900FFE60059FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000009900FF0C00FF\
0026FF0073FF3300FF00FFE600FFE600FFA600FF9900FFB300FF5900FF4C00FF40
00FF3300FF3300FF3300FF1900FF0C00FF000CFF0019FF0019FF0026FF0026FF0033FF0033FF00\
33FF003FFF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF00
66FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0059FF00
3FFF0026FF0000FF194CFF0059FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF008CFF0066FF0080FF0080FF0080FF0080FF0080FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF0033FF0019FF000CFF0000FF19\
00FF4000FF5900FF8C00FF2600FF2600FF4000FF3300FF3300FF4000FF590059FF
00FFBF00A6FF0019FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000C000FF\
0000000000000099FF00D9FF00E6FF00FFCC00E6FF00FF8000FF5900FF4C00FF33
00FF3300FF2600FF1900FF0C00FF0000FF000CFF0019FF0019FF0026FF0026FF0033FF0033FF00\
33FF003FFF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0066FF00
66FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF00
59FF003FFF0000FF8C00FF1926FF0059FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF00
66FF0066FF0066FF0059FF0059FF0059FF004CFF003FFF003FFF0033FF0019FF0000FF0C00FF33\
00FF6600FF4000FF4000FF6600FF7300FF7300FF6600FF4C00FF4C00FF6600FF99
0073FFD900FF000000000000E600FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000CC00FF0066FF00E6FF00FFE600FFBF00FFBF00FFBF00FF8000FF4C00FF33
00FF2600FF2600FF1900FF0C00FF000CFF000CFF0019FF0019FF0026FF0026FF0026FF0033FF00\
33FF0033FF003FFF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0066FF00
66FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00
66FF0026FF004CFF003FFF0033FF0066FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF00\
80FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF00
66FF0066FF0066FF0066FF0059FF0059FF004CFF003FFF0033FF0026FF0019FF0000FF0C00FF73\
00FF3300FF1900FF0C00FF1900FF7300FF4C0019FF00FF6600FF5900FF7300FF8C
00CCFF0000000026FF3300FF3F00FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000033FF00CCFF00FFE600FFA600FF9900FFA600FF6600FF4C00FF33
00FF2600FF2600FF1900FF0C00FF0000FF000CFF0019FF0019FF0019FF0026FF0026FF0026FF00\
33FF0033FF0033FF0033FF003FFF003FFF004CFF0059FF0059FF0059FF0066FF00
66FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF00
73FF0066FF0066FF0059FF0026FF0066FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00\
8CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF00
73FF0066FF0066FF0066FF0059FF0059FF004CFF003FFF0019FF0000FF0C00FFF300FF5900FF33\
00FF0000FF0000FF0000FF0C00FF1900FF3300FF5900FFFF00FFCC00FFE600FFB3
00F3FF00B3FF00A6FF0073FF0026FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000080FF00F3FF00FFCC00FF8C00FF7300FF5900FF4C00FF40
00FF3300FF2600FF2600FF1900FF0C00FF000CFF000CFF0019FF0019FF0019FF0026FF0026FF00\
26FF0026FF0026FF0026FF0019FF0033FF003FFF004CFF0059FF0059FF0066FF00
66FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0073FF0073FF0066FF003FFF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00\
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00
73FF0066FF0066FF0066FF0059FF0059FF004CFF0026FF0000FF5900FF260CFF0019FF000CFF00\
0CFF000CFF000CFF0000FF0000FF0C00FF2600FF5900FF7300FF5900FF7300FFFF
00FFB300FFD900FFFF00CCFF0080FF000CFF6600FFF300FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000008C00FF7300FF004CFF00FFE600FFA600FF8C00FF8000FF6600FF4C00FF40
00FF4000FF3300FF4000FFD900FF1900FF000CFF000CFF000CFF0019FF0019FF0019FF0019FF00\
19FF0019FF000CFF000CFF0000FF4C00FF0C19FF004CFF0059FF0059FF0066FF00
66FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF00\
8CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00
73FF0073FF0066FF0066FF0066FF0059FF004CFF0033FF0000FF9926FF0026FF0026FF0026FF00\
19FF0019FF000CFF000CFF0000FF0C00BFFF00FF4000FF4000FF4C00FF6600FF80
00FF8C00FFE60059FF00BFFF0099FF0066FF4C00FFCC00FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
E600FF2600FF0066FF00E6FF0000FF00FFBF00FFBF00FFA600FF7300FF5900FF4C
00FF4C00FF6600FF9900FF3300FF1900FF0C00FF000CFF000CFF000CFF000CFF000CFF000CFF00\
0CFF0000FF0000FF1900FFB300FF0033FF003FFF004CFF0059FF0059FF0066FF00
66FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00\
8CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF00
73FF0073FF0066FF0066FF0066FF0059FF004CFF004CFF003FFF0033FF0033FF0033FF0026FF00\
26FF0019FF0019FF000CFF0000FF0000FF1900FF2600FF3300FF4000FF4C00FF73
00FF8C00FFA600FFE600FFFF00CCFF0059FF1900FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000C000FFA600FF0026FF\
004CFF00A6FF00D9FF00FFF300FFE600FFD900FFFF00FFB300FF8000FF6600FF66
00FFCC00FFE600FF4C00FF2600FF1900FF0C00FF0000FF0000FF0000FF0000FF0000FF0C00FF59\
00FF4C00FF8000FF0C19FF0026FF003FFF004CFF0059FF0059FF0059FF0066FF00
66FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00\
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF00
73FF0073FF0066FF0066FF0066FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0033FF00\
26FF0026FF0019FF000CFF0000FF0000FF0C00FF1900FF2600FF4000FF9900FFA6
00FFA600FFB300FFCC00FFF300B3FF0019FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000A600FF0000FF5900FF\
0099FF0026FF00F3FF00FFE600FFBF00FFB300FFB300FFFF00CCFF00FFBF00FF99
00FFCC00FF7300FF4C00FF3300FF2600FF1900FF0C00FF0C00FF0C00FF0C00FF1900FF194C00FF\
00FF190CFF0019FF0026FF0033FF003FFF004CFF0059FF0059FF0059FF0066FF00
66FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00\
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF00
73FF0073FF0066FF0066FF0066FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0033FF00\
26FF0026FF0019FF000CFF0000FF0000FF1900FF2600FF3300FF4000FF5900FF80
00FFE600FFF300B3FF00F3FF00CCFFB300FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF0080FF\
00BFFF00CCFF00B3FF00FFF300FFB300FF9900FF9900FFA600FF8C00FF8000FF80
00FF80008CFF00FF8000FF5900FF3300FF4C00FF2600FF1900FF1900FF1900FF3300FF8000FF73\
00FF3319FF0026FF0033FF003FFF003FFF004CFF0059FF0059FF0059FF0066FF00
66FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00\
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF00
73FF0073FF0066FF0066FF0066FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0033FF00\
26FF0019FF000CFF0000FF2600FF1900FF4000FF4000FF4000FF4000FF5900FFE6
00FFB300FFB300FFE600D9FF0073FF0026FF1900FFE600FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000CFF0026FF\
0033FF00FFFF00FFFF0040FF00FFB300FF8C00FF8000FF8000FF7300FF6600FF66
00FF6600FF7300FFA600FF6600FF7300FFBF00FF4C00FF3300FF3300FF5900FF6600FF4C00FF19\
00FF0019FF0026FF0033FF003FFF003FFF004CFF0059FF0059FF0059FF0066FF00
66FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00\
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF00
73FF0073FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0033FF00\
26FF0019FF000CFF0000FF0C00FF4000BFFF00FFE600FF4C00FF4C00FF5900FF73
00FF8C00FFA600FFCC00FFF300D9FF0099FF0040FF6600FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000003300FF0099FF\
008CFF00FFFF00FFD900FFBF00FFA600FF8C00FF8000FF7300FF6600FF5900FF59
00FF4C00FF5900FFA600FFBF00FF7300FF4C00FF6600FF4C00FF8000FF5900FF7300FF4000FF26\
00FF000CFF0019FF0033FF0033FF003FFF004CFF004CFF0059FF0059FF0066FF00
66FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00\
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF00
73FF0073FF0066FF0066FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0033FF0026FF00\
26FF0019FF000CFF0000FF0000FF1900FF3300FF8C00FF7300FF6600FF7300FF80
00FF8C00E6FF00FFE600FFF3004CFF008CFF0040FF3300FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000F300FF7300FF000CFF00A6FF\
00D9FF00FFF300FFD900FFBF00FF9900FF8C00FF8000FF7300FF5900FF4C00FF4C
00FF4C00FF4000FF4C00FF5900FF4C00FF3300FF2600FF2600FF2600FF2600FF3300FFA600FF99\
00FF1900FF1900FF1926FF0033FF0033FF003FFF004CFF0059FF0059FF0059FF00
66FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00\
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF00
73FF0066FF0066FF0059FF0059FF004CFF004CFF003FFF0019FF0026FF0026FF0026FF0026FF00\
26FF0019FF000CFF0000FF0000FF0C00FF3300FF7300FFB300FFB300FFA600FF99
00FF9900FFBF0099FF00E6FF00B3FF0026FF0C00FF9900FFCC00FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000E600FF3300FF0019FF0080FF008CFF\
00BFFF00E6FF00F3FF00FFBF00FFA600FF9900FF9900FFB300FF5900FF4C00FF40
00FF4000FF3300FF3300FF4000FFFF00FF2600FF1900FF0C00FF0C00FF0C00FF1900FF4000FF4C\
00FFA600FF3300FF0019FF0026FF000CFF0033FF003FFF004CFF0059FF0059FF00
66FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00\
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF00
73FF0066FF0059FF004CFF004CFF003FFF003FFF0033FF000CFF0000FF0019FF0019FF0019FF00\
19FF0019FF000CFF0000FF0000FF6600FF6600FFBF00FF5900FF6600FF9900FFD9
00FFB300FFCC00FFF33F00FF0026FF0019FFCC00FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000008000FF1900FF0059FF0099FF00BFFF\
00CCFF00D9FF00BFFF00FFE600FFBF00FFF300FFA600FF7300FF5900FF4C00FF40
00FF3300FF3300FF2600FF2600FF2600FF1900FF0C00FF0C00FF0C00FF0000FF0C00FF0C00FF19\
00FF3300FF5900FF0C00FF0000FF0000FF5926FF003FFF003FFF004CFF004CFF00
59FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00\
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF00
66FF004CFF0033FF000CFF000CFF0026FF0026FF0026FF000CFF0000FF3300FF000CFF000CFF00\
0CFF000CFF000CFF0000FF0000FF1900FF2600FF3300FF4000FF5900FF9900FFE6
00CCFF00FFF300CCFF0026FF000000D900FF000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000B300FF0026FF0073FF00B3FF00CCFF\
00F3FF00FFFF00F3FF00FFF300FFE600E6FF00FFBF00FF8000FF6600FF4C00FF40
00FF3300FF2600FF2600FF1900FF1900FF0C00FF0C00FF0000FF0000FF0000FF0000FF0000FF0C\
00FF2600FF6600FF3300FF5900FF4000FF4000FF0C26FF0033FF0033FF0033FF00
4CFF0059FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00\
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF00
66FF0059FF003FFF0033FF0026FF0019FF0000FF4C00FF0C00FF8000FF4C00FF5900FF0C00FF00\
0CFF0000FF0000FF0000FF0C00FF1900FF2600FF3300FF4000FF5900FF8000FF99
00FFD900CCFF00A6FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000005900FF0000FF0026FF0000FF008CFF00B3FF\
00F3FF00FFE600FFD900FFCC00FFB300FFB300A6FF00F3FF00FF9900FFA600FF40
00FF3300FF2600FF2600FF1900FF0C00FF0C00FF0000FF000CFF000CFF000CFF000CFF0000FF00\
00FF8C00FF1900FF8000FF0C0CFF000CFF000CFF000CFF0000FF8000FF9900FF4C
00FF190CFF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF00
73FF0066FF0059FF004CFF004CFF003FFF0026FF0000FF0C00FF0000FF0C00FF6600FF1900FF0C\
00FF0000FF0000FF0C00FF0C00FF1900FF2600FF3300FF7300FF7300FF8000FFD9
00FFD900F3FF008CFF2600FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000B300FF8000FF1900FF004CFF0073FF0099FF0033FF\
0066FF00FFE600FFD900FFBF00FFA600FF9900FF9900FF9900FF6600FF4C00FF40
00FF3300FF2600FF2600FF1900FF0C00FF0000FF000CFF000CFF000CFF000CFF0019FF000CFF00\
0CFF000CFF0000FF190CFF0026FF0026FF0033FF0033FF0033FF0033FF0026FF00
4CFF0059FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00\
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF00
73FF0066FF0066FF0059FF0059FF004CFF0033FF0026FF0026FF0000FF0000FF4C00FF8000FF33\
00FF1900FF1900FF1900FF3300FF3300FF3300FF4000FF4C00FFA600FFB300CCFF
00E6FF008CFF0066FF0C00FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000CC00FF3F00FF0000FF0040FF0066FF00A6FF00CCFF\
00F3FF00FFF300FFF300FFE600FFA600FF8C00FF8000FF7300FF5900FF4C00FF40
00FF3300FF3300FF2600FF1900FF1900FF0000FF000CFF000CFF0019FF0019FF0019FF0019FF00\
19FF0019FF0000FF0000FF0C26FF0033FF003FFF003FFF004CFF004CFF004CFF00
59FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF00
73FF0066FF0066FF0066FF0059FF004CFF004CFF003FFF0033FF000CFF0000FF0000FF2600FF80\
00FF4C00FF6600FF4C00FF4C00FF6600FF4C00FF4C00FF5900FF9900FFD900F3FF
0019FF004CFF0040FF9900FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000C000FFB300FF1900FF4C00FF0019FF0073FF00B3FF\
0099FF00E6FF00A6FF00FFD900FFBF00FF8C00FF8000FF7300FF6600FF4C00FF40
00FF4000FF3300FF3300FF3300FF3300FF0C00FF000CFF0019FF0019FF0019FF0026FF0026FF00\
26FF0026FF0026FF0019FF0033FF003FFF004CFF004CFF004CFF0059FF0059FF00
66FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF00
73FF0066FF0066FF0066FF0059FF0059FF004CFF003FFF0033FF0026FF000CFF0000FF2600FF8C\
00FF3300FF2600FF3300FF5900FFA600FF8000FF6600FF7300FF8C00FFF36600FF
B300FF7300FF3300FFD900FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000003300FF0C00FF0059FF0066FF\
0080FF00B3FF00F3FF00FFFF00FFB300FF9900FF8C00FF8C00FFB300FF5900FF4C
00FF4C00FF5900FF5900FFB300FF3300FF0C0CFF000CFF0019FF0019FF0026FF0026FF0026FF00\
33FF0033FF0033FF0033FF003FFF004CFF004CFF0059FF0059FF0059FF0066FF00
66FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF00
73FF0073FF0066FF0066FF0059FF0059FF004CFF003FFF0033FF0026FF000CFF0000FFE600FF26\
00FF0C00FF0C00FF0C00FF1900FF4000FF8C00FF8C00FFBF00FFBF00F3FF0019FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000F300FF000000000CFF0066FF\
0099FF00CCFF00FFFF00FFD900FFBF00FFA600FFA6008CFF00FF8C00FF6600FF66
00FF6600FF8000FF6600FF3300FF1900FF0C00FF000CFF0019FF0019FF0026FF0026FF0033FF00\
33FF0033FF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0066FF0066FF00
66FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00
73FF0073FF0066FF0066FF0059FF0059FF004CFF003FFF0026FF0000FF0000FF8000FF2600FF00\
0CFF000CFF0000FF0000FF0C00FF4000FFCC00FF4C00FF6600FF9900FFCC00D9FF
004CFF5900FF000000000000000000000000000000000000000000000000000000000000000000\
000000CC00FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000005900FF0019FF\
0040FF0073FF00B3FF00FFF300B3FF00FFCC00FFCC00FFF300FFCC00FF9900FF8C
00FF9900FFB300FF6600FF4000FF2600FF0C00FF000CFF0019FF0019FF0026FF0026FF0033FF00\
33FF003FFF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0066FF0066FF00
66FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00
73FF0066FF0066FF0066FF0059FF0059FF004CFF0026FF0000FF5900FF0C19FF0019FF0019FF00\
19FF000CFF000CFF0000FF0C00FF3300FF3300FF3300FF5900FF8000FFB300FFF3
00A6FF1900FF000000000000A600FFCC00FF000000F300FF000000000000000000000000000000\
5900FF3F00FF9900FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000B300FF\
8000FF0000000040FF0073FF00D9FF0059FF00FFCC00FFBF00FFD900FFBF00FF8C
00FF7300FF8000FFA600FF6600FF4C00FF2600FF0C00FF0019FF0019FF0026FF0026FF0033FF00\
33FF003FFF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0066FF0066FF00
66FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
99FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00
73FF0066FF0066FF0066FF0059FF0059FF003FFF0026FF0019FF0026FF0026FF0026FF0026FF00\
19FF0019FF000CFF0000FF0000FF0C00FF1900FF3300FF6600FFCC00FFCC00FFF3
00A6FF0000000000004C00FF0019FF0019FF1900FF4C00FF0000000000000000003F00FF0000FF\
0C00FF3F00FF8C00FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000059FF00CCFF00FFFF00FFD900FFBF00FFA600FF9900FF8C00FF66
00FF5900FF5900FF6600FFA600FF5900FF4000FF4C00FF190CFF0019FF0026FF0033FF0033FF00\
33FF003FFF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0066FF0066FF00
66FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF00\
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00
99FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF00
73FF0066FF0066FF0066FF0059FF0059FF004CFF003FFF003FFF0033FF0033FF0033FF0026FF00\
26FF0019FF0019FF000CFF0000FF0C00FF2600FF3300FF4C00FF8C00FFA600FFFF
0C00FF0000000000002600FF1900FF004CFF0073FF0019FF4C00FF000000000000000CFF0059FF\
0019FF0066FF0026FF0C00FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000005900FF0026FF004CFF004CFF00FFE600FFF300FFA600FF8C00FF7300FF66
00FF4C00FF4C00FF4000FF4000FF5900FF1900FF0C0CFF0019FF0019FF0026FF0026FF0033FF00\
33FF003FFF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0066FF0066FF00
66FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00
8CFF008CFF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF00
66FF0066FF0066FF0066FF0059FF0059FF004CFF004CFF003FFF003FFF003FFF0033FF0033FF00\
26FF0026FF0019FF0000FF0000FF1900CCFF00FF5900FF5900FF8000FFA600D9FF
000CFF000000B300FF0000FF00BFFF0026FF00CCFF0099FF00A6FF0059FF0033FF008CFF0099FF\
00A6FF0099FF008CFF004CFF0026FF3300FFA600FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
A600FF1900FF0059FF00A6FF00D9FF00F3FF00FFFF00FFE600FF9900FF8000FF73
00FF4C00FF4000FF3300FF2600FF1900FF0C00FF000CFF0019FF0019FF0026FF0026FF0033FF00\
33FF0033FF003FFF003FFF003FFF004CFF004CFF0059FF0059FF0066FF0066FF00
66FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
8CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF00
8CFF0080FF0026FF0059FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
66FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0033FF00\
26FF0026FF0019FF0000FF4000FF1900FF4000FF9900FFD900FFA600BFFF0073FF
0000002600FF0099FF00B3FF00F3FF00FFF300FFFF00D9FF00FFFF00D9FF0099FF00BFFF0033FF\
00D9FF00CCFF0080FF0099FF0073FF4C00FF7300FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000008C00FF000CFF0073FF0059FF0033FF00FFFF00FFCC00FFA600FFB300FF80
00FF5900FF4000FF3300FF2600FF1900FF0C00FF000CFF0019FF0019FF0026FF0026FF0026FF00\
33FF0033FF0033FF0033FF003FFF003FFF004CFF0059FF0059FF0066FF0066FF00
66FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00
8CFF0080FF0073FF0000FF8C4CFF004CFF0059FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF00
66FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0033FF00\
33FF0026FF0019FF000CFF0000FF0000FF1900FF5900FF4C00FF5900FF8000D9FF
9900FF0073FF00CCFF00FFFF00D9FF00FFCC00D9FF00FFF300FFD900FFF300A6FF00FFF300FFE6\
00FFFF00CCFF00D9FF00CCFF00A6FF0059FF9900FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000CFF0073FF00B3FF00A6FF00FFFF00D9FF00FFCC00F3FF
00FF8000FF4000FF3300FF2600FF1900FF0C00FF000CFF000CFF0019FF0019FF0026FF0026FF00\
26FF0026FF0026FF0026FF000CFF0033FF003FFF004CFF0059FF0059FF0066FF00
66FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00\
80FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00
8CFF0080FF0073FF0033FF0000E6FF00FF4C4CFF0066FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF00
66FF0066FF0066FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0033FF00\
33FF0026FF0019FF0019FF000CFF0000FF3300FF3300FF3300FF400099FF00FFBF
0099FF00FFF300FFF300FFCC00FFB300FFA600FFBF00FFA600FFB300FFE600FFD900D9FF00FFBF\
00BFFF00BFFF00FFF300E6FF0099FF0066FF000000000000000000000000000000
F300FF8000FF9900FFD900FF000000000000000000A600FFB300FFF300FF0000006600FF6600FF\
8C00FFD900FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000007300FF3F00FF004CFF0040FF0080FF00FFFF00FFB300FF80
00FF5900FF4000FF3300FF3300FF2600FF4000FF0C00FF000CFF0019FF0019FF0019FF0019FF00\
19FF0019FF0019FF0000FF0000FF3300FF0C33FF004CFF0059FF0059FF0066FF00
66FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00\
80FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00
8CFF0080FF0073FF0059FF004CFF000026FF33FF003FFF0066FF0066FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF0033FF0033FF00\
26FF0026FF0019FF0019FF000CFF0000FF0000FF0C00FF2600FF3300FF4C00FF73
00FFB300FF9900FF8C00FFD900FFD900FF8C00FF8C00FF9900FFB300F3FF00FFB300FFA600FFA6\
00FFB300FFD900FFCC00FFE600F3FF00A6FF0019FF000000000000000000000000
3F00FF2600FF0019FF000CFF3300FF000000E600FF0000FF3F00FF1900FF0019FF0000001900FF\
CC00FFA600FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000008000FF0000000000000000008C00FF00FFCC00FF8C
00FFB300FF4C00FF4C00FF4C00FF7300FF4000FF0C00FF000CFF000CFF000CFF000CFF000CFF00\
0CFF000CFF0000FF1900FF7300FF1926FF003FFF004CFF0059FF0059FF0066FF00
66FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF0099FF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF00
80FF0080FF0073FF0066FF0059FF0033FF0000FF003FFF0059FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF0033FF0033FF0026FF00\
26FF0026FF0019FF000CFF000CFF0000FF0000FF0C00FF2600FF3300FF4C00FF66
00FF9900FFD900FF6600D9FF00FF8000FF7300FF7300FF9900FFF300FFBF00FFE600FF8C00FF8C\
00FF9900FFA600FFBF00A6FF0C00FF00F3FF0099FF0059FF000000CC00FF3F00FF
0040FF3F00FF008CFF0073FF0040FF0033FF0040FF004CFF0066FF0C00FF0059FF0040FF0019FF\
2600FF8C00FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F300FF0000000000000000003300FF0033FF00CCFF00FFF300F3FF
00FF8C00FF6600FF6600FF9900FF4C00FF2600FF0C00FF0C00FF0000FF0000FF0000FF0000FF0C\
00FF2600FF5900FF2600FF0026FF0033FF003FFF004CFF0059FF0059FF0059FF00
66FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00
80FF0080FF0073FF0073FF0066FF004CFF0033FF0019FF004CFF0059FF0059FF0066FF0066FF00\
59FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF0033FF0026FF0026FF0026FF00\
19FF0019FF0019FF000CFF000CFF0000FF0000FF0C00FF7300FF6600FF7300FFE6
00FF5900FF4000FF4000FF4C00FF4C00FF5900FF6600FF8C00FFB300FF8000FFCC00FF7300FF73\
00FF8C00FFA600FFCC00FFD900FFD900FFD900FFFF0099FFC000FF1900FF0059FF
0066FF00CCFF000CFF00B3FF00BFFF0080FF00B3FF00B3FF0080FF008CFF008CFF0033FF0026FF\
0000FF5900FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000009900FF3F00FF5900FF1900FF0C00FF00CCFF00A6FF00FFB300FFA6
00FFCC00FFB300FFD900FF8C00FF4C00FF3300FF1900FF0C00FF0C00FF0000FF0C00FF1900FF26\
00FF7300FF0C0CFF0026FF0033FF003FFF004CFF004CFF0059FF0059FF0059FF00
66FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
8CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00
80FF0080FF0073FF0073FF0066FF0059FF004CFF0000FF1933FF004CFF004CFF0059FF0059FF00\
4CFF0033FF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0059FF0059FF00
59FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF0026FF0000FF0C0CFF0019FF00\
0CFF000CFF000CFF0000FF0000FF0000FF0C00FF1900FF3300FFCC00FF5900FF4C
00FF5900FF3300FF3300FF3300FF4000FF4C00FF6600FF8C00FF7300FF6600FF6600FF5900FF66\
00FFB30066FF00FFD900FFB300FF9900FFBF00FFFF00FFF300CCFF00D9FF00E6FF
0099FF00FFFF00F3FF00FFFF00D9FF00CCFF00D9FF008CFF00A6FF00BFFF00B3FF008CFF0066FF\
0000004C00FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000004C00FF0000FF004CFF0040FF0040FF0059FF00FFE600FFBF00FF9900FF80
00FF7300FF6600FF6600FFE600FFD900FF4C00FF4000FF3300FF1900FF1900FF1900FF4000FF8C\
00FFE600FF1919FF0026FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF00
59FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF0073FF0059FF00
80FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0073FF0073FF0066FF0059FF003FFF0000FF1900FF0000FF333FFF004CFF004CFF00\
3FFF0000FF0033FF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF0026FF000CFF0000FF4000FF0C\
00FF0C00FF1900FF0000FF0C00FF0C00FF1900FF3300FFB300FF6600FF1900FF26
00FF7300FF1900FF1900FF2600FF4000FF5900FF7300F3FF00FF6600FF4C00FF4C00FF4C00FF59\
00D9FF00FF8000FF8C00FF8C00FF8C00FF9900FFA600FFCC00BFFF00FFE600FFE6
00FFFF00FFD900FFD900FFF300CCFF00F3FF00FFF300E6FF00F3FF00E6FF00BFFF00A6FF004CFF\
0033FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000002600FF0033FF0026FF008CFF00A6FF00F3FF00FFFF00FFB300FF8C00FF73
00FF6600FF5900FF5900FF5900FFD900FF8000FFCC00FF7300FF4000FF3300FF5900FF8000FF40\
00FF1900FF0019FF0026FF0033FF003FFF003FFF004CFF004CFF004CFF0059FF00
59FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
73FF0073FF0073FF0073FF0073FF0066FF003FFF0066FF0073FF0066FF0033FF00
73FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00
80FF0073FF0073FF0073FF0066FF0059FF004CFF0033FF0000FF0000FF0033FF003FFF003FFF00\
33FF0000FF5933FF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF004CFF004CFF004CFF004CFF003FFF003FFF0033FF0026FF0019FF0000FF0C00FF8C\
00FF6600FF4C00FF2600FF3300FF3300FF3300FF9900FF1900FF0C00FF0C00FF0C
00FF2600FF0C00FF0C00FF2600FF6600FFE600FF8000FFD900FF6600FF4000FF4000FF4000FF4C\
00FF5900FF5900FF7300FF7300FF7300FF8C00FFA600FFBF00FFCC00FFA600FFB3
00FFB300FFB300FFCC00D9FF00A6FF00BFFF00FFD900FFE600FFF300E6FF0099FF0000FF0099FF\
0073FF3300FF8C00FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000003300FF0073FF00B3FF00D9FF00FFFF00FFE600FFFF00FFCC00D9FF00BFFF
00FF5900FF4C00FF4000FF4C00FF590099FF00FF4000FFF300FF3300FF5900FF4C00FF9900FF40\
00FF1900FF000CFF0019FF0026FF0033FF003FFF003FFF004CFF004CFF0059FF00
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0026FF0059FF0066FF00\
66FF0066FF0066FF0066FF0059FF0059FF0000FF0C59FF0059FF003FFF0000FFB3
3FFF0000FF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF00
73FF0073FF0073FF0066FF0066FF0059FF004CFF0033FF0000FF9900FF0019FF0000FF0C26FF00\
0CFF000CFF0033FF003FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00
4CFF004CFF004CFF004CFF004CFF003FFF003FFF0033FF0033FF0026FF000CFF0000FF0C00FF4C\
00FF1900FF5900FF6600FFB300FF5900FF5900FF4000FF0C00FF0000FF000CFF00
0CFF0000FF0000FF0000FF1900FF4C00FF4000FF4000FF4C00FF5900FF3300FF3300FF3300FF33\
00FF4000FF4C00FF4C00FF5900FF7300FF9900E6FF00E6FF00FFD900FF8C00FF8C
00FF8C00FFA600FFBF0073FF00FFBF00FFBF00FFBF00FFD900CCFF00B3FF00E6FF00CCFF00CCFF\
0073FF3300FF7300FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000C000FF\
4C00FF0019FF000CFF0066FF00E6FF00FFE600FFCC00FFB300FFCC00FFB300FF66
00FF4C00FF4000FF3300FF3300FF3300FFBF00FF2600FF1900FF1900FF1900FF2600FF3300FF8C\
00FF5900FF1900FF1900FF0C26FF0033FF0033FF003FFF003FFF004CFF004CFF00
4CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF0000FF003FFF004CFF00\
4CFF0059FF0059FF003FFF003FFF0033FF0000FF190CFF0033FF0000B3FF3FFF00
00FF4C00FF404CFF0026FF008CFF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF00
73FF0073FF0066FF0066FF0059FF004CFF004CFF0033FF0000FF0000FF5900FF6600FFB300FF33\
00FF4C00FF0026FF0033FF003FFF004CFF004CFF004CFF004CFF004CFF004CFF00
4CFF004CFF004CFF003FFF003FFF003FFF0033FF0033FF000CFF000CFF0000FF0000FF7300FF40\
00FF0000FF0000FFCC00FF0C00FF0C00FF4000FF4C00FF0C0CFF000CFF000CFF00
0CFF000CFF0000FF0000FF1900FF3300FF1900FF1900FF3300FF5900FF2600FF2600FF2600FF33\
00FF3300FF4000FF4C00FF5900FF6600FF8C00FFE600FF8C00FFB300FF8000FF73
00FF8C00FFB300F3FF00FFE600FFA600FFA600FFA600FFD900FFE600F3FF00FFF300FFFF0099FF\
0099FF004CFF5900FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000B300FF\
2600FF004CFF008CFF00A6FF0033FF00B3FF00FFCC00FFA600FFA600FFE600FF80
00FF4C00FF4000FF3300FF2600FF2600FF2600FF1900FF0C00FF0C00FF0C00FF0C00FF1900FF73\
00FF5900FF7300FF260CFF0019FF0026FF0026FF000CFF0033FF003FFF004CFF00
4CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF003FFF0019FF0019FF0026FF00\
00FF0033FF000CFF0000FF4C00FF7300FF5933FF0000FF0C00FF004CFF0066FF00
73FF0080FF0080FF0080FF008CFF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF00
73FF0066FF0066FF0059FF004CFF003FFF0033FF0019FF0000FF6619FF0019FF0000FF400CFF00\
00FF0000FF7300FF1926FF0033FF003FFF003FFF003FFF0026FF003FFF003FFF00
3FFF003FFF003FFF003FFF0033FF0033FF0026FF0019FF0000FF0000FF8000FF4C00FF260CFF00\
19FF0019FF0000FF800CFF0000FF0000FF5900FFB300FF000CFF0019FF0019FF00
19FF0019FF000CFF0000FF5900FF0000FF0000FF0000FF1900FF2600FF1900FF1900FF1900FF26\
00FF3300FF4000FF4C00FF5900FF6600FF9900FF8000FF6600FF6600FF6600FF66
00FF8C00FFCC00FFA600FFD900FF9900FF8C00FF9900FFA600FFB300FFFF00FFD900FFE600F3FF\
00B3FF0040FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
4C00FF6600FF0066FF00CCFF00FFFF004CFF00FFBF00FF8C00FF8000FF7300FF66
00FF4C00FF3300FF2600FF2600FF1900FF0C00FF0C00FF0C00FF0000FF0000FF0000FF0C00FF19\
00FF2600FF5900FFB300FF000CFF000CFF000CFF0000FF3326FF003FFF003FFF00
3FFF004CFF004CFF004CFF004CFF003FFF0033FF003FFF003FFF0026FF0000FF0000FF0000FF26\
26FF003FFF003FFF0026FF003FFF0019FF0059FF0059FF0059FF004CFF0073FF00
80FF008CFF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
8CFF008CFF008CFF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00\
80FF0080FF0080FF0080FF0080FF0073FF0059FF003FFF0066FF0066FF0066FF00
66FF0066FF0059FF0033FF0026FF0019FF0000FF0C00FF1926FF0033FF0033FF0033FF0026FF00\
19FF0000FF8000FF0026FF0033FF0033FF0033FF0026FF0000FFA626FF0033FF00
33FF0033FF0033FF0026FF0000FF2619FF0000FF0000FF1900FF8C00FF0000FF0000FF6619FF00\
26FF0026FF0026FF0026FF0019FF0000FF0000FF4C00FF0019FF0026FF0026FF00
26FF0026FF0019FF000CFF000CFF000CFF000CFF0000FF0000FF0C00FF0C00FF0C00FF1900FF26\
00FF3300FF4000FF5900FF6600FF8000FFF300FF6600FF5900FF4C00FF4C00FF4C
00FF8000FF8000FF7300FFCC00FF8000FF8000FF8C00FF8C00FFA600FFB300FFCC00FFE600FFFF\
00BFFF0040FF1900FF8C00FF5900FFA600FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
C000FF8000FF0019FF0019FF00FFF300FFCC00FFA600FF8C00FF8000FF6600FF4C
00FF4000FF3300FF2600FF1900FF1900FF0C00FF0000FF0000FF0000FF0000FF0000FF0000FF00\
00FF1900FF7300FF3300FF1900FF1900FF2600FF2600FF0C19FF0033FF0033FF00
3FFF003FFF003FFF003FFF003FFF0026FF0000FF6626FF0026FF0019FF0000FFFF26FF003FFF00\
4CFF0059FF0066FF0066FF0066FF0059FF0073FF0073FF0073FF0066FF0080FF00
8CFF0099FF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
8CFF008CFF0080FF0080FF0059FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0073FF0073FF0066FF0059FF0000FF004CFF0059FF0059FF00
59FF0059FF004CFF0026FF0000FF1900FF3300FF1919FF0033FF003FFF003FFF003FFF0033FF00\
26FF0000FF3300FF1900FF2619FF0026FF0019FF0000FF1900FF260CFF000CFF00
26FF0026FF0026FF0019FF0000FF0C00FF4C00FF0C19FF0026FF0026FF0026FF0000FF0C26FF00\
33FF0033FF0033FF0033FF0026FF000CFF0000FF0C19FF0026FF0026FF0026FF00
26FF0026FF0026FF0019FF0019FF0019FF000CFF000CFF0000FF0000FF0000FF0C00FF1900FF33\
00FF4C00FF6600FF8C00FF9900FF9900FFCC00FF6600FF4C00FF4000FF4000FF40
00FF6600FF4C00FF5900FF7300FF6600FF7300FF8000FF8C00FFA600FFB300FFCC0026FF008CFF\
00F3FF00D9FF0033FF0073FF3300FF6600FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
00000000000000000000A6FF00FFFF00FFFF00FFA600FF9900FF8C00FF8000FF4C
00FF4000FF3300FF2600FF2600FF1900FF0C00FF0000FF000CFF000CFF000CFF000CFF0000FF00\
00FF1900FF3300FF9900FF6600FFD900FF5900FF1900D9FF00FF0000FF0C26FF00
33FF0033FF0026FF0033FF0033FF0026FF0000FF1900FF0C00FF0000FF0C0CFF0033FF004CFF00\
59FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
80FF0080FF0080FF0073FF0026FF0019FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0066FF0066FF0059FF0033FF0026FF003FFF004CFF00
4CFF004CFF003FFF0026FF0000FF4C00F3FF00FF2626FF003FFF004CFF004CFF004CFF003FFF00\
00FF0C19FF0000FF0C00FFCC00FF0C00FF0C00FF3300D9FF00FFA600FF4000FF33
0CFF0019FF000CFF0000FF0C00FF4000FF0019FF0033FF0033FF003FFF003FFF003FFF003FFF00\
3FFF003FFF003FFF003FFF0033FF0000FF1900FF0C26FF0026FF0033FF0033FF00
33FF0033FF0026FF0026FF0026FF0019FF0019FF000CFF000CFF0000FF0000FF0C00FF1900FF33\
00FF4C00FFBF00FF7300F3FF00FF5900FF8C00FFE600FF4000FF3300FF3300FF33
00FF4000FF4000FF4C00FF5900FF5900FF6600FF8000FF9900FFB300FFBF00A6FF00FFD900FFD9\
00FFD900FFF300CCFF00B3FF0066FF6600FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
7300FF0C00FF0073FF00CCFF00D9FF0026FF00FFCC00B3FF00FFA600FF7300FF59
00FF4C00FF4000FF4000FF3300FF2600FF0C00FF000CFF000CFF000CFF0019FF0019FF000CFF00\
00FF0000FF0000FF3300FF3300FF0000FF000CFF0000FF2600FF4000FF4C0CFF00
19FF0019FF000CFF000CFF0019FF0000FF3300FF8000FF0C00FF4000FF0000FF1926FF004CFF00\
66FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
80FF0080FF0073FF0073FF0059FF0000FF1959FF0066FF0066FF0066FF003FFF0066FF0066FF00\
73FF0066FF0066FF004CFF0059FF0059FF004CFF0033FF0000FF190CFF0026FF00
3FFF003FFF0033FF0000FF0C00BFFF0CFF0000FFBF33FF004CFF0059FF0059FF0059FF004CFF00\
3FFF0033FF0026FF0000FF1900FF0019FF0000FF0000FF1900FF6600FF1900FF59
00FF2600FF2600FF2600FF3300FF2600FF0C26FF003FFF003FFF003FFF004CFF004CFF004CFF00\
4CFF004CFF004CFF003FFF0033FF0000FF1900FF0026FF0033FF0033FF0033FF00
33FF0033FF0033FF0026FF0026FF0019FF0019FF000CFF000CFF0000FF0000FF0C00FF0C00FF26\
00FF40008CFF00FF4C00FF4000FF3300FF4000FF6600FF3300FF2600FF2600FF26
00FF3300FF3300FF4000FF4C00FF5900FF6600FF8C00FFF300E6FF00FFE600FFFF00FFA600FFA6\
00FFBF00FFF300E6FF0066FF0073FF0019FFA600FF000000000000F300FFC000FF
A600FF000000000000CC00FFCC00FF000000000000000000000000000000000000000000000000\
0C00FF0059FF0073FF00CCFF00FFF300F3FF00FFD900FFE600FFBF00FF8000FF66
00FF5900FF6600FF9900FFBF00FF3300FF0C0CFF000CFF0019FF0019FF0019FF0019FF0019FF00\
19FF000CFF0000FF0C00FF0C0CFF0019FF0019FF0000FF0019FF0019FF0000FF19
00FF9900FF0C00FF3300FF4000FF0C00FF4000FFB319FF0019FF0026FF0033FF0026FF0000FF0C\
66FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
73FF0073FF0073FF0066FF0059FF000CFF003FFF004CFF0059FF0059FF0033FF004CFF004CFF00\
59FF0059FF004CFF0026FF003FFF003FFF0000FF6600FF5919FF0000FF000CFF00
19FF0019FF0000FF330CFF0033FF003FFF003FFF004CFF0059FF0059FF0066FF0059FF0059FF00\
4CFF003FFF0019FF0000FF4C26FF0033FF0033FF0019FF0000FF0C0CFF0019FF00
19FF0000FF0000FFD900FF0019FF0026FF0033FF003FFF004CFF004CFF004CFF004CFF004CFF00\
4CFF004CFF004CFF004CFF003FFF0019FF0000FF1933FF003FFF003FFF003FFF00
3FFF0033FF0033FF0026FF0026FF0019FF0019FF000CFF000CFF0000FF0000FF0C00FF1900FF26\
00FFFF00FF7300FF4000FF2600FF1900FF2600FFB300FF2600FF1900FF1900FF26
00FF2600FF3300FF4000FF4C00FF5900FF6600FF9900F3FF00FF8C00FF8C00FFCC00FF8C00FF99\
0099FF00FFD900E6FF00E6FF00BFFF7300FF3F00FF0000000000007300FF3300FF
0000FF5900FF3F00FF1900FFA600FFB300FF000000000000000000000000000000000000A600FF\
0000FF8000FF00BFFF00E6FF00FFE600FFCC00FFB300FFB30099FF00CCFF00FFBF
00F3FF00FFA600FF6600FF2600FF0C00FF000CFF000CFF0019FF0019FF0026FF0026FF0026FF00\
26FF0019FF0000FF0000FF4C19FF0026FF0033FF0033FF0033FF0033FF0026FF00
0CFF0000FF4C00FF0000FF2600FF7300FF190CFF0026FF0033FF003FFF004CFF0059FF0066FF00\
73FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
73FF0073FF0066FF0066FF004CFF0033FF0000FF0019FF0026FF0033FF0000FF2600FF0C00FF4C\
00FF0C0CFF0019FF0000FF3300FF800CFF0000FF0C19FF003FFF0033FF0000FF66
00FF0C00FF0000FF0C33FF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF00\
59FF004CFF0033FF000CFF0033FF003FFF003FFF0033FF0033FF0033FF0033FF00
26FF000CFF0000FF5900FF0C26FF0033FF003FFF004CFF004CFF004CFF0059FF0059FF0059FF00\
59FF0059FF0059FF004CFF004CFF000CFF003FFF003FFF004CFF003FFF003FFF00
3FFF003FFF0033FF0033FF0026FF0019FF0019FF000CFF0000FF0000FF0000FF0C00FF1900FF40\
00FF4C00FF2600FF1900FF0C00FF0C00FF1900FF6600FF1900FF0C00FF1900FF19
00FF2600FF4000FF4C00FF5900FF6600FF8C00FF9900FF7300FF6600FF7300FF9900FF8000FF80\
00FF9900FFB300FFD900F3FF0040FF0059FF2600FFE600FF0000000C00FF1900FF
0066FF0033FF0066FF0019FF0026FF3F00FF000000000000E600FF000000000000000000000000\
0000000059FF00A6FF00E6FF00FFF300FFFF00FFA600FF9900FF9900FF8C00FF73
00FF7300FFE600FF6600FF3300FF0C00FF000CFF0019FF0019FF0026FF0026FF0026FF0026FF00\
26FF0026FF0019FF0000FF4026FF0033FF0033FF003FFF003FFF003FFF0033FF00
26FF000CFF0026FF000CFF0000FF0000FFD919FF0026FF003FFF004CFF0059FF0059FF0066FF00\
73FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
66FF0066FF0059FF004CFF003FFF0026FF000CFF0019FF0000FF5900FF3326FF003FFF003FFF00\
59FF004CFF0033FF004CFF0000FF2600FF0C3FFF004CFF0059FF004CFF0026FF00
3FFF0026FF0000FF0C3FFF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0066FF00\
66FF004CFF0000FF1933FF004CFF004CFF004CFF004CFF004CFF003FFF003FFF00
26FF0019FF0000FF1900FF0026FF0033FF003FFF004CFF0059FF0059FF0059FF0059FF0059FF00\
59FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF004CFF004CFF004CFF00
3FFF003FFF0033FF0026FF0026FF0019FF000CFF0000FF0000FF0000FF0C00FF1900FF3300FF66\
00FF2600FF1900FF0C00FF0000FF0000FF0000FF0C00FF0C00FF0C00FF0C00FF19
00FF4000FF5900FF9900FF8000FFD900F3FF00FF8000FF5900FF5900FF5900FF6600FF6600FF80\
00FF9900FFB300FFD900FFFF00CCFF0059FF9900FF0000005900FF004CFF0073FF
00A6FF0080FF00A6FF0080FF0059FF7300FF0000005900FF2600FF5900FFB300FF000000000000\
4C00FF0066FF0099FF00A6FF0033FF00FFD900FFA600FF8C00FF7300FF6600FF59
00FF5900FF6600FFA600FF4C00FF2600FF0C0CFF0019FF0019FF0026FF0026FF0033FF0033FF00\
33FF0033FF0033FF0026FF0033FF003FFF003FFF003FFF003FFF003FFF003FFF00
3FFF0033FF0033FF0026FF0019FF0000FF2600FF0026FF0033FF004CFF0059FF0059FF0066FF00\
73FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
4CFF0059FF004CFF0033FF0000FF0000FF0C33FF003FFF003FFF000CFF004CFF0066FF0066FF00\
66FF0066FF0066FF0066FF0066FF003FFF004CFF0066FF0066FF0066FF0059FF00
59FF003FFF0019FF0033FF0059FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
66FF003FFF0000FF004CFF0059FF0059FF0059FF0059FF004CFF004CFF003FFF00
26FF000CFF0000FF2600FFCC00FF0C19FF004CFF004CFF0059FF0059FF0059FF0059FF0066FF00\
66FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF00
4CFF003FFF0033FF0019FF000CFF0000FF0000FF4C00FF0C00FF1900FF4C00FF4000FF6600FF59\
00FF1900FF0C00FF0000FF000CFF000CFF000CFF0000FF0000FF0000FF0000FF0C
00FF2600FF5900FF7300FFD900FF6600FFE600FF7300FF4C00FF4C00FF4C00FF4C00FF5900FF99\
00E6FF00FFD900FFE600CCFF0073FF0000000000007300FF0000FF008CFF00CCFF
00A6FF00BFFF00D9FF008CFF0099FF0019FF5900FF0033FF000CFF3300FF8000FFA600FF000000\
8000FF1900FF0099FF00E6FF00FFF300FFD900FFA600FF8C00FF7300FF6600FF4C
00FF4C00FF4C00FF6600FF4C00FF4C00FF5900FF0C19FF0026FF0026FF0033FF0033FF0033FF00\
33FF003FFF003FFF003FFF003FFF003FFF004CFF004CFF004CFF004CFF004CFF00
3FFF003FFF003FFF0033FF0026FF0000FF0C00FF1900FF0C0CFF0033FF004CFF0059FF0066FF00\
73FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
33FF003FFF003FFF0026FF0000FF6600FF734CFF0059FF0059FF004CFF004CFF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0059FF0059FF0073FF0073FF0073FF0073FF00
66FF0059FF0033FF004CFF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0073FF0073FF00\
73FF0059FF000CFF0059FF0066FF0066FF0066FF0059FF0059FF004CFF003FFF00
19FF0000FFCC00FF1919FF0026FF0033FF004CFF0059FF0059FF0059FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF004CFF00
4CFF003FFF0000FF3300FF3300FF3300FF2600FF7300FF4C00FF4000FFCC00FF4000FF4C00FF59\
00FF2600FF000CFF000CFF000CFF000CFF000CFF000CFF000CFF0000FF0000FF0C
00FF2600FF7300FF4000FF4000FF4000FF5900FF8000FF4000FF4000FF4000FF4000FF6600FF80\
00FF8000FFD900FFA600FFB300FFFF0040FF0019FF00A6FF004CFF00F3FF00FFF3
00D9FF00F3FF00FFF300FFFF00D9FF0080FF00A6FF00A6FF00A6FF0040FF0066FF5900FF9900FF\
000000000CFF0073FF0066FF00FFF300FFCC00FFA600FF9900FF9900FF6600FF4C
00FF4000FF3300FF3300FF2600FF0C00FF0C0CFF0019FF0026FF0026FF0033FF0033FF0033FF00\
3FFF003FFF003FFF003FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00
4CFF004CFF003FFF003FFF0033FF0000FF00004CFF00FFD900FF0033FF004CFF0059FF0059FF00\
66FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
00FF4026FF0026FF000CFF0026FF003FFF0059FF0066FF0066FF0066FF0073FF0073FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
73FF0066FF0019FF003FFF0066FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
73FF0059FF0066FF0066FF0073FF0073FF0066FF0066FF0059FF004CFF0033FF00
00FF0000FF400CFF0026FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF00
4CFF003FFF0033FF0026FF0000FF0000FF5900FF1900FF4000FF5900FF1900FF0C00FF3300FF80\
00FF1900FF000CFF000CFF0019FF0019FF0019FF0019FF000CFF0000FF0000FF19
00FF8000FF2600FF2600FF1900FF2600FF4C00FF4C00FF3300FF3300FF3300FF3300FF4C00FF4C\
00FF6600FF8C00FF8000FF9900FFE60073FF00000000FFF300CCFF00FFE600FFD9
00FFFF00F3FF00FFD900FFE600E6FF00F3FF00E6FF00F3FF0066FF0066FF00B3FF0080FF0033FF\
0000008C00FF0040FF00B3FF00E6FF0073FF00FFD900FFD900FF9900FF6600FF4C
00FF3300FF2600FF1900FF0C00FF000CFF0019FF0019FF0026FF0026FF0033FF0033FF003FFF00\
3FFF003FFF004CFF004CFF004CFF004CFF004CFF0059FF0059FF0059FF004CFF00
4CFF004CFF004CFF003FFF0033FF0000FF0C00FF6600FF1900FF2626FF003FFF003FFF003FFF00\
33FF004CFF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
00FF1900FF1900FFCC00FF9933FF004CFF0066FF0066FF0073FF0073FF0080FF0080FF0080FF00\
80FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00
80FF0073FF0033FF003FFF0066FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF004CFF0000FF73
19FF000CFF0000FF0C26FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF00\
66FF0073FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF00
4CFF003FFF0033FF0026FF0000FF0000B3FF00FF000CFF0000FF800CFF000CFF0000FFA600FFB3\
00FF1900FF000CFF0019FF0019FF0019FF0019FF0019FF0019FF000CFF0000FF26
00FF1900FF0C00FF0C00FF0C00FF1900CCFF00FF3300FF2600FF2600FF2600FF3300FF3300FF40\
00FF4C00FF6600FF7300FF8C00FFBF00FFBF00FFD900FFBF008CFF00FFB300FFA6
00FFB300FFB300FFBF00FFFF00FFFF00FFFF00FFD900F3FF00B3FF00FFFF00CCFF000CFF0073FF\
0000FF0000000000000066FF00BFFF00FFFF0059FF00FFBF00FFF300FFE600FF66
00FF3300FF2600FF1900FF0C00FF000CFF0019FF0019FF0026FF0026FF0033FF0033FF003FFF00\
3FFF004CFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF004CFF004CFF003FFF0026FF0000FF0019FF0000FF190CFF000CFF0000FF1900FF19\
26FF0066FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
33FF000CFF0033FF0000FF190CFF0059FF0066FF0073FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
80FF0073FF0059FF0000FF8059FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00\
80FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0059FF004CFF00
3FFF0019FF0000FFE626FF003FFF004CFF0059FF0066FF0066FF0066FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0059FF0059FF00
4CFF003FFF0033FF0000FF2600FF2600FF0C19FF0026FF0019FF0026FF0019FF000CFF0000FF33\
00FF190CFF0019FF0019FF0026FF0026FF0026FF0026FF0019FF0019FF0000FF00
0CFF000CFF0000FF0000FF0000FF0C00FF3300FF1900FF1900FF1900FF2600FF2600FF3300FF40\
00FF4C00FF5900FF7300FFE600FFB300FF8C00FF8000FFA600FFF300FF9900FF8C
00FF8C00FF9900FFB300FFF300FFBF00FFA600FFB300D9FF0019FF00FFD900FFF300E6FF00B3FF\
1900FF000000000000004CFF00A6FF00F3FF00FFD900FFA600FF8C00FF6600FF4C
00FF4000FF3300FF2600FF1900FF000CFF0019FF0019FF0026FF0026FF0033FF0033FF003FFF00\
3FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF0059FF004CFF004CFF003FFF0033FF0026FF0019FF0000FF2600FF0C26FF004CFF00\
59FF0066FF0073FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
4CFF0026FF004CFF004CFF0019FF003FFF0066FF0073FF0080FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF0080FF0073FF004CFF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0059FF00
4CFF0033FF0000FF0000FF1926FF003FFF0059FF0066FF0066FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF00
4CFF003FFF0019FF0000FF4019FF0000FF2626FF0033FF0033FF0033FF0026FF0019FF0000FF26\
00FF0019FF0026FF0026FF0026FF0026FF0026FF0026FF0026FF0019FF0019FF00
19FF000CFF000CFF000CFF0000FF0000FF0C00FF0C00FF0C00FF1900FF1900FF2600FF3300FF40\
00FF4C00FF5900FF8000FF8C00FF6600FF7300FF6600FFBF00FF8000FF8C00FF73
00FF8000FF9900FFCC00FFE600FFB300FF8C00FF9900FF9900FFB300FFCC00FFF300E6FF00BFFF\
00B3FF0059FF0000002600FF0080FF00CCFF00BFFF00FFFF00FF8C00FF8000FF59
00FF4C00FF4000FF4C00FF4C00FF0C0CFF000CFF0019FF0026FF0026FF0033FF0033FF003FFF00\
3FFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF0019FF0000FF7319FF003FFF0059FF00\
66FF0073FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
59FF0066FF0066FF0066FF004CFF0000FF2619FF0073FF0080FF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
8CFF008CFF0080FF0073FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF0066FF00
4CFF0000FF0C00FF8033FF0033FF0026FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF00
3FFF0019FF000CFF0033FF003FFF003FFF003FFF003FFF003FFF003FFF0033FF0019FF0000FFA6\
0CFF0026FF0026FF0026FF0033FF0033FF0026FF0026FF0026FF0026FF0026FF00
19FF0019FF0019FF000CFF000CFF0000FF0000FF0000FF0C00FF0C00FF1900FF2600FF4000FF59\
00FF5900FF8000FFD900FF6600FF4C00FF4C00FF4C00FF6600FF4C00FF5900FF66
00FF8000FFBF00FFB300FF8C00FFB300FF8000FF8000FF8C00FFA600FFBF00CCFF00F3FF00FFF3\
00A6FF00A6FF0040FF0000000000FF004CFF00B3FF00FFE600FFB300FFB300FF73
00FF6600FF8000FF4C00FF2600FF0C00FF000CFF000CFF0019FF0019FF0026FF0033FF0033FF00\
3FFF004CFF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0059FF0059FF0059FF004CFF003FFF0033FF0019FF0000FF1900FF4000FF3359FF00\
66FF0066FF0073FF0080FF0080FF0080FF008CFF008CFF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0066FF0073FF0073FF0066FF0059FF0000FF0C80FF008CFF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF00
4CFF0026FF0019FF004CFF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF00
3FFF0000FF5933FF004CFF004CFF004CFF004CFF004CFF004CFF003FFF0033FF0019FF0000FFF3\
0CFF0026FF0033FF0033FF0033FF0033FF0033FF0033FF0026FF0026FF0026FF00
26FF0019FF0019FF000CFF000CFF000CFF0000FF0000FF0000FF0C00FF1900FF6600FF7300FF8C\
00FFB300FFB300FF8000FF7300FF4000FF3300FF3300FF3300FF4000FF4C00FF59
00FF6600FFCC00CCFF00FF6600FF8C00FF6600FF7300FF9900FFCC00B3FF00FFB300FFB300FFCC\
00FFFF00BFFF0073FF9900FF0000000000000040FF00FFFF00FFBF00FFBF00FFD9
00FFCC00FFB300FF5900FF2600FF1900FF0C00FF0000FF0000FF000CFF0019FF000CFF0019FF00\
33FF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0059FF0059FF004CFF003FFF0033FF0000FF0C00FF0C26FF003FFF004CFF00\
59FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF008CFF0099FF0099FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
73FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF00
4CFF0000FF263FFF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF0059FF00
26FF0033FF004CFF0059FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF000CFF0000FF66\
26FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0026FF0026FF00
26FF0019FF0019FF0019FF000CFF000CFF0000FF0000FF0000FF0C00FF1900FF2600FF4C00FF99\
00FF5900FF6600FF4000FFB300FF3300FF2600FF2600FF2600FF3300FF4000FF59
00FF7300FFA600FF6600FF5900FF4C00FF4C00FF6600FFA600FF9900FFB300FF9900FF9900E6FF\
00FFF300F3FF008CFF8C00FF0000000000000080FF00FFFF00FFB300FF8C00FF73
00FF5900FF6600FFD900FF5900FF4000FF1900FF1900FF5900FFCC00FF6600FFD900FF1900FF0C\
00FFA64CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0059FF004CFF003FFF0026FF0000FF2600FF0026FF003FFF004CFF00\
59FF0059FF0066FF0066FF0073FF0073FF0066FF0026FF0080FF0099FF0099FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
73FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0066FF0059FF00
26FF0033FF0059FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF00
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF003FFF0019FF0019FF00\
33FF003FFF003FFF003FFF003FFF003FFF0033FF0033FF0033FF0033FF0026FF00
26FF0026FF0019FF0019FF000CFF000CFF0000FF0000FF0000FF0C00FF1900FF2600FF4C00FF80\
00FF3300FF2600FF2600FF5900FF3300FF1900FF1900FF2600FF3300FF5900FF73
00CCFF00FFCC00FF5900FF4C00FF4000FF4000FF5900FF6600FF6600FFBF00FF8000FF8000FF99\
00FFB300FFE600B3FF2600FF0000FF0000005900FF00FFFF00FFBF00FF8C00FF66
00FF4C00FF4000FF5900FF4C00FF6600FF8000FF7300FF8C00FF400CFF0019FF0026FF0033FF00\
3FFF004CFF0059FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF00
73FF0066FF0066FF0066FF0066FF004CFF000CFF000CFF0019FF0000FF3300FF4033FF003FFF00\
3FFF0033FF0033FF0059FF0059FF0059FF0000FF3333FF008CFF0099FF0099FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
73FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0066FF004CFF00
00FF403FFF0059FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF0033FF003FFF00\
3FFF003FFF003FFF003FFF003FFF003FFF003FFF0033FF0033FF0033FF0026FF00
26FF0026FF0019FF0019FF000CFF000CFF0000FF0000FF0000FF0C00FF1900FF3300FFBF00FF40\
00FF3300FF1900FF0C00FF1900FF1900FF0C00FF0C00FF1900FFB300FFA600FF8C
00FF5900FF8C00FFF300FF4000FF3300FF3300FF4000FF4000FF4C00FF5900FF6600FF8000FF99\
00FFB300BFFF00FFE600D9FF00CCFF0C00FF2600FF00BFFF00FFF300FFF300FF66
00FF4000FF3300FF2600FF2600FF1900FF1900FF3300FF4C00FF0C19FF0033FF003FFF004CFF00\
4CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0066FF0066FF0059FF0033FF003FFF003FFF0019FF0000FF0C0CFF0019FF00\
19FF0000FF0C00FF0033FF0033FF0019FF0066FF0073FF008CFF0099FF0099FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
80FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0073FF0033FF0026FF00
00FF1933FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF00
73FF0073FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF00\
4CFF004CFF004CFF004CFF003FFF003FFF003FFF003FFF0033FF0033FF0026FF00
26FF0019FF0019FF0019FF000CFF000CFF0000FF0000FF0C00FF0C00FF2600FF8C00FF3300FF19\
00FF0C00FF0000FF0000FF0000FF0000FF0000FF0000FF0C00FF2600FF8C00FF33
00FF2600FF4000FF4C00FF3300FF2600FF2600FF3300FF3300FF4000FF4C00FF5900FF800080FF\
00FFBF00FFA600FF9900FFCC00FFE600B3FF000CFF0080FF00FFE600FFA600FF80
00FF4000FF2600FF1900FF0C00FF0000FF0000FF1900FF6600FF2600FFB333FF003FFF004CFF00\
59FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF004CFF0033FF0000FF0C19FF0026FF00\
00FF0000FF4C19FF0019FF0000FF333FFF0066FF0080FF008CFF008CFF0099FF00
99FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
80FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0059FF0026FF00
26FF004CFF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF00
73FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF00\
4CFF004CFF004CFF004CFF004CFF003FFF003FFF003FFF0033FF0033FF0026FF00
26FF0019FF0019FF000CFF000CFF0000FF0000FF0C00FF0C00FF1900FF3300FFD900FF2600FF0C\
00FF0000FF000CFF000CFF000CFF000CFF000CFF0000FF0000FF3300FF2600FF19
00FF1900FF3300FF4000FF2600FF1900FF2600FF2600FF3300FF4000FF4C00FF6600FF8000FF99\
00FF7300FF8000FF8000FFA600E6FF00FFE600D9FFCC00FF00D9FF00FFA600FF8C
00FF4000FF3300FF1900FF000CFF000CFF0000FF0000FF1900FF4C0CFF0026FF003FFF004CFF00\
59FF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF004CFF000CFF0000FF0C3FFF004CFF00\
4CFF000CFF003FFF004CFF0026FF0000FF4C4CFF0073FF0080FF008CFF0099FF00
99FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
80FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0059FF0033FF00
19FF004CFF0066FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
73FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF00\
59FF0059FF004CFF004CFF004CFF004CFF003FFF003FFF0033FF0033FF0026FF00
19FF0019FF000CFF0000FF0000FF0000FF0C00FF1900FF2600FF3300FF5900FF6600FF2600FF0C\
00FF000CFF000CFF000CFF0019FF0019FF000CFF0000FF0000CCFF00FF0C00FF00
00FF0000FF0C00FF1900FF0C00FF1900FF1900FF2600FF3300FF4C00FF5900FF7300FFE600FF66\
00FF4C00FF4C00FF6600FF8C00FFA600FF9900FFF300B3FF8000FF00FFFF00FFE6
00FF8000FF4C00FF190CFF0019FF0019FF000CFF0000FF7300FF6600FF190CFF0026FF004CFF00\
59FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0059FF003FFF0000FF264CFF0059FF00\
66FF0066FF0066FF0059FF0026FF000CFF003FFF0059FF0066FF008CFF008CFF00
99FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
80FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0073FF0066FF003FFF0000FF0C
33FF0026FF0066FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0059FF0059FF00\
59FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF0033FF0026FF0019FF00
19FF000CFF0000FF0000FF5900FF1900FF1900FF2600FF9900FF8000FF4C0099FF00FF4000FF0C\
00FF000CFF0019FF0019FF0019FF0019FF0019FF000CFF0000FF000CFF000CFF00
0CFF0000FF0000FF0000FF0000FF0C00FF1900FF2600FF4C00FF6600FFA600FFA600FF9900FF66\
00FF4000FF3300FF4C00FF4C00FF6600FF8000FFBF00FFFF0040FF00FFFF00FF73
00FF5900FF4000FF0019FF0019FF0026FF0019FF000CFF0000FF6600FF0C00FF4026FF004CFF00\
59FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0059FF0033FF003FFF0059FF0066FF00\
73FF0073FF0073FF0066FF004CFF0019FF0000FFFF0CFF0066FF0080FF008CFF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
80FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0026FF0026FF0000FF8033FF00
59FF0066FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF00
80FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0059FF00\
59FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF0026FF000CFF0000FF00
00FF0000FF0C00FF1900FF4000FF6600FF4000FF4C00FF7300FF3300FF2600FF4C00FF4000FF0C\
00FF0019FF0019FF0019FF0026FF0026FF0026FF0019FF0019FF0019FF0019FF00
0CFF000CFF000CFF0000FF0000FF0000FF0C00FF2600FF4000FF9900FF5900FF8000FF4000FF59\
00FF3300FF2600FF3300FF4000FF5900FF8C00FF7300FF7300E6FF00FFD900FF4C
00FF2600FF1900FF7319FF0026FF0026FF0026FF0026FF0000FF0026FF0019FF0000FF0033FF00\
4CFF0059FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0000FF003FFF0066FF0073FF00\
73FF0080FF0080FF0073FF003FFF0059FF0059FF000CFF004CFF0073FF0080FF00
8CFF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
73FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0066FF003FFF0000FF40
59FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00
80FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF00\
59FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF0019FF0000FF3300FF73
00FF19000CFF00FF4C00FFBF00FF4000FF4C00FF8C00FF1900FF0C00FF0C00FF3300E6FF00FF33\
00FF0C19FF0026FF0026FF0026FF0026FF0026FF0026FF0026FF0026FF0019FF00
19FF000CFF000CFF0000FF0000FF0000FF0C00FF1900FF3300FF8000FF4000FF2600FF2600FFB3\
00FF1900FF1900FF2600FF4000FF7300FFCC00FF4C00FF4000FF4C00FF6600FF59
00FF190CFF0019FF0026FF0033FF0033FF0033FF0033FF0033FF003FFF003FFF0033FF0000E6FF\
19FF0059FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0066FF0019FF004CFF0066FF0080FF00\
80FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0000FF0059FF0066FF00
80FF0080FF008CFF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
66FF0073FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF0073FF004CFF0000FF0C
59FF0073FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00
80FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF00\
59FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0026FF0019FF00
0CFF0000FF0C00FF6600FF1900FF0C00FF0C00FF2600FF0C0CFF000CFF0000FF0C00FF1900FF33\
0CFF0019FF0026FF0026FF0033FF0033FF0033FF0026FF0026FF0026FF0026FF00
19FF0019FF000CFF000CFF0000FF0000FF0C00FF1900FF4000FF4000FF2600FF0C00FF0C00FF0C\
00FF0C00FF0C00FF1900FF4C00FF4C00FF4000FF3300FF2600FF3300FF8000FF33
00FF0C0CFF0019FF0026FF0033FF003FFF003FFF003FFF004CFF004CFF004CFF004CFF003FFF00\
4CFF0059FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0066FF004CFF0000FF4C73FF0080FF00\
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0066FF0000FF264CFF00
66FF0026FF0080FF008CFF008CFF008CFF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
4CFF004CFF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0066FF0000FF593FFF00
00FF6659FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF00\
59FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF0033FF0033FF0026FF00
19FF0000FF0C00FF8000FF1900FF000CFF000CFF0000FF0019FF0019FF0019FF000CFF0000FF26\
0CFF0026FF0026FF0033FF0033FF0033FF0033FF0033FF0033FF0026FF0026FF00
19FF0019FF000CFF000CFF0000FF0000FF0C00FF2600FF9900FF2600FF0C00FF0000FF000CFF00\
0CFF0000FF0000FF0C00FF8000FF0C00FF0C00FF1900FF0C00FF1900FF4000FF4C
00FF000CFF0019FF0026FF0033FF003FFF004CFF004CFF0059FF0059FF0059FF0059FF0066FF00\
66FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0059FF0080FF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0066FF0000FF0C
00FF0033FF0066FF0073FF0073FF0033FF0099FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
4CFF0000FF0080FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0066FF0033FF0073FF00
80FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF00\
59FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF0033FF0026FF00
19FF0000FF0C00FFCC00FF260CFF0019FF0026FF0026FF0026FF0026FF0026FF0019FF0000FF73\
0CFF0026FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0026FF00
19FF0019FF000CFF0000FF0000FF0C00FF1900FF3300FF9900FF1900FF000CFF000CFF000CFF00\
19FF000CFF0000FF0000FF260CFF000CFF0000FF0000FF0000FF0C00FF1900FF40
00FF0C00FF0019FF0026FF0033FF003FFF004CFF004CFF0059FF0059FF0066FF0066FF0066FF00\
73FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0073FF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0073FF0066FF00
66FF0000FF264CFF0000FF4C26FF0066FF008CFF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00
80FF0073FF0026FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0080FF0000FF0C80FF008CFF00
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF00\
59FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF0033FF0033FF0019FF00
0CFF0000FF0C00FF7300FF0019FF0026FF0033FF0033FF0033FF0033FF0033FF0026FF0000FF0C\
00FF1926FF0033FF003FFF003FFF003FFF003FFF003FFF0033FF0033FF0026FF00
19FF000CFF0000FF0000FF0C00FF2600FF5900FF7300FFA600FF3300FF000CFF0019FF0019FF00\
19FF0019FF0019FF0019FF0019FF0019FF000CFF000CFF0000FF0000FF0C00FF4C
00FF8C00FF3300FF190CFF0019FF0033FF004CFF0059FF0059FF0066FF0066FF0066FF0073FF00\
73FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00
80FF0059FF004CFF004CFF0066FF0033FF0033FF0099FF00A6FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
8CFF008CFF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0080FF0073FF008CFF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF00\
59FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0026FF0000FF0C
00FF4C00FF6600FF2600FF2619FF0033FF0033FF003FFF003FFF003FFF003FFF0033FF0000FF33\
00FF3326FF003FFF003FFF003FFF003FFF003FFF003FFF003FFF0033FF0026FF00
19FF0000FF0000FF5900FF3300FF4000FF6600FF2600FF4000FF3300FF0C0CFF0019FF0026FF00\
26FF0026FF0026FF0026FF0026FF0019FF0019FF000CFF0000FF0000FF0C00FF73
00FF2600FF330CFF0000FF0C008CFF00FF333FFF0059FF0059FF0066FF0066FF0073FF0073FF00\
73FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00
8CFF0066FF0073FF0080FF0080FF0073FF0059FF0080FF0099FF00B3FF00B3FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF00\
59FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF0033FF0026FF000CFF00
00FF8C00FF0019FF0019FF0000FF5933FF003FFF003FFF003FFF004CFF003FFF003FFF0033FF00\
00FF5933FF003FFF004CFF004CFF004CFF004CFF003FFF003FFF0033FF000CFF00
00FF0000FF2600FF9900FF5900FFA600FF0C00FF0000FF2600FF4C00FF260CFF0026FF0026FF00\
26FF0033FF0033FF0026FF0026FF0026FF0019FF0019FF0000FF0000FF0C00FF66
00FF0C0CFF0026FF0033FF0033FF003FFF004CFF0059FF0066FF0066FF0066FF0073FF0073FF00\
73FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0080FF0080FF0099FF0099FF0099FF008CFF0059FF003FFF00A6FF00B3FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0059FF00\
59FF0059FF0059FF004CFF004CFF004CFF003FFF0033FF0033FF0019FF0000FF0C
00FF6600FF0026FF0033FF0033FF003FFF004CFF004CFF004CFF004CFF004CFF004CFF003FFF00\
00FF663FFF004CFF004CFF004CFF004CFF004CFF004CFF003FFF0026FF0000FF26
0CFF0000FF1900FF2600FF0000FF0000FF0019FF0019FF0000FF0000FF0C19FF0026FF0033FF00\
33FF0033FF0033FF0033FF0033FF0026FF0026FF0019FF0000FF1900FF4000FFCC
00F3FF0CFF0033FF003FFF003FFF004CFF0059FF0059FF0066FF0066FF0073FF0073FF0073FF00\
73FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00C0FF00C0FF00C0FF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0059FF0059FF00\
59FF0059FF004CFF004CFF004CFF003FFF003FFF0033FF0026FF0000FF0C00FF00
19FF0033FF0033FF003FFF003FFF004CFF004CFF004CFF004CFF0059FF0059FF004CFF004CFF00\
4CFF004CFF0059FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF0033FF00
19FF0000FF3300FF730CFF0026FF0026FF0026FF0026FF000CFF0000FF4019FF0026FF0033FF00\
33FF003FFF003FFF0033FF0033FF0033FF0026FF0019FF0000FF0C00FF8C00FF19
0CFF0026FF0033FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF00\
80FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF00\
59FF004CFF004CFF004CFF003FFF003FFF0033FF0000FF0000FF0000FF7319FF00
26FF0033FF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF00\
59FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF00
26FF0000FF0C00FF6619FF0033FF0033FF0033FF0033FF0026FF0000FF4C19FF0033FF003FFF00\
3FFF003FFF003FFF003FFF0033FF0033FF0026FF000CFF0000FF3300FF8000FF19
0CFF0026FF0033FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF00\
80FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF00
80FF0080FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF00\
4CFF004CFF004CFF003FFF003FFF0033FF0026FF000CFF0000FF2600FF0019FF00
33FF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00\
59FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF00
26FF0000FF5919FF0000FF193FFF003FFF003FFF003FFF0033FF000CFF0000FF1933FF003FFF00\
3FFF003FFF003FFF003FFF003FFF0033FF0019FF0000FF6600FF0000FF0000D9FF
00FF0C0CFF0026FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF00\
80FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF00
80FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF00\
4CFF003FFF003FFF003FFF0033FF0033FF0026FF000CFF0000FF1900FF0C19FF00
33FF003FFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF0033FF00
00FF0C26FF003FFF003FFF004CFF004CFF004CFF004CFF003FFF0026FF0033FF003FFF004CFF00\
4CFF004CFF004CFF004CFF003FFF003FFF000CFF0019FF0026FF0019FF0000FF00
00FF730CFF0033FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF00\
80FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF0099FF0099FF00
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0080FF00
73FF0073FF0073FF0066FF0066FF0059FF003FFF004CFF004CFF004CFF004CFF004CFF004CFF00\
3FFF0026FF0033FF0033FF0026FF0026FF0019FF0000FF4000FF8000FF0C0CFF00
33FF003FFF004CFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF0033FF00
00FF193FFF004CFF004CFF0059FF0059FF0059FF0059FF004CFF004CFF004CFF004CFF004CFF00\
4CFF004CFF004CFF004CFF004CFF003FFF003FFF0033FF0033FF0026FF0000FF00
00FF2619FF0033FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF00\
73FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF00
73FF0073FF0066FF0066FF0059FF004CFF0000FF2633FF003FFF004CFF004CFF003FFF003FFF00\
33FF0000FF1919FF0000FF330CFF000CFF0000FF0C00FF3300FF0C0CFF0026FF00
33FF003FFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF004CFF000CFF00
19FF003FFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00\
59FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF0033FF0033FF0019FF00
00FF190CFF0033FF003FFF004CFF004CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF00\
73FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF0066FF00
66FF0066FF0066FF0059FF0059FF004CFF0033FF000CFF0033FF003FFF003FFF003FFF0033FF00\
26FF0000FF5900FF2600FF4000FF5900FF3300FF2600FF1900FF260CFF0026FF00
33FF003FFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0033FF00
26FF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF00\
59FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF0033FF0026FF00
00FF0019FF0033FF003FFF004CFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0073FF00\
73FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0073FF0059FF0019FF003FFF00
3FFF004CFF004CFF004CFF004CFF003FFF0026FF0000FF330CFF0000FF3326FF0033FF0026FF00\
19FF0000FF1900FFFF00FF4C00FF0019FF0019FF000CFF0000FF5900FF7319FF00
26FF0033FF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0026FF00
59FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF00\
59FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF0033FF00
00FF0000FF0C26FF0033FF003FFF004CFF004CFF004CFF0059FF0059FF0066FF0066FF0066FF00\
73FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF008CFF0073FF004CFF0000FF8C33FF000CFF00
00FF1919FF0033FF0000FFA633FF0026FF0000FF0C00FFD900FF5900FF2619FF0019FF0019FF00\
00FF1900FF9900FF1900FF3319FF0026FF0026FF0019FF0000FF0000FF3300FF59
00FF3333FF004CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF0033FF00
0CFF0000FF330CFF0000FF4033FF003FFF003FFF003FFF004CFF0059FF0059FF0059FF0059FF00\
66FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0000FF2666FF0059FF00
59FF003FFF0000FF0C00FF0C00FF0000FF0C00FFFF19FF000CFF0000FF4000FF4000BFFF00FF8C\
0CFF0026FF0026FF000CFF0033FF003FFF0033FF0026FF000CFF0000FF4000FF00
33FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF00\
66FF0066FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF00
00FF0C00FF0C00FF4C00FF0026FF0026FF0019FF000CFF003FFF004CFF004CFF0033FF004CFF00\
66FF0066FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF0099FF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0080FF0073FF0073FF00
66FF0059FF003FFF0019FF0000FF0C0CFF0026FF0033FF0033FF000CFF0019FF000CFF0000FFBF\
26FF003FFF003FFF003FFF004CFF004CFF003FFF0026FF0000FF0C00FF2619FF00
33FF003FFF004CFF0059FF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00\
66FF0066FF0066FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF00
26FF0019FF0000FF4000FF0C00FF0000FF0000FF2619FF0033FF0033FF0033FF0000FF803FFF00\
59FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF00
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF00
66FF0066FF004CFF003FFF000CFF0026FF003FFF003FFF003FFF0019FF003FFF0033FF0000FF00\
19FF004CFF004CFF0059FF0059FF004CFF004CFF003FFF000CFF0000FFB300FF00
19FF003FFF004CFF0059FF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF00\
66FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF00
33FF0019FF0000FF0C00FFD900FF9900FF3300FF2600FF2619FF0000FF1900FF2600FFA626FF00\
33FF0059FF0066FF0066FF0066FF0073FF0073FF0080FF0080FF0080FF008CFF00
8CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF00
73FF0066FF004CFF0033FF0000FFF333FF004CFF004CFF0059FF0059FF004CFF004CFF0019FF00\
3FFF004CFF0059FF0059FF0059FF0059FF004CFF0033FF0000FF1919FF0000FF26
00FF3326FF0033FF003FFF0059FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF00\
66FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF00
33FF0019FF0000FF0C00FF0C0CFF000CFF000CFF0000FFB300FF2600FF190CFF0026FF0000FF0C\
00FF263FFF004CFF003FFF0059FF0059FF0033FF0066FF0073FF0073FF0073FF00
8CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF00
73FF0066FF003FFF0019FF0000FF1926FF004CFF0059FF0059FF0066FF0059FF0059FF0026FF00\
0CFF0059FF0066FF0066FF0066FF0066FF0059FF0019FF003FFF003FFF0026FF00
0CFF0000FF4C19FF0033FF0059FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
66FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF004CFF003FFF003FFF00
26FF000CFF0000FF6619FF0026FF0026FF0026FF0019FF0000FF8C26FF003FFF003FFF003FFF00\
4CFF0000FF000CFF0000FF333FFF0033FF0033FF0059FF0066FF0059FF004CFF00
80FF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF00
73FF0059FF003FFF0000FF2600FF400CFF004CFF0066FF0066FF0066FF0066FF0066FF0033FF00\
00FF9966FF0066FF0073FF0073FF0066FF0066FF0059FF0059FF004CFF003FFF00
00FF4000FF264CFF0059FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF004CFF003FFF0033FF00
0CFF0000FF4000FF1919FF0033FF003FFF003FFF003FFF0033FF0000FF004CFF0059FF0059FF00\
59FF0059FF0033FF0000FF4000FF0019FF0000FF593FFF0000FF8C00FF264CFF00
73FF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0080FF0073FF00
66FF0059FF003FFF000CFF0000FF193FFF0059FF0066FF0073FF0073FF0073FF0073FF0066FF00\
4CFF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF0033FF00
19FF0019FF004CFF0066FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00\
73FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF004CFF0033FF000CFF00
00FF0C00F3FF00FF1900FF0033FF003FFF004CFF004CFF004CFF0033FF0059FF0066FF0066FF00\
66FF0066FF0066FF0059FF003FFF0059FF0033FF0000FF333FFF004CFF000CFF00
4CFF0080FF008CFF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0066FF0059FF00
59FF004CFF003FFF0000FF263FFF0059FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF00\
73FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0066FF004CFF00
26FF0033FF0059FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00\
73FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF004CFF003FFF0026FF00
00FF9900FF7300FF5900FF1933FF004CFF0059FF0059FF0059FF0066FF0066FF0073FF0073FF00\
73FF0073FF0073FF0073FF0066FF0073FF0066FF0000FF0066FF0073FF0073FF00
73FF0000FF0080FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0059FF0019FF00
26FF0019FF0000FF4C00FF4C3FFF0059FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0059FF00
00FF193FFF0059FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00\
73FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF004CFF003FFF0026FF00
0CFF0000FF1900FF1926FF003FFF004CFF0059FF0066FF0066FF0066FF0073FF0073FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0073FF004CFF0073FF0080FF008CFF00
8CFF008CFF008CFF0099FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0073FF0066FF003FFF00
26FF0026FF0033FF0033FF0000FF3359FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0066FF004CFF00
00FF8C3FFF0059FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00\
73FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF003FFF003FFF0033FF00
19FF0000FF260CFF0033FF004CFF0059FF0059FF0066FF0066FF0073FF0073FF0080FF0080FF00\
80FF0080FF0080FF008CFF008CFF008CFF008CFF0080FF008CFF008CFF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0066FF003FFF0026FF00
3FFF0059FF0066FF0066FF004CFF003FFF0073FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0066FF004CFF00
19FF0000FF0059FF0066FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF00\
73FF0066FF0066FF0066FF0059FF0059FF004CFF004CFF003FFF0033FF0026FF00
19FF0000FF6619FF0033FF003FFF0059FF0059FF0066FF0073FF0073FF0080FF0080FF0080FF00\
80FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0066FF004CFF0000FF593FFF00
4CFF0073FF0080FF0080FF0073FF0026FF0033FF0080FF008CFF008CFF008CFF0099FF0099FF00\
99FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF0073FF0066FF003FFF00
00FF733FFF0059FF0066FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF00\
73FF0066FF0066FF0059FF0059FF004CFF004CFF003FFF0033FF0033FF0026FF00
0CFF0000FF4000FF2619FF003FFF004CFF0059FF0066FF0073FF0073FF0080FF0080FF008CFF00\
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF00A6FF0099FF008CFF0080FF0073FF0059FF0000FF1959FF0066FF0073FF00
73FF0080FF008CFF008CFF0080FF0073FF0073FF008CFF008CFF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0066FF004CFF00
0CFF0026FF004CFF0066FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF00\
73FF0066FF0066FF004CFF003FFF0033FF0033FF0033FF0000FF1919FF000CFF00
00FF5900FF0C00FF0C00FF0019FF0033FF004CFF0059FF0073FF0080FF0080FF0080FF008CFF00\
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00\
A6FF0099FF0099FF008CFF0073FF0000FF0000FF193FFF0073FF0080FF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0073FF0059FF00
33FF0000FF4000FF4C26FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF00\
73FF0066FF0066FF004CFF0000FF1900FF590CFF000CFF0000FF0000FFBF00FF33
00FF1919FF0033FF0033FF0033FF0019FF0000FF7300FFA673FF0080FF0080FF008CFF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00\
A6FF0099FF008CFF0080FF0066FF0019FF004CFF0073FF0080FF008CFF008CFF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0059FF00
00FF1926FF0059FF0066FF0073FF0080FF008CFF008CFF008CFF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF00\
73FF0066FF0066FF0059FF003FFF0033FF000CFF0000FF8000FF4000FF0000FF0C
00FF0C26FF003FFF004CFF004CFF0059FF004CFF0066FF0073FF0080FF0080FF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00\
8CFF0073FF0073FF0066FF0033FF000CFF0059FF0080FF008CFF008CFF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF0080FF0059FF0033FF00
00FF263FFF0059FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF00\
73FF0066FF0066FF0059FF004CFF003FFF0026FF0000FF0000FF0019FF0026FF00
33FF0026FF004CFF0059FF0059FF0066FF0066FF0073FF0080FF0080FF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00\
99FF0073FF0059FF0000FF0C3FFF0059FF004CFF0080FF008CFF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0000FF0059FF00
3FFF0000FF4059FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF00\
73FF0066FF0066FF0059FF004CFF003FFF0019FF0000FF4000FF2626FF0033FF00
3FFF004CFF0059FF0059FF0066FF0066FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00A6FF00\
99FF008CFF0073FF0033FF0059FF0073FF0080FF008CFF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0073FF00
59FF0026FF0019FF0059FF0073FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF00\
66FF0066FF0059FF004CFF003FFF0033FF0026FF0000FF1900FF0C26FF003FFF00
4CFF004CFF0059FF0066FF0066FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00\
99FF008CFF0073FF0033FF0059FF0080FF008CFF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF00
19FF0000FF4C59FF003FFF0066FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF00\
66FF0066FF0059FF003FFF0000FF0019FF000CFF0000FF3319FF0033FF003FFF00
4CFF0059FF0059FF0066FF0066FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF00\
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00\
99FF0066FF0059FF0000FF003FFF0080FF008CFF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF0080FF00
59FF0019FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF00\
66FF0059FF004CFF003FFF000CFF0000FF3300FF5900FF1900FF0C26FF003FFF00
4CFF004CFF0059FF0066FF0066FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00\
99FF0080FF0000FF2666FF0073FF003FFF0099FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF0080FF00
00FF2673FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0066FF0059FF00\
4CFF0033FF0033FF0000FF1900FF4026FF0000FF4C26FF000CFF0019FF0033FF00
3FFF004CFF0059FF0066FF0066FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00A6FF00\
80FF0059FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0080FF00
3FFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0073FF0059FF0059FF003FFF00\
00FF0000FF8033FF003FFF0000FF0C3FFF003FFF003FFF0026FF0000FF800CFF00
26FF0026FF003FFF0059FF0066FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF0099FF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF0099FF00\
0CFF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF008CFF00
80FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0073FF0059FF0000FF1900FF33\
0CFF003FFF004CFF0059FF0059FF0059FF004CFF004CFF0033FF0000FF1900FF26
00FF1900FF4026FF004CFF0066FF0066FF0073FF0073FF0080FF0080FF008CFF008CFF008CFF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00B3FF003FFF00\
8CFF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0073FF0059FF0000FF4033FF00\
3FFF0059FF0066FF0066FF0066FF0066FF0059FF0059FF003FFF0026FF0000FF66
00FFBF00FF4C26FF004CFF0059FF0066FF0066FF0073FF0073FF0080FF0080FF008CFF008CFF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0073FF0059FF0000FF1900FF004CFF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF004CFF0019FF0000FF40
00FF0000FF0C19FF003FFF004CFF0059FF0066FF0066FF0066FF0066FF0073FF0080FF008CFF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0066FF004CFF0066FF0066FF0059FF00\
73FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF004CFF003FFF0033FF00
33FF0000FF0000FF3333FF003FFF0026FF004CFF004CFF0000FFBF33FF0026FF0059FF0080FF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF004CFF00
3FFF0033FF0019FF0000FF2600FF2600FFD926FF0019FF0033FF0000FF5966FF0073FF008CFF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF00
4CFF003FFF0026FF0000FF7326FF0000FF3359FF0059FF0066FF0073FF0080FF0080FF008CFF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00\
8CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0066FF0059FF00
4CFF003FFF0019FF0000FFE633FF004CFF0066FF0073FF0073FF0080FF0080FF008CFF008CFF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF00\
8CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0059FF00
4CFF0033FF0019FF0000FF8C26FF004CFF0066FF0073FF0080FF0080FF008CFF008CFF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00\
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF0059FF00
3FFF0000FF0000FF260CFF003FFF004CFF0066FF0073FF0080FF008CFF008CFF008CFF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0059FF004CFF00
33FF0000FF000CFF0033FF004CFF0066FF0073FF0080FF0080FF008CFF008CFF008CFF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0066FF0026FF0000FF19
00FF2600FF000CFF0033FF004CFF0066FF0073FF0073FF0080FF008CFF008CFF008CFF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF008CFF008CFF008CFF008CFF0080FF0073FF0033FF0000FF404CFF00
4CFF003FFF0000FF0C00FF193FFF0059FF0066FF0073FF0080FF008CFF008CFF0099FF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
99FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0066FF0066FF00
59FF004CFF0033FF0000FF0019FF0033FF000CFF003FFF0080FF008CFF008CFF0099FF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00\
E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00E6FF00
E6FF00E6FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0073FF00
66FF0059FF003FFF0026FF0019FF004CFF0059FF0073FF0080FF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00\
D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00440917 0.0238095 0.00440917 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
648 string
216 216 8 [216 0 0 216 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF00\
73FF0073FF0066FF004CFF003FFF0026FF0000FF9900FF9900FF0000FF8C4CFF00
59FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF008CFF00\
0CFF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF00\
73FF0073FF0066FF0026FF0000FF0C00FF6600FF2619FF0033FF003FFF004CFF00
59FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0080FF003FFF00\
99FF00A6FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0080FF00\
73FF0073FF0066FF004CFF003FFF0019FF0000FF3319FF0033FF003FFF004CFF00
59FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0059FF0066FF00\
99FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF00\
73FF0066FF0059FF004CFF003FFF0000FF0C00FFE600FF0033FF003FFF004CFF00
59FF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0073FF008CFF008CFF00
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00\
99FF008CFF0080FF008CFF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF0099FF0080FF008CFF008CFF008CFF004CFF000CFF0073FF008CFF00\
A6FF00A6FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0073FF00\
66FF0066FF0059FF003FFF0033FF0019FF0000FFB319FF0033FF003FFF004CFF00
4CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0059FF0066FF0066FF0059FF0019FF0073FF0080FF008CFF00
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
8CFF0080FF0000FF1980FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF0099FF0000FFD94CFF0073FF0066FF0000FFA666FF008CFF0099FF00\
A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF0066FF00\
59FF0059FF004CFF0026FF0000FF2600FF1900FF4C00FF0026FF0033FF003FFF00
4CFF004CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0066FF0066FF0033FF003FFF0019FF003FFF0066FF0080FF0080FF008CFF00
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00\
8CFF0073FF0000FF4073FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0080FF0066FF0000FF4C00FF1933FF004CFF008CFF0099FF00\
A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0059FF003FFF003FFF00\
19FF0019FF000CFF0000FF0C19FF0000FF4019FF0000FF000CFF0026FF0033FF00
26FF0033FF0033FF0033FF0059FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0066FF00\
66FF0066FF0059FF003FFF0000FF2633FF0059FF0073FF0080FF0080FF008CFF00
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00\
80FF0066FF004CFF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF008CFF0080FF0073FF003FFF004CFF0073FF0080FF0099FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00D9FF00D9FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0066FF0059FF003FFF0000FF1900FF99\
33FF003FFF003FFF0026FF003FFF003FFF0033FF0026FF0000FF4C00FF2619FF00
00FF0000FF330CFF003FFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
59FF003FFF003FFF0026FF0000FF194CFF0066FF0073FF0080FF0080FF008CFF00
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF00\
73FF000CFF0059FF0073FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF008CFF008CFF0080FF0066FF0000FF5900FF3373FF008CFF0099FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0059FF004CFF0026FF004CFF004CFF00\
59FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF0019FF0000FF9900FF19
00FF7300FF0C26FF003FFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0059FF0059FF00\
4CFF0033FF0000FF0000FF0C00FF193FFF0066FF0073FF0080FF0080FF008CFF00
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0073FF00\
59FF0019FF0019FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF008CFF008CFF0080FF0073FF0066FF003FFF004CFF0073FF0080FF0099FF0099FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0059FF0066FF0066FF00\
66FF0066FF0066FF0066FF0059FF0059FF004CFF003FFF0000FF4000FF0C00FF99
00FFA600FF190CFF0000FF4C3FFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF004CFF00\
3FFF0026FF0000FF1926FF003FFF003FFF004CFF0073FF0080FF0080FF008CFF00
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0073FF0000FF0000FF4C\
00FF0019FF0059FF0073FF0080FF0080FF008CFF0099FF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF0099FF008CFF0059FF0059FF0066FF004CFF0026FF0000FF0C59FF0073FF0080FF0099FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0073FF00\
73FF0073FF0066FF0066FF0066FF0059FF0059FF004CFF0033FF000CFF0000FFB3
00A6FF00FF4000FF2626FF003FFF004CFF004CFF004CFF004CFF0033FF003FFF003FFF003FFF00\
0CFF0000FF4C19FF004CFF0059FF0066FF0073FF0073FF0080FF0080FF008CFF00
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0066FF0059FF00\
3FFF0000FF7326FF0066FF0066FF0073FF0080FF008CFF0099FF0099FF0099FF00
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00
99FF008CFF008CFF0073FF004CFF0000FF0000FF1926FF0059FF0066FF003FFF0059FF008CFF00\
A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0080FF00\
73FF0073FF0073FF0073FF0066FF0066FF0059FF004CFF0026FF0000FF9900FF26
00FF2600FF0000FF400CFF0033FF003FFF003FFF003FFF003FFF0019FF0019FF0000FF7300FF4C\
0CFF0033FF003FFF0059FF0066FF0066FF0073FF0080FF0080FF0080FF008CFF00
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0066FF00\
4CFF0000FF730CFF003FFF003FFF0026FF0073FF008CFF008CFF0099FF0099FF00
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
8CFF008CFF0080FF0073FF0059FF0000FF804CFF0059FF0073FF0080FF008CFF008CFF0099FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF00\
80FF0073FF0073FF0073FF0073FF0066FF0059FF003FFF0033FF0026FF0000FF26
26FF0019FF0000FF0000FF6619FF0026FF0033FF0019FF0026FF0000FF0000FF0C00FF1933FF00\
4CFF004CFF0059FF0066FF0066FF0073FF0073FF0080FF0080FF0080FF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0066FF00\
59FF003FFF0019FF0000FF0C4CFF0066FF0080FF008CFF008CFF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00
8CFF0080FF0073FF0059FF004CFF0000FF0059FF0073FF0080FF008CFF0099FF0099FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF00\
80FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF004CFF004CFF003FFF00
33FF0033FF0026FF000CFF0000FF2600FF400CFF0000FFB300FF0000FF4019FF0033FF004CFF00\
59FF0059FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0066FF00\
59FF003FFF000CFF0026FF0059FF0073FF0080FF0080FF008CFF008CFF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0073FF0066FF0019FF0000FF2600FF0059FF0080FF008CFF0099FF0099FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF00\
80FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF004CFF004CFF00
3FFF003FFF0033FF0026FF0000FF0C00FFA600FF3300FF2600FF4000FF260CFF003FFF004CFF00\
59FF0066FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0059FF00\
3FFF0019FF000CFF003FFF0059FF0073FF0080FF0080FF008CFF008CFF008CFF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00\
8CFF0073FF0073FF0080FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00
73FF0066FF0019FF0000FF0059FF0066FF0066FF0080FF008CFF0099FF0099FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF00\
80FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF004CFF00
4CFF003FFF003FFF0033FF0019FF0000FF0000FF260CFF0019FF0026FF0026FF003FFF0059FF00\
59FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF004CFF00\
33FF0026FF0000FF4033FF0059FF0066FF0073FF0080FF008CFF008CFF008CFF00
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00\
80FF0073FF003FFF0066FF0080FF0080FF0080FF0080FF0073FF0000FFD966FF00
33FF0000FF5933FF0059FF0066FF0080FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00\
80FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF00
4CFF003FFF003FFF0033FF0019FF0000FF0C00FF1919FF0026FF0033FF003FFF004CFF0059FF00\
59FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0066FF00\
59FF003FFF0000FF000CFF0019FF003FFF0073FF0080FF0080FF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00\
80FF0066FF0033FF004CFF0073FF0073FF0073FF0073FF0066FF003FFF0000FF00
00FF194CFF0066FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00\
80FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF00
4CFF003FFF003FFF0033FF000CFF0000FF3300FF660CFF0033FF003FFF004CFF004CFF0059FF00\
66FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00
80FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0066FF00\
59FF004CFF0026FF0000FF264CFF0066FF0073FF0080FF0080FF0080FF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00\
80FF0073FF004CFF0000FFBF59FF0066FF0059FF0059FF004CFF0019FF0026FF00
4CFF0066FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00\
80FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF004CFF00
4CFF003FFF003FFF0026FF000CFF0000FF4000FF400CFF0033FF003FFF004CFF004CFF0059FF00\
66FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00
80FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF00\
66FF0033FF0000F3FF19FF004CFF0066FF0073FF0073FF0080FF0080FF0080FF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00\
80FF0073FF0066FF003FFF0026FF003FFF003FFF0026FF0033FF0000FF003FFF00
66FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00\
80FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF004CFF00
3FFF003FFF0033FF0026FF0019FF0000FF0C00FF2619FF0033FF003FFF004CFF004CFF0059FF00\
66FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00
80FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF0066FF00\
66FF004CFF0033FF0000FF2619FF0066FF0073FF0073FF0080FF0080FF0080FF00
80FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF00\
73FF0073FF0066FF004CFF0019FF000CFF0000FFBF0CFF0000FF4000FF0C33FF00
59FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF00\
80FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF004CFF003FFF00
33FF0033FF0026FF0026FF000CFF0000FF0C00FF330CFF0026FF0033FF003FFF004CFF0059FF00\
59FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF00\
66FF0059FF003FFF0000FFE64CFF0059FF0066FF0073FF0073FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF00\
73FF0066FF0066FF004CFF0033FF0000FF4026FF0033FF0026FF004CFF003FFF00
00FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF00\
80FF0080FF0073FF0073FF0066FF0066FF0059FF0059FF0059FF004CFF0033FF00
00FF3319FF0019FF0000FF0000FF0000FF6600FF3300FF4000FF0C19FF0019FF0000FF004CFF00\
59FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF00\
66FF0059FF003FFF000CFF004CFF0059FF0066FF0073FF0073FF0073FF0073FF00
80FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0080FF0080FF0073FF0073FF0073FF00\
73FF0066FF0059FF004CFF0026FF000CFF003FFF004CFF0059FF0066FF0066FF00
73FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF00\
80FF0073FF0073FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF00
19FF0000FF8000FF2600FFA600FF3300FF2600FF0000FF5919FF0000FF0000FF400CFF000CFF00\
4CFF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF00\
66FF0059FF0033FF0000FF663FFF0059FF0066FF0066FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0066FF0019FF0066FF0073FF0073FF0073FF0073FF0073FF00\
66FF0059FF003FFF0026FF0000FF4C19FF003FFF0059FF0066FF0066FF0073FF00
80FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF00\
80FF0066FF004CFF004CFF0000FF593FFF003FFF003FFF003FFF0033FF0033FF00
19FF0000FF0C00FF2600FF0C00FF0C00FF1919FF0026FF0033FF0033FF0033FF003FFF004CFF00\
59FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF00\
59FF004CFF0026FF0000D9FF19FF004CFF0059FF0059FF0066FF0066FF0073FF00
73FF0073FF0073FF0073FF0066FF0059FF0000FF264CFF0066FF0066FF0066FF0066FF0066FF00\
66FF0059FF0033FF0000FF2600FF7300FF1926FF0059FF0066FF0073FF0073FF00
80FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00\
73FF0066FF004CFF0000FF4000FF0000FF1900FF0026FF0026FF0000FF1919FF00
00FF0000FFCC00FF0C0CFF0019FF000CFF0026FF0033FF003FFF003FFF004CFF004CFF0059FF00\
59FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF00\
59FF004CFF0026FF0000FF4019FF003FFF004CFF004CFF004CFF0059FF0066FF00
66FF0066FF0066FF0066FF0066FF004CFF0019FF003FFF0059FF0066FF0066FF0066FF0066FF00\
59FF004CFF0033FF0019FF0000FF2600FF0026FF004CFF0066FF0073FF0073FF00
80FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00\
73FF0073FF0066FF003FFF003FFF0033FF0026FF0000FF0000FF1900FF6600FF19
00FF1900FF4C00FF0C19FF0026FF0033FF0033FF003FFF004CFF004CFF004CFF0059FF0059FF00\
66FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0059FF00\
4CFF003FFF0019FF0000FF6619FF0033FF003FFF003FFF0000FFE64CFF0059FF00
66FF0066FF0066FF0066FF0059FF004CFF0026FF0026FF004CFF0059FF0059FF0059FF0059FF00\
59FF004CFF003FFF000CFF0000FF800CFF004CFF0059FF0066FF0073FF0080FF00
80FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00\
73FF0073FF0066FF0059FF0059FF004CFF003FFF0033FF000CFF000CFF0000FF26
00FF9900FF0019FF0026FF0033FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF0059FF00\
66FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF004CFF00\
00FFCC00FF0C00FF0000FF0000FF3300FF0026FF000CFF0019FF004CFF0059FF00
59FF0059FF0059FF0059FF0059FF004CFF0033FF0019FF003FFF004CFF004CFF004CFF004CFF00\
4CFF003FFF0033FF0019FF0000FF003FFF004CFF0059FF0066FF0073FF0073FF00
80FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00\
73FF0073FF0066FF0066FF0059FF0059FF004CFF003FFF0033FF0026FF000CFF00
00FF2600FF0019FF0026FF0033FF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF00\
66FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF00\
4CFF003FFF0033FF0026FF0000B3FF00FF4C00FF1900FF6633FF003FFF004CFF00
59FF0059FF0059FF004CFF004CFF003FFF0000FF2600FF730CFF0033FF0026FF0033FF003FFF00\
3FFF003FFF0033FF0000FF4019FF003FFF004CFF0059FF0066FF0073FF0073FF00
80FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF00\
73FF0073FF0066FF0066FF0059FF0059FF004CFF004CFF003FFF0033FF0019FF00
00FF3300FF0019FF0026FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0066FF00\
66FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF00\
59FF004CFF003FFF0033FF0026FF000CFF0000FF2600FF0026FF003FFF003FFF00
4CFF004CFF004CFF003FFF003FFF0033FF0026FF0000FF730CFF0019FF0000FF0019FF0033FF00\
33FF000CFF0019FF0000FF1900FF0000FF193FFF004CFF0059FF0066FF0073FF00
73FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF00\
73FF0073FF0066FF0066FF0059FF0059FF004CFF004CFF003FFF0033FF0019FF00
00FF2600FF8C19FF0026FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0066FF00\
66FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00\
59FF004CFF004CFF003FFF0033FF0019FF0000FF0C00FF400CFF0033FF003FFF00
3FFF003FFF0033FF0026FF0033FF0026FF0019FF0000FF4000FF6600FFA600FF7300FF1919FF00\
19FF0000FF3300FF4C00FF0000FF0C00FF000CFF0033FF004CFF0059FF0066FF00
66FF0066FF0073FF0080FF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF00\
73FF0073FF0066FF0066FF0059FF0059FF004CFF004CFF003FFF0026FF0000FF4C
00FFE600FF1900FF000CFF0033FF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0066FF00\
66FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00\
59FF0059FF004CFF003FFF0033FF000CFF0000FF5900FF0C19FF0026FF0033FF00
33FF0033FF000CFF0000FF1900FF0C00FF0000FF9900FF000CFF0000FF0000FF0000FF6600FF19\
00FF0C00FF3300FF4C26FF0026FF0000FF8019FF0000FF0033FF0033FF0000FF0C
4CFF000CFF0066FF0073FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF00
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00\
73FF0066FF0066FF0066FF0059FF0059FF004CFF003FFF0026FF000CFF0000FF0C
00FF7300FFBF00FF2600FF0C26FF0033FF003FFF004CFF004CFF0059FF0059FF0059FF0066FF00\
66FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF00\
59FF0059FF004CFF0033FF000CFF0000FF1900FF7300FF0C0CFF0019FF0026FF00
26FF0019FF0000FF0C00FF8C00FFB300FF2600FF0019FF0026FF0026FF0019FF000099FF00FF19\
00FFA619FF0033FF003FFF003FFF000CFF003FFF004CFF0000FF0C00FF2619FF00
00FF2633FF003FFF0000FF1973FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
99FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0073FF0066FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00\
66FF0066FF0066FF0059FF0059FF004CFF004CFF003FFF0026FF0000FF2600FF4C
00F3FF00FFBF00FF3300FF6600FF4C00FF003FFF004CFF004CFF0059FF0059FF0059FF0059FF00\
66FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF00\
59FF0059FF004CFF0019FF000CFF000CFF0000FF0000FF8C00FF330CFF0019FF00
19FF0000FF3300FF1900FF660073FF00FF0C19FF0026FF0033FF0033FF0033FF0026FF0026FF00\
00FF0C26FF003FFF004CFF004CFF0059FF0059FF0059FF0059FF003FFF0059FF00
26FF0059FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00\
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0059FF0026FF0066FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF00\
59FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF0000FF3300FF19
00FF4C00FF4000FF0C0CFF0026FF0033FF003FFF004CFF004CFF0059FF0059FF0059FF0059FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0059FF00\
59FF0059FF004CFF003FFF0033FF0026FF0019FF0000FF3300FF5900FF1900FF73
00FF1900FF7300FF6600FF2600FF2600FF2619FF0033FF003FFF003FFF003FFF003FFF0033FF00\
26FF000CFF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF00
66FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF00\
8CFF0026FF0000FF5966FF0073FF0066FF0073FF0066FF0059FF0019FF0059FF00
66FF0066FF0066FF004CFF0066FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF00\
00FF004CFF004CFF004CFF004CFF004CFF003FFF003FFF0033FF0019FF0000FF00
00FF2600FF5900FF3319FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0059FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF0059FF00\
59FF0059FF004CFF003FFF003FFF0033FF0019FF000CFF0000FF1900FF4C00FF4C
0CFF000CFF000CFF0000FF000CFF0000FF1933FF003FFF003FFF004CFF004CFF004CFF004CFF00\
3FFF0000FF0C33FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF00
73FF0080FF0080FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF0099FF00\
99FF0080FF0073FF0059FF0033FF0000FF0059FF004CFF003FFF0000FFCC33FF00
3FFF0059FF004CFF0019FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF00\
26FF0000FF193FFF003FFF003FFF003FFF003FFF0033FF0026FF0019FF0000FF00
00FF8C00FF0C19FF0026FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0059FF00\
59FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF00\
66FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF00\
59FF0059FF004CFF003FFF003FFF0033FF0019FF0000FF0000FF2600FF260CFF00
19FF0026FF0026FF0026FF0033FF0026FF003FFF004CFF004CFF004CFF004CFF004CFF004CFF00\
4CFF004CFF003FFF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF00
80FF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00\
99FF008CFF008CFF0073FF004CFF0019FF0026FF0000FF0000FF1926FF0000FF00
19FF0033FF0026FF000CFF003FFF003FFF004CFF0059FF0059FF0059FF0059FF0059FF004CFF00\
3FFF000CFF0026FF0033FF0033FF0033FF0033FF0033FF0026FF0019FF0000FF00
00FF5900FF0026FF0033FF0033FF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF00\
59FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF00\
59FF0026FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF00\
59FF004CFF004CFF003FFF003FFF0026FF0000FF6600FF8C00FF3300FF0C19FF00
26FF0033FF0033FF003FFF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF00\
59FF0059FF0059FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF00
80FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF008CFF0080FF0073FF0059FF0000FF003FFF003FFF004CFF000CFF00
00FF4000FF4C0CFF000CFF000CFF0000FF0033FF004CFF004CFF004CFF004CFF004CFF003FFF00\
33FF000CFF0000FFF319FF0000FF2619FF0026FF0026FF0019FF000CFF0000FF19
00FF0C19FF0026FF0033FF0033FF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF00\
59FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF00\
4CFF0000FF194CFF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF00\
59FF004CFF004CFF003FFF003FFF0033FF0019FF0000FF0C00FF800CFF0026FF00
33FF0033FF003FFF003FFF004CFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0066FF00\
66FF0066FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00
80FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF008CFF008CFF0080FF004CFF004CFF0066FF0066FF0059FF004CFF00
00FF663FFF003FFF0033FF0019FF0026FF000CFF0000FF0C26FF0033FF0000FF1933FF0033FF00\
26FF000CFF0000FFB300FF5900FF730CFF000CFF0000FF000CFF0000FF0000FF33
00FF4C19FF0026FF0033FF0033FF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF00\
59FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF00\
33FF0000FF263FFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF00\
4CFF004CFF004CFF003FFF003FFF0033FF0019FF0000FF0C00FF6600FF0026FF00
33FF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0066FF0066FF00\
66FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF0099FF008CFF0080FF0033FF0066FF0073FF0073FF0066FF0059FF00
26FF0059FF0059FF004CFF004CFF004CFF004CFF003FFF0000FF0000E6FF00FFCC19FF000CFF00\
00FFA600FF8000FF0000FF0000FF4C00FF1900FF0C00FF7300FFE600FF3300FF80
00FF1900FF0019FF0026FF0033FF003FFF003FFF004CFF004CFF004CFF004CFF0059FF0059FF00\
59FF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF00\
33FF0000FF4000FF8C4CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF004CFF00\
4CFF004CFF003FFF003FFF0033FF0026FF000CFF0000FF6600FF190CFF0026FF00
3FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0066FF0066FF0066FF00\
66FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF00
66FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF0026FF0033FF0000FF0C00FF8C00FF4C\
00FF1900FF0019FF0019FF0000FF2600FF4C00FF4000FF8000FF4000FF0C00FF26
00FF8000FF1919FF0026FF0033FF0033FF003FFF003FFF004CFF004CFF004CFF004CFF0059FF00\
59FF0059FF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF00\
26FF0000FF5933FF004CFF0059FF0059FF0059FF0059FF0066FF0066FF0066FF00
66FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF00\
4CFF004CFF003FFF003FFF0033FF0026FF000CFF000099FF19FF0026FF0033FF00
3FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF00\
66FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF00
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0080FF0073FF00
73FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF004CFF0033FF0000FF0C19FF00\
26FF0033FF0033FF0026FF0019FF0000FF2600FF000CFF000CFF000CFF0000FF0C
00FFBF00FF0C0CFF0019FF0019FF0033FF003FFF003FFF004CFF004CFF004CFF004CFF0059FF00\
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF003FFF00\
33FF0000FF7326FF003FFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF00\
3FFF003FFF003FFF0033FF0019FF000CFF0000FF4C19FF0026FF0033FF003FFF00
3FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF00\
73FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF00
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0080FF00
80FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF003FFF0000FF3333FF00\
3FFF003FFF003FFF0033FF0026FF0000FF4019FF0026FF0026FF0019FF000CFF00
00FF4000FF5900FF3300FF1900FF0C26FF0033FF003FFF003FFF004CFF004CFF004CFF004CFF00\
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF00\
26FF0000FF0033FF003FFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF0059FF0059FF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF003FFF00\
3FFF0033FF0033FF0026FF000CFF0000FF6600FF0C26FF0033FF0033FF003FFF00
3FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF00\
73FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF00
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF003FFF0019FF003FFF00\
4CFF004CFF004CFF003FFF0026FF0000FF0C33FF0033FF0033FF0026FF0000FF00
00FF0C00FF0C00FF1900FF3319FF0026FF0033FF003FFF003FFF004CFF004CFF004CFF004CFF00\
4CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF003FFF0033FF0026FF00\
00FF0000FF0033FF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF00
59FF004CFF004CFF003FFF003FFF004CFF004CFF004CFF004CFF004CFF004CFF003FFF003FFF00\
26FF0000FF0C0CFF000CFF0000FF0C00FF6600FF0026FF0033FF003FFF003FFF00
4CFF004CFF004CFF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0073FF00\
73FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0033FF004CFF004CFF00\
59FF004CFF004CFF004CFF003FFF0033FF003FFF003FFF003FFF0033FF0000FF00
19FF0019FF0000FF0C00FF4000FF0C26FF0033FF003FFF003FFF003FFF004CFF004CFF004CFF00\
4CFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
4CFF004CFF003FFF003FFF004CFF004CFF004CFF004CFF004CFF003FFF003FFF0000FF2600FF0C\
00FF9900FF0026FF0033FF003FFF003FFF004CFF004CFF004CFF004CFF004CFF00
4CFF004CFF004CFF0033FF000CFF0033FF003FFF003FFF003FFF003FFF003FFF003FFF0033FF00\
26FF000CFF0000FF3300FF3300FF4000FF1900FF1926FF0033FF003FFF003FFF00
4CFF004CFF004CFF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0073FF00\
73FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00
80FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF00\
59FF0059FF0059FF004CFF004CFF004CFF004CFF003FFF003FFF003FFF0033FF00
33FF0026FF000CFF0000FF0C00FF0C26FF0033FF0033FF003FFF003FFF003FFF003FFF004CFF00\
4CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00
4CFF003FFF0033FF0019FF0033FF003FFF003FFF003FFF003FFF003FFF0033FF0026FF0000FF00\
00FF6600FF0019FF0026FF0033FF003FFF003FFF004CFF004CFF004CFF004CFF00
4CFF004CFF003FFF0026FF0000FF330CFF0026FF0033FF003FFF003FFF003FFF0033FF0033FF00\
26FF0019FF0000FF0000FF3300FF190CFF0019FF0026FF0033FF003FFF003FFF00
4CFF004CFF004CFF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0073FF00\
73FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00
8CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00\
66FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF004CFF003FFF003FFF00
33FF0033FF0026FF000CFF0000FF1919FF0026FF0033FF0033FF003FFF003FFF003FFF003FFF00\
4CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00
4CFF003FFF0026FF0000FF260CFF0026FF0033FF003FFF0033FF0033FF0026FF0019FF000CFF00\
00FF4C00FF190CFF000CFF0000FF4033FF003FFF003FFF004CFF004CFF004CFF00
3FFF003FFF0033FF0026FF0000FF0000FF4019FF0033FF0033FF0033FF0033FF0033FF0026FF00\
26FF0019FF0000FF0C00FF8000FF4C0CFF0019FF0026FF0033FF003FFF003FFF00
4CFF004CFF004CFF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0073FF00\
73FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF008CFF0080FF0073FF0099FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF00\
66FF0066FF0066FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF00
3FFF0033FF0026FF0019FF0000FFA600FF0019FF0026FF0033FF0033FF003FFF003FFF003FFF00\
3FFF003FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00
3FFF0033FF0026FF0000FF0000FF5919FF0026FF0033FF0033FF0026FF0019FF000CFF0000FF00\
00FF1900FF6600FF5900FF1919FF0033FF003FFF003FFF003FFF003FFF003FFF00
3FFF003FFF0033FF0026FF0000FF4000FF8C00FF0C26FF0026FF0026FF0026FF0019FF0019FF00\
19FF000CFF0000FF0C00FF4000FF8C0CFF0019FF0026FF0033FF0033FF003FFF00
4CFF004CFF004CFF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0073FF00\
73FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF008CFF008CFF008CFF008CFF0080FF0019FF0080FF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF00\
66FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF00
3FFF003FFF0033FF000CFF0000FFBF00FF3300FF0C00FF0026FF0033FF0033FF0033FF0033FF00\
33FF003FFF003FFF003FFF003FFF004CFF004CFF004CFF004CFF003FFF003FFF00
3FFF0033FF0026FF000CFF0000FF2600FF1919FF0026FF0026FF0019FF0000FF1900FF1900FF99\
00FF3300FF5900FF000CFF0026FF0033FF0033FF003FFF003FFF003FFF003FFF00
3FFF0033FF0033FF0026FF0019FF0000FF1900FF2619FF0019FF0019FF0019FF0000FF0C00FF19\
00FF0000FF0000FF0C00FF3300FF2600FF000CFF0019FF0026FF0033FF003FFF00
3FFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0073FF00\
73FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00
8CFF008CFF008CFF008CFF0080FF0073FF0059FF004CFF0080FF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF00
8CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF00\
66FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF00
3FFF003FFF0033FF0019FF0000FF0000FF3300FF260CFF0019FF0026FF0026FF0026FF0026FF00\
26FF0033FF003FFF003FFF003FFF003FFF003FFF003FFF003FFF003FFF003FFF00
3FFF0033FF0026FF0019FF000CFF0000FF4000FF000CFF000CFF000CFF0000FF0C00FF4C00FFBF\
00FF6600FF8000FF0019FF0026FF0026FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0033FF0026FF0019FF000CFF0000FF7300FF000CFF000CFF000CFF0000FF0000FF59\
00FF2600FF4000FF2600FF7300FF7300FF8000FF2600FF3300FF6600FF333FFF00
3FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF00\
73FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF00
8CFF0066FF0073FF0073FF0073FF0033FF004CFF0073FF008CFF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF00
8CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF00\
66FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF004CFF004CFF00
3FFF003FFF0033FF0026FF0000FF0C00FF8000FF190CFF0019FF0019FF0019FF0019FF0000FF19\
00FF0C26FF0033FF003FFF003FFF003FFF003FFF003FFF003FFF003FFF003FFF00
33FF0033FF0026FF0026FF0019FF0000FF0C00FF5900FF0C00FF1900FF0C00FF4000FFB300FF33\
00FF1900FF0C0CFF0019FF0026FF0026FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0026FF0026FF0019FF0000FF0000FF4C00FF3300FF6600FF0C00FF0000FF0C00FF33\
00FF9900FF7300FF7300FF4000FF1900FF0C00FF0000FF0019FF0033FF003FFF00
3FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF00\
73FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
80FF0066FF0000FFCC59FF000CFF0000FF2666FF0080FF008CFF0099FF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF00
8CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00\
73FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF004CFF004CFF00
3FFF003FFF0033FF0019FF0000FF0000FF4C00FF2600FF0C00FF000CFF000CFF000CFF0000FF40\
00FF5926FF0033FF0033FF003FFF003FFF003FFF003FFF003FFF003FFF0033FF00
33FF0033FF0026FF0026FF0019FF0000FF0000FF7300FF8C00FF5900FF2600FF4000FF9900FF33\
00FF0C00FF000CFF0019FF0019FF0026FF0026FF0026FF0033FF0033FF0033FF00
33FF0026FF0026FF0026FF0019FF0000FF0000FF1900FF4000FF7300FF2600FF1900FF8000FFFF\
00FF3300FF2600FF3300FF4000FF000CFF0019FF0019FF0026FF0033FF003FFF00
3FFF004CFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF00\
66FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00
80FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0073FF0059FF0019FF0000FF003FFF0066FF0080FF008CFF008CFF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00\
73FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF00
4CFF003FFF0026FF0000FF9900FF2600FF1900FF4C00FF9900FF2600FF0000FF0C00FF1900FF26\
0CFF0026FF0026FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0026FF0026FF0019FF0000FF0000FF0C00FF2600FFA600FF8000FF7300FF3300FF19\
00FF000CFF000CFF0019FF0019FF0026FF0026FF0026FF0026FF0026FF0026FF00
26FF0026FF0026FF0019FF0019FF000CFF0000FF0C00FF2600FF9900FF4000FF4000FF8C00D9FF\
00FF2600FF0C00FF0C00FF0C0CFF0019FF0019FF0026FF0033FF0033FF003FFF00
3FFF003FFF004CFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0066FF0066FF0066FF00\
66FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00
80FF0073FF0059FF003FFF0019FF0059FF0073FF0080FF008CFF008CFF0099FF0099FF0099FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00\
73FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF00
4CFF003FFF0026FF0019FF000CFF000CFF0000FF1900FF6600FF8C00FF2600FF4000FF2600FF00\
19FF0026FF0026FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0026FF0026FF0026FF0019FF000CFF0000FF0000FF1900FF2600FF4C00FF6600FF2600FF0C\
00FF0000FF000CFF0019FF0019FF0019FF0019FF0026FF0026FF0026FF0026FF00
26FF0026FF0019FF0019FF000CFF000CFF0000FF0000FF2600FF4000FF8000FF5900FF3300FF26\
00FF0C00FF0000FF000CFF000CFF0019FF0026FF0026FF0033FF0033FF003FFF00
3FFF003FFF003FFF004CFF004CFF004CFF004CFF004CFF0059FF0059FF0059FF0066FF0066FF00\
66FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00
73FF0066FF0059FF0026FF0000FF664CFF0066FF0073FF0080FF008CFF0099FF0099FF0099FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00\
73FF0073FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF00
4CFF003FFF0033FF0026FF0026FF0019FF0000FF0000FF0C00FF2600FF5900FF4000FF190CFF00\
19FF0019FF0026FF0026FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
26FF0026FF0026FF0019FF0019FF000CFF000CFF0000FF0000FF1900FF4000FFB300FF2600FF0C\
00FF0000FF000CFF000CFF000CFF0019FF0019FF0019FF0019FF0019FF0019FF00
19FF0019FF0019FF0019FF000CFF000CFF0000FF0000FF0C00FF3300FFBF00FF3300FF1900FF0C\
00FF0C00FF000CFF000CFF0019FF0019FF0026FF0026FF0033FF0033FF0033FF00
3FFF003FFF003FFF003FFF004CFF004CFF004CFF004CFF004CFF004CFF0059FF0059FF0066FF00\
66FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF00
66FF0066FF0059FF003FFF0000FFA633FF004CFF003FFF0073FF008CFF0099FF0099FF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00\
73FF0073FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF00
4CFF003FFF003FFF0033FF0026FF0019FF000CFF0000FF0000FF1900FF9900FF4000FF0C00FF00\
19FF0019FF0026FF0026FF0026FF0026FF0026FF0033FF0026FF0026FF0026FF00
26FF0026FF0026FF0019FF0019FF000CFF000CFF0000FF0000FF0C00FF2600FFD900FF2600FF0C\
00FF0C00FF0000FF000CFF000CFF000CFF000CFF000CFF0000FF0000FF000CFF00
19FF0019FF000CFF000CFF000CFF0000FF0000FF0000FF1900FF2600FF8C00FF9900FF1900FF0C\
00FF0000FF000CFF000CFF0019FF0019FF0026FF0026FF0033FF0033FF0033FF00
3FFF003FFF003FFF003FFF003FFF003FFF003FFF0033FF0019FF003FFF0059FF0059FF0059FF00\
66FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0073FF0066FF00
3FFF003FFF003FFF0019FF0000FF4026FF004CFF0019FF0073FF008CFF008CFF0099FF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00\
73FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF00
4CFF003FFF003FFF0033FF0026FF0019FF000CFF0000FF0C00FF2600FF4C00FFF300FF5900FF59\
0CFF0019FF0019FF0026FF0026FF0026FF0026FF0026FF0026FF0026FF0026FF00
26FF0019FF0019FF0019FF0019FF000CFF0000FF0000FF0000FF0C00FF260033FF00FF3300FF19\
00FF0C00FF0C00FF0000FF0000FF0000FF0000FF0000FF0000FF2600FF1900FF00
0CFF000CFF000CFF0000FF0000FF0000FF0000FF0C00FF1900FF3300FF4C00FF2600FF0C00FF0C\
00FF000CFF000CFF0019FF0019FF0019FF0026FF0026FF0026FF0033FF0033FF00
33FF0033FF003FFF003FFF003FFF0033FF0026FF0000FF190CFF003FFF004CFF0059FF0059FF00\
59FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0066FF00
4CFF0026FF0000FF260CFF000CFF0059FF0066FF0073FF0080FF008CFF008CFF0099FF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00\
73FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF00
3FFF003FFF0033FF0033FF0026FF000CFF0000FF0000FF1900FF4C00FF6600FF3300FF1900FF00\
0CFF0019FF0019FF0019FF0026FF0026FF0026FF0026FF0026FF0026FF0019FF00
19FF0019FF0019FF0019FF000CFF000CFF0000FF0000FF0C00FF190059FF00FF8000FF4000FF33\
00FF1900FF0C00FF0C00FF0C00FF1900FF1900FF0C00FF1900FF7300FF1900FF0C
00FF0000FF0000FF0000FF0C00FF0C00FF0C00FF1900FF3300FF7300FF4000FF1900FF0C00FF0C\
00FF000CFF000CFF000CFF0019FF0019FF0026FF0026FF0026FF0026FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0019FF0000FF0C00FF0C3FFF004CFF004CFF0059FF00\
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0066FF0073FF0073FF00
73FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF00
59FF003FFF0000FF2633FF004CFF0066FF0073FF0080FF0080FF008CFF008CFF0099FF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF00A6FF00A6FF00A6FF0099FF0099FF0080FF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF00\
73FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF004CFF00
3FFF003FFF0033FF0033FF0019FF0000FF9900FF3300FFE600FF8C00FF3300FF1900FF0C00FF00\
0CFF0019FF0019FF0019FF0019FF0019FF0019FF0019FF0019FF0019FF000CFF00
0CFF000CFF000CFF000CFF000CFF0000FF0000FF0C00FF0C00FF1900FF3300FF8000FF7300FF80\
00FF2600FF1900FF1900FF1900FF3300FF4C00FF2600FF3300FFA600FF3300FF19
00FF0C00FF0C00FF2600FF2600FF1900FF1900FF2600FF5900FF6600FF3300FF2600FF0C00FF0C\
00FF0000FF000CFF000CFF0019FF0019FF0019FF0026FF0026FF0026FF0026FF00
33FF0033FF0033FF0033FF0026FF0026FF000CFF0000FFD919FF0033FF003FFF004CFF004CFF00\
4CFF004CFF004CFF004CFF004CFF0026FF0026FF004CFF0066FF0073FF0073FF00
73FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0066FF00
59FF003FFF000CFF0033FF004CFF0066FF0073FF0080FF008CFF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
00FF0C59FF008CFF008CFF0099FF0099FF008CFF0080FF004CFF008CFF0099FF0099FF0099FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF00\
73FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF004CFF004CFF003FFF00
3FFF0033FF0033FF0026FF0019FF000CFF0000FF0000FF1900FF9900FF3300FF1900FF0C00FF00\
0CFF000CFF0019FF0019FF0019FF0019FF0019FF0019FF0019FF000CFF0000FF40
00FF000CFF000CFF0000FF0000FF0000FF2600FF2600FF2600FF2600FF6600FF8C00FF8000FF40\
00FF3300FF2600FF2600FF2600FF3300FFFF00FF5900FFF300FF8C00FF4000FF26
00FF1900FF1900FF3300FF8000FF3300FF3300FF4000FF5900FF8C00FF4000FF3300FF1900FF0C\
00FF0000FF0000FF000CFF000CFF0019FF0019FF0019FF0019FF0026FF0026FF00
26FF0026FF0026FF0026FF0026FF0019FF000CFF0000FF4019FF0033FF003FFF003FFF003FFF00\
3FFF003FFF004CFF003FFF0033FF0000FF4C33FF0059FF0066FF0066FF0073FF00
73FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0059FF00
33FF0026FF0000FF7300FF0000FF0059FF0073FF0080FF008CFF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0080FF0026FF0073FF0033FF0080FF0080FF0073FF004CFF0080FF008CFF0099FF0099FF00\
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF00\
66FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF003FFF003FFF0033FF00
33FF0033FF0026FF0026FF0019FF000CFF0000FF0000FF2600FFBF00FFF300FF3300FF0C00FF00\
0CFF000CFF000CFF000CFF0019FF0019FF0019FF000CFF000CFF0000FF0000FF26
00FF2600FF0C00FF0000FF0000FF0C00FF2600FF8000FF4C00FF4000FF6600FF8C00FF5900FF40\
00FF3300FF3300FF3300FF3300FF4000FF5900E6FF00FF7300FF4C00FF3300FF26
00FF2600FF2600FF3300FF7300FF5900FF4C00FF9900FF8000FF9900FF8000FF4C00FF1900FF0C\
00FF0C00FF0000FF0000FF000CFF000CFF000CFF000CFF0019FF0019FF0026FF00
26FF0026FF0026FF0026FF0019FF000CFF0000FF1900FF0C19FF0026FF0033FF0033FF0033FF00\
26FF0033FF0033FF0033FF0000FF0000FF6600FF1959FF0066FF0066FF0073FF00
73FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF00
3FFF0000FF2626FF004CFF0059FF0066FF0073FF0080FF008CFF008CFF008CFF008CFF0099FF00\
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0073FF000CFF0000FF0C66FF0066FF004CFF0000FF0073FF0080FF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF00\
66FF0066FF0066FF0066FF0059FF0059FF004CFF0026FF0026FF0026FF000CFF00
19FF0019FF0019FF0019FF000CFF0000FF0000FF0C00FF2600FF6600FF7300FF1900FF0C00FF00\
00FF000CFF000CFF000CFF000CFF000CFF000CFF000CFF0000FF0000FF0000FF19
00FF4000FF1900FF0C00FF0C00FF1900FF2600FF3300FF6600D9FF00FF8C00FF8000FF5900FF4C\
00FF4000FF4000FF4000FF4000FF4C00FF5900FF9900FF6600FF4C00FF4000FF33
00FF3300FF3300FF4000FF6600FFFF00FF8000FFA600FF8000FF8000FF4000FF3300FF1900FF19\
00FF0C00FF0C00FF0C00FF0C00FF0000FF0000FF0000FF0000FF730CFF0019FF00
19FF0019FF0019FF0019FF0019FF0000FF0000FF4C00FF1900FF0019FF0019FF0026FF0026FF00\
0CFF0000FF0C00FF0C00FF0C26FF003FFF004CFF0059FF0066FF0066FF0066FF00
73FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF004CFF00
33FF0000FF1933FF0059FF0066FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF008CFF0073FF0000FF000CFF0000FFBF33FF0000FFFF3FFF0073FF0066FF0066FF00\
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF008CFF008CFF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF00\
66FF0066FF0066FF0059FF0059FF0059FF004CFF003FFF0000FF1900FF3300BFFF
00FF1900FF0C0CFF0000FF0000FF0C00FF2600FF2600FF3300FF5900FF3300FF1900FF0C00FF0C\
00FF0000FF000CFF000CFF000CFF000CFF0000FF0000FF0000FF0000FF0C00FFB3
00FF6600FF4000FF2600FF1900FF1900FF2600FF3300FF4C00FF6600FFA600FF8000FF5900FF59\
00FF4C00FF4C00FFA600FF5900FF6600FF7300D9FF00FF8000FF5900FF5900FF59
00FF4C00FF4000FF4C00FF5900FF8C00FF9900FF7300FF5900FF4C00FF3300FF3300FF2600FF19\
00FF1900FF1900FF3300FF4000FF0C00FF0C00FF0C00FF2600FF260CFF000CFF00
19FF0019FF0019FF000CFF000CFF0000FF0000FF2600FF7300FF0C00FF0000FF190CFF000CFF00\
00FF1900FF1900FF0026FF003FFF004CFF004CFF0059FF0066FF0066FF0066FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF003FFF00
0CFF0033FF004CFF0066FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00
B3FF00A6FF0099FF0080FF0000FFE666FF0059FF0066FF0033FF0033FF0000FF2619FF0066FF00\
80FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF008CFF00
8CFF008CFF0080FF0073FF0066FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00\
66FF0066FF0066FF0059FF0059FF0059FF004CFF003FFF0026FF000CFF0000FF00
00FF0C00FF2600FF4C00FF8C00FF5900FF7300FF7300FFB30080FF00FF4C00FF2600FF1900FF0C\
00FF0000FF0000FF0000FF0000FF0000FF0000FF0C00FF0C00FF1900FF1900FF33
00FF6600FF7300FF3300FF2600FF2600FF3300FF3300FF4000FF5900FF7300FFA600FF7300FF66\
00FF6600FF7300FFBF00FF8000FF8000FFFF00FFB300FF8C00FF8000FF8C00FFB3
00FF5900FF5900FF5900FF6600FF9900FF7300FF5900FF4C00FF4000FF4000FF3300FF2600FF26\
00FF2600FF2600FF4000FF8C00FF2600FF2600FF6600FF5900FF0C00FF000CFF00
0CFF000CFF000CFF000CFF0000FF0000FF0C00FF4000FF5900FF2600FF3300FF9900FF2600FF0C\
00FF5900FF0C26FF0033FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF00
66FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF003FFF0000FF4C
26FF004CFF0059FF0066FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
B3FF00A6FF0099FF0066FF0073FF0080FF0080FF0073FF0059FF0033FF0000FFF326FF004CFF00\
66FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF0080FF0073FF0059FF004CFF0073FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF00\
66FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF0033FF0026FF00
19FF000CFF0000FF0000FF1900FF3300FF2600FF5900FF4000FF5900FF8000E6FF00FF1900FF0C\
00FF0C00FF0C00FF0000FF0000FF0000FF0C00FF1900FF8C00FF3300FF3300FF59
00FFD900FF6600FF4000FF3300FF3300FF4000FF4000FF4C00FF5900FF8000F3FF00FF9900FF73\
00FF8000FFBF00FFCC00FF9900FFA600FFCC00FFBF00FFBF00FFB300FFD900FF99
00FF7300FFA600FF7300FF9900FFB300FF7300FF5900FF4C00FF4C00FF4000FF3300FF3300FF33\
00FF3300FF3300FF4000D9FF00FF4000FF7300FF6600FF4000FF1900FF0C00FF00
00FF0000FF0000FF0000FF0000FF0000FF0C00FF4000FFA600FFA600D9FF00FF3300FF6600FF80\
00FF8C00FF0026FF0033FF003FFF004CFF0059FF0059FF0059FF0066FF0066FF00
66FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0066FF0066FF0059FF0059FF004CFF003FFF0019FF0000FF00
3FFF0059FF0066FF0066FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
B3FF00A6FF00A6FF008CFF008CFF008CFF008CFF0080FF003FFF0066FF0066FF004CFF0000FF0C\
3FFF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00
80FF0080FF0066FF0026FF0026FF004CFF0073FF0080FF0080FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF0066FF00\
59FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0033FF00
26FF0019FF0019FF0000FF0C00FF0C00FF0C00FF4000FF1900FF3300FF4000FF9900FF2600FF19\
00FF1900FF0C00FF0C00FF0C00FF0C00FF0C00FF1900FF4000FF8000FF6600FF73
00FFB300FF5900FF4C00FF4000FF4000FFA600FF5900FF5900FFF300FF9900FFE600FF9900FF8C\
00FF9900FFA600CCFF00FFE600FFFF00BFFF00F3FF0040FF00CCFF00FFE600FFBF
00FF9900FFB300FFB300FFE600FFCC00FF8000FF6600FF5900FF4C00FF4C00FF4000FF4000FF33\
00FF3300FF4000FF4C00FF8C00FF8000FFA600FFA600FF4000FF2600FF1900FF0C
00FF1900FF1900FF0C00FF0C00FF1900FF2600FF6600FF3300FF1900FF2600FF0C00FF1900FF26\
00FF0000FF1900FF8C33FF003FFF004CFF0059FF0059FF0059FF0066FF0066FF00
66FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0066FF0066FF0066FF0059FF000CFF0033FF003FFF0000FF000CFF000CFF00
3FFF0059FF0066FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
B3FF00B3FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0080FF0080FF0073FF0066FF00\
33FF0059FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00
80FF0073FF0066FF004CFF0000FF264CFF0066FF0073FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF00\
59FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF0033FF0033FF00
26FF0026FF0019FF000CFF000CFF0000FF0000FF0000FF0C00FF1900FF2600FF7300FF4000FF26\
00FF2600FF1900FF1900FF1900FF1900FF1900FF2600FF3300FF4000FF7300FFA6
00FF8C00FF6600FF5900FF5900FF5900FFCC00FFE600FF7300FF8C00FFCC00FFD900FFB300FFA6\
00B3FF00FFD900D9FF0099FF0000000066FF0059FF000000B300FF0C00FF00FFE6
00FFCC00FFCC00FFCC00FFB300FF8C00FF8000FF6600FF6600FF6600FF5900FF5900FF6600FF4C\
00FF4000FF4C00FF5900FF7300FF9900FF6600FF4C00FF3300FF2600FF1900FF19
00FF4000FF3300FF1900FF2600FF5900FF9900FF3300FF1900FF0C00FF0000FF000CFF000CFF00\
19FF0019FF0026FF0033FF003FFF004CFF004CFF0059FF0059FF0059FF0066FF00
66FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
66FF0066FF0066FF0059FF0059FF0033FF000CFF0000FF0000FF0C00FF0C26FF00
3FFF0059FF0066FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF00\
66FF000CFF000CFF0066FF0066FF0000FF0C73FF0073FF0080FF0080FF0080FF00
73FF0073FF0066FF003FFF0000FF594CFF0066FF0073FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0073FF0073FF0073FF0066FF0059FF003FFF004CFF004CFF0059FF0059FF0059FF00\
59FF0059FF004CFF004CFF004CFF004CFF004CFF003FFF003FFF0033FF0033FF00
33FF0026FF0026FF0019FF000CFF000CFF0000FF0000FF0000FF0C00FF1900FF4000FFD900FF40\
00FF3300FFBF00FF2600FF1900FF1900FF2600FF2600FF3300FF4000FF4C00FF66
00FFB300FF7300FF6600FF6600FFBF00FFBF00FFA600FF8C00FF9900FFB300E6FF00FFCC00FFD9\
0073FF00F3FF0080FF2600FF000000B300FF0000000000007300FF0066FF00A6FF
00A6FF00FFFF00FFB300FFA600FF8C00FF8000FF8000FF8000FF9900FF7300FF8C00FF7300FF59\
00FF5900FF5900FF6600FF8000FF8000FF5900FF4C00FF4000FF3300FF3300FF33
00FF4000FF4C00FF4000FF4000FFA600FF4000FF1900FF0C00FF0000FF000CFF0019FF0019FF00\
26FF0026FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0059FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0059FF0059FF004CFF0033FF0019FF0000FF3319FF0033FF00
3FFF0059FF0059FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF00\
73FF004CFF0019FF0019FF003FFF003FFF0066FF0073FF0073FF0073FF0073FF00
73FF0066FF0066FF004CFF0000FF194CFF0066FF0073FF0073FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0073FF0073FF0073FF0073FF0066FF0059FF0019FF0026FF0000FF0C3FFF004CFF004CFF00\
4CFF004CFF004CFF004CFF004CFF004CFF003FFF003FFF003FFF0033FF0033FF00
33FF0026FF0026FF0019FF0019FF000CFF000CFF0000FF0000FF0C00FF1900FF4C00FF8C00FFA6\
00FF6600FF5900FF3300FF2600FF2600FF2600FF3300FF3300FF4000FF4C00FF66
00FFA600FFCC00FF8000FF8000FF9900FFCC00FFBF00FFCC00FFCC00F3FF00CCFF00FFF300FFF3\
00D9FF0099FF0000000000000000000000000000000000000C00FF0080FF00D9FF
00FFF300FFD900FFBF00FFA600FF9900FF8C00FF8C00FF9900FFBF00FFB300FFD900FFE600FF66\
00FF7300FFA600FF8000FFD900FF8C00FF6600FF5900FF4C00FF5900FF4000FF40
00FF4C00FFF300FFB300FFE600FFB300FF4C00FF1900FF0C00FF000CFF000CFF0019FF0026FF00\
26FF0033FF0033FF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF00
59FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0066FF0059FF0059FF004CFF004CFF003FFF0026FF0000FF6600FF8C26FF00
3FFF004CFF0059FF0066FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF00\
73FF003FFF003FFF0000FF1900FF2633FF0059FF0066FF0066FF0066FF0066FF00
66FF0066FF0059FF003FFF0026FF0059FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
73FF0073FF0073FF0073FF0066FF0066FF0059FF0026FF0019FF0000FF6600FF193FFF003FFF00\
4CFF004CFF003FFF003FFF003FFF003FFF003FFF003FFF0033FF0033FF0033FF00
26FF0026FF0026FF0019FF0019FF000CFF000CFF0000FF0000FF0C00FF1900FF3300FF4000FF66\
00FFB300FF5900FF4000FF3300FF3300FF3300FF3300FF4000FF4C00FF5900FF73
00FF9900FFD900FF9900FF9900FFB300E6FF00FFF300D9FF00E6FF00E6FF00CCFF00E6FF0080FF\
00B3FF004CFF7300FF0000000000000000000000006600FF3F00FF0059FF0073FF
00CCFF00FFE600FFF300FFCC00FFD900FFA600FF9900FFA600FFE600F3FF00FFB300FF8C00FF80\
00FF8000FFB300FFBF00FFD900FF9900FF7300FF8000FF8000FF8000FF5900FF59
00FF6600FFCC00FF7300FF5900FF4C00FF3300FF1900FF0C00FF000CFF000CFF0019FF0026FF00\
26FF0033FF0033FF003FFF003FFF003FFF004CFF004CFF004CFF004CFF0059FF00
59FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0059FF0059FF0059FF004CFF004CFF003FFF0026FF0000FF2600FF5926FF00
33FF003FFF003FFF004CFF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00\
80FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF00\
80FF0066FF0066FF004CFF000CFF0026FF004CFF0059FF0059FF0059FF0059FF00
59FF0059FF0033FF0000FF0C33FF004CFF0066FF0066FF0073FF0073FF0073FF0073FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF00
73FF0073FF0073FF0073FF0066FF0066FF0059FF004CFF003FFF0019FF0000FF4033FF003FFF00\
3FFF003FFF0033FF003FFF003FFF003FFF003FFF0033FF0033FF0033FF0033FF00
26FF0026FF0026FF0019FF0019FF000CFF000CFF0000FF0000FF0C00FF1900FF2600FF4000FF73\
00FFE600FF6600FF4000FF4000FF3300FF4000FF4C00FF5900FF5900FF6600FF99
00B3FF00FFF300FFB300F3FF00F3FF00D9FF004CFFE600FFCC00FF0033FF00B3FF00B3FF0000FF\
0066FF4C00FF0000000000000000000000000000000000000000FF0073FF00B3FF
00D9FF00F3FF00D9FF00A6FF008CFF00FFBF00FFB300FFBF00FFFF00FFBF00FFA600FF9900FF8C\
00FF8C00FFA600E6FF00FFB300FF9900FF9900FF9900FFE600FF8C00FF8000FF80
00FF9900FF8000FF5900FF4C00FF3300FF2600FF1900FF0C00FF000CFF000CFF0019FF0026FF00\
26FF0033FF0033FF0033FF003FFF003FFF003FFF004CFF004CFF004CFF004CFF00
4CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
59FF0059FF0059FF004CFF004CFF003FFF0033FF0026FF000CFF0000FF3300FF19
00FF0000FF0C0CFF004CFF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF00\
80FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF00\
8CFF0080FF0073FF003FFF0000FF0000FF003FFF003FFF0033FF0019FF004CFF00
4CFF004CFF0033FF0000FF2626FF004CFF0059FF0066FF0066FF0073FF0073FF0073FF0073FF00\
73FF0073FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF004CFF0033FF0000FF0C0CFF0026FF00\
33FF0026FF0000FF9926FF0033FF0033FF0033FF0033FF0033FF0033FF0026FF00
26FF0026FF0019FF0019FF0019FF000CFF0000FF0000FF0000FF0C00FF1900FF2600FF4C00FF8C\
00FF8000FF5900FF4C00FF4000FF4000FF4C00FF5900FFA600FF7300FF7300FF80
00FF9900FFD900FFFF00FFF30099FF000000B300FF0000008000FF004CFF0033FF0073FF0033FF\
000CFF0000000000000000000000000000000000000000000000001900FF0080FF
00B3FF0099FF00CCFF00FFFF00FFE600FFD900D9FF00FFF300CCFF00FFCC00FFB300FFB30099FF\
00FFA600FFBF00CCFF00FFCC00FFCC00E6FF00FFD900FFF300FFE600FFA6008CFF
00FFE600FF8000FF5900FF4C00FF4000FF3300FF2600FF1900FF1900FF000CFF0019FF0019FF00\
26FF0026FF0033FF0033FF0033FF003FFF003FFF003FFF003FFF0033FF0019FF00
3FFF004CFF0059FF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0059FF0059FF0059FF00\
59FF0059FF004CFF004CFF003FFF0033FF0033FF0019FF000CFF0000FF8000FF0C
19FF0033FF003FFF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF00\
80FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
8CFF0080FF0073FF0066FF003FFF0000FF0C0CFF000CFF0000FF0000FF0C00FF99
33FF0033FF000CFF0000FFB326FF003FFF0059FF0059FF0066FF0066FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0066FF0066FF0066FF0059FF0059FF004CFF003FFF0019FF0000FF4C0CFF00\
19FF000CFF0000FF4019FF0026FF0033FF0033FF0033FF0033FF0026FF0026FF00
26FF0019FF0019FF0019FF000CFF000CFF0000FF0000FF1900FF3300FF3300FF3300FF4C00FF80\
00FFB300FF6600FF5900FF4C00FF4C00FF5900FF6600FF8C00FFBF00FF8C00FF99
00FFB300F3FF00CCFF00CCFF004CFF0000000000000000009900FF1900FF3300FF0C00FF0C00FF\
4C00FF0000000000000000000000000000000000000000000000001900FF004CFF
0033FF0099FF00CCFF00CCFF00F3FF00FFF300F3FF00B3FF00FFFF00FFD900FFD900FFFF00E6FF\
00FFCC00D9FF00CCFF00FFE600FFE60040FF004CFF0040FF0040FF0040FF00FFBF
00FF9900FF8000FF7300FF6600FF5900FF4000FF3300FF3300FF4C00FF0C00FF000CFF0019FF00\
26FF0026FF0033FF0033FF0033FF0033FF0033FF0033FF0026FF0000FF0C19FF00
3FFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00\
59FF004CFF004CFF0033FF0000FF0019FF0019FF0000FF1900FF1900FF800CFF00
26FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
8CFF0080FF0073FF0066FF0026FF000CFF0033FF0019FF0000FF1900FFFF00FF19
00FF2600FF4000FF400CFF0026FF003FFF004CFF0059FF0059FF0066FF0066FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF003FFF0019FF0000FF6600FF33\
00FF0C00FF4000FF0C19FF0026FF0026FF0026FF0026FF0026FF0026FF0026FF00
19FF0019FF000CFF000CFF000CFF0000FF0000FF0000FF1900FF4C00FF8000FF7300FFD900FFBF\
00FF9900FF7300FF6600FF5900FF5900FF7300FFB300FFB300FFCC00FFA600FFBF
00FFFF00FFF300A6FF0099FF000CFF000000000000000000000000000000A600FF000000000000\
E600FF0000000000000000000000000000000000000000000000005900FF000CFF
0059FF004CFF0099FF0066FF00BFFF00CCFF00CCFF00D9FF00FFFF00FFFF00FFF300D9FF00F3FF\
0059FF00E6FF00CCFF00D9FF0073FF00A6FF1900FF0000000059FF00E6FF00FFE6
00FFBF00FF9900FFA600FFBF00FF8000FF4C00FF4C00FF6600FF4000FF2600FF1900FF2600FF00\
19FF0026FF0026FF0026FF0033FF0033FF0033FF0026FF000CFF0000FF3319FF00
3FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00\
4CFF004CFF004CFF003FFF0019FF0000FF0000FF3300FF7300FF2600FF0C00FF26
33FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF00\
26FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00\
8CFF0080FF0066FF0033FF0026FF004CFF004CFF004CFF0026FF0000FFD926FF00
33FF0026FF0019FF0000FF5900FF4033FF003FFF003FFF0026FF004CFF0066FF0066FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF004CFF0033FF0019FF000CFF0000FF66\
00FF4000FF5900FF0C0CFF0019FF0026FF0026FF0026FF0026FF0026FF0019FF00
19FF0000FF0000FF0000FF0000FF0000FF0000FF0C00FF1900FF2600FF3300FF5900FF6600FF80\
00FF9900FF8C00FF7300FF6600FF6600FF7300FF8C00FFB300E6FF00FFCC00FFE6
008CFF0099FF0073FF0040FF3300FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000D900FF3300FF
0C00FF1900FF0026FF0066FF0073FF00A6FF0066FF00BFFF00CCFF008CFF00CCFF0066FF0099FF\
0080FF0080FF00B3FF00B3FF0066FF0059FF0000000000000033FF00BFFF00B3FF
00FFFF00FFCC00FFE600FFB300FF8000FFCC00FF6600E6FF00FFD900FF6600FF4C00FF190CFF00\
19FF0019FF0026FF0026FF0026FF0026FF0026FF0019FF0000FF0C00FF1919FF00
33FF003FFF004CFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF004CFF004CFF00\
4CFF004CFF003FFF003FFF0026FF0019FF0000FF0C00FF4000FF0019FF0026FF00
33FF003FFF004CFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0059FF003FFF0000FFD9\
4CFF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00\
8CFF0073FF0026FF0026FF0059FF0066FF0066FF0059FF0000FFA63FFF004CFF00
3FFF003FFF0026FF0000FF6600FF4019FF0019FF0000FF260CFF004CFF0059FF0066FF0066FF00\
66FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF00
66FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF0019FF000CFF00\
00FF1900FF7300FF3300FF1919FF0019FF0019FF0019FF0019FF0019FF0019FF00
0CFF0000FF2600FF4000FF0C00FF0C00FF0C00FF0C00FF1900FF2600FF3300FF4000FF4C00FF59\
00FF7300FFD900FF9900FF9900FF8000FF8000FF8C00FFA600FFD900F3FF00E6FF
0080FF000000D900FF7300FFA600FF000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000D900FF
0000000000000000000000000033FF000CFF008CFF00A6FF00A6FF5900FF004CFF0019FF1900FF\
000000000CFF3F00FF0073FF0C00FF0000FFA600FF0000006600FF0000FF00B3FF
00BFFF00F3FF00E6FF00FFFF00FFCC0066FF00FFE600FF6600FF4C00FF4000FF4000FF0C0CFF00\
19FF0019FF0019FF0026FF0026FF0019FF0019FF000CFF0000FF4C00FF0C26FF00
33FF003FFF003FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00\
4CFF003FFF003FFF0033FF0026FF0019FF0000FF0C00FF4C00FF0019FF0026FF00
33FF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF004CFF003FFF0000FFBF\
3FFF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0073FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00\
8CFF004CFF003FFF0066FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF00
4CFF003FFF0033FF0019FF0000FF0000FFBF00FF0033FF003FFF0059FF0059FF0066FF0066FF00\
66FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF003FFF003FFF0033FF0019FF000CFF00\
00FF4000FFA600FF1900FF000CFF0019FF0019FF0019FF0019FF0019FF000CFF00
0CFF0000FF0C00FF3300FF2600FF2600FF1900FF1900FF1900FF2600FF3300FF4000FF4C00FF59\
00FF6600FF9900FFE600FFA600FF8C00FF8C00FFA600FFB300FFE600BFFF00B3FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000002600FF0040FF0066FFA600FF0073FF0026FF1900FF000000000000\
0000006600FF0000FF6600FF2600FF8C00FF0000000000006600FF0019FF0040FF
0059FF0073FF0059FF00000000BFFF00FFD900FF8C00FF6600FF4000FF2600FF1900FF0C00FF00\
0CFF0019FF0019FF0019FF0019FF000CFF0000FF0000FF2600FF0C19FF0026FF00
33FF003FFF003FFF003FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00\
3FFF003FFF0033FF0033FF0026FF0019FF0000FF3300FF8C00FF0C19FF0026FF00
33FF003FFF003FFF003FFF004CFF004CFF004CFF0059FF004CFF004CFF003FFF0019FF000CFF00\
4CFF0059FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF00\
8CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0066FF0059FF00
59FF004CFF0033FF0026FF0000FF0000FF1926FF003FFF004CFF0059FF0059FF0066FF0066FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF0033FF0000FF0000FF4C\
00D9FF00FF3300FF1900FF000CFF000CFF000CFF0019FF000CFF000CFF000CFF00
00FF0000FF0C00FF4000FF6600FF6600FF3300FF2600FF2600FF3300FF3300FF4000FF4C00FF59\
00FF7300FF9900BFFF00FFB300FFA600FFA600FFCC00FFF300FFF300CCFFD900FF
D900FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000008C00FF0C00FF0000FF0000FF3F00FF1900FF9900FF000000000000\
000000D900FFE600FFD900FF000000E600FF000000000000000000000000000000
000000000000CC00FF0000000000FF008CFF00FFCC00FF8C00FF4C00FF3300FF1900FF1900FF0C\
00FF000CFF000CFF000CFF000CFF0000FF0000FF3300FF4C00FF0019FF0026FF00
33FF0033FF003FFF003FFF003FFF003FFF003FFF003FFF003FFF003FFF003FFF003FFF003FFF00\
3FFF0033FF0019FF0019FF0019FF000CFF0000FF0C00D9FF00FF0019FF0026FF00
26FF0033FF0033FF0033FF0033FF003FFF004CFF004CFF004CFF003FFF0033FF0000FF1926FF00\
4CFF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF0066FF00
59FF003FFF0026FF0000FF0000FF4C00FF0C00FF0C3FFF004CFF004CFF0059FF0059FF0066FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0033FF0026FF0019FF0000FF00\
00FF2600FF6600FF2600FF0C00FF000CFF000CFF000CFF000CFF000CFF0000FF00
00FF0C00FF1900FF3300FF6600FF7300FF4000FF3300FF3300FF3300FF4000FF4C00FF5900FF73\
00FFCC00FFBF00FFFF00FFBF00FFB300FFBF00E6FF00D9FF00D9FF0059FF000000
CC00FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000007300FF7300FF3300FFCC00FF000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000F300FF0C00FFA600FF0019FF00E6FF00FF7300FF4C00FF3300FF3300FF4000FF26\
00FF0000FF000CFF000CFF0000FF0000FF0C00FF2600FF4C00FF190CFF0019FF00
26FF0033FF0033FF0033FF0033FF0033FF0019FF0033FF003FFF003FFF003FFF003FFF003FFF00\
33FF0033FF0019FF0000FF6600FF0C00FF0C00FF2600FF8000FF190CFF0019FF00
19FF0026FF000CFF0019FF0000FF0033FF003FFF003FFF003FFF0026FF000CFF0019FF003FFF00\
4CFF0059FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0066FF0066FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF0099FF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0066FF0066FF00
59FF003FFF0026FF0000FF0C00FF0C19FF0033FF003FFF004CFF004CFF0059FF0059FF0059FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0059FF0059FF004CFF003FFF0033FF0033FF0026FF0026FF0026FF0019FF000CFF0000FF00\
00FF2600FF9900FF2600FF0C00FF0000FF0000FF0000FF0000FF0000FF0000FF40
00FF2600FF2600FF4000FFF300FF6600FF4C00FF4000FF4000FF4000FFA600FF6600FF6600FF73\
00FF8C00FFA600FFBF00FFFF0059FF00FFD900FFE600D9FF0099FFCC00FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000A600FFA600FF000000000000000000000000000000\
0000000000000000000000000000000000000000000000009900FF4C00FF8C00FF
0000000C00FF0000FF00B3FF00A6FF00FFF300FFCC00FFB300FF5900FF4C00FFA600FF5900FF26\
00FF0C00FF0C00FF0000FF0000FF0C00FF4C00FF6600FF5900FF0C0CFF0019FF00
19FF0019FF0026FF0033FF0026FF0026FF0000FF3319FF0033FF0033FF0033FF0033FF0033FF00\
26FF0026FF000CFF0000FF0C00FF9900FF8000FF5900FF2600FF4000FF3300FF00
00FF000CFF0000FF0C00FFA600FF0019FF0033FF0033FF0033FF0019FF0000FF3326FF003FFF00\
4CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0066FF0066FF00
59FF003FFF0033FF0000FF1900FF3319FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF00\
59FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF00
59FF0059FF0059FF004CFF003FFF0000FF0C00FF2600FF3300FF660CFF000CFF0000FF3300FF26\
00FF3300FF9900FF2600FF1900FF0C00FF0000FF0000FF0000FF0000FF0C00FF26
00FFA600FF4C00FF6600FFA600FF7300FF5900FF4C00FF4C00FF5900FF7300FF9900FF8000FF80\
00FF8C00FF9900FFB300FFE60C00FF00FFF300D9FF00CCFF0066FF9900FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000CC00FF3F00FF7300FF0033FF
0033FF0099FF0066FF00F3FF00A6FF00FFCC00FFB300FFFF00FF9900FF7300F3FF00FF4C00FF26\
00FF1900FF1900FF0C00FF0C00FF1900FF3300FFCC00FF3300FF1900FF0000FF00
00FF0C00FF0019FF0026FF0026FF0019FF0000FF0C0CFF0019FF0026FF000CFF0026FF0026FF00\
19FF0000FF1900FF0000FFE600FF1900FF0C00FF260CFF000CFF0000FF0C00FF59
00FFB300FF0C00FF6600FF8C00FF2600FF2619FF0026FF0019FF0000FF1900FF6600FF733FFF00\
4CFF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0066FF0059FF00
4CFF0033FF0000FF0C00FF1900FF0C19FF0026FF0033FF003FFF004CFF004CFF0059FF0059FF00\
59FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF00
59FF0059FF0059FF004CFF003FFF0026FF0019FF0000FF2600FF0C00FF2600FF5900FF8000FF59\
00FFF300FF6600FF4C00FF2600FF1900FF0C00FF0C00FF0C00FF0C00FF1900FF26
00FF3300FF5900FF8000FFB300FF8000FF6600FF5900FF5900FF8000FF8C0019FF00FF9900FF8C\
00FF9900FFA6008CFF00F3FF00D9FF00F3FF00A6FF0066FF0C00FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000D900FF0000FF0033FF0040FF
008CFF008CFF00FFFF00FFD900FFE600FFA600FF8C00FFB300FF8C00F3FF00F3FF00FF7300FF59\
00FF3300FF8C00FF2600FF2600FF4000FFA600FFBF00FF4000FF3300FF2600FF19
00FF4C00FF000CFF0019FF000CFF000CFF0000FF2600FF1900FF3300FF0000FF4C00FF0C00FF00\
00FF3300FF5900FF5900FF2600FF0019FF0019FF0019FF0019FF0019FF0000FF00
00FF4C00FF4C00FF7300FFBF00FF4000FF6600FF4000FF0000FF7300FF9900FF0019FF0033FF00\
3FFF003FFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF004CFF0000FF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0073FF0059FF0026FF00
00FF3300FF6600FF0C00FF1900FF0C00FF0019FF0026FF0033FF003FFF004CFF004CFF0059FF00\
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF004CFF004CFF003FFF0033FF0033FF0026FF0019FF000CFF0000FF0C00FF1900FF19\
00FF3300FF3300FF4000FF4C00FF2600FF1900FF1900FF1900FF1900FF1900FF26
00FF3300FF4000FF5900FF7300FFB300FF7300FF7300FF7300FF8C00FFFF00FFCC00FFA600FFA6\
00FFCC00FFD900FFD900FFF300CCFF00B3FF00B3FF0066FFA600FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000A600FF0026FF0073FF004CFF
00BFFF0073FF00F3FF00FFE600FFA600FF8C00FF8000FF7300FF6600FF6600FF6600FF8000FF73\
00D9FF00FF800080FF00FF8000FFA600FF4000FF4000FF7300FFE600FF9900FF4C
00FF4C00FF0C00FF0000FF0000FF0C00FF1900FF4000FF7300FF9900FF4000FF2600FF3300FF00\
00FF0000FF0C00FF0000FF8C19FF0026FF0026FF0026FF0026FF0026FF0019FF00
00FF3300FF1900FF8C00FF5900FF0C00FF0C00FF0000FF0000FF1900FF3300FF190CFF0026FF00\
26FF0000FF193FFF004CFF0059FF0059FF0059FF0059FF004CFF003FFF000CFF00
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF004CFF0000FF3333FF00
3FFF003FFF0033FF0033FF0019FF0000FF3300FF0C00FF2600FF3300FF003FFF004CFF004CFF00\
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF004CFF004CFF004CFF003FFF003FFF0033FF0033FF0026FF0019FF000CFF0000FF0000FF00\
00FF0C00FF0C00FF1900FF6600FF6600FF3300FF7300FF2600FF2600FF2600FF26
00FF3300FF4000FF4C00FF6600FFA600FFD900FF8000FF8000FF8C00FFB300CCFF00FFCC00FFD9\
00FFFF00FFFF00FFF300F3FF0033FF0073FF0080FF3F00FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000004C00FF4C00FF0066FF00B3FF
00E6FF00F3FF00B3FF00FFCC00FFA600FF8C00FF7300FF6600FF5900FF4C00FF4C00FF7300FF80\
00FF6600FF4000FF3300FF2600FF2600FF2600FF2600FF3300FFFF00FF4000FF40
00FFBF00FF4000FF0C00FF0C00FF3300B3FF00FF2600FF0C00FF3300FFA600FF0019FF0019FF00\
26FF0026FF0026FF0019FF0026FF0033FF0033FF0033FF0033FF0033FF0026FF00
19FF000CFF0000FF2600FF5900FF0019FF0019FF0019FF000CFF0000FF0C8000FF00FF2600FF00\
00FF8026FF003FFF004CFF004CFF004CFF004CFF004CFF003FFF0019FF0000FF73
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF0066FF0059FF00
59FF004CFF004CFF003FFF0026FF0000FF3300FFA600FF4C00FF0026FF003FFF003FFF004CFF00\
4CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
4CFF004CFF004CFF004CFF003FFF003FFF0033FF0033FF0026FF0026FF0019FF000CFF000CFF00\
00FF0000FF0000FF1900FF3300F3FF00FF6600FF6600FF3300FF3300FF3300FF33
00FF4000FF4C00FF5900FF7300FFB300FFBF00FF9900FF9900FFA600FFE600A6FF00FFE600FFE6\
00E6FF00E6FF00BFFF00B3FF00B3FF0073FF004CFF3300FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000009900FF1900FF008CFF0059FF
00FFFF00FFF300D9FF00E6FF00FFCC00FFFF00FFD900FF5900FF4C00FF4000FF4000FF4000FF4C\
00FF7300FF2600FF1900FF1900FF0C00FF0C00FF0C00FF1900FF1900FF1900FF26
00FF5900FF4C00FF3300FF2600FF7300FF4000FF190CFF000CFF0000FF0C19FF0026FF0026FF00\
33FF0033FF0033FF0033FF0033FF0033FF003FFF003FFF003FFF003FFF0033FF00
33FF0019FF0000FF4C0CFF000CFF0026FF0026FF0026FF0026FF000CFF0000FF0000FF1900FF40\
0CFF0026FF003FFF003FFF003FFF004CFF004CFF003FFF003FFF0026FF000CFF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0073FF0073FF0066FF00
66FF0059FF004CFF003FFF0026FF0000FF0C00E6FF00FFBF00FF0026FF0033FF003FFF004CFF00\
4CFF004CFF004CFF004CFF004CFF0059FF0059FF004CFF004CFF004CFF004CFF00
4CFF004CFF004CFF003FFF003FFF003FFF0033FF0033FF0026FF0026FF0019FF0019FF000CFF00\
0CFF0000FF0000FF0C00FF2600FF4000FF7300FF8C00FF4C00FF4000FF4000FF40
00FF8000FF5900FF6600FF8C00FFF300FFCC00FFB300FFCC00FFF300FFE600BFFF00E6FF00A6FF\
0099FF00A6FF008CFF0080FF0026FF0059FF7300FF8C00FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000008CFF00D9FF
00FFF300FFD900FFBF00FFBF00FFFF00FFA600FF7300FF5900FF4000FF4000FF3300FF3300FF33\
00FF3300FF2600FF1900FF0C00FF0C00FF0C00FF0000FF0000FF0C00FF0C00FF19
00FF3300FF6600FFD900FFE600FF2600FF000CFF0019FF0019FF0026FF0026FF0033FF0033FF00\
33FF003FFF003FFF003FFF003FFF003FFF003FFF003FFF003FFF003FFF003FFF00
33FF0026FF000CFF0033FF0033FF0033FF0033FF0033FF0026FF0026FF000CFF0000FF0C00FF99\
00FF8026FF0033FF0033FF003FFF003FFF003FFF003FFF0033FF0019FF000CFF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0073FF00
66FF0059FF0059FF004CFF0026FF0000FF0000FF0C00FF3300FF0C26FF0033FF003FFF003FFF00\
3FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00
4CFF004CFF003FFF003FFF003FFF003FFF0033FF0033FF0026FF0026FF0026FF0019FF000CFF00\
0CFF0000FF0000FF0C00FF1900FF400059FF00FF7300FF4C00FF4C00FF4C00FF4C
00FF8000FFCC00FF8000FF8C00FFA600F3FF00FFE600FFF300D9FF0099FF0099FF0000003300FF\
0026FF2600FF0000FF3F00FF1900FF2600FF3F00FFC000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000008000FF0066FF00CCFF
00FFFF00FFE600FFB300FFA600FFB300FFBF00FF8C00FF5900FF4000FF3300FF3300FF2600FF26\
00FF1900FF1900FF0C00FF0C00FF0000FF0000FF0000FF0000FF0000FF0000FF0C
00FF4000FF2600FF1900FF6600FF2600FF0019FF0026FF0026FF0033FF0033FF0033FF003FFF00\
3FFF003FFF003FFF003FFF003FFF003FFF004CFF004CFF004CFF004CFF003FFF00
3FFF003FFF0033FF003FFF003FFF003FFF003FFF0033FF0033FF0026FF000CFF0000FF2600FF26\
0CFF0019FF0026FF0026FF0033FF0033FF0033FF0033FF0026FF0000FF0C00FF73
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00\
99FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF00
66FF0059FF0059FF004CFF003FFF0026FF0019FF0000FF1900FF4019FF0033FF0033FF003FFF00\
3FFF003FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00
3FFF003FFF003FFF003FFF003FFF0033FF0033FF0033FF0026FF0026FF0026FF0019FF000CFF00\
0CFF0000FF0000FF0C00FF2600FF4000FF7300FFBF00FF6600FF5900FF5900FFBF
00FF8C00FFBF00FF9900000000FFCC00D9FF00E6FF0099FF3300FF8000FF000CFF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000C00FF00A6FF00D9FF
0033FF00FFCC00FFA600FF9900FF8C00FFA600FF8000FFA600FF4000FF3300FF2600FF2600FF19\
00FF1900FF0C00FF0C00FF0000FF0000FF000CFF000CFF000CFF000CFF0000FF00
00FF4C00FF0000FF0000FF1900FF7300FF0019FF0026FF0033FF0033FF0033FF003FFF003FFF00\
3FFF003FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00
4CFF004CFF004CFF004CFF003FFF003FFF003FFF003FFF0033FF0026FF0000FF4000FF2600FF66\
00FF0C0CFF000CFF0000FF0019FF0026FF0026FF0019FF0000FF0000FF730CFF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00\
99FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF00
66FF0059FF0059FF004CFF003FFF0033FF0026FF000CFF0000FF260CFF0026FF0026FF0033FF00\
33FF003FFF003FFF003FFF003FFF003FFF003FFF003FFF003FFF003FFF003FFF00
3FFF003FFF003FFF003FFF0033FF0033FF0033FF0033FF0026FF0026FF0019FF0019FF000CFF00\
0CFF0000FF0C00FF4C00FFA600FF7300FFF300FFFF00FF7300FF6600FF6600FF80
00FFA600FFF300FFCC00B3FF00FFFF00D9FF0059FF000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000008000FF0000003300FF0059FF00FFFF
00FFE600FFD900FFA600FF8C00FF8000FF6600FF5900FF4C00FF4000FF3300FF2600FF2600FF19\
00FF0C00FF0C00FF0000FF000CFF000CFF000CFF000CFF000CFF000CFF000CFF00
0CFF000CFF000CFF000CFF0000FF2600FF260CFF0026FF0033FF0033FF003FFF003FFF003FFF00\
4CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00
4CFF004CFF004CFF004CFF004CFF004CFF004CFF003FFF003FFF0033FF0026FF000CFF0000FF19\
00FF4000FF1900FF1900A6FF00FF730CFF0000FF0000FFBF0CFF0026FF0033FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00\
99FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF00
66FF0059FF004CFF004CFF003FFF0033FF0026FF000CFF0000FF4000FF0C00FF5919FF0019FF00\
00FF0033FF0033FF003FFF003FFF003FFF003FFF003FFF003FFF0033FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF0026FF0026FF0026FF0019FF000CFF000CFF00\
00FF0000FF0C00FF2600FF3300FF4C00FF5900FF6600FFBF00FFB300FF8C00FF8C
00FFA600CCFF00E6FF008CFF0099FF0033FF0026FF6600FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000E600FF2600FF1900FF0033FF0066FF00D9FF00FFF3
00FFCC00FFB300FF9900FF8C00FF7300FF6600FF5900FF4C00FF4000FF3300FF2600FF2600FF19\
00FF0C00FF0C00FF0000FF000CFF000CFF000CFF0019FF0019FF0019FF0019FF00
19FF0019FF0019FF0019FF000CFF000000FF00FF3326FF0033FF003FFF003FFF003FFF004CFF00\
4CFF004CFF004CFF004CFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF00
59FF0059FF004CFF004CFF004CFF004CFF004CFF004CFF003FFF003FFF0033FF0019FF0000FF40\
00FF2600FF0000BFFF00B3FF00FF2600FF3300FFB300FF0C26FF0033FF003FFF00
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF00
4CFF003FFF003FFF0033FF0033FF0026FF0019FF0000FF0000FF4C00FF8C00FF4C00FF0C00FF0C\
00FF0026FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0019FF000CFF00
26FF0033FF0033FF0033FF0033FF0033FF0026FF0026FF0026FF0019FF000CFF000CFF0000FF00\
00FF0000FF0C00FF1900FF2600FF3300FF4C00FF5900FF8000CCFF00FFA600FFA6
00D9FF00BFFF0000FF0000000000009900FF3300FFD900FF000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000A600FF0000001900FF004CFF0073FF0099FF00CCFF00FFFF
00E6FF00FFB300FF9900FF8C00FF8C00FF8000FF5900FF4C00FF4000FF3300FF3300FF2600FF26\
00FF1900FF0C00FF000CFF000CFF000CFF0019FF0019FF0019FF0019FF0019FF00
26FF0026FF0026FF0026FF0019FF0019FF0000FF0026FF0033FF003FFF003FFF004CFF004CFF00\
4CFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF0033FF0019FF0000FF66\
19FF0026FF0019FF0000FF000CFF000CFF0000FF7300FF0026FF003FFF004CFF00
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF0059FF00
33FF0000FF3326FF0019FF0000FF0C0CFF0000FF0C00FFBF00FF0C00FF0000FF3300FF4000FF19\
00FF6600FF5919FF0026FF0026FF0026FF0026FF0026FF0026FF000CFF0000FF4C
19FF0026FF0026FF0026FF0026FF0026FF0026FF0026FF0019FF000CFF0000FF5900FF1900FF0C\
00FF0C00FF1900FF1900FF2600FF3300FF4C00FF6600FF9900FFF300FFCC00FFCC
00B3FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000C000FF3F00FF8C00FF004CFF0080FF00B3FF00CCFF00D9FF00A6FF
00FFF300FFBF00FFB300FFBF00FFE600FF8000FF5900FF4C00FF4C00FF4000FF4000FF3300FF33\
00FF3300FF0C00FF000CFF000CFF0019FF0019FF0019FF0019FF0026FF0026FF00
26FF0026FF0026FF0026FF0026FF0026FF0033FF0033FF003FFF003FFF004CFF004CFF004CFF00\
4CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF0000FF0019FF00\
33FF0033FF0033FF0033FF0026FF0019FF0000FF1900FF1926FF003FFF004CFF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF00\
8CFF008CFF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF00
4CFF0033FF0000FF0C00FF2600FF3300FF2600FF4C00FF190CFF0019FF000CFF0000FF0019FF00\
00FF1900FF0C00FF1900FF000CFF000CFF0019FF0019FF0019FF0000FF0000FF33
0CFF0019FF0026FF0026FF0026FF0026FF0026FF0019FF0019FF000CFF0000FF0C00FF3300FF33\
00FF7300FF2600FF2600FF3300FF4000FF4C00FF6600FF8000FFA600FFD900F3FF
00B3FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000007300FFCC00FF0019FF0019FF0080FF00B3FF00D9FF00FFFF00F3FF
00B3FF00E6FF00FFFF00FFE600FF9900FF7300FF6600FF5900FF5900FF5900FF6600FF6600FF80\
00FF3300FF0C00FF000CFF000CFF0019FF0019FF0019FF0026FF0026FF0026FF00
26FF0026FF0033FF0033FF0033FF0033FF0033FF003FFF003FFF004CFF004CFF004CFF004CFF00\
4CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF0033FF0000FF3326FF00\
3FFF003FFF003FFF003FFF0033FF0019FF0000FF5900FF0026FF003FFF004CFF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF00\
80FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF004CFF00
3FFF0033FF0000FF0000FF000CFF0000FF0C00FF6619FF0026FF0026FF0026FF0026FF0026FF00\
26FF0026FF0000FF0000FF4C00FF4000FF0C0CFF000CFF000CFF0000FF4000FF19
0CFF0019FF0019FF0019FF0026FF0019FF0019FF0019FF0019FF000CFF0000FF0000FF2600FFCC\
00FF9900FF4000FF3300FF4000FF5900FF8000FF8000FF8C00FFA600FFD900FFFF
0099FF0033FF3F00FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000009900FF4C00FF0033FF0066FF0080FF0033FF00E6FF00FFF300FFE6
00FFF300FFCC00FFCC00A6FF00FFF300FF8C00FF8C00FF6600FF6600FF8C00FFA600FF4C00FF33\
00FF1900FF0C00FF000CFF000CFF0019FF0019FF0026FF0026FF0026FF0026FF00
33FF0033FF0033FF0033FF0033FF003FFF003FFF003FFF004CFF004CFF004CFF004CFF004CFF00\
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0066FF00
66FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF004CFF0033FF0000FF6633FF00\
4CFF004CFF004CFF004CFF003FFF000CFF0000FF0000B3FF00FF0000FF4C4CFF00
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF000CFF00\
66FF0073FF0066FF0059FF004CFF0059FF0059FF0059FF0059FF004CFF000CFF00
33FF000CFF005900FF19FF0026FF0026FF0000FF0019FF0033FF003FFF003FFF003FFF003FFF00\
33FF0033FF0026FF000CFF0000FF1900FF3300FF1900D9FF00FF1900FF4000FF33
00FF0C00FF000CFF0019FF0019FF0019FF0019FF0019FF000CFF000CFF0000FF0000FF1900FF40\
00FFA600FF5900FF4C00FF4C00FF6600FFB300FFA600FF990019FF00FFE600A6FF
00B3FF1900FF2600FF000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000F300FF8C00FF0026FF0066FF00A6FF00B3FF00D9FF00FFE600FFD9
00FFBF00FFB300FFB300FFB300D9FF008CFF00FFE600FF9900FFCC00FFD900FF6600FF4000FF26\
00FF1900FF0C00FF000CFF000CFF0019FF0019FF0026FF0026FF0026FF0026FF00
33FF0033FF0033FF0033FF003FFF003FFF003FFF003FFF004CFF004CFF004CFF004CFF0059FF00\
59FF0059FF0059FF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF003FFF0033FF004CFF00\
4CFF0059FF0059FF004CFF004CFF0026FF0033FF0019FF0000FF4033FF004CFF00
B3FF00B3FF00B3FF00A6FF00A6FF0099FF0099FF008CFF008CFF008CFF0080FF0073FF0059FF00\
33FF004CFF0059FF004CFF0000FF0C26FF0019FF0026FF0033FF0019FF0000FF0C
00FF1900FF5919FF0033FF003FFF003FFF0033FF0026FF003FFF003FFF003FFF003FFF003FFF00\
3FFF003FFF0033FF0026FF000CFF0000FF4C00FF3300FF8000FF4000FF3300FFE6
00FF3300FF800CFF000CFF000CFF0019FF000CFF000CFF000CFF0000FF0000FF0C00FF2600FF40\
00FFA600FF6600FF5900FF6600FF8C00BFFF00FFBF00FFBF0099FF00F3FF00B3FF
0059FF004CFF2600FFE600FF000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000FF0040FF0099FF00CCFF00F3FF00FFF300FFD9
00FFBF00FFA600FF9900FF9900FFA600FF9900FF8000FF8000FF8000FFD900FF8C00FF6600FF33\
00FF1900FF0C00FF000CFF000CFF0019FF0019FF0026FF0026FF0026FF0033FF00
33FF0033FF0033FF003FFF003FFF003FFF003FFF004CFF004CFF004CFF004CFF0059FF0059FF00\
59FF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF0059FF00\
59FF0059FF0059FF0059FF0059FF004CFF003FFF0033FF0000FF263FFF004CFF00
B3FF00B3FF00B3FF00A6FF00A6FF008CFF0080FF004CFF0073FF0073FF0066FF0066FF004CFF00\
00FF0C00FF2626FF0000FFA619FF0000FF2619FF000099FF3FFF0026FF0026FF00
00FF1900FF1926FF003FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00\
4CFF003FFF003FFF0033FF000CFF0000FF0C0CFF0000FF0C00FF0000FF1900FF40
00FF4C00FF0C00FF000CFF000CFF000CFF000CFF000CFF0000FF0000FF0C00FF5900FF7300FFB3\
00FF8C00FFE600FF8000FF8000FF8C00FFB30026FF00FFF300E6FF0099FF1900FF
0059FF0000FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000005900FF0059FF008CFF008CFF00D9FF00F3FF00D9FF
00FFBF00FFA600FF9900FF8C00FF8000FF8000FF6600FF6600FF6600FFCC00FF8C00FF7300FF40\
00FF4C00FF1900FF0C00FF000CFF0019FF0019FF0026FF0026FF0026FF0033FF00
33FF0033FF0033FF003FFF003FFF003FFF003FFF004CFF004CFF004CFF004CFF0059FF0059FF00\
59FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0059FF0059FF004CFF003FFF000CFF0033FF004CFF00
B3FF00B3FF00A6FF00A6FF00A6FF0099FF0073FF0059FF003FFF0033FF000CFF003FFF0000FF80\
33FF0033FF000CFF0026FF003FFF003FFF003FFF0059FF0059FF0059FF004CFF00
4CFF0026FF0033FF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF00\
4CFF004CFF003FFF0033FF0000FFCC19FF0019FF0019FF000CFF0000FF0C00FF73
00FF4000FF1900FF0C00FF0000FF0000FF0000FF0000FF0000FF0000FF0C00FF1900FF3300FF40\
00FF4C00FF7300FFBF00FFA600FFB300FFD900D9FF00B3FF0080FF0033FF0033FF
B300FF3F00FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000005900FF0033FF2600FF008CFF0033FF00CCFF0099FF
0099FF00FFB300FF8C00FF8000FF7300FF6600FF5900FF5900FF5900FF5900FF7300FFCC00FFB3\
00FF8000FF8000FF2600FF3300FF000CFF0019FF0026FF0026FF0026FF0033FF00
33FF0033FF003FFF003FFF003FFF003FFF004CFF004CFF004CFF004CFF004CFF0059FF0059FF00\
59FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF0000FF7300FF003FFF00
B3FF00B3FF00A6FF00A6FF00A6FF0099FF008CFF008CFF0080FF0059FF0000FF0C00FF333FFF00\
59FF0059FF003FFF003FFF0059FF0059FF0066FF0066FF0066FF0066FF0059FF00
59FF004CFF003FFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00\
4CFF004CFF004CFF003FFF0033FF0033FF0026FF0026FF000CFF0000FF0C00FF80
00FF5900FF3300FF2600FF0C00FF0000FF0000FF0000FF0000FF0C00FF0C00FF1900FF2600FF33\
00FF4C00FF7300FFD900FFD900FFE600A6FF0033FF000000C000FF7300FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000E600FF3F00FF0026FF0073FF00A6FF00CCFF00F3FF00FFF3
00FFCC00FFA600FF8C00FF8000FF7300FF6600FF5900FF4C00FF4C00FF4C00FF5900FF6600FF4C\
00FF3300FF2600FF7300FF3300FF000CFF0019FF0026FF0026FF0026FF0033FF00
33FF0033FF003FFF003FFF003FFF003FFF004CFF004CFF004CFF004CFF0059FF0059FF0059FF00\
59FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0066FF0066FF0066FF0066FF0059FF0059FF0033FF0000FF8C26FF00
B3FF00B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0066FF0033FF0066FF00\
66FF0066FF0059FF0059FF0066FF0066FF0073FF0073FF0073FF0066FF0066FF00
66FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF00\
59FF004CFF004CFF004CFF003FFF003FFF0033FF0026FF000CFF0000FF5900FF19
00FF400019FF00FF3300FF1900FF0C00FF0C00FF0C00FF0C00FF1900FF1900FF2600FF2600FF33\
00FF4C00FF6600FF8C00FFFF0066FF9900FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000E600FF4C00FF000CFF0000FF0066FF00A6FF00E6FF00FFE6
00FFCC00FFA600FF9900FF8C00FF8C00FF6600FF4C00FF4C00FF4000FF4000FF3300FF4000FFA6\
00FF1900FF0C00FF0C00FF000CFF0019FF0019FF0026FF0026FF0026FF0033FF00
33FF0033FF003FFF003FFF003FFF003FFF004CFF004CFF004CFF004CFF0059FF0059FF0059FF00\
59FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF0000FF0026FF0000FF0C
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0073FF003FFF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF00\
59FF0059FF004CFF004CFF003FFF003FFF0033FF0033FF0019FF000CFF0000FF00
00FF2600FF4C00FF4C00FF2600FF2600FF1900FF1900FF1900FF4000FF2600FF2600FF3300FF40\
00FF9900FF9900FF9900FFFF0080FF000CFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000008C00FF8C00FF2600FF0073FF00D9FF00FFFF
00CCFF00FFBF00FFB300FFF300FF9900FF6600FF4C00FF4000FF4000FF3300FF2600FF2600FF26\
00FF0C00FF0C00FF000CFF000CFF0019FF0019FF0026FF0026FF0026FF0033FF00
33FF0033FF0033FF003FFF003FFF003FFF004CFF004CFF004CFF004CFF0059FF0059FF0059FF00\
59FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF003FFF0000FF66
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF00\
59FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0026FF0019FF0000FF00
00FF0C00FF3300FFB300FF7300FF8000FF3300FF3300FF3300FF7300FF4000FF3300FF4000FF4C\
00FF6600FFE600FFCC00D9FF0C00FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000006600FF0080FF00A6FF
008CFF00B3FF00E6FF00FFD900FF8C00FF6600FF4C00FF4000FF3300FF3300FF2600FF1900FF19\
00FF0C00FF0000FF000CFF000CFF0019FF0019FF0026FF0026FF0026FF0033FF00
33FF0033FF0033FF003FFF003FFF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF00\
59FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF004CFF0019FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF00\
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF0066FF00\
59FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0026FF0019FF0000FF33
00FF3300FF5900FF9900FF4C00FF3300FF4C00FF9900FF8000FFB300FF8000FF4C00FF4C00FF59\
00FF7300FF9900F3FF0040FF000000000000000000CC00FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000001900FF0073FF00D9FF
00FFF300FFD900FFB300FFBF00FFCC00FFB300FF8000FF4C00FF3300FF2600FF2600FF1900FF19\
00FF0C00FF0000FF000CFF000CFF0019FF0019FF0026FF0026FF0026FF0026FF00
33FF0033FF0033FF0033FF003FFF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF00\
59FF0066FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0059FF0033FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF00\
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF00\
59FF0059FF0059FF004CFF004CFF003FFF0033FF0033FF0026FF000CFF0000FF0C
00FFA600FF3300FF4000FF1900FF1900FF1900FF4000FF4C00FF5900FF9900FF6600FF5900FF66\
00FF7300FF8C00B3FF3F00FF3F00FF9900FF8000FF6600FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000000040FF00A6FF
00FFE600FFCC00FFA600FF9900FFA600FF7300FF5900FF4000FF3300FF3300FF2600FF1900FF19\
00FF0C00FF0000FF000CFF000CFF0019FF0019FF0019FF0026FF0026FF0026FF00
26FF0033FF0033FF0033FF0033FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF0059FF00\
59FF0066FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0066FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF00\
66FF0059FF0059FF004CFF004CFF003FFF0033FF0019FF0000FF0000FF1900FF80
00FF4000FF0C00FF0C00FF0000FF0000FF0C00FF1900FF2600FF6600FF7300FFBF00FF8C00FF80\
00FFB300FFA600FFCC00D9FF00A6FF0033FF0059FF0000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000004CFF
0099FF00FFD900FF9900FF8000FF7300FF6600FF4C00FF4000FF3300FF3300FF2600FF2600FF19\
00FF1900FF0C00FF000CFF000CFF0019FF0019FF0019FF0019FF0026FF0026FF00
26FF0026FF0026FF0026FF0033FF0033FF0033FF0033FF003FFF004CFF004CFF0059FF0059FF00\
59FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00\
66FF0059FF0059FF004CFF004CFF0033FF0000FF0000FF3300FF2600FF0000FF00
00FF0C0CFF000CFF000CFF0000FF0000FF0000FF0C00FF1900FF3300FF6600FFD900FF8000FF8C\
00FFA60080FF00FFF300CCFF00F3FF008CFF00A6FF1900FF0000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000000000003300FF
00FFFF00FFCC00FF9900FF8C00FF7300FF6600FF4C00FF4000FF4000FF3300FF3300FF3300FF33\
00FFA600FF4C00FF0000FF000CFF000CFF0019FF0019FF0019FF0019FF0019FF00
26FF0026FF0026FF0026FF0026FF0019FF000CFF0019FF0033FF003FFF004CFF0059FF0059FF00\
59FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
99FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF00\
66FF0059FF0059FF004CFF003FFF0000FF0000FF4C0CFF000CFF0019FF0019FF00
19FF0019FF0019FF000CFF000CFF0000FF0000FF0000FF1900FF4000FFA600FF5900FF5900FF59\
00FF8000FFBF00FFA600FFBF00FFE600F3FF00B3FF008CFF0033FF0000FF7300FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000009900FF004CFF0099FF
00FFFF00E6FF00FFA600FF9900FF9900FFD900FF5900FF4C00FF4000FF4000FF4000FF4000FF59\
00FFE600FF1900FF0C00FF000CFF000CFF000CFF000CFF0019FF0019FF0019FF00
19FF0019FF0019FF0019FF0000FF0000FF0000FF5900FF400CFF0033FF004CFF0059FF0059FF00\
66FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF00\
66FF0066FF0059FF0059FF004CFF0033FF000CFF0026FF0026FF0026FF0026FF00
26FF0019FF0019FF0019FF000CFF000CFF0000FF0000FF3300FF5900FF4000FF4000FF4000FF4C\
00FF7300FF8000FF8C00FFFF00FFFF0000FF00CCFF0099FF0080FF0033FF8000FF
F300FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000F300FF5900FF3F00FF3300FF0033FF0033FF00E6FF
00E6FF00FFE600FFBF00FFCC00FFA600FF7300FF6600FF5900FF4C00FF4C00FF8C00FFCC00FF59\
00FF3300FF1900FF0C00FF0000FF000CFF000CFF000CFF000CFF000CFF000CFF00
00FF000CFF000CFF0000FF0C00FF2600FF4000FF6626FF0033FF003FFF004CFF0059FF0059FF00\
66FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF00\
66FF0066FF0059FF0059FF004CFF004CFF003FFF0033FF0033FF0033FF0033FF00
26FF0026FF0019FF0019FF0019FF000CFF0000FF0000FF0C00FF1900FF2600FF3300FF3300FF4C\
00FF5900FF7300FF8C00FF9900FFD900FFF300FFFF00CCFF0099FF1900FF9900FF
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000CC00FF6600FF0019FF0040FF0040FF00B3FF00CCFF00FFF3
00FFE600FFE600FFE600F3FF00FFB300FF8000FF7300FF6600FF6600FFBF00FF8C00FF6600FF40\
00FF2600FF1900FF0C00FF0C00FF0000FF0000FF0000FF0000FF0000FF0000FF0C
00FF8C00FF2600FF5900FF5900FF0C0CFF0019FF0033FF003FFF004CFF004CFF0059FF0059FF00\
66FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF00\
66FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0033FF00
33FF0026FF0026FF0019FF0019FF000CFF0000FF0000FF0C00FF1900FF1900FF2600FF3300FF4C\
00FF6600FFCC00FF9900FFA600FFBF00FFD900FFFF008CFF0080FF0000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000008000FF0C00FF0033FF0073FF008CFF0099FF00FFFF00FFE6
00FFCC00FFBF00FFB300FFBF00B3FF00FFA600FFB300FF8000FF8000FFA600FF9900FF6600FF40\
00FF3300FF2600FF1900FF0C00FF0C00FF0000FF0000FF0000FF0C00FF0C00FF19
00FF4C00FF4000FF0C0CFF0019FF0026FF0033FF003FFF003FFF004CFF0059FF0059FF0059FF00\
66FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF00\
66FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF003FFF0033FF00
33FF0026FF0026FF0019FF0019FF000CFF0000FF0000FF0C00FF1900FF1900FF2600FF3300FF4C\
00FF7300FFA600FFD900FFBF00FFD900FFE600FFFF00CCFF0099FF0019FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000008C00FF1900FF004CFF0099FF00B3FF004CFF00E6FF00FFFF
00FFD900FFA600FFA600FFA600FFBF00FFBF00FFA600FF990026FF00FFB300FF9900FF7300FF59\
00FF4C00FF3300FF2600FF2600FF1900FF0C00FF0C00FF0C00FF1900FF6600FF33
00FF7300FF1900FF0019FF0026FF0033FF0033FF003FFF004CFF004CFF0059FF0059FF0059FF00\
66FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF00\
66FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF003FFF0033FF00
33FF0026FF0026FF0019FF000CFF000CFF0000FF0000FF0C00FF2600FF2600FF3300FF3300FF4C\
00FF5900FF8000FFD900FFE600A6FF00B3FF00E6FF00BFFF0099FF0000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000FF0066FF00B3FF00D9FF00E6FF00CCFF00FFF3
00FFBF00FFA600FF9900FF8C00FF8C00FFBF00FF8000FF7300FF7300FF7300FFB30080FF00FFFF\
00FF4C00FF4000FF4000FF4000FF2600FF1900FF1900FF2600FF2600FF5900FF80
00FF4C00FF3300FF0019FF0026FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF0059FF00\
66FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF00
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF00\
66FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF003FFF0033FF00
33FF0026FF0026FF0019FF0000FF0000FF5900FF1900FF2600FF8000FF4000FF4000FF4000FF4C\
00FF6600FFBF00FFA600FFA600FFBF00F3FF00E6FF00A6FF0059FF0026FF2600FF
C000FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000019FF0019FF0040FF00D9FF00FFFF00FFFF00BFFF
00FFCC00FF9900FF8C00FF8000FF8000FF7300FF6600FF6600FF6600FF6600FF6600FF8000E6FF\
00FF6600FF7300FF8000FF8000FF5900FF3300FF3300FF5900FF4C00FFA600FF40
00FF2600FF0C0CFF0019FF0026FF0033FF0033FF003FFF004CFF004CFF004CFF0059FF0059FF00\
59FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF00\
66FF0066FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF0033FF0033FF00
33FF0026FF0026FF0019FF000CFF0000FF1900FF2600FF8000E6FF00FFF300FF4C00FF4C00FF59\
00FF6600FF7300FF8C00FF9900FFB300FFD900FFF300D9FF00B3FF0066FF0019FF
B300FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000059FF00A6FF00BFFF00FFE600FFD900FFBF
00FFB300FF9900FF8C00FF8000FF7300FF6600FF5900FF5900FF5900FF5900FF5900FF6600FFB3\
00FFD900FF8C00FF6600FF6600FF5900FF5900FF8C00FFA600FFBF00FFB300FF40
00FF2600FF0C00FF000CFF0019FF0026FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF00\
59FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF00\
66FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF003FFF0033FF0033FF00
26FF0026FF0026FF0019FF000CFF0000FF0000FF0C00FF3300FF4C00FF9900FF6600FF5900FF66\
00FF6600FF7300FF8C00FFA600FFBF00FFD900FFFF00A6FF00B3FF0000FF2600FF
8C00FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000B300FF0026FF00A6FF00D9FF00FFFF00FFE600FFCC00FFBF
00FFA600FF9900FF8C00FF8000FF7300FF6600FF5900FF4C00FF4C00FF4C00FF4C00FF5900FF59\
00FF8C00FF5900FF4000FF3300FF3300FF2600FF3300FF4000FF3300FF4000FFA6
00FFFF00FF2600FF0C00FF0C00FF0C26FF0033FF0033FF003FFF003FFF004CFF004CFF0059FF00\
59FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF00\
59FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0033FF0033FF0026FF00
26FF0026FF0019FF0019FF000CFF0000FF0000FF0C00FF1900FF4000FF7300FF9900FF8000FF73\
00FFB300FF8C00FF8C00FFA600FFFF00FFFF00F3FF0080FF0073FF0066FF0019FF
3F00FFD900FF000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000C000FFCC00FF0026FF0059FF0073FF00B3FF00F3FF00FFF300FFF300FFD9
00FFA600FF9900FF8C00FF8C00FF8000FF6600FF5900FF4C00FF4000FF4000FF4000FF4000FF40\
00FF4C00FF7300FF3300FF2600FF1900FF1900FF1900FF1900FF1900FF2600FF59
00FFE600FF5900FF4000FF260CFF0019FF0026FF0026FF0033FF003FFF004CFF004CFF0059FF00\
59FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF00\
59FF004CFF004CFF004CFF003FFF003FFF0019FF0019FF0026FF0026FF0026FF00
26FF0026FF0019FF0019FF000CFF0000FF0000FF0C00FF2600FF4000D9FF00FF8C00FF8000FFD9\
00D9FF00FFA600FFA600FFB300F3FF008CFF00CCFF00B3FF2600FF0026FF6600FF
8000FF000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000002600FF0019FF0026FF008CFF00A6FF0080FF00CCFF0099FF00FFF300FFCC
00FFB300FFA600FFB300FFB3008CFF00FF7300FF4C00FF4C00FF4000FF4000FF3300FF3300FF33\
00FF3300FF4C00FF2600FF1900FF0C00FF0C00FF0C00FF0C00FF0C00FF1900FF59
00FF3300FF4000FF8000FF1900FF000CFF0019FF0019FF0000FF4C33FF003FFF004CFF004CFF00\
59FF0059FF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0059FF0059FF00\
3FFF003FFF003FFF003FFF003FFF0033FF0019FF0000FF5919FF0019FF0019FF00
19FF0019FF0019FF000CFF000CFF0000FF0000FF3300FF6600FF4C00FF6600FF5900FF6600FF80\
00CCFF00FFD900FFB300FFBF00FFE600F3FF0066FF0033FF3F00FF8000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
B300FF1900FF004CFF0040FF0099FF00BFFF00BFFF00E6FF00CCFF1900FF00FFF3
00FFCC00FFCC00F3FF00FF9900FF8000FF6600FF4C00FF4C00FF4000FF3300FF3300FF2600FF26\
00FF2600FF1900FF1900FF0C00FF0C00FF0C00FF0000FF0000FF0000FF0C00FF0C
00FF1900FF2600FF6600FF3300FF0C00FF0000FF0C00FF0C00FF0026FF0033FF003FFF004CFF00\
4CFF004CFF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0059FF003FFF0033FF00\
00FF0C19FF0026FF0033FF0026FF0026FF000CFF0000FF3300FF000CFF000CFF00
19FF0019FF000CFF000CFF000CFF0000FF0000FF0C00FF2600FF3300FF3300FF4000FF5900FF73\
00FFA600FFE600CCFF00FFF300FFF300A6FF0073FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000E600FF\
9900FF000CFF0059FF008CFF00B3FF00CCFF00E6FF00FFFF00FFFF00D9FF00FFFF
00FFE600FFF300FFF300FFB300FF8000FF6600FF5900FF4C00FF4000FF3300FF3300FF2600FF26\
00FF1900FF1900FF0C00FF0C00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0C00FF1900FF6600FF4C00FF2600FF4000FFF300FF2600FFBF00FF0026FF0033FF0033FF00\
3FFF0033FF004CFF0059FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0059FF004CFF0019FF00\
19FF0000FF000CFF000026FF00FFCC00FF0000FF1900FF4000FF3300FF5900FF00
0CFF000CFF000CFF000CFF0000FF0000FF0000FF0C00FF1900FF2600FF3300FF4000FF4C00FF73\
00FF8C00FFA600FFCC00A6FF00D9FF0080FF8000FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000007300FF\
0C00FFE600FF0C00FF0080FF0099FF0099FF00D9FF00FFF300FFE600FFE600FFD9
00FFBF00FFBF00FFCC00A6FF00FFBF00FF8C00FF6600FF4C00FF4000FF3300FF2600FF2600FF19\
00FF1900FF0C00FF0C00FF0000FF0000FF0000FF000CFF000CFF000CFF000CFF00
00FF0000FF1900FF3300FF4000FF9900FF1900FF1900FF0000FF0C00FF0C00FF6600FF0000FF00\
0CFF0000FF0C19FF003FFF0059FF0066FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0059FF004CFF00\
3FFF003FFF0033FF0019FF0000FF7300FF4000FFA600FF1900FF3300FF4C00FF0C
00FF0000FF0000FF0000FF0000FF0000FF0C00FF0C00FF1900FF2600FF3300FF4000FF5900FF73\
00FF8000FF9900FFCC00FFF30099FF000CFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000B300FF3F00FF\
000CFF0033FF004CFF0040FF000CFF008CFF00D9FF00FFF300FFE600FFCC00FFBF
00FFB300FFA600FFA600FFB300FFA600FF8000FF7300FF4C00FF4000FF3300FF2600FF2600FF19\
00FF1900FF0C00FF0C00FF0000FF000CFF000CFF000CFF000CFF000CFF000CFF00
0CFF0000FF0C00FF0000FF0C00FFB300FF0019FF0019FF0019FF0026FF0026FF0019FF000CFF00\
00FF0C26FF0033FF003FFF0059FF0066FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF00\
59FF004CFF004CFF003FFF000CFF000CFF000CFF0000FF0000FF3300FF4C00FF26
00FF1900FF0C00FF0C00FF0C00FF0C00FF1900FF1900FF2600FF2600FF3300FF5900FFA600FF99\
00FF9900FFCC00FFE600F3FF00BFFF0026FF3F00FFE600FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000D900FF8C00FF000000\
7300FF0033FF0066FF0080FF00A6FF00A6FF00D9FF00FFFF00FFE600FFD900FFBF
00FFA600FF9900FF9900FF8C00FF8C00FF6600FF5900FF4C00FF4000FF3300FF3300FF2600FF19\
00FF1900FF0C00FF0C00FF0000FF000CFF000CFF000CFF0019FF0019FF0019FF00
19FF0019FF000CFF000CFF0000FF1900FF0019FF0026FF0033FF0033FF003FFF003FFF003FFF00\
33FF003FFF004CFF0059FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0066FF00\
59FF0059FF004CFF003FFF0033FF0033FF0026FF000CFF0000FF3300FF3300FFFF
00FF4000FF1900FF1900FF1900FF1900FF2600FF4C00FF3300FF3300FF4000FF4C00FF7300BFFF\
00FFB300FFFF00D9FF00D9FF0073FF0059FF1900FFB300FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000003F00FF\
0C00FF0026FF0059FF0040FF00A6FF00CCFF00E6FF00FFFF00FFF300FFF300FFF3
00FFA600FF9900FF8C00FF8000FF7300FF6600FF5900FF4C00FF4000FF3300FF3300FF2600FF26\
00FF1900FF1900FF0C00FF000CFF000CFF000CFF0019FF0019FF0019FF0019FF00
19FF0019FF0019FF0019FF0000FF0000FF2626FF0033FF003FFF003FFF003FFF004CFF004CFF00\
4CFF0059FF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF00\
59FF0059FF0059FF004CFF003FFF003FFF0033FF000CFF0000FF0000FF0C00FF33
00FF8000FF4C00FFBF00FF3300FF5900FF4000FFA600FF5900FF4000FF4C00FF5900FF8C00FFB3\
0026FF00BFFF0066FF00A6FF0073FF2600FF5900FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000A600FF9900FF\
3300FF0000FF0000FFA600FF0080FF00B3FF00B3FF00E6FF00E6FF008CFF00FFD9
00FFBF00FFA600FF8C00FF8000FF7300FF6600FF5900FF4C00FF4000FF4000FF3300FF3300FF33\
00FF3300FF3300FF1900FF000CFF000CFF0019FF0019FF0019FF0019FF0026FF00
26FF0026FF0026FF0026FF0019FF0019FF0026FF003FFF003FFF004CFF004CFF004CFF0059FF00\
59FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF00\
66FF0059FF0059FF004CFF004CFF003FFF0033FF0026FF0019FF0000FF0000FF19
00FF5900FF5900FF4000FF3300FF6600FFB300FF7300FF8000FF5900FF5900FF6600FF8000FFA6\
00FFF3B300FF0019FF3300FF2600FF3F00FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000B300FF\
6600FF7300FF000CFF004CFF0073FF008CFF0040FF0080FF00BFFF00E6FF0C00FF
00FFD900FFA600FF8C00FF8C00FF8000FF9900FF6600FF5900FF4C00FF4C00FF4C00FF4C00FF4C\
00FFD900FF4000FF1900FF000CFF000CFF0019FF0019FF0019FF0026FF0026FF00
26FF0026FF0033FF0033FF0033FF0033FF0033FF003FFF004CFF004CFF004CFF0059FF0059FF00\
59FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF00\
66FF0059FF0059FF004CFF004CFF003FFF0033FF0026FF0019FF0000FF4000FF66
00FF6600FF2600FF1900FF1900FF2600FF3300FF4C00FF8000FF8C00FF8000FF9900FF9900FFCC\
0073FF000000000000000000E600FF9900FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000008000FF4C00FF1900FF3F00FF0019FF0099FF00B3FF00E6FF00FFFF00FFE6
00FFBF00FFA600FF9900FF9900FF990019FF00FF7300FF5900FF5900FF5900FF5900FFA600FF59\
00FF3300FF1900FF0C00FF000CFF000CFF0019FF0019FF0026FF0026FF0026FF00
26FF0033FF0033FF0033FF0033FF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF00\
66FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF00\
66FF0059FF0059FF004CFF004CFF003FFF0033FF0026FF000CFF0000FF1900FFB3
00FF1900FF0C00FF0000FF0000FF0C00FF1900FF2600FF5900FFD900FF7300FF8000FFE600F3FF\
00B3FF0040FF3300FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000FF004CFF0059FF0066FF00BFFF00F3FF00FFE6
00FFD900FFD900FFB300FFB300FFF300FF9900FF8000FF7300FF6600FF6600FF9900FFCC00FF4C\
00FF3300FF1900FF0C00FF000CFF000CFF0019FF0019FF0026FF0026FF0026FF00
33FF0033FF0033FF0033FF003FFF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0059FF00\
66FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF00\
66FF0059FF0059FF004CFF004CFF0033FF0026FF0000FF4000FFA600FF2600FF19
00FF000CFF000CFF0000FF0000FF0000FF0C00FF2600FF9900FF4C00FF4C00FF6600FF8C00FF99\
00FFE600BFFF0C00FF0000FFC000FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000CC00FFD900FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000004C00FF000CFF000CFF0066FF0059FF00CCFF00FFFF
00E6FF00FFE600FFD900FFD900E6FF00FFCC00FFA600FFB30080FF00FF9900D9FF00FF8000FF59\
00FF4C00FF2600FF1900FF0C00FF000CFF0019FF0019FF0026FF0026FF0026FF00
33FF0033FF0033FF003FFF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0066FF00\
66FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF00\
66FF0059FF0059FF004CFF003FFF0026FF0000FF3300FF800CFF0019FF0019FF00
19FF0019FF000CFF000CFF000CFF0000FF0C00FF8C00FF3300FF3300FF4000FF4C00FF7300FF8C\
00FFE600FFFF00B3FF0026FFE600FF000000000000000000B300FF000000000000
000000000000000000000000000000000000000000E600FFA600FF5900FF000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000A600FFD900FF0000007300FF0080FF00A6FF
0080FF00BFFF00E6FF00FFD900FFBF00FFCC0073FF00FFB300FF8C00FF8000FF7300FFCC00D9FF\
00FF5900FF4000FF4000FF1900FF0C00FF0019FF0019FF0026FF0026FF0033FF00
33FF0033FF0033FF003FFF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0066FF00\
66FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF00\
66FF0059FF0059FF004CFF0000FF0000FFE600FF0019FF0026FF0026FF0026FF00
26FF0019FF0019FF0019FF000CFF0000FF0000FF0C00FF1900FF2600FF3300FF7300FFB300FFB3\
00FFCC00FFF3000CFF5900FF0000000000008C00FF3300FF5900FF0C00FF2600FF
8000FF000000000000000000000000B300FF7300FF3F00FF000CFF3F00FF3F00FF000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000009900FF0066FF00CCFF
00F3FF00FFF300FFE600FFBF00FFA600FFA600FF9900D9FF00FF7300FF6600FF5900FF6600FF80\
00FFA600D9FF00FFF300FF5900FF5900FFCC0CFF0019FF0026FF0026FF0033FF00
33FF0033FF003FFF003FFF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0066FF00\
66FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00\
66FF0059FF0059FF004CFF004CFF003FFF0033FF0033FF0033FF0033FF0026FF00
26FF0026FF0019FF0019FF000CFF000CFF0000FF0000FF1900FF2600FF3300FF4C00FF7300E6FF\
00FFE600D9FF00A6FF7300FF000000C000FF0000FF0033FF0059FF0C00FF0040FF
1900FF000000000000000000A600FF000CFF0026FF000CFF0059FF0040FF0C00FF4C00FF000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000006600FF0059FF00A6FF
00F3FF00FFE600FFCC00FFBF00FFA600FF9900FF8000FF7300FF6600FF5900FF4C00FF4C00FF59\
00FF6600FF4000FF2600FF1900FF0C00FF000CFF0019FF0026FF0026FF0033FF00
33FF0033FF0033FF003FFF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0066FF00\
66FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00\
66FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0033FF0033FF00
26FF0026FF0026FF0019FF0019FF000CFF0000FF0C00FF2600FF3300FF4000FF4C00FF6600FF8C\
00FFBF00FFFF0066FFF300FF000000B300FF0033FF0066FF0099FF008CFF008CFF
0066FF0026FF3300FF0000003F00FF0040FF0073FF004CFF008CFF1900FF004CFF3F00FF000000\
A600FFB300FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000CFF0059FF0099FF
00BFFF00FFF300FFE600D9FF00FFA600FF9900FF8000FF7300FF6600FF4C00FF4C00FF4000FF33\
00FF3300FF4C00FF1900FF0C00FF000CFF0019FF0019FF0026FF0026FF0026FF00
33FF0033FF0033FF003FFF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0066FF00\
66FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00
99FF0099FF0099FF008CFF008CFF0080FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00\
66FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF0033FF0033FF00
33FF0026FF0026FF0019FF000CFF0000FF0000FF1900FF3300FF7300FF5900FF5900FF7300FF8C\
00FFD900B3FF0026FF000000B300FF0000FF004CFF00BFFF00A6FF0099FF00CCFF
008CFF00B3FF0099FF0073FF0040FF008CFF00A6FF0080FF00B3FF00A6FF008CFF004CFF0033FF\
0000003300FFD900FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000F300FF6600FF000CFF0059FF0099FF
00CCFF00E6FF00E6FF00E6FF00CCFF00FF9900FF8C00FF8000FF8000FF4C00FF4000FF3300FF33\
00FF2600FF1900FF0C00FF0000FF000CFF0019FF0019FF0026FF0026FF0026FF00
33FF0033FF0033FF0033FF003FFF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0066FF00\
66FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00
99FF0099FF0099FF008CFF008CFF0073FF0000FF3366FF0073FF0073FF0073FF0073FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF00\
66FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF003FFF0033FF00
33FF0033FF0026FF0026FF000CFF0000FF3300FF1900FFA600FF5900B3FF00FFBF00FFD900F3FF\
00CCFF0000FFCC00FF4C00FF0059FF00B3FF0019FF00E6FF00FFFF00FFF300F3FF
00D9FF00F3FF00CCFF00D9FF0040FF00D9FF00BFFF00CCFF00D9FF00BFFF008CFF008CFF0080FF\
004CFF0C00FF7300FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000C000FF8C00FF0019FF0073FF
0099FF004CFF00D9FF00FFFF00FFCC00FFB300FFA600A6FF00FF7300FF5900FF4000FF3300FF26\
00FF1900FF1900FF0C00FF000CFF000CFF0019FF0019FF0019FF0026FF0026FF00
26FF0033FF0033FF0033FF0033FF003FFF003FFF003FFF004CFF004CFF0059FF0059FF0059FF00\
66FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00
99FF0099FF008CFF008CFF0080FF0080FF0066FF0033FF0059FF0066FF003FFF0066FF0073FF00\
73FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF00\
66FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF003FFF0033FF00
33FF0033FF0026FF0026FF0019FF000CFF0000FF0000FF0C00FF2600FF8C00FF6600FF5900FFB3\
00FFA600E6FF0C00FF0033FF00CCFF00F3FF00E6FF00D9FF00FFD900FFD900B3FF
0099FF00FFE600FFE600F3FF00CCFF00FFF300FFF300FFF300F3FF00A6FF00BFFF00BFFF00A6FF\
0040FF0026FF5900FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000F300FF0C00FF
0066FF00A6FF00CCFF00F3FF00FFE600FFF300FFD90080FF00FFA600FF8000FF8000FF3300FF26\
00FF2600FF1900FF0C00FF0000FF000CFF000CFF0019FF0019FF0026FF0026FF00
26FF0026FF0026FF0033FF0033FF0033FF0033FF0033FF003FFF003FFF004CFF0059FF0059FF00\
66FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00
99FF008CFF008CFF008CFF0080FF0080FF0066FF000CFF0033FF003FFF0019FF0066FF0066FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF0066FF00\
59FF0059FF0059FF0059FF004CFF004CFF004CFF004CFF003FFF003FFF0033FF00
33FF0033FF0026FF0026FF0019FF0019FF000CFF0000FF0000FF4000FF4C00FF4000FF4000FF59\
00FF9900FFE66600FF0099FF00F3FF00FFD900D9FF00FFD900FFBF00FFB300FFCC
00FFCC00FFBF00FFD900A6FF00FFFF00FFE600FFCC00FFF3008CFF00D9FF00FFFF00F3FF00A6FF\
0073FF0026FF0000000000000000000000000000000000000000000000008000FF
8C00FF000000000000000000000000000000000000000000000000000000CC00FFA600FFA600FF\
000000D900FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000000000003300FF
0033FF0019FF0059FF0099FF0066FF00F3FF00FFD900FFA600FF9900FF6600FF4C00FF3300FF33\
00FF2600FF2600FF1900FF0C00FF000CFF000CFF0019FF0019FF0019FF0019FF00
26FF0026FF0026FF0026FF0026FF0019FF0019FF0000FF000CFF000CFF004CFF0059FF0059FF00\
66FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF008CFF008CFF008CFF0080FF0073FF0059FF0026FF000CFF0000FF0C26FF0059FF0066FF00\
66FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
59FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF003FFF0033FF00
33FF0033FF0026FF0026FF0019FF0019FF000CFF0000FF0000FF1900FF2600FF2600FF3300FF99\
00FF8000FF9900D9FF00FFF300FFE600FFB300FFCC00FFBF00FF9900FF9900FF99
00FFA600FFB300FFCC00D9FF00FFBF00FFBF00FFB300FFF300FFE600E6FF00FFE600FFFF00E6FF\
00B3FF004CFF000000000000000000000000000000000000C000FF4C00FF0C00FF
2600FFC000FF0000000000000000000000006600FFB300FFA600FF7300FF6600FF8000FF4C00FF\
6600FFB300FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
2600FF000CFF000CFF9900FF0000FF0033FF00FFFF00FFA600FF8000FF6600FF4C00FF4000FF33\
00FF3300FF3300FF4C00FF3300FF0000FF000CFF000CFF0019FF0019FF0019FF00
19FF0019FF0019FF0019FF000CFF0000FF6600FF1900FF0026FF003FFF004CFF0059FF0059FF00\
59FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00
8CFF008CFF008CFF008CFF0080FF0080FF0066FF0059FF004CFF0019FF000CFF0033FF004CFF00\
66FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF00\
59FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF003FFF0033FF00
33FF0026FF0026FF0026FF0019FF0019FF000CFF0000FF0000FF0C00FF1900FF1900FF3300FF40\
00FF5900FF7300FFB300FFB300FF8000FF9900F3FF0080FF00FF8C00FF8000FF8C
00FF9900FFA600FFCC00FFD900FFA600FF9900FF9900FFBF00FFB300FFCC00FFCC00FFE600FFFF\
00BFFF004CFF0019FF5900FF000000000000000000000000E600FF0019FF0040FF
0040FF6600FF0C00FFB300FF0000003F00FF0019FF0C00FF000CFF9900FF000CFF4C00FF0C00FF\
5900FF6600FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
B300FFA600FF000000000000000000C000FF008CFF00FFBF00FF9900E6FF00FF5900FF4C00FF4C\
00FF5900FF7300FF4C00FF1900FF0C00FF000CFF000CFF000CFF000CFF000CFF00
0CFF000CFF000CFF000CFF0000FF4000A6FF00FFCC00FF3333FF003FFF004CFF0059FF0059FF00\
59FF0066FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00
8CFF008CFF008CFF008CFF0080FF0080FF0073FF0066FF0059FF0019FF0019FF0000FF194CFF00\
59FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF00\
59FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF0033FF0033FF00
33FF0026FF0026FF0019FF0019FF0019FF000CFF0000FF0000FF0000FF0C00FF1900FF3300FF40\
00FF4C00FF7300FFA600FF8000FF6600FF8000FF8C00FF8000FF8000FF7300FF80
00FF9900FFCC00E6FF0066FF00FFA600FF8C00FF8C00FF8C00FF9900FFB300FFBF00FFFF00CCFF\
00E6FF00D9FF0099FF0040FF7300FF000000CC00FF7300FF000CFF0066FF0033FF
0059FF0059FF0066FF0040FF2600FF004CFF0059FF0066FF0026FF004CFF0019FF0033FF0019FF\
0C00FF4C00FFCC00FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000000000000
000000000000000000A600FF004CFF0080FF00FFFF00FFFF00E6FF00FF8C00FF6600FF5900FF66\
00E6FF00FF4C00FF3300FF1900FF0C00FF0000FF0000FF000CFF000CFF0000FF00
00FF0000FF4C00FF1900FF4000FF6600FF0C19FF0033FF003FFF004CFF004CFF0059FF0059FF00\
59FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF00
8CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF0059FF003FFF0000FF0033FF00\
4CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF00\
59FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF0033FF0033FF0026FF00
26FF0026FF0019FF0019FF0019FF000CFF000CFF0000FF0000FF0000FF0C00FF3300FF4000FF66\
00FF6600FF9900FF6600FF4C00FF4C00FF5900FF5900FF5900FF5900FF6600FF73
00FFA600FFBF00FFD900FF9900FF9900FF8000FF8000FF8C00FF9900FFB300FFCC008CFF00FFD9\
00FFF300FFE600D9FF00A6FF000000000000000CFF0026FF0059FF00B3FF00BFFF
0066FF00B3FF00B3FF0099FF0080FF0099FF0099FF0080FF0066FF0066FF0073FF004CFF0C00FF\
3F00FF5900FFB300FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000C000FF7300FF8000FF
CC00FF9900FF0000000059FF00A6FF00D9FF00FFF300FFB300FFB300FFCC00FFE600FF8C00FFA6\
00FF8000FF4C00FF3300FF2600FF1900FF0C00FF0C00FF0000FF0000FF0000FF0C
00FF1900FF4C00FF4000FF000CFF0019FF0026FF0033FF003FFF004CFF004CFF004CFF0059FF00\
59FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF00
8CFF008CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF0059FF004CFF0033FF0026FF00\
3FFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0026FF0059FF0059FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF00\
59FF0059FF004CFF004CFF004CFF004CFF003FFF0033FF0019FF0019FF0019FF00
19FF0019FF0019FF0019FF000CFF000CFF0000FF0000FF0000FF0C00FF1900FF3300FF6600FF80\
00FF8C00FF8000FF6600FF4000FF3300FF3300FF4000FF4000FF4C00FF5900FF66
00FFA600FFCC00FF7300FF7300FFBF00FF6600FF7300FF8C00FFB300FFCC00F3FF00FFBF00FFB3\
00FFB300FFD900E6FF00D9FF00A6FF0000000073FF00CCFF004CFF00A6FF00E6FF
00D9FF00D9FF00CCFF0066FF0059FF00CCFF00B3FF0066FF0099FF00A6FF0073FF0059FF004CFF\
0033FF0C00FFA600FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000E600FF7300FF1900FF1900FF
2600FF0059FF0066FF00B3FF00E6FF00FFE600FFD900FF9900FF8C0026FF00FF8000FF8000FF8C\
00FFCC00FF7300FF7300FF3300FF2600FF1900FF0C00FF0C00FF0C00FF1900FFCC
00FF3300FF7300FF190CFF0019FF0026FF0033FF0033FF003FFF004CFF004CFF004CFF0059FF00\
59FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF0099FF00
8CFF008CFF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0059FF0059FF003FFF0000FF59\
26FF003FFF003FFF004CFF0059FF0059FF004CFF0033FF0000FF004CFF0059FF00
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00\
59FF004CFF004CFF004CFF004CFF003FFF003FFF0033FF0000FF0000FFA600FF00
0CFF000CFF0000FF0000FF0000FF0000FF0000FF0000FF0C00FF0C00FF1900FF4C00FF8000FF40\
00FF4000FF4000FF5900FF3300FF2600FF2600FF3300FF4000FF4C00FF5900FF73
00FFE600FF7300FF5900FF5900FF5900FF5900FF6600FF8000F3FF00D9FF00FFE600FFB300FF99\
00FF9900FFD900FFD900FFD900FFFF00A6FF00F3FF00FFFF0080FF00FFFF00FFF3
00FFF300FFFF00E6FF00B3FF00F3FF00F3FF00BFFF00CCFF00BFFF00BFFF00B3FF0099FF0073FF\
004CFF2600FFC000FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000002600FF0019FF0066FF
0033FF00A6FF00CCFF0066FF00FFFF00FFCC00FFA600FF8C00FF7300FF7300FF6600FF6600FF66\
00FF8000FFFF00FF5900FF4C00FF6600FF3300FF2600FF1900FF2600FF2600FF4C
00FF8000FF4C00FF3300FF0019FF0026FF0033FF0033FF003FFF003FFF004CFF004CFF0059FF00\
59FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0026FF0073FF008CFF008CFF00
8CFF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF0033FF0000FF73\
00FF590CFF0026FF003FFF004CFF004CFF003FFF0026FF0000FF593FFF004CFF00
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00\
4CFF004CFF004CFF004CFF004CFF003FFF003FFF0033FF0019FF0000FF0000FF40
00FF0C00FF0C00FF4000FF0C00FF0C00FF0C00FF0C00FF0C00FF2600FF3300FF8C00FF3300FF26\
00FF1900FF2600FF8000FF2600FF1900FF1900FF2600FF4000FF4C00FF6600FF8C
00FFB300FF6600FF4C00FF4C00FF4C00FF4C00FF5900FF9900FF8000FF7300FF9900FF8C00FF80\
00FF8C00FF9900FFA600FFBF00CCFF00FFFF00FFCC00FFF300FFFF00FFF300FFD9
00FFD900FFFF00CCFF00CCFF00FFF300FFF300FFFF00FFFF00E6FF00D9FF00B3FF0099FF0026FF\
0040FF1900FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000A600FF000CFF0040FF0073FF
00A6FF00A6FF00F3FF00F3FF00F3FF00FFBF00FF9900FF8C00FF7300FF6600FF5900FF4C00FF4C\
00FF5900FFCC00FF8C00FFCC00FF7300FF7300FF4C00FF4000FF4C00FF5900FFA6
00FF4000FF2600FF0C0CFF0019FF0026FF0033FF0033FF003FFF003FFF004CFF004CFF004CFF00\
59FF0059FF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF00\
66FF0066FF004CFF0066FF0066FF0066FF0059FF0000FF0066FF0080FF008CFF00
80FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0059FF0059FF003FFF0026FF00\
00FF0000FF1926FF0033FF003FFF003FFF0033FF0019FF0000FF0C3FFF004CFF00
4CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF00\
4CFF004CFF004CFF004CFF003FFF003FFF0033FF0033FF0026FF000CFF0000FF0C
00FF8C00FF4000FF7300FF4000FF1900FF2600FF3300FF2600FF4000FF5900FF2600FF1900FF0C\
00FF0C00FF0C00FF7300FF0C00FF0C00FF1900FF2600FF5900FFBF00FFA600FF80
00FFCC00FF6600FF4C00FF4000FF4000FF4000FF4C00FF7300FF5900FF5900FF8C00FF7300FF73\
00FF8000FF8C00FFA600FFBF00F3FF00FFB300FFA600FFBF00FFB300FFBF00FFBF
00FFE62600FF0066FF00FFFF00FFE600FFD900FFE600FFF300F3FF00D9FF2600FF0C00FF008CFF\
2600FF004CFF3F00FFB300FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000019FF0073FF00A6FF
00CCFF00CCFF00FFF300FFE600E6FF00FFD900FFCC00FFB300FFCC00FF5900FF4C00FF4C00FF40\
00FF4C00FF5900FFB300FF4C00FF4000FF5900FF4000FF5900FF6600FF8C00FFD9
00FF4000FF2600FF0C00FF000CFF0019FF0026FF0033FF003FFF003FFF003FFF004CFF004CFF00\
4CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF0059FF004CFF003FFF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
59FF004CFF0000FF0059FF0059FF0059FF003FFF0000FF593FFF0066FF0080FF00
80FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF004CFF0033FF00\
00FF0C00FF1919FF0026FF0026FF0026FF0026FF0000FF1919FF0033FF003FFF00
4CFF004CFF004CFF004CFF004CFF0059FF0059FF004CFF004CFF004CFF004CFF004CFF004CFF00\
4CFF004CFF003FFF003FFF003FFF0033FF0033FF0026FF0019FF000CFF0000FF0C
00FF4C00FF3300FF3300FF7300FF4000FF6600FFFF00FFA600FFD900FF4000FF1900FF0C00FF00\
00FF0000FF0000FF0000FF0000FF0000FF0C00FF2600FF4C00FF6600FF5900FF40
00FF5900FF7300FF4000FF3300FF3300FF3300FF4000FF4000FF4C00FF4C00FF5900FF6600FF66\
00FF8000FF9900FFBF00F3FF00F3FF00FFA600FF8C00FF8C00FF9900FFA600FFB3
00FFCC0026FF00FFCC00FFCC00FFCC00FFCC00FFD900FFFF00E6FF0019FF00CCFF00B3FF00BFFF\
0099FF004CFF0000FF8C00FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000E600FF3300FF0019FF0059FF00A6FF
00BFFF00FFFF00FFE600FFCC00FFBF00FFCC00FFE600FF8C00FF6600FF4C00FF4000FF4000FF40\
00FF3300FF4000FFF300FF4000FF2600FF2600FF2600FF2600FF2600FF2600FF40
00FF8C00FFCC00FF1900FF0C00FF0C00FF7326FF0033FF0033FF0033FF003FFF003FFF004CFF00\
4CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF004CFF003FFF0000FF404CFF0059FF0059FF0059FF0059FF0059FF004CFF004CFF00\
4CFF003FFF0000FF4026FF003FFF0026FF0000FF0C33FF0000FF0C00FF0059FF00
80FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF004CFF003FFF0033FF00\
0CFF0000FF8C00FF0000FF0000FF330CFF000CFF0000FF590CFF0033FF003FFF00
3FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00\
4CFF003FFF003FFF003FFF0033FF0033FF0026FF0019FF0019FF0000FF0000FF40
00FF4000FF0C00FF0C00FF2600FF8000FF2600FF3300FF2600FF7300FF4000FF0C00FF000CFF00\
0CFF000CFF000CFF000CFF000CFF0000FF0000FF1900FF8C00FF5900FF2600FF26
00FF4000FF5900FF3300FF2600FF2600FF2600FF3300FF3300FF4000FF4000FF4C00FF5900FF66\
00FF8000FFB300FFCC00FFBF00FFA600FF9900FF8000FF8000FF8C00FF9900FFB3
00FFD900FFD900FFB300FFA600FFA600FFB300FFD900E6FF00E6FF0073FF00FFFF00F3FF00D9FF\
00B3FF0066FF0026FF6600FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000E600FF7300FF0C00FF0059FF0066FF0073FF
00CCFF00F3FF00FFF300FFBF00FFA600FFA600FFD900FF9900FF6600FF4C00FF4000FF3300FF33\
00FF3300FF2600FF3300FF3300FF1900FF1900FF0C00FF1900FF1900FF1900FF26
00FF6600FFE600FF4000FF3300FF4000FF0019FF0026FF0026FF0033FF0033FF0033FF003FFF00\
4CFF004CFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF004CFF00
4CFF004CFF004CFF003FFF0000FF2633FF003FFF0026FF003FFF004CFF003FFF0033FF0019FF00\
33FF0000FF6619FF0000FF4000FF0C0CFF003FFF0059FF003FFF0066FF0066FF00
73FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF004CFF004CFF003FFF0033FF00\
00FF3300FFCC00FF0C00FF8000FFFF00FF5900FF4000FF4000FF000CFF0033FF00
3FFF003FFF003FFF003FFF003FFF003FFF003FFF003FFF004CFF004CFF004CFF003FFF003FFF00\
3FFF003FFF003FFF0033FF0033FF0026FF0019FF0000FF1900FF0000FF0C00FF80
00FF6600FF000CFF0000FF0000FF2600FF0000FF0000FF1900FFCC00FF3300FF0C0CFF000CFF00\
19FF0019FF0019FF0019FF000CFF0000FF0000FF3300FF2600FF0C00FF0C00FF19
00FF4000FF4C00FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF4000FF4C00FF5900FF66\
00FF7300FFA600FFB300FF8000FF8000FFB300FF7300FF7300FF8C00FFB300FFD9
00FFE600FFFF00FFA600FF9900FF9900FFA600FFE600FFCC00FFE600FFF300FFE600FFFF00B3FF\
0080FF0040FF000CFFB300FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000003F00FF0000FF004CFF008CFF00BFFF
00CCFF00B3FF00FFE600FFB300FF9900FF9900FFA600FF9900FFA600FF5900FF4000FF3300FF26\
00FF2600FF2600FF1900FF1900FF0C00FF0C00FF0C00FF0C00FF0C00FF0C00FF19
00FF3300FF3300FF4C00FF5900FF1900FF0019FF0019FF0026FF0019FF0000FF1926FF003FFF00\
3FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00
4CFF003FFF003FFF0033FF0000FF0000FF0C0CFF0000FF2600FFFF00FF0C00FF8C00FF400CFF00\
00FF3326FF003FFF0026FF0033FF0000FF0059FF0073FF0073FF0080FF0080FF00
73FF0073FF0073FF0073FF0066FF0066FF0059FF004CFF004CFF003FFF003FFF0033FF0019FF00\
00FF730CFF0019FF0019FF0000FF0C0CFF000CFF0000FF1900FF6600FF0026FF00
33FF003FFF003FFF003FFF003FFF0033FF0033FF003FFF003FFF003FFF003FFF003FFF003FFF00\
33FF0033FF0033FF0026FF0026FF0019FF0000FF0000FF4000FFB300FF8000FF19
0CFF0019FF0019FF000CFF0000FF260CFF000CFF0000FF3300FF3300FF4000FF0C0CFF0019FF00\
19FF0019FF0019FF0019FF0019FF000CFF0000FF4C00FF0000FF0000FF0000FF0C
00FF2600FF2600FF1900FF1900FF1900FF1900FF2600FF3300FF3300FF4000FF4C00FF5900FF66\
00FF8000FFCC00FF7300FF6600FF5900FF6600FF5900FF6600FF8000FFE600FFA6
00FF9900A6FF00FF9900FF8C00FF8C00FF9900FFA600FFA600FFE600FFCC00FFD900FFE600FFFF\
00B3FF0099FF3300FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000007300FF0C00FF0040FF008CFF00CCFF
00F3FF00FFFF0080FF00FFBF00FF9900FF8000FF8000FF6600FF5900FF4C00FF4000FF3300FF26\
00FF2600FF1900FF1900FF0C00FF0C00FF0000FF0000FF0000FF0000FF0000FF0C
00FF0C00FF1900FF3300FF8000FF5900FF000CFF000CFF000CFF0000FF0000FF4026FF0033FF00\
3FFF003FFF003FFF004CFF004CFF004CFF004CFF003FFF003FFF0019FF0033FF00
3FFF003FFF0033FF000CFF0000FF800CFF0000FF0C19FF003FFF003FFF003FFF0000FF0C4CFF00\
3FFF003FFF0059FF0066FF0066FF0019FF0059FF0080FF0080FF008CFF008CFF00
66FF0066FF0066FF0066FF0066FF0059FF0059FF0019FF0033FF0026FF0000FF1900FF0000FF0C\
19FF0033FF0033FF0033FF0026FF0026FF0019FF0000FF0C00FF990CFF0026FF00
26FF0033FF0033FF0033FF0026FF000CFF0019FF0033FF0033FF0033FF0033FF0033FF0033FF00\
26FF0000FF0019FF0000FF0000FF0000FF1900FFF300FF1900FF0000FF0000FF26
19FF0026FF0026FF0026FF0026FF0026FF0019FF000CFF0000FF0C00FFCC00FF0019FF0019FF00\
26FF0026FF0026FF0026FF0019FF0019FF000CFF000CFF000CFF000CFF0000FF00
00FF0000FF0C00FF0C00FF0C00FF1900FF1900FF2600FF3300FF4000FF4C00FF5900FF6600FF73\
00FF9900FF8C00FF6600FF5900FF4C00FF4C00FF4C00FF5900FF7300FF8C00FF73
00FF73000CFF00FF8C00FF8000FF8000FF8C00FF9900FFA600FFB300FFBF00FFCC00FFE600FFFF\
00D9FF00A6FF0000005900FFF300FF5900FFA600FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000CC00FF4C00FF1900FF1900FF0040FF
00F3FF00FFD900FFBF00FFA600FF8C00FF8000FF7300FF5900FF4C00FF4000FF3300FF3300FF26\
00FF1900FF1900FF0C00FF0C00FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0C00FF4000FF7300FF2600FF0C00FF0C00FF4000FF0C00FF2600FF0C19FF0026FF00\
33FF003FFF003FFF003FFF003FFF003FFF003FFF003FFF0033FF0019FF0000FF00
26FF0026FF0026FF0000FF1900FF8026FF0033FF0026FF004CFF0059FF0059FF0066FF0066FF00\
66FF0026FF0073FF0073FF0073FF0066FF004CFF0080FF008CFF0099FF0099FF00
59FF0059FF0066FF0066FF0059FF0059FF004CFF0033FF0000FF4C00FF0000FF2600FF0C00FF0C\
33FF003FFF003FFF003FFF003FFF0033FF0026FF0000FF0000FFA600FF0C0CFF00
19FF0026FF0026FF0019FF0000FF5900FFE600FF0019FF0026FF0033FF0033FF0033FF0026FF00\
19FF0000FF0000FF2600FF4000FF190CFF0019FF0000FF0026FF0019FF0000FF33
19FF0033FF0033FF0033FF0033FF0033FF0026FF0019FF0000FF0000FF0C0CFF0019FF0026FF00\
26FF0026FF0026FF0026FF0026FF0026FF0019FF0019FF0019FF000CFF000CFF00
00FF0000FF0000FF0000FF0C00FF0C00FF1900FF2600FF3300FF4C00FFFF00FF7300FF8000FFF3\
00FFB300FF9900FF6600FF4C00FF4000FF4000FF4000FF4C00FF9900FF5900FF59
00FF6600FF8C00FF7300FF7300FF8000FF8000FF8C00FF9900FFA600FFBF00FFF300E6FF00D9FF\
00B3FF00B3FF00B3FF004CFF004CFF0026FF3300FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000000000000000000000003F00FF00A6FF
00F3FF00FFE600FFCC00FFA600FF9900FF8C00FF8000FF6600FF4C00FF4000FF3300FF3300FF26\
00FF1900FF1900FF0C00FF0000FF0000FF000CFF000CFF000CFF000CFF000CFF00
00FF0000FF0C00FF3300FF4C00FFD900FF3300FF4000FFBF00FF5900FF3300FF4C00FF000CFF00\
26FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0026FF0019FF0000FF33
0CFF000CFF000CFF0000FF3319FF0033FF004CFF0059FF0059FF0066FF0066FF0073FF0073FF00\
73FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF0099FF0099FF0099FF00
4CFF004CFF0059FF0059FF0059FF004CFF003FFF000CFF0000FF2600FF73000CFF00FF0026FF00\
3FFF003FFF004CFF004CFF003FFF003FFF0026FF0000FF0000FF0C00FFBF00FF33
0CFF000CFF000CFF0000FF0000FF1900FF7300FF2600FF190CFF0019FF0026FF0026FF0019FF00\
0CFF0000FF3300FF2600FF0019FF0026FF0033FF0033FF0033FF0033FF0026FF00
33FF003FFF003FFF003FFF003FFF0033FF0033FF0019FF0000FF1900FF0C19FF0026FF0026FF00\
33FF0033FF0033FF0026FF0026FF0026FF0026FF0019FF0019FF0019FF000CFF00
0CFF0000FF0000FF0000FF0000FF0C00FF1900FF6600FFB300FF8000FFF300CCFF00B3FF00FF80\
00FF7300FFA600FF6600FF4C00FF4000FF3300FF3300FF4000FF4000FF4C00FF4C
00FF4C00FF5900FF6600FF6600FF7300FF8000FF9900FFA600FFB300FFBF00F3FF00FFFF00FFF3\
00FFFF00FFF30073FF00A6FF008CFF000CFF0019FFA600FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
000000000000000000000000000000000000000000000000000000000CFF0099FF
00A6FF00A6FF00FFD900FFB300FFA600FFA600FFD900FF6600FF4C00FF4C00FF4000FF3300FF33\
00FF2600FF1900FF0C00FF0000FF000CFF000CFF000CFF000CFF000CFF000CFF00
0CFF0000FF0000FF2600FF1900FF3300FF4C00FF1900FF2600FF0C00FF0C00FF8C00FF3300FF66\
0CFF0026FF0026FF0026FF0026FF0000FF4C26FF0026FF0019FF000CFF0000FF40
00FF7300FF3300FFA600FF660CFF003FFF004CFF0059FF0066FF0066FF0073FF0073FF0073FF00\
80FF0080FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00
33FF0033FF003FFF004CFF004CFF003FFF003FFF0026FF0000FF1900FF4C00FF2600FF400CFF00\
3FFF004CFF004CFF004CFF004CFF004CFF0026FF0019FF0026FF0000FF0000FF19
00FF5900FF6600FF5900FF9900FF6600FFE600FFCC00FF4C00FF2600FF0C0CFF000CFF0000FF19\
00FF2600FF3300FF0C19FF0026FF0033FF003FFF003FFF003FFF003FFF003FFF00
3FFF003FFF003FFF003FFF003FFF003FFF0033FF0026FF0000FF1900FF0C26FF0026FF0033FF00\
33FF0033FF0033FF0033FF0033FF0026FF0026FF0026FF0019FF0019FF0019FF00
0CFF000CFF0000FF0000FF0000FF0C00FF1900FF2600FF4000FF5900FF8000FF5900FF7300FF4C\
00FF4C00FF6600FF6600FF4000FF3300FF3300FF3300FF3300FF3300FF4000FF40
00FF4C00FF4C00FF5900FF6600FF7300FFA600FFB300FFBF0099FF00FFF300FFD900FFBF00FFCC\
00FFD900FFD900FFFF00E6FF00B3FF0080FF0033FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000000000\
0000000000000000000000000000000000008000FF6600FF0026FF0C00FF00CCFF
00F3FF00D9FF00FFFF00FFD900FFE600FFFF00FF8000FF6600FF5900FF4C00FF4C00FF4C00FF40\
00FF4C00FFE600FF1900FF000CFF000CFF000CFF0019FF0019FF0019FF0019FF00
19FF000CFF000CFF0000FF0000FF4C00FF3300FF000CFF000CFF000CFF0000FF0C00FF0C00FF0C\
00FF2600FF000CFF000CFF000CFF0000FF190CFF000CFF0000FF0000FF8000FF19
00FF0000FF0C00FF0019FF000CFF0000FF0C4CFF0066FF0066FF0073FF0073FF0080FF0080FF00\
80FF0080FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00
00FF2600FFA633FF003FFF003FFF0033FF0026FF0000FF0C00FF730CFF0019FF0000FF0C3FFF00\
4CFF0059FF0059FF0059FF0059FF004CFF003FFF003FFF0033FF0019FF0000FF19
00FF1919FF0019FF0000FF0000FF0C00FF3300FF3300FF0C00FF2600FF1900FF8C00FF4000E6FF\
00FF2600FF1900FF6619FF0033FF003FFF003FFF003FFF004CFF004CFF004CFF00
4CFF004CFF004CFF004CFF004CFF003FFF003FFF000CFF0000FF8C0CFF0026FF0033FF0033FF00\
33FF0033FF0033FF0033FF0033FF0033FF0026FF0026FF0019FF0019FF0019FF00
0CFF000CFF0000FF0000FF0000FF0C00FF1900FF2600FF3300FF5900FF8C00FF4000FF3300FF33\
00FF3300FF4C00FF5900FF3300FF2600FF2600FF2600FF2600FF3300FF3300FF40
00FF4000FF4C00FF5900FF6600FF7300FF9900FFF300D9FF00FFCC00FFE600FFBF00FFA600FFA6\
00FFB300FFE600F3FF00D9FF0066FF0080FF0059FF2600FFE600FF000000000000
000000E600FF9900FFF300FFF300FF000000000000000000C000FF000000000000000000000000\
0000000000000000000000000000000000003F00FF0033FF0073FF0080FF00CCFF
00FFF300FFE600FFFF00FFCC00FFD900FFF300FFA600FF8000FF6600FF6600FF6600FF9900FF80\
00FF6600FF3300FF0C00FF000CFF000CFF0019FF0019FF0019FF0019FF0019FF00
19FF0019FF0019FF000CFF0000FF0C00FF190CFF0019FF0019FF0019FF000CFF0019FF0019FF00\
19FF0000FF0000FF9900FF2600FF5900FFB300FFCC00FF0C00FF1900FF8C00FF19
19FF0026FF0000FF1933FF003FFF000CFF0033FF0066FF0073FF0073FF0080FF0080FF0080FF00\
80FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00
0CFF0000FF2619FF0019FF0019FF0026FF0000FF730CFF0026FF0019FF003FFF000CFF004CFF00\
59FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF003FFF0000FF3300FF8C
19FF0026FF0033FF0026FF0019FF0000FF5900F3FF19FF0019FF0019FF0000FF0000FF1900FF26\
00FF000CFF0019FF0026FF003FFF003FFF004CFF004CFF004CFF004CFF004CFF00
4CFF004CFF004CFF004CFF004CFF004CFF003FFF0033FF0000FF0C00FF3333FF003FFF003FFF00\
3FFF003FFF003FFF0033FF0033FF0033FF0026FF0026FF0026FF0019FF0019FF00
0CFF000CFF0000FF0000FF0000FF0C00FF1900FF2600FF7300FFB300A6FF00FF3300FF2600FF19\
00FF2600FF4000FFA600FF3300FF2600FF1900FF2600FF2600FF2600FF3300FF40
00FF4000FF4C00FF5900FF6600FF7300FFA600FFD900FF8C00FF8C00FFA600FFB300FF9900FF99\
00FFB300FFF300FFFF00E6FF00E6FF00CCFF004CFF3300FF000000000000000000
C000FF3F00FF2600FF0000FF3300FF0000005900FF2600FF6600FFB300FF000000000000000000\
000000000000000000000000000000C000FF3300FF0000FF0080FF00BFFF00D9FF
00FFF300FFD900FFBF00FFB300FFB300FFCC00FFCC00FFFF00FF9900FF9900BFFF00FF9900FF40\
00FF2600FF1900FF0000FF000CFF0019FF0019FF0019FF0019FF0026FF0026FF00
26FF0026FF0019FF0019FF0000FF0C00FF2619FF0026FF0026FF0033FF0033FF0033FF0033FF00\
26FF0026FF000CFF0000FF4C00FF0C00FF0C00FF408C00FF00FF5900FF0019FF00
26FF0033FF003FFF003FFF004CFF0059FF0059FF0066FF0073FF0073FF0080FF0080FF0080FF00\
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
33FF0000FF0000FF8000FF7300FF4000FF4000FF1933FF003FFF004CFF004CFF0059FF0059FF00\
66FF0066FF0066FF0066FF0066FF0066FF0059FF004CFF003FFF0026FF0000FF66
19FF003FFF003FFF003FFF0033FF0019FF0033FF0033FF0026FF0026FF0019FF0000FF0C00FF40\
00FF0019FF0026FF0033FF003FFF004CFF004CFF004CFF004CFF0059FF0059FF00
59FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF000CFF0033FF003FFF003FFF003FFF00\
3FFF003FFF003FFF003FFF0033FF0033FF0026FF0026FF0019FF0019FF000CFF00
0CFF0000FF0000FF0000FF0C00FF0C00FF1900FF3300FF8000FF4C00FF3300FF2600FF1900FF0C\
00FF1900FF2600FF9900FF2600FF1900FF1900FF1900FF1900FF2600FF3300FF40
00FF4C00FF5900FF6600FF7300FF8C00FFB300FF8C00FF7300FF7300FFA600FF8C00FF8000FF8C\
00FF9900FFA600FFFF00FFE600FFF32600FF0099FF0059FF2600FFE600FF000000
7300FF000CFF000CFF004CFF0040FF0033FF0040FF5900FF0C00FF4C00FFA600FF000000000000\
000000000000000000000000000000000000B300FF0000FF008CFF00BFFF00E6FF
00FFF300FFD900FFBF00FFA600FF9900FF9900FFFF00FF8C00FF8000FF9900CCFF00FF7300FF4C\
00FF2600FF0C00FF000CFF000CFF0019FF0019FF0019FF0026FF0026FF0026FF00
26FF0026FF0026FF0026FF000CFF0000FFD90CFF0026FF0033FF0033FF0033FF0033FF0033FF00\
33FF0033FF0026FF0000FF6619FF0019FF0000FF3300FF0000FF8C00FF0019FF00
26FF0033FF003FFF004CFF0059FF0059FF0066FF0073FF0073FF0080FF0080FF0080FF008CFF00\
8CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
4CFF0033FF000CFF0033FF0026FF0000FF0000FF193FFF004CFF0059FF0059FF0066FF0066FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF003FFF0000FF0C26FF00
3FFF004CFF004CFF004CFF003FFF003FFF003FFF003FFF0033FF0026FF0019FF0000FF400059FF\
00FF0026FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0059FF00
59FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF004CFF004CFF004CFF004CFF00\
4CFF003FFF003FFF003FFF0033FF0033FF0026FF0026FF0019FF0019FF000CFF00
0CFF0000FF0000FF0000FF0C00FF1900FF4C00FF6600FF4000FF2600FF1900FF0C00FF0C00FF0C\
00FF0C00FF0C00FF3300FF0C00FF0C00FF0C00FF0C00FF1900FF2600FF4000FF4C
00FF6600FF6600FF8000FF8C00D9FF00FF7300FF6600FF5900FF6600FF8000FF7300FF7300FF80\
00FF8C00FF9900FFB300FFCC00FFF30040FF0099FF0000FF4C00FF000000000000
4C00FF004CFF0019FF0080FF0C00FF0059FF004CFF5900FF004CFF7300FFB300FF000000A600FF\
8000FFA600FFC000FF000000000000000000000000000CFF3300FF0019FF00CCFF
00E6FF00FFFF00FFB300FF9900FF8C00FF8000FF8000FF7300FF6600FF6600FF8C00FFA600FF66\
00FF3300FF2600FF0C00FF000CFF0019FF0019FF0026FF0026FF0026FF0026FF00
33FF0033FF0033FF0026FF0026FF000CFF0026FF0033FF003FFF003FFF003FFF003FFF003FFF00\
3FFF003FFF0033FF0026FF0026FF0026FF0026FF0019FF0000FF0C00FF0019FF00
26FF0033FF003FFF004CFF0059FF0059FF0066FF0073FF0073FF0080FF0080FF0080FF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
59FF003FFF003FFF004CFF003FFF0000FF660CFF003FFF0059FF0066FF0066FF0066FF0073FF00\
73FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF003FFF0000FF4033FF00
4CFF004CFF0059FF0059FF004CFF004CFF004CFF003FFF003FFF0033FF0019FF000CFF0000FF33\
00FF0019FF0033FF003FFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF004CFF00\
4CFF004CFF003FFF003FFF0033FF0033FF0026FF0019FF0019FF0000FF0000FF00
00FF0000FF0C00FF1900FF1900FF2600FF4000FFA600FF3300FF1900FF0C00FF0000FF0000FF00\
00FF0000FF0000FF0000FF0000FF0000FF0C00FF0C00FF1900FF5900FFA600FF80
0080FF00FF8C0099FF00FF9900F3FF00FF6600FF5900FF4C00FF4C00FF5900FF5900FF6600FF80\
00FF9900FFA600FFBF00F3FF00F3FF00BFFF0080FF1900FF000000000000B300FF
0033FF0066FF00A6FF00B3FF0073FF00B3FF00BFFF0099FF0059FF3F00FF0000000000002600FF\
0C00FF0000FF3F00FF000000000000000000C000FF000CFF0080FF00B3FF0073FF
00E6FF008CFF00FFD900FFA600FF8C00FF8000FF7300FF6600FF5900FF5900FF5900FF8000FF80\
00FF9900FF4000FF1900FF000CFF0019FF0019FF0026FF0026FF0026FF0033FF00
33FF0033FF0033FF0033FF0033FF0033FF0033FF003FFF003FFF003FFF003FFF003FFF003FFF00\
3FFF003FFF003FFF003FFF0033FF0033FF0033FF0026FF0000FF0000FF4C00FF00
19FF0033FF003FFF004CFF0059FF0059FF0066FF0073FF0073FF0080FF0080FF0080FF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
66FF0066FF0059FF0059FF004CFF003FFF0000FF403FFF0059FF0066FF0066FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0066FF0059FF0000FF4019FF003FFF00
59FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF0026FF0019FF0000FF0C00FF8C\
00FF9900FF2600FF003FFF004CFF004CFF0059FF0059FF0059FF0059FF0066FF00
66FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00\
4CFF004CFF004CFF003FFF0033FF0026FF0019FF000CFF000CFF0000FF1900FF26
00FF1900FF1900FF5900FF6600FF4C00FF8000FF5900FF2600FF0C00FF0000FF0000FF000CFF00\
0CFF000CFF000CFF0000FF0000FF0000FF0000FF0C00FF0C00FF2600FF4000FFF3
00FF6600FF8C00FF6600FF7300FFA600FF6600FF4C00FF4C00FF4000FF4C00FF4C00FF6600FF8C\
00A6FF00FFFF00E6FF00FFE600FFFF00F3FF004CFF000000CC00FF1900FF000000
0080FF0066FF00D9FF00A6FF00B3FF2600FF00D9FF0073FF0099FF0066FF000000000CFF0059FF\
0000FF0059FF0019FF0000009900FF0000000000001900FF0026FF00B3FF00D9FF
00FFFF00FFE600FFBF00FF9900FF8C00FF8000FF6600FF5900FF4C00FF4C00FF4000FF4C00FF99\
00FF4000FF4000FF7300FFA600FF0019FF0026FF0026FF0026FF0033FF0033FF00
33FF0033FF003FFF003FFF003FFF003FFF003FFF003FFF004CFF004CFF004CFF004CFF004CFF00\
4CFF004CFF004CFF003FFF003FFF003FFF0033FF0026FF000CFF00000CFF00FF19
00FF0C00FF0000FF264CFF0059FF0059FF0066FF0066FF0073FF0073FF0080FF0080FF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
73FF0073FF0073FF0066FF0066FF004CFF0000FF194CFF0066FF0066FF0073FF0073FF0073FF00\
80FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF003FFF0000FF264CFF00
66FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF003FFF0026FF0000FF1900FF4C00FF33\
19FF0026FF0026FF003FFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF00\
59FF004CFF004CFF003FFF0033FF0000FF1900FF8C00FF2600FF4C00FF3300FF8C
00FF4000FF3300FF7300FF9900FF4000FF4C00FF7300FF2600FF0C00FF000CFF000CFF000CFF00\
0CFF000CFF000CFF000CFF000CFF0000FF0000FF0000FF0C00FF2600FF5900FF73
00FF4000FF4C00FF4000FF5900FF9900FF8000FF4000FF4000FF4000FF4000FF4C00FF6600FFA6\
00FF8C00FF9900FFCC00FFA600FFB300FFE600BFFF8000FF5900FF0080FF00A6FF
00BFFF0073FF00FFFF00E6FF00E6FF00FFF300FFFF00F3FF00D9FF00B3FF0099FF0080FF00A6FF\
00A6FF0080FF0019FF004CFF1900FF5900FF0000008C00FF004CFF008CFF00A6FF
00F3FF00FFD900FFBF00FFA600FF9900FF8C00F3FF00FF5900FF4C00FF4000FF3300FF3300FF40\
00FF2600FF1900FF0C00FF000CFF0019FF0026FF0026FF0033FF0033FF0033FF00
33FF003FFF003FFF003FFF003FFF003FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00\
4CFF004CFF004CFF004CFF004CFF003FFF003FFF0033FF0000FF0000FF2600FFF3
00FF8C00FF0C26FF003FFF004CFF0059FF0059FF0066FF0066FF0073FF0080FF0080FF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
80FF0080FF0073FF0073FF0066FF0059FF0000FF264CFF0066FF0073FF0073FF0073FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0073FF0066FF0000FF0059FF0066FF00
66FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF003FFF0026FF0000FF0C00FF8C19FF00\
26FF0033FF003FFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF00\
59FF004CFF004CFF004CFF003FFF0026FF0019FF0000FF0000FF4C00FF4000FF26
00FF59004CFF00FF2600FF3300FF1900FF3300BFFF00FF4000FF0C00FF000CFF000CFF0019FF00\
19FF0019FF0019FF000CFF000CFF000CFF0000FF0000FF0C00FF4000F3FF00FF4C
00FF2600FF2600FF2600FF4000FF8C00FF4000FF3300FF3300FF3300FF3300FF4000FF5900FF59\
00FF6600FF8C00FF8C00FF8C00FFA600FFE600B3FFA600FF00A6FF00D9FF00F3FF
00F3FF00FFD900FFE60019FF00E6FF00FFE600FFD900FFF300F3FF00B3FF00F3FF00A6FF00D9FF\
00BFFF004CFF00A6FF004CFF0066FF000CFF9900FF0000000000FF0066FF00B3FF
00F3FF00FFF300FFF300FFBF00FFBF00FFCC00FF7300FF5900FF4000FF3300FF3300FF2600FF19\
00FF0C00FF0000FF000CFF0019FF0019FF0026FF0026FF0033FF0033FF0033FF00
3FFF003FFF003FFF003FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00\
4CFF004CFF004CFF004CFF004CFF004CFF003FFF0033FF0019FF0000FF1900FF59
00FF8000FF8026FF003FFF003FFF004CFF004CFF004CFF004CFF0066FF0073FF0080FF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
80FF0080FF0080FF0073FF0073FF0059FF000CFF0000FF0C66FF0073FF0073FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0066FF0066FF0059FF003FFF000CFF0000FF7300FF7300FF1919FF00\
33FF003FFF004CFF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF00\
59FF0059FF004CFF004CFF003FFF0033FF0026FF000CFF0000FF4000FF1900FF00
00FF0C00FF4C00FF0C00FF0000FF0C00FF3300FF5900FF2600FF0C0CFF000CFF0019FF0019FF00\
19FF0019FF0019FF0019FF0019FF000CFF0000FF0000FF8C00FF9900FF1900FF0C
00FF0C00FF0C00FF1900FF4000FF6600FF3300FF2600FF2600FF2600FF3300FF3300FF4000FF4C\
00FF4C00FF6600FF7300FF8000FF8C00FFA600FFF300FFF300B3FF00FFD900E6FF
00FFD900FFBF00FFBF00FFD900FFBF00FFBF00FFCC00FFF300BFFF00CCFF00FFE600FFE600FFFF\
00BFFF00D9FF00D9FF00BFFF0080FF5900FF0000FF000000F300FF6600FF004CFF
0073FF0099FF00B3FF00D9FF00BFFF0073FF00FF9900FF7300FF4C00FF3300FF2600FF2600FF19\
00FF0C00FF000CFF000CFF0019FF0019FF0026FF0026FF0033FF0033FF0033FF00
3FFF003FFF003FFF004CFF004CFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF00\
59FF0059FF0059FF004CFF004CFF004CFF003FFF0033FF0000FFCC00FF0000FF0C
00FF0000FF9919FF0026FF0026FF0033FF0026FF0000FF4033FF0059FF0073FF0080FF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
8CFF0080FF0080FF0080FF0073FF0059FF0000FF263FFF0066FF0073FF0080FF0080FF0080FF00\
80FF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
73FF0073FF0073FF0073FF0073FF0066FF0059FF0000FF0C19FF0033FF0026FF0000FF4000FF4C\
26FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF00
73FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF00\
59FF0059FF004CFF004CFF003FFF0033FF0019FF0000FF0000FF7300FF260CFF00
0CFF0000FF330CFF000CFF0000FF0000FF3300FF4000FF4000FF190CFF0019FF0019FF0019FF00\
19FF0019FF0019FF0019FF0019FF0019FF000CFF0000FF6600FF1900FF0000FF00
00FF0000FF0C00FF0C00FF3300FF4C00FF2600FF2600FF2600FF2600FF2600FF3300FF3300FF40\
00FF4C00FF5900FF6600FF7300FF9900FFBF00FFCC00FFA600FFA600FFA600FFD9
00FFB300FF9900FF9900FFA600FFA600FFB300FFBF00FFF300FFE600FFD900FFCC00FFD90066FF\
008CFF00FFF300FFFF0066FF0080FF0099FF0040FF8000FF000000000000004CFF
00B3FF00E6FF00FFF300FFD900FFB300FFA600FFD900FF6600FF4C00FF3300FF2600FF2600FF19\
00FF0C00FF000CFF000CFF0019FF0019FF0026FF0026FF0033FF0033FF0033FF00
3FFF003FFF003FFF004CFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF00\
59FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF0033FF0026FF00
19FF000CFF0000FF3300FF0C00FF1900FF2626FF003FFF004CFF0066FF0073FF0080FF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
8CFF008CFF008CFF0080FF0080FF0066FF004CFF0000FF0000FF4080FF0080FF0080FF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF00
80FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF004CFF003FFF0033FF0000FF1900FF73\
26FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF00\
59FF0059FF004CFF004CFF003FFF0026FF0000FF1900FF3300FF4C0CFF0026FF00
26FF0026FF0026FF0026FF0019FF000CFF0000FF4000FF3300FF000CFF0019FF0019FF0026FF00\
26FF0026FF0026FF0026FF0019FF0019FF000CFF000CFF000CFF000CFF000CFF00
00FF0000FF0000FF0C00FFB300FF1900FF1900FF1900FF1900FF1900FF2600FF2600FF3300FF40\
00FF4C00FF4C00FF5900FF7300FFBF00FFBF00FFB300FF8000FF8000FFA600CCFF
00FFCC00FF8C00FF8C00FF8C00FF9900FFA600FFBF00A6FF00FFBF00FFA600FFA600FFBF00FFD9\
00FFFF00FFD900FFE600FFFF00E6FF00BFFF0073FF000000C000FF0000005900FF
0099FF00BFFF00FFF300FFD900FFA600FF8C00FF7300FF5900FF4C00FF4000FF3300FF2600FF26\
00FF1900FF000CFF000CFF0019FF0019FF0026FF0026FF0033FF0033FF0033FF00
3FFF003FFF004CFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00\
59FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF00
26FF0019FF0000FF0000FF190CFF0033FF004CFF0059FF0066FF0073FF0073FF0080FF0080FF00\
8CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
8CFF008CFF008CFF008CFF0080FF0080FF0066FF004CFF0073FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00
80FF0080FF0080FF0073FF0073FF0073FF0066FF0066FF0059FF004CFF003FFF0026FF0000FF26\
00FF0026FF003FFF0059FF0059FF0066FF0066FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF00\
59FF0059FF004CFF003FFF0033FF0019FF0000FF800CFF000CFF000CFF0033FF00
33FF0033FF0033FF0026FF0026FF0019FF0000FF0C00FF0C0CFF0019FF0026FF0026FF0026FF00\
26FF0026FF0026FF0026FF0026FF0019FF0019FF0019FF0019FF000CFF000CFF00
0CFF000CFF0000FF0000FF0000FF0C00FF0C00FF0C00FF1900FF1900FF2600FF2600FF3300FF40\
00FF4C00FF5900FF6600FF8000FFA600FF7300FF7300FF6600FF6600FFA600FF80
00FFCC00FF8000FF7300FF8000FF8C00FFB3004CFF00F3FF00FFB300FF9900FF9900FF9900FFA6\
00FFB300FFBF00FFD900FFFF00E6FF00B3FF00B3FF0026FF0000FF0000006600FF
0066FF00B3FF00B3FF00B3FF00FFF300FF9900FF8000FF7300FF4C00FF4000FF4000FF4000FF59\
00FF4000FF0C00FF000CFF0019FF0019FF0026FF0026FF0026FF0033FF0033FF00
3FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00\
59FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF00
33FF0026FF0000FF4C00FF7326FF003FFF004CFF0059FF0066FF0073FF0073FF0080FF0080FF00\
8CFF008CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF008CFF008CFF008CFF0080FF0073FF0066FF0080FF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
80FF0080FF0080FF0080FF0073FF0073FF0073FF0066FF0059FF004CFF0033FF0000FF1900FF33\
26FF0000FF0000FF0C4CFF0066FF0066FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF00\
66FF0059FF004CFF0033FF0000FFBF0CFF0026FF0033FF0033FF0026FF003FFF00
3FFF003FFF0033FF0033FF0026FF0019FF0000FF4C00FF0019FF0026FF0026FF0026FF0026FF00\
26FF0026FF0026FF0026FF0026FF0026FF0026FF0019FF0019FF0019FF0019FF00
0CFF000CFF000CFF0000FF0000FF0000FF0C00FF0C00FF0C00FF1900FF2600FF3300FF3300FF4C\
00FF5900FF5900FF7300FFB300FF7300FF5900FF4C00FF4C00FF5900FFA600FF59
00FF6600FF6600FF6600FF7300FFCC008CFFA600FF00FFA600FFE600FF8C00FF8000FF8C00FF99\
00FFA600FFBF00FFE600CCFF00B3FF00FFFF00E6FF0080FF0026FF6600FF000000
3300FF0073FF0080FF00E6FF00FFD900FFA600FFB300FF8C00FF6600FF5900FF5900FFBF00FF40\
00FF1900FF0C00FF000CFF000CFF0019FF0019FF0026FF0026FF0026FF0033FF00
33FF003FFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF00
33FF0019FF0000FF0000FF330CFF0033FF004CFF0059FF0066FF0073FF0073FF0080FF0080FF00\
80FF008CFF008CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF0080FF0080FF0080FF0080FF0073FF0073FF0066FF0066FF004CFF0033FF0000FF4026FF00\
3FFF004CFF0059FF0059FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF00\
66FF0059FF003FFF0000FF1900FF2633FF003FFF003FFF003FFF003FFF004CFF00
3FFF003FFF003FFF0033FF0033FF000CFF0000FF730CFF0019FF0026FF0026FF0033FF0033FF00\
33FF0033FF0033FF0026FF0026FF0026FF0026FF0026FF0019FF0019FF0019FF00
19FF000CFF000CFF000CFF0000FF0000FF0000FF0C00FF0C00FF1900FF2600FF4000FF4C00FF66\
00FF7300FF8000FFE600FFBF00FFA600FF4C00FF4000FF4000FF4000FF4C00FF40
00FF4C00FF5900FF5900FF7300FF8C00A6FF00FF8C00FF8000FFE600FF8000FF7300FF8000FF99\
00FFA600FFBF00FFFF00FFCC00FFFF00FFD900FFF300D9FF00B3FF004CFF8000FF
0000000000000000FF8C00FF008CFF00F3FF00D9FF00FFF300FFB300FF7300FFA600FF7300FF40\
00FF1900FF0C00FF0000FF000CFF000CFF000CFF0019FF0019FF0026FF0026FF00
26FF0033FF003FFF004CFF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF004CFF003FFF00
26FF0000FF0000FF5900FF0C26FF003FFF004CFF0059FF0066FF0066FF0073FF0073FF0080FF00\
80FF0080FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF00
8CFF008CFF0080FF0080FF0080FF0073FF0073FF0066FF0066FF004CFF0033FF0000FF4C0CFF00\
4CFF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF00\
66FF0059FF003FFF000CFF0026FF003FFF004CFF004CFF004CFF004CFF004CFF00
4CFF004CFF003FFF003FFF0033FF0000FF0000FF4000FF0026FF0033FF0033FF0033FF0033FF00\
33FF0033FF0033FF0033FF0033FF0026FF0026FF0026FF0026FF0019FF0019FF00
19FF000CFF000CFF000CFF0000FF0000FF0000FF0000FF0C00FF1900FF3300FF6600FF9900FFA6\
00FF9900FFD900FF6600FF7300FFB300FF4C00FF3300FF3300FF3300FF3300FF33
00FF4000FF4C00FF5900FF6600FF8C00FF8C00FF7300FF6600FF6600FF6600FF6600FF8000FFE6\
00F3FF00FFE600FFCC00FFA600FFA600FFBF00FFFF00E6FF0073FF0019FF8000FF
0000000000006600FF0080FF00FFFF00FFCC00FFA600FFBF00FF8C00FF8000FF8000FFCC00FFF3\
00FF3300FF2600FF0C00FF0C00FF0000FF0000FF0C00FF0C00FF0000FF0000FF73
0CFF0026FF003FFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF004CFF003FFF00
26FF0000FF0000FF2619FF0033FF003FFF004CFF0059FF0059FF0066FF0066FF0073FF0073FF00\
73FF0073FF0073FF0080FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF00
8CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF0059FF004CFF0019FF0033FF004CFF00\
59FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF00\
66FF0059FF0026FF0033FF0019FF004CFF0059FF0059FF0059FF0059FF0059FF00
4CFF004CFF004CFF003FFF0033FF000CFF0000FF3319FF0033FF0033FF0033FF0033FF0033FF00\
33FF0033FF0033FF0033FF0033FF0033FF0026FF0026FF0026FF0026FF0019FF00
19FF0019FF000CFF000CFF000CFF0000FF0000FF0000FF0C00FF1900FF2600FF3300FF4C00FFCC\
00FF5900FF5900FF4000FF4000FF6600FF4000FF3300FF2600FF2600FF2600FF33
00FF4000FF4C00FF5900FF7300B3FF00FF7300FF5900FF4C00FF4C00FF4C00FF5900FF6600FFD9\
00FF8C00FF9900FFB300FF8C00FF9900E6FF00FFD900F3FF00E6FF0066FF5900FF
000000000000B300FF0080FF00F3FF00FFD900FF9900FF8000FF7300FF5900FF5900FF7300FF80\
00FF9900FF5900FF2600FF1900FF1900FF4000FF3300FF4000FF1900FF2600FF0C
00FF0019FF0019FF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF003FFF00
19FF0000FF6600FF260CFF0026FF003FFF004CFF004CFF0059FF0059FF0059FF0066FF0066FF00\
73FF0066FF0059FF0000FF2666FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF00
8CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF004CFF0033FF000CFF004CFF0059FF00\
66FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00\
66FF0066FF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF004CFF004CFF003FFF000CFF000CFF0019FF0033FF003FFF003FFF003FFF003FFF00\
3FFF003FFF0033FF0033FF0033FF0033FF0026FF0026FF0026FF0026FF0019FF00
19FF0019FF000CFF000CFF000CFF0000FF0000FF0000FF0C00FF0C00FF1900FF3300FF4C00FFCC\
00FF4000FF3300FF2600FF2600FF7300FF7300FF2600FF1900FF1900FF2600FF33
00FF4000FF5900FF7300FFCC00FFFF00FF8000FF5900FF4C00FF4000FF4000FF4C00FF9900FF66\
00FF6600FF8000FF8C00FF8000FF8C00FF9900FFB300FFCC00FFF3008CFF2600FF
000CFF3F00FF5900FF0080FF00F3FF00D9FF00FF9900FF8000FF6600FF4C00FF4C00FF4C00CCFF\
00FF4C00FFD900FF8000FF4C00FF4C00FF6600FF4C00FF0C19FF0026FF0026FF00
33FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0073FF00\
73FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF0059FF003FFF000CFF00
0CFF0019FF0000FF0000FF3300FF0033FF003FFF003FFF003FFF003FFF003FFF0059FF0059FF00\
59FF004CFF0000FF1900FF3380FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00
8CFF008CFF008CFF0080FF0080FF0073FF0073FF0066FF004CFF0000FF0033FF004CFF0059FF00\
66FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00\
73FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF00
59FF0059FF0059FF004CFF003FFF000CFF0033FF003FFF003FFF003FFF003FFF003FFF003FFF00\
3FFF003FFF003FFF0033FF0033FF0033FF0033FF0026FF0026FF0026FF0019FF00
19FF0019FF000CFF000CFF000CFF0000FF0000FF0000FF0C00FF1900FF2600FF4000FFBF00FF59\
00FF5900FF1900FF1900FF1900FF2600FF5900FF1900FF0C00FF0C00FF1900FF33
00FF5900FFB300FFFF00FF7300FF8000FF8000FF4C00FF4000FF3300FF3300FF4000FF4C00FF4C\
00FF4C00FF5900FF6600FF7300FF8000FF8C00FFA600FFCC0059FF00FFFF00CCFF
0099FF0059FF8C00FF0040FF00CCFF00FFE600FFB300FFBF00FF6600FF4000FF3300FF3300FF40\
00FF2600FF1900FF2600FF3300FF4C00FF3300FF0C0CFF0026FF0033FF003FFF00
3FFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0033FF0019FF00
3FFF0033FF0019FF0000FF2600FF1919FF0026FF0026FF0026FF0000FF6626FF003FFF004CFF00\
26FF0026FF0059FF0073FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
8CFF008CFF008CFF0080FF0080FF0073FF0066FF0059FF0026FF0000FF0019FF004CFF0066FF00\
66FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF00\
73FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
59FF0059FF0059FF0059FF004CFF004CFF004CFF004CFF004CFF004CFF003FFF003FFF003FFF00\
3FFF003FFF003FFF0033FF0033FF0033FF0033FF0026FF0026FF0026FF0019FF00
19FF0019FF000CFF000CFF0000FF0000FF0000FF0C00FF0C00FF1900FF2600FF4C00FF4C00FF26\
00FF1900FF0C00FF0C00FF0C00FF0C00FF1900FF0C00FF0C00FF0C00FF0C00FF33
00FF4C00FF7300FF4C00FF4000FF4C00FF9900FF4000FF3300FF3300FF3300FF3300FF3300FF40\
00FF4000FF4C00FF5900FF6600FF8C00FFA600FFCC008CFF00FFB300FFBF00CCFF
00FFF300BFFF0000FF000000008CFF00F3FF00FFD900FFF300FF8C00FF4C00FF3300FF2600FF19\
00FF0C00FF0C00FF0C00FF1900FF3300FFA600FF190CFF0026FF0033FF003FFF00
4CFF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF004CFF00
4CFF004CFF0033FF0019FF0000FF1900A6FF00FF9900FF6600FF0C00FFFF00FF1900FF4019FF00\
00FF4C33FF0066FF0073FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF008CFF008CFF008CFF0080FF0073FF003FFF0000FF1900FF1919FF003FFF0059FF0066FF00\
73FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
73FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF00
66FF0066FF0059FF0059FF0059FF004CFF004CFF004CFF004CFF004CFF004CFF004CFF003FFF00\
3FFF003FFF003FFF003FFF0033FF0033FF0033FF0026FF0026FF0026FF0019FF00
19FF000CFF000CFF000CFF0000FF0000FF0000FF0C00FF1900FF2600FF4C00FF7300FF2600FF19\
00FF0C00FF0C00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0C00FF19
00FF5900FF8000FF2600FF2600FF3300B3FF00FF4000FF2600FF2600FF2600FF2600FF3300FF33\
00FF4000FF4C00FF5900FF6600FF8000D9FF00FFCC00FFB300FF8C00FF8C00FFA6
00FFCC00F3FF00B3FF0066FF0000FF00E6FF00FFE600FF8C00FF6600FF4000FF2600FF1900FF0C\
00FF0000FF0000FF0000FF0000FF1900FF3300FF6600FFB319FF0033FF003FFF00
4CFF0059FF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF00
59FF004CFF003FFF0000FF0000FF8026FF0033FF0033FF0019FF0000FF8C26FF0033FF0019FF00\
00FF0C3FFF0066FF0073FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF00
99FF008CFF008CFF008CFF0080FF0073FF0066FF004CFF0019FF000CFF004CFF0059FF0066FF00\
73FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00
8CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00
66FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF004CFF004CFF00\
3FFF003FFF003FFF003FFF0033FF0033FF0033FF0026FF0026FF0019FF0019FF00
0CFF000CFF000CFF0000FF0000FF0000FF0C00FF0C00FF1900FF2600FF5900FF4C00FF2600FF0C\
00FF0C00FF0000FF000CFF000CFF000CFF000CFF000CFF000CFF0000FF0000FF19
00FF4000FF1900FF0C00FF0C00FF1900FF7300FF3300FF1900FF1900FF1900FF2600FF2600FF33\
00FF4000FF4C00FF5900FF6600FF8C00FF8C00FF7300FF8000FF7300FF8000FFA6
00FFE600FFCC00FFD900D9FF0C00FF0099FF00FFE600FF9900FFCC00FF4C00FF3300FF2600FF0C\
00FF000CFF000CFF000CFF0000FF0000FF2600E6FF00FF0019FF0033FF003FFF00
4CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF00
66FF0059FF0026FF000CFF0019FF003FFF004CFF004CFF003FFF0033FF004CFF004CFF003FFF00\
0CFF000CFF0059FF0073FF0080FF008CFF008CFF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF00
99FF008CFF008CFF008CFF0080FF0073FF0066FF004CFF0026FF0019FF003FFF0059FF0066FF00\
73FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF00
66FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF004CFF00\
4CFF003FFF003FFF003FFF0033FF0033FF0026FF0026FF0026FF0019FF0019FF00
0CFF0000FF0000FF0000FF0000FF0C00FF1900FF2600FF3300FF4000FFCC00FF4C00FF2600FF0C\
00FF0000FF000CFF000CFF000CFF000CFF0019FF000CFF000CFF0000FF0000FF4C
00FF1900FF0000FF0000FF0000FF0C00FF8000FF1900FF0C00FF1900FF1900FF1900FF2600FF33\
00FF4000FF5900FF6600FF8000E6FF00FF6600FF5900FF4C00FF5900FF7300FF99
00FFD900FF9900FFFF00FFF30099FF00000000A6FF00FFD900FFA600FF7300FF9900FF4000FF0C\
0CFF000CFF0019FF000CFF0000FF0000FF6600FFBF00FF0C00FF000CFF0026FF00
4CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
80FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF00
66FF0059FF004CFF0000FF0019FF004CFF0059FF0059FF0059FF0059FF0059FF0059FF004CFF00\
00FF3326FF004CFF0059FF0059FF0080FF008CFF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
99FF0099FF008CFF0080FF0080FF0073FF0059FF0000FF3300FF2619FF0000FF5933FF0073FF00\
73FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF00
66FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF00\
4CFF003FFF003FFF003FFF0033FF0033FF0026FF0026FF0019FF0019FF000CFF00
00FF1900FF2600FF0C00FF0C00FF1900FF3300FF6600FFD900FF7300FF7300FF8000FF3300FF0C\
00FF000CFF000CFF0019FF0019FF0019FF0019FF0019FF0019FF000CFF0000FF59
00FF000CFF000CFF000CFF0000FF0000FF0000FF0000FF0C00FF0C00FF0C00FF1900FF3300FF40\
00FF5900FF8000FF8C00FFB300FFBF00FF6600FF4C00FF4000FF4000FF9900FF59
00FF8C00FF7300FF8C00FFBF00E6FF000CFF0073FF00FFBF00FF7300FF6600FFB300FF1900FF00\
0CFF0019FF0019FF0019FF0019FF0000FF0000FF9900FF2600FF2600FF0C33FF00
4CFF0059FF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00
66FF0066FF004CFF0000FF734CFF0059FF0066FF0066FF0066FF0073FF0066FF0066FF0059FF00\
26FF0000FF0000FFFF00FF0059FF0080FF008CFF008CFF0099FF0099FF0099FF00
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF0099FF008CFF0080FF0066FF004CFF003FFF0000FF0026FF004CFF0059FF0066FF0073FF00\
80FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
66FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF00\
4CFF004CFF003FFF003FFF0033FF0026FF0019FF0019FF000CFF000CFF0000FF00
00FF1900FF9900FF3300FF2600FF2600FF4C1900FF00FF5900FF3300FF4000FF7300FF4000FF19\
00FF000CFF0019FF0019FF0019FF0019FF0019FF0019FF0019FF0019FF0019FF00
19FF000CFF000CFF000CFF000CFF000CFF0000FF0000FF0000FF0C00FF0C00FF1900FF7300FF99\
00FFBF00FF8000FFD900FF5900A6FF00FF8C00FF4000FF3300FF3300FF3300FF40
00FF4C00FF6600B3FF00FFBF00FF9900FFD90099FF00FFD900FF5900FF3300FF8C00FF4000FF00\
19FF0026FF0026FF0026FF0026FF0019FF0000FF1919FF0019FF0000FF3326FF00
3FFF004CFF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF00
73FF0066FF003FFF0000FF404CFF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0059FF00\
00FF264CFF004CFF0000FF994CFF0073FF0080FF008CFF008CFF0099FF0099FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF008CFF0080FF0059FF004CFF003FFF0019FF0033FF0059FF0066FF0073FF0080FF00\
80FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF00\
4CFF004CFF003FFF003FFF0026FF0019FF0000FF1900FF1900FF1900FF0C00FF19
00FF2600FF5900FF8C00FF5900FF5900FF5900FF3300FF2600FF1900FF2600FFA600FF3300FF19\
00FF000CFF0019FF0019FF0026FF0026FF0026FF0026FF0026FF0026FF0019FF00
19FF0019FF0019FF0019FF000CFF000CFF000CFF0000FF0000FF0000FF0C00FF1900FF2600FF40\
00FF8C00FF5900FF4000FF3300FF3300FF8C00FF3300FF2600FF2600FF2600FF40
00FF4C00FF6600FF8C00FF6600FF6600FFCC00FF8C00FFA600FF4000FF1900FF0C00FF0000FF00\
19FF0026FF0033FF0033FF0033FF0026FF0000FF0C33FF0033FF0026FF0000FF66
0CFF003FFF0059FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF00
73FF0066FF003FFF0000FF0C4CFF0066FF0073FF0080FF0080FF0080FF0080FF0073FF0066FF00\
3FFF0066FF0066FF003FFF0000FF1966FF0073FF0080FF008CFF008CFF008CFF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF00
99FF0099FF008CFF008CFF0080FF0073FF0059FF0019FF0000FF0C59FF0066FF0073FF0080FF00\
80FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF00
73FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF004CFF00\
4CFF004CFF003FFF003FFF0033FF000CFF0000FF0C00FF1900FF0C00FFB30073FF
00FF6600FF5900FF3300FF7300FF4000FF4000FF0C00FF0000FF0000FF1900FFFF00F3FF00FF40\
00FF730CFF0019FF0026FF0026FF0026FF0026FF0026FF0026FF0026FF0026FF00
26FF0026FF0019FF0019FF0019FF000CFF000CFF0000FF0000FF0000FF0C00FF0C00FF2600FF40\
00FF7300FF4C00FF2600FF1900FF1900FFBF00FF2600FF1900FF1900FF2600FF40
00FF6600FFD900FFB300FF4000FF4000FF4000FF4C00FFA600FF8C00FF2600FF000CFF0019FF00\
26FF0033FF0033FF0033FF003FFF003FFF003FFF003FFF003FFF003FFF0033FF00
00FF0C00FF264CFF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
73FF0066FF003FFF0019FF0059FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0073FF0073FF0059FF0033FF0066FF0066FF0080FF0080FF0080FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF008CFF0080FF0073FF0066FF003FFF0019FF0059FF0066FF0080FF0080FF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF004CFF00\
4CFF004CFF003FFF003FFF0033FF0026FF0019FF0019FF000CFF0000FF0C00FF26
00FFF300FF1900FF0C00FF1900FF0C00FF6600FF000CFF000CFF0000FF0000FF0C00FF1900FF40\
00FF0019FF0019FF0026FF0026FF0026FF0033FF0033FF0033FF0026FF0026FF00
26FF0026FF0026FF0019FF0019FF000CFF000CFF000CFF0000FF0000FF0C00FF0C00FF2600FF40\
00FF5900FF3300FF1900FF0C00FF0C00FF1900FF0C00FF0C00FF0C00FF2600FF4C
00FF5900FF4000FF7300FF3300FF2600FF2600FF4000FFA600FF3300FF0C0CFF0019FF0026FF00\
26FF0033FF0033FF003FFF003FFF003FFF004CFF004CFF004CFF004CFF004CFF00
33FF004CFF0019FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00
80FF0073FF004CFF0026FF0026FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF0080FF0080FF0080FF0073FF0000E6FF00FF264CFF0066FF0059FF004CFF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF008CFF008CFF0073FF0033FF0000FF0C33FF0000FF2659FF0080FF0080FF00\
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00
73FF0073FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF004CFF00\
4CFF004CFF003FFF003FFF003FFF0033FF0026FF0019FF0019FF0000FF0000FF26
00FF7300FF0C00FF000CFF000CFF0000FF4000FF0019FF0019FF0019FF000CFF0000FF0000FFB3\
0CFF0019FF0026FF0026FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
26FF0026FF0026FF0019FF0019FF0019FF000CFF000CFF0000FF0000FF0C00FF1900FF2600FFA6\
00FF2600FF1900FF0C00FF0000FF0000FF0000FF0000FF0000FF0000FF0C00FF4C
00FF8000FF1900FF4C00FF2600FF1900FF1900FF6600FFE600FF3300FF000CFF0019FF0026FF00\
26FF0033FF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF00
59FF0059FF0066FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0073FF004CFF0066FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF0080FF0066FF0000FF4026FF000CFF0000FF0C66FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF008CFF0073FF004CFF003FFF0066FF0066FF0059FF0080FF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00
73FF0073FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF004CFF00\
4CFF004CFF004CFF003FFF003FFF0033FF0026FF0026FF0019FF0000FF0000FF4C
00FFB300FF190CFF0019FF0019FF0019FF0019FF0026FF0026FF0026FF0019FF000CFF0000FF73\
00FF0019FF0026FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0026FF0026FF0019FF0019FF000CFF000CFF0000FF0000FF0000FF0C00FF1900FF4C00FF59\
00FF2600FF0C00FF0000FF000CFF000CFF000CFF000CFF000CFF0000FF0C00FF8C
00FF0000FF0000FF0000FF0C00FF0C00FF0C00FF1900FFBF00FF3300FF0C0CFF0019FF0019FF00\
26FF0033FF003FFF003FFF004CFF004CFF0059FF0059FF0059FF0059FF0066FF00
66FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF0080FF0080FF003FFF0073FF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF00\
99FF0099FF008CFF008CFF008CFF0080FF0059FF004CFF004CFF0019FF004CFF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF008CFF0073FF0000FF0066FF0080FF0080FF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00
73FF0073FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF004CFF00\
4CFF004CFF004CFF003FFF003FFF0033FF0026FF0026FF0019FF0000FF0000FF26
00FF8C00FF000CFF0019FF0026FF0026FF0026FF0033FF0033FF0033FF0026FF0019FF0000FF59\
00FF0C19FF0026FF0033FF0033FF0033FF003FFF003FFF003FFF0033FF0033FF00
33FF0026FF0026FF0019FF0019FF000CFF000CFF0000FF0000FF0C00FF1900FF2600FF6600FF59\
00FF2600FF0C00FF000CFF000CFF0019FF0019FF0019FF0019FF000CFF0000FF00
0CFF000CFF000CFF000CFF0000FF0000FF0000FF0C00FF2600FF5900FF1900FF0C00FF0019FF00\
26FF0033FF0033FF003FFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF00
66FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF0080FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF008CFF008CFF003FFF0073FF0073FF0019FF0000FF4C
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF0080FF000CFF0073FF0080FF008CFF008CFF008CFF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00
73FF0073FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF004CFF00\
4CFF004CFF004CFF003FFF003FFF0033FF0026FF0019FF000CFF0000FF0C00FF26
00FF2600FF0019FF0026FF0033FF0033FF0033FF0033FF0033FF0033FF0033FF0026FF0000FF00\
00FF3319FF0026FF0033FF003FFF003FFF003FFF003FFF003FFF003FFF0033FF00
33FF0033FF0026FF0019FF000CFF0000FF0000FF0000FF0C00FF1900FF6600FF9900FF5900D9FF\
00FF4000FF0C00FF000CFF0019FF0019FF0019FF0019FF0019FF0019FF0019FF00
19FF0019FF0019FF000CFF000CFF0000FF0000FF0000FF1900FF7300FFB300FF5900FF6600FF19\
0CFF0019FF0026FF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0066FF00
73FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF000CFF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF0099FF008CFF004CFF0080FF008CFF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00
73FF0073FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF004CFF00\
4CFF004CFF003FFF003FFF003FFF0033FF0026FF0000FF8000FF2600FF8000FF8C
00FF5900FF0C19FF0026FF0033FF0033FF003FFF003FFF003FFF003FFF0033FF0026FF0000FF19\
00FF590CFF0033FF003FFF003FFF003FFF003FFF003FFF003FFF003FFF003FFF00
33FF0033FF0026FF0019FF000CFF0000FF2600FF2600FF2600FF3300FFA600FF9900FF2600FF4C\
00FF4000FF0C00FF0019FF0019FF0026FF0026FF0026FF0026FF0026FF0026FF00
26FF0019FF0019FF0019FF000CFF000CFF0000FF0000FF1900FF7300FF2600FF2600FF0C00FF00\
00FF3300FF5900FF4033FF004CFF0059FF0059FF0066FF0066FF0066FF0073FF00
73FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF0080FF0000FF0C
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF0099FF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00
73FF0073FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF004CFF00\
4CFF004CFF003FFF003FFF0033FF0033FF0026FF000CFF0000FF2600FF1900FF19
0CFF0000FF0C00FF3326FF0033FF003FFF003FFF003FFF003FFF003FFF003FFF0033FF0026FF00\
00FF0C19FF0033FF003FFF003FFF004CFF004CFF004CFF003FFF003FFF003FFF00
33FF0026FF0019FF000CFF0000FF0C00FF2600FF7300FF7300FFBF00FF2600FF0C00FF0C00FF33\
00FF9900FF3300FF2619FF0026FF0026FF0026FF0026FF0026FF0026FF0026FF00
26FF0026FF0026FF0019FF0019FF000CFF0000FF0000FF2600FFF300FF2600FF0019FF0026FF00\
26FF0026FF0033FF003FFF004CFF0059FF0066FF0066FF0066FF0073FF0073FF00
73FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0000FF80
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF00
73FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF004CFF004CFF00\
4CFF004CFF003FFF003FFF0033FF0026FF0019FF0000FF1900FF4000FF0C19FF00
26FF0026FF0026FF0033FF003FFF003FFF004CFF004CFF004CFF004CFF004CFF003FFF003FFF00\
19FF0033FF003FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF003FFF00
33FF0026FF0000FF9900FF33004CFF00FFCC00FF2600FF2600FF1900FF190CFF000CFF0000FF0C\
00FF0C00FF400CFF0019FF0026FF0026FF0033FF0033FF0033FF0033FF0033FF00
33FF0026FF0026FF0019FF0019FF000CFF0000FF0C00FF2600FF9900FF190CFF0026FF0033FF00\
33FF003FFF003FFF004CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF00
73FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0080FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00\
8CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF00
73FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF00\
4CFF003FFF003FFF0033FF0033FF0026FF000CFF0000FF5900FF000CFF0026FF00
33FF0033FF003FFF003FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00\
3FFF003FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF003FFF00
3FFF0026FF0019FF0019FF0000FF0000FF7300FF0C0CFF000CFF0000FF8C19FF0019FF0019FF00\
0CFF0000FFE60CFF0019FF0026FF0033FF0033FF0033FF0033FF0033FF0033FF00
33FF0033FF0026FF0026FF0019FF0000FF2600FF4C00FFBF00FF4000FF0C00FF0C26FF0033FF00\
3FFF004CFF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0073FF0073FF00
73FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00\
8CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF00
66FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF00\
3FFF003FFF0033FF0033FF0026FF0000FF0C00FF400CFF0019FF0026FF0033FF00
3FFF003FFF003FFF004CFF004CFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF004CFF00\
4CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF00
3FFF003FFF0033FF0026FF000CFF0000FF8000FF3319FF0026FF0026FF0026FF0033FF0026FF00\
19FF0000FF4C00FF0026FF0033FF0033FF0033FF003FFF003FFF003FFF0033FF00
33FF0033FF0026FF0026FF0019FF0000FF0000FF2600FF4000FF0C0CFF0019FF0033FF003FFF00\
3FFF004CFF004CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF00
73FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00\
8CFF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF00
66FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF004CFF00\
3FFF003FFF0033FF000CFF000CFF0000FF1900FF2619FF0026FF0033FF003FFF00
3FFF003FFF004CFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00\
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF00
4CFF003FFF0033FF0026FF000CFF0000FF2600FF0C19FF0033FF0033FF0033FF0033FF0033FF00\
26FF0000FF0C00FF1926FF0033FF0033FF003FFF003FFF003FFF003FFF003FFF00
3FFF0033FF0033FF0026FF000CFF0000FF0C00FFD900FFBF00FF0C0CFF0026FF0033FF003FFF00\
3FFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF00
73FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00\
80FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF00
66FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF004CFF003FFF00\
3FFF0033FF0026FF000CFF0000FF7300FF3300FF0019FF0033FF0033FF003FFF00
3FFF004CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00\
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF00
4CFF003FFF003FFF0026FF0000FF2600FF3300FF0000FF2633FF003FFF003FFF003FFF003FFF00\
33FF0000FF3300FF8C19FF0033FF003FFF003FFF003FFF003FFF003FFF003FFF00
3FFF0033FF0033FF0019FF0000FF2600FF0C00FF0C00FF2600FFCC00FF0C19FF0026FF0033FF00\
3FFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF00
73FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00\
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00
66FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF003FFF00\
33FF0033FF0026FF0019FF0000FF0C00FF8C0CFF0026FF0033FF003FFF003FFF00
4CFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF00
4CFF004CFF0033FF0026FF0000FF2619FF0033FF0033FF003FFF004CFF004CFF004CFF003FFF00\
3FFF0033FF0000FF4C26FF003FFF003FFF004CFF004CFF004CFF004CFF003FFF00
3FFF003FFF0033FF000CFF0000FF0C19FF000CFF0000FF0000FF2600FF4C00FF8C00FF4C33FF00\
3FFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF00
73FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF00\
80FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF0059FF00
59FF0059FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF003FFF003FFF0033FF00\
33FF0026FF0019FF000CFF0000FF0C00FFF300FF0C0CFF0033FF003FFF003FFF00
4CFF004CFF0059FF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF00
4CFF004CFF0033FF0000FF1926FF003FFF003FFF004CFF004CFF004CFF004CFF004CFF004CFF00\
4CFF003FFF000CFF003FFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00
4CFF003FFF003FFF0026FF0026FF0026FF0026FF0019FF0000FF0000FF590CFF0026FF003FFF00\
3FFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0073FF0073FF00
73FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF008CFF0080FF00\
80FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF0019FF004CFF00
4CFF004CFF004CFF004CFF004CFF004CFF004CFF003FFF0033FF0026FF0033FF0033FF0026FF00\
26FF0026FF000CFF0000FF2600FF8000FF3300FF0019FF0033FF003FFF004CFF00
4CFF004CFF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF00
59FF003FFF0026FF0000FF4033FF003FFF004CFF004CFF0059FF0059FF0059FF0059FF0059FF00\
4CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF004CFF00
4CFF004CFF003FFF003FFF0033FF0033FF0026FF0019FF0000FF1900FF330CFF0026FF003FFF00\
3FFF004CFF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0073FF0073FF00
73FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0080FF00\
73FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0059FF0033FF0000FF0C
3FFF003FFF004CFF004CFF004CFF004CFF003FFF003FFF0026FF0000FF0019FF0000FF0C19FF00\
19FF000CFF0000FF0C00FF2600FF4C00FF0019FF0026FF0033FF003FFF004CFF00
4CFF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF00
59FF003FFF0000FF190CFF003FFF004CFF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00\
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF00
4CFF004CFF004CFF003FFF003FFF003FFF0033FF0026FF000CFF0000FF1900FF0C26FF003FFF00\
3FFF004CFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0073FF00
73FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF00\
73FF0073FF0066FF0066FF0066FF0066FF0059FF0059FF004CFF003FFF000CFF00
26FF0033FF003FFF003FFF003FFF003FFF003FFF0033FF0019FF0000FFF300FF0C00FF2600FF4C\
00FF6600FFA600FF8000FF4000FF2600FF0019FF0026FF0033FF003FFF004CFF00
4CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF00
59FF004CFF0033FF0000FF593FFF0059FF0059FF0059FF0059FF0066FF0066FF0066FF0059FF00\
59FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
4CFF004CFF004CFF004CFF003FFF003FFF0033FF0033FF0026FF0000FF0000FF0C26FF0033FF00\
3FFF004CFF004CFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0073FF00
73FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF0080FF0080FF0073FF0033FF00\
59FF0059FF0059FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF0026FF00
00FF0026FF0026FF0033FF0033FF0033FF0033FF0026FF0000FF0000FF3300FF7300FF7300FF19\
00FF0C0CFF000CFF0000FF0000FF4C00FF8000FF0026FF0033FF0033FF003FFF00
4CFF0059FF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF00
66FF0059FF0026FF003FFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF0059FF0059FF00
59FF004CFF004CFF004CFF004CFF003FFF003FFF0033FF0026FF000CFF0000FF0C26FF0033FF00\
3FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF00
73FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF0073FF0066FF004CFF003FFF00\
0CFF0033FF0033FF003FFF004CFF004CFF0033FF003FFF003FFF0033FF0019FF00
3F00FF00FF0000FF1919FF0026FF0026FF0026FF0019FF0000FF0000FF8000FF8C00FF4000FF00\
19FF0026FF0019FF0019FF0000FF8000FF4000FF0C0CFF000CFF0000FF003FFF00
4CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF00
66FF0059FF000CFF0059FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF0059FF0059FF00
59FF0059FF004CFF004CFF004CFF004CFF003FFF0033FF0033FF0000FF0000FF8000FF0026FF00\
33FF003FFF003FFF004CFF004CFF004CFF0059FF0059FF0059FF0066FF0066FF00
66FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0073FF0059FF0033FF0026FF00\
33FF0026FF0000FF6600FF0C19FF0026FF0000FF0026FF0026FF0000FF0000FF19
00FF3300FF4C1900FF00FF000CFF0019FF000CFF0000FF0000FF4000FF4C00FF0C00FF4000FF33\
26FF0033FF0026FF0026FF000CFF0000FF0C00FF8C00FF2600FF0026FF003FFF00
4CFF0059FF0059FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF0059FF00
59FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF0033FF0019FF0000FF8C00FF0C0CFF00\
00FF3333FF0033FF003FFF0033FF0033FF004CFF004CFF0059FF0059FF0059FF00
59FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF0080FF0080FF0066FF0059FF00\
59FF0059FF0059FF004CFF0019FF0000FF2600FF260CFF000CFF0000FF8C00FF26
19FF000CFF0000FFCC00FF2600FF4000FF3300FF4000FF0019FF0019FF0026FF0000FF0033FF00\
3FFF003FFF0033FF0026FF0019FF0000FF0C00FF660CFF0026FF003FFF004CFF00
4CFF0059FF0059FF0066FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
66FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF0059FF00
59FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF0033FF0000FF4C00FF0000FF6600FFB3\
0CFF0026FF0026FF0026FF000CFF0026FF003FFF004CFF004CFF004CFF0019FF00
4CFF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00\
8CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF00\
73FF0066FF0066FF0059FF003FFF0033FF0000FF4000FF9900FF1900FF0000FF26
26FF0026FF0019FF0000FF260CFF0000FF0000FF7319FF0033FF0033FF003FFF003FFF003FFF00\
3FFF003FFF003FFF0033FF0000FF0C00FF6600FF0C19FF0033FF003FFF004CFF00
4CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF0059FF00
59FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF0033FF0026FF0019FF0000FF0000FFCC\
00FF000CFF000CFF000CFF0000FFD926FF0033FF003FFF003FFF0033FF0000FF33
3FFF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00A6FF00
A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF00\
73FF0073FF0066FF0066FF0059FF004CFF0033FF0000FF0000FF0026FF0033FF00
3FFF003FFF0026FF0019FF0033FF0019FF0000FF5919FF003FFF003FFF004CFF004CFF004CFF00\
4CFF004CFF003FFF0033FF0019FF0000FF5900FF0C19FF0026FF003FFF003FFF00
4CFF0059FF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF0066FF0066FF00
59FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF0033FF0026FF0000FF3300FF66\
00FF2600FF1900FF4C00FF2600FF330CFF0026FF0026FF0019FF0019FF0000FF99
33FF004CFF0059FF0066FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF00\
8CFF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF00\
80FF0073FF0073FF0066FF0059FF004CFF003FFF0000FFE626FF0033FF003FFF00
4CFF004CFF003FFF003FFF003FFF0033FF000CFF0019FF003FFF004CFF0059FF0059FF0059FF00\
59FF0059FF004CFF003FFF0026FF0000F3FF00FF2600FF0C00FF0033FF003FFF00
4CFF004CFF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0073FF0073FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF0066FF00
59FF0059FF0059FF0059FF004CFF004CFF004CFF003FFF003FFF0033FF0026FF000CFF0000FF26\
00FF3300FF2600FF8C00FF0C00FF2600FF190CFF000CFF0000FFB300FF0C00FF26
0CFF0019FF004CFF0059FF0059FF0066FF0066FF0066FF0066FF0066FF0073FF0080FF0080FF00\
80FF0080FF008CFF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF00\
80FF0073FF0073FF0066FF0059FF004CFF0026FF0000FF3326FF003FFF004CFF00
4CFF0059FF0059FF0059FF004CFF004CFF0026FF0026FF004CFF0059FF0059FF0059FF0066FF00\
59FF0059FF004CFF003FFF0000FF4019FF0019FF0000FF2600FF5919FF0026FF00
33FF003FFF0059FF0066FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF00
66FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0026FF000CFF0000FF99\
00FF000CFF0019FF0019FF0000FF0000FF4C00FF7300FF0C0CFF0026FF0026FF00
00FF0C00FF0019FF003FFF004CFF003FFF0059FF0059FF004CFF003FFF0066FF0073FF0073FF00\
73FF0066FF008CFF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF00\
80FF0073FF0073FF0066FF0059FF003FFF000CFF0000FF1926FF003FFF004CFF00
59FF0059FF0066FF0066FF0059FF0059FF0019FF0000FF004CFF0059FF0066FF0066FF0066FF00\
66FF0066FF0059FF0026FF0026FF003FFF0033FF0026FF000CFF0000FF8C00FF0C
0CFF0033FF0059FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF0066FF00
66FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF0033FF0019FF0000FF1900FF19\
19FF0026FF0026FF0026FF0019FF0019FF0000FF0C00FF0033FF003FFF003FFF00
33FF003FFF0033FF0000FFB319FF0000FF333FFF003FFF0026FF003FFF0059FF0066FF0066FF00\
4CFF004CFF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF00\
80FF0073FF0073FF0066FF004CFF000CFF0000FF2600FF7300FF663FFF0059FF00
66FF0066FF0066FF0066FF0066FF0059FF0033FF0000FF404CFF0066FF0066FF0066FF0073FF00\
66FF0066FF0066FF004CFF004CFF004CFF004CFF0033FF000CFF0000FF2633FF00
4CFF0059FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF00
66FF0059FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF0019FF0000FF0C00FF4C00FF26\
19FF0026FF0033FF0033FF0033FF0033FF0026FF0000FF003FFF004CFF0059FF00
59FF0059FF0059FF003FFF0026FF000CFF0000FF0000FF7300FF0000FF193FFF003FFF003FFF00\
00FF1966FF0080FF008CFF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF0099FF008CFF008CFF0080FF00\
80FF0073FF0066FF0066FF0059FF0033FF0000FF0000FF190CFF0019FF0059FF00
66FF0066FF0073FF0073FF0073FF0066FF0059FF0026FF0059FF0066FF0073FF0073FF0073FF00\
73FF0073FF0066FF0066FF0066FF0059FF004CFF0026FF0000FF4C19FF003FFF00
59FF0059FF0066FF0073FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
73FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF0066FF00
66FF0059FF0059FF0059FF0059FF004CFF003FFF0033FF0026FF000CFF0000FF1900FF3300FF00\
19FF0033FF003FFF003FFF004CFF004CFF003FFF0000FF2633FF0059FF0066FF00
66FF0066FF0066FF0059FF0059FF004CFF0000FF593FFF003FFF0000CCFF0CFF0000FF4019FF00\
26FF003FFF0019FF0080FF008CFF0099FF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF00\
73FF0066FF0066FF0059FF004CFF003FFF0000FF0C19FF004CFF0059FF0066FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0059FF0073FF0073FF0073FF0073FF0073FF00\
73FF0073FF0073FF0073FF0066FF0066FF0059FF003FFF0026FF0000FF6619FF00
59FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00
66FF0059FF0059FF0059FF004CFF004CFF003FFF0019FF0000FFB300FF5900FF5900FF8000FF19\
00FF1933FF003FFF004CFF004CFF004CFF0059FF004CFF004CFF0066FF0066FF00
73FF0073FF0073FF0073FF0066FF0059FF0019FF0059FF0059FF004CFF0000FF404CFF0059FF00\
59FF003FFF0000FF0066FF0080FF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0066FF00\
59FF0059FF0059FF004CFF003FFF0033FF0000FF0C3FFF0059FF0066FF0066FF00
73FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0073FF0073FF0073FF0066FF0059FF004CFF0033FF0000FF404CFF00
59FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00
66FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF0019FF0000FF4000FF4C0033FF00FF33\
00FF3333FF004CFF004CFF0059FF0059FF0059FF0066FF0066FF0066FF0073FF00
73FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF000CFF0066FF0073FF00\
73FF0073FF0073FF004CFF0000FF4C80FF0099FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF00\
4CFF0000FF0033FF000CFF0026FF0000FF4000FF7333FF0059FF0066FF0073FF00
73FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0073FF0073FF0066FF0066FF004CFF0026FF0033FF004CFF00
66FF0066FF0073FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0073FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00
66FF0059FF0059FF0059FF004CFF004CFF003FFF0033FF0026FF000CFF0000FF0C00FF5900FF00\
26FF0033FF004CFF0059FF0059FF0066FF0066FF0066FF0073FF0073FF0073FF00
73FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0073FF004CFF0066FF0080FF00\
80FF008CFF008CFF008CFF008CFF008CFF00A6FF00A6FF00A6FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF008CFF0080FF0073FF00\
59FF003FFF0000FF000CFF0000FF6633FF0019FF0000FF264CFF0066FF0073FF00
80FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF00\
80FF0080FF0080FF0080FF0073FF0073FF0066FF004CFF000CFF0000FF004CFF00
66FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00
66FF0059FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0019FF0000FF4C00FF330CFF00\
33FF003FFF004CFF0059FF0059FF0066FF0066FF0073FF0073FF0073FF0080FF00
80FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF0080FF008CFF00\
8CFF008CFF0099FF0099FF0099FF0099FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF00\
59FF0000FF0C19FF004CFF0026FF0059FF0059FF003FFF003FFF0066FF0073FF00
80FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF0080FF0080FF0080FF0073FF0073FF0066FF003FFF000CFF0026FF004CFF00
59FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0073FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00
59FF0059FF0059FF004CFF004CFF003FFF003FFF0033FF0033FF0019FF0000FF0000FF0C26FF00\
33FF003FFF004CFF0059FF0066FF0066FF0073FF0073FF0073FF0080FF0080FF00
80FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF00\
99FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF0099FF0099FF0099FF008CFF008CFF0080FF0080FF0073FF004CFF00\
0CFF0000FF264CFF0066FF0066FF0073FF0066FF0059FF0000FF2659FF0073FF00
80FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF0080FF0080FF0080FF0073FF0066FF004CFF0019FF0000FF003FFF00
59FF0066FF0073FF0073FF0080FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0066FF00
59FF0059FF004CFF004CFF004CFF003FFF003FFF0033FF0026FF0019FF0000FF8000FF0C19FF00\
33FF003FFF004CFF0059FF0066FF0066FF0073FF0073FF0080FF0080FF0080FF00
80FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF00\
99FF0099FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00A6FF00A6FF00A6FF0099FF0099FF008CFF008CFF0080FF0073FF0066FF0059FF0000FF0C\
3FFF004CFF0033FF0073FF0073FF0080FF0080FF0073FF0000FF5900FF3373FF00
80FF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF008CFF008CFF008CFF00\
8CFF008CFF008CFF0080FF0080FF0073FF0059FF0033FF0000FF7333FF004CFF00
59FF0066FF0073FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF00
59FF004CFF004CFF003FFF003FFF0033FF0033FF0026FF0019FF000CFF0000FF1900FF5900FF19\
19FF0033FF004CFF004CFF0059FF0066FF0073FF0073FF0080FF0080FF0080FF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF00A6FF0099FF0099FF0080FF0080FF0073FF0059FF0000FF003FFF0066FF00\
66FF0073FF0073FF0080FF0080FF0080FF0080FF0080FF0073FF004CFF0080FF00
8CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00\
8CFF008CFF008CFF0080FF0080FF0073FF004CFF003FFF0019FF0000FF8C3FFF00
59FF0066FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF0080FF00\
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF00
4CFF0033FF003FFF003FFF0033FF0026FF0000FF0019FF000CFF0000FFB300FF3300FF0000FF40\
00FF0C0CFF0033FF003FFF004CFF0066FF0073FF0073FF0080FF0080FF0080FF00
8CFF008CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF00A6FF0099FF0099FF008CFF0073FF0000FF264CFF0026FF003FFF0066FF0073FF00\
80FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF0080FF008CFF00
8CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
8CFF008CFF008CFF008CFF0080FF0073FF0066FF0059FF0033FF0000FF0C00FF19
26FF0059FF0073FF0080FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
8CFF008CFF008CFF008CFF0099FF0099FF008CFF008CFF008CFF008CFF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00\
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0059FF003FFF00
00FF5900FF9900FF4026FF0019FF000CFF0000FF9900FF4C00FF0C00FFA600FF0026FF0019FF00\
33FF0026FF000066FF00FF2619FF004CFF0066FF0073FF0080FF0080FF008CFF00
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00\
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00C0FF00C0FF00C0FF00\
C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00B3FF00B3FF00B3FF00B3FF00
A6FF00A6FF0099FF0099FF008CFF008CFF0073FF0059FF0000FF003FFF003FFF0073FF0080FF00\
8CFF008CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00\
99FF008CFF008CFF008CFF0080FF0080FF0066FF004CFF0026FF0000FF5933FF00
4CFF0066FF0073FF0080FF0080FF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF00\
99FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF0099FF008CFF00
8CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF008CFF0080FF0080FF00\
80FF0080FF0080FF0080FF0073FF0073FF0073FF0073FF0066FF0066FF0059FF00
33FF0026FF0019FF0000FF4C00FF6600FF1900FF4000FF4C00FF3300FF4019FF0033FF003FFF00\
3FFF004CFF003FFF0033FF003FFF0033FF0066FF0080FF0080FF0080FF008CFF00
8CFF008CFF008CFF0099FF0099FF0099FF0099FF0099FF0099FF0099FF00A6FF00A6FF00A6FF00\
A6FF00A6FF00A6FF00A6FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00B3FF00
B3FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00C0FF00\
C0FF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00CCFF00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  AnimationDisplayTime->0.3,
  AnimationCycleOffset->-0.0625,
  AnimationCycleRepetitions->Infinity,
  ImageCacheValid->False]}, Open]]}, Open]]}, Open]]}, Open]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 832}, {0, 604}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{520, 509},
WindowMargins->{{52, Automatic}, {Automatic, 16}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060001T1T00000000000
00000000000000000000000000000000\>"
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 91, 2, 70, "Title",
  Evaluatable->False],
Cell[1825, 55, 860, 29, 70, "Text",
  Evaluatable->False],
Cell[2688, 86, 477, 16, 70, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[3188, 104, 89, 2, 70, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[3300, 108, 74, 1, 70, "Input"],
Cell[3377, 111, 159, 7, 70, "Output",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3568, 120, 68, 1, 70, "Input"],
Cell[3639, 123, 278, 11, 70, "Output",
  Evaluatable->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3958, 136, 91, 2, 70, "Section",
  Evaluatable->False],
Cell[4052, 140, 67, 1, 70, "Input"],
Cell[4122, 143, 144, 3, 70, "Input"],

Cell[CellGroupData[{
Cell[4289, 148, 57, 1, 70, "Input"],
Cell[4349, 151, 216, 9, 70, "Output",
  Evaluatable->False]
}, Open  ]],
Cell[4577, 162, 155, 3, 70, "Input"],
Cell[4735, 167, 140, 3, 70, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[4898, 172, 75, 1, 70, "Input"],

Cell[CellGroupData[{
Cell[4996, 175, 286661, 3940, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[291660, 4117, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[578253, 8057, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[864846, 11997, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[1151439, 15937, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[1438032, 19877, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[1724625, 23817, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[2011218, 27757, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[2297811, 31697, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[2584404, 35637, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[2870997, 39577, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[3157590, 43517, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[3444183, 47457, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[3730776, 51397, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[4017369, 55337, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[4303962, 59277, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[4590555, 63217, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[4877148, 67157, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[5163741, 71097, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[5450334, 75037, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[5736927, 78977, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[6023520, 82917, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[6310113, 86857, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[6596706, 90797, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[6883299, 94737, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[7169892, 98677, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[7456485, 102617, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[7743078, 106557, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[8029671, 110497, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[8316264, 114437, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[8602857, 118377, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[8889450, 122317, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[9176043, 126257, 286590, 3938, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[9462636, 130197, 286662, 3940, 70, 286403, 3932, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
